########################################################
# Bald Eagle Demography in the Northeast, USA 1990-2018
# 
# Author: Brenda Hanley                
# Date: April 2019                   
# License: MIT   
# 
# This code shows the demography of Bald Eagles given   
# pre-saved datasets from a combinatorial       
# optimization algorithm. 
# 
# The software supports the article:
#
# Hanley, B, Dhondt, A, Dennis, B, & Schuler, K. 
# 2019. Using time series data to assess recent 
# population dynamics of Bald Eagles in the northeast 
# United States. Ecosphere. 
# doi: https://doi.org/10.1002/ecs2.2963
#                           
########################################################
# To load the proper versions of each package, 
# uncomment these lines and run ONCE on your machine.
#library(devtools)  
#devtools::install_version("shiny", version = "1.3.2")
#devtools::install_version("shinyBS", version = "0.61")
#devtools::install_version("rgl", version = "0.100.26")
#devtools::install_version("rmarkdown", version = "1.14")
#devtools::install_version("FSA", version = "0.8.25")
#devtools::install_version("popdemo", version = "1.3-0")
# _______________________________________________________
# Once the proper version has been installed on 
# your machine, then run these lines:
library(shiny)
library(shinyBS)
library(rgl)
library(rmarkdown)
library(FSA)
library(popdemo)

ui<-fluidPage(
 tags$head(tags$script("
            window.onload = function() {
            $('#mynavlist a:contains(\"Life table\")').parent().addClass('disabled');
            $('#mynavlist a:contains(\"Predicted annual abundances\")').parent().addClass('disabled');
            $('#mynavlist a:contains(\"Predicted bi-annual abundances\")').parent().addClass('disabled');
            $('#mynavlist a:contains(\"Predicted bi-annual hatchling abundances\")').parent().addClass('disabled');
            $('#mynavlist a:contains(\"Predicted bi-annual immature and non-breeding female abundances\")').parent().addClass('disabled');
            $('#mynavlist a:contains(\"Predicted bi-annual breeding female abundances\")').parent().addClass('disabled');
            $('#mynavlist a:contains(\"Predicted abundances during the breeding period\")').parent().addClass('disabled');
            $('#mynavlist a:contains(\"Predicted abundances during the non-breeding period\")').parent().addClass('disabled');
            $('#mynavlist a:contains(\"Migration and dispersal\")').parent().addClass('disabled');
            $('#mynavlist a:contains(\"Asymptotic growth rates\")').parent().addClass('disabled');
            $('#mynavlist a:contains(\"Survival rates\")').parent().addClass('disabled');
            $('#mynavlist a:contains(\"Stable stage distribution\")').parent().addClass('disabled');
            $('#mynavlist a:contains(\"Reproductive value\")').parent().addClass('disabled');
            $('#mynavlist a:contains(\"Sensitivities\")').parent().addClass('disabled');
            $('#mynavlist a:contains(\"Elasticities\")').parent().addClass('disabled');
            $('#mynavlist a:contains(\"Damping ratio and convergence time\")').parent().addClass('disabled');
            $('#mynavlist a:contains(\"Cross partials\")').parent().addClass('disabled');
            $('#mynavlist a:contains(\"Cumulative growth\")').parent().addClass('disabled');
            $('#mynavlist a:contains(\"Stochastic growth rate\")').parent().addClass('disabled');
            $('#mynavlist a:contains(\"Transient growth rate\")').parent().addClass('disabled');
            $('#mynavlist a:contains(\"Transient sensitivities\")').parent().addClass('disabled');
            $('#mynavlist a:contains(\"Harmonic vs. arithmetic mean abundances\")').parent().addClass('disabled');
            $('#mynavlist a:contains(\"Loss of genetic diversity\")').parent().addClass('disabled');
            $('#mynavlist a:contains(\"Population momentum\")').parent().addClass('disabled');
            $('#mynavlist a:contains(\"Population inertia\")').parent().addClass('disabled');
            $('#mynavlist a:contains(\"Reactivity\")').parent().addClass('disabled');
            $('#mynavlist a:contains(\"Maximum amplification\")').parent().addClass('disabled');
            $('#mynavlist a:contains(\"Maximum attenuation\")').parent().addClass('disabled');
            };
            Shiny.addCustomMessageHandler('activeNavs', function(nav_label) {
            $('#mynavlist a:contains(\"' + nav_label + '\")').parent().removeClass('disabled');
            });
            ")), 
 mainPanel(
  
  bsModal(id = 'startupModal', title = 'Bald eagle demography through data science', trigger = '',
      size = 'large', 
p(HTML("

<p>This research integrates knowledge from ecology, biology, 
mathematics, statistics, and resource management.</p>

<p>The results in this software were 
generated using an interdisciplinary
approach to study wildlife populations 
that includes symbolic population matrix models, 
methods in demography, and a newly tailored 
combinatorial algorithm from data science.</p>

"))
      ),
  width = 12
      ),

titlePanel("Bald Eagle Demography in the Northeast, USA"),
      navlistPanel(selected = "Introduction", id='mynavlist',
             
     tabPanel("Introduction", 
      h2("Introduction to the app"),
      h5("This research used a symbolic life history of bald eagles to model 
        population abundances through time. The life history includes
        bi-annual time periods, density dependence, dispersal and migration. 
        The mathematical model is a one-sex
        deterministic projection matrix (Caswell, 2001) with vital and 
        migration rates that are 
        assumed to remain constant in the Northeast, USA from 1990-2018."),
      
      h5("The empirical data consists of time series abundances of breeding 
        adult eagles collected by permitted federal and state biologists
        in seven states in the Northeast, USA from 1990-2018."),
      
      h5("The matrix elements were generated using a 
        combinatorial algorithm (e.g. Korte & Vygen, 2018). 
        Validation of the combinatorial 
        optimization algorithm as a tool to backfill a population matrix 
        model for wildlife research is found in Hanley et al. (in revision) and Hanley et al., (2019). "),
      
      h3("Instructions to use this app"),
      h5("Click Run the App! The tabs to your left 
        will illuminate in blue. Click through the 
        tabs to access the demographic result of interest.
        For each tab, graphs will appear in the central frame. These 
        graphs are drawn using the 
        data frame that was generated by the algorithm. "),
      
      actionButton("Lambda_done1", "Run the app!"),
      br(),
      actionButton("Foundational", "Foundational matrix model information"),
      br(),
      actionButton("HelpboxT1","Foundational information on matrix vital rates")
      ), # end panel 
     
     tabPanel("Life table", 
          h2("Life table"),
          h5("Life tables form the basis of demography. A life table shows the 
         probability that an individual will 
         survive to any given age."),
          h5("Each color represents the life table of an algorithm-predicted model."),
          h5("For information on the experimental validation, please see Figure S32, Supplement III in 
           Hanley et al. (2019)."),
          h5("__________________________________________________________________________"),
          plotOutput("LifeTable"),
          h5("Experimental validation of the performance of the algorithm in predicting the life table using simulated data revealed that the 
           algorithm predictions are biased to the low side. The true value is likely higher than what is shown here."),
          h5("__________________________________________________________________________"),
          actionButton("HelpboxLifeTableA","How do I interpret this from the mathematical modeling perspective?"),
          br(),
          actionButton("HelpboxLifeTableABio","How do I interpret this from the biological perspective?"),
          br(),
          actionButton("HelpboxLifeTableAEco","How do I interpret this from the ecological perspective?"),
          br(),
          actionButton("HelpboxLifeTableAMgmt","How do I interpret this from the resource management perspective?")
          ), #end panel 
     
     tabPanel("Predicted annual abundances", 
           h2("Annual abundances through time"),
           h5("A population matrix model projects abundances of 
             stage-structured populations 
            in discrete time (van Groenendael, de Kroon, & Caswell, 1988)."),
           h5("This graph shows the range of algorithm-predicted 
            annual abundances of 
            breeding adult females (grey) and (combined) immature and non-breeding 
            adult females (blue) in the Northeast, USA from 1990-2018."),

          h5("__________________________________________________________________________"),
           plotOutput("Annual"),
          h4("Experimental validation of the performance of the algorithm in predicting annual abundances using simulated data revealed that the 
           algorithm predictions accurately captured the true value of the unknown abundances for each life stage in each year."),
          h5("For further information on the experimental validation, please see Figure S7, Supplement III in 
           Hanley et al. (2019)."),
          h5("__________________________________________________________________________"),
           actionButton("HelpboxAnnualA","How do I interpret this from the mathematical modeling perspective?"),
           br(),
           actionButton("HelpboxAnnualABio","How do I interpret this from the biological perspective?"),
           br(),
           actionButton("HelpboxAnnualAEco","How do I interpret this from the ecological perspective?"),
           br(),
           actionButton("HelpboxAnnualAMgmt","How do I interpret this from the resource management perspective?")
      ), #end panel
      
      tabPanel("Predicted bi-annual abundances",
           h2("Bi-annual abundances"),
           h5("This graph illustrates the ranges of algorithm-predicted 
           bi-annual abundances of 
           breeding adult females (grey), (combined) immature and non-breeding 
           adult females (light blue), and female hatchlings 
           (dark blue) in the Northeast, USA from 1990-2018. Within each 
           year, the leftmost vertical bar 
           represents ranges in the breeding period (January-June) and the rightmost
           vertical bar represents ranges in the non-breeding period (July-December). Some bars are too small to be graphed. "),
           h5("__________________________________________________________________________"),
           plotOutput("BiannualAll"),
           h4("Experimental validation of the performance of the algorithm in predicting bi-annual abundances using simulated data revealed that the 
           algorithm predictions accurately captured the true value of the unknown abundances for each life stage in each bi-annual time period."),
           h5("For further information on the experimental validation, please see Figure S8-S10, Supplement III in 
            Hanley et al. (2019)."),
           h5("__________________________________________________________________________"),
           actionButton("HelpboxBiannualA","How do I interpret this from the mathematical modeling perspective?"),
           br(),
           actionButton("HelpboxBiannualABio","How do I interpret this from the biological perspective?"),
           br(),
           actionButton("HelpboxBiannualAEco","How do I interpret this from the ecological perspective?"),
           br(),
           actionButton("HelpboxBiannualAMgmt","How do I interpret this from the resource management perspective?")
           ), #end panel 
      
      tabPanel("Predicted bi-annual hatchling abundances", 
           h2("Bi-annual hatchling abundances"),
           h5("This graph shows the range of algorithm-predicted 
           bi-annual abundances of 
           hatchlings in the Northeast, USA from 1990-2018."),
           h5("The information displayed in this graph was generated by deriving a 
            symbolic stage-structured life history of the Bald Eagle, 
            identifying the set of vital rates that would have resulted 
            in similar breeding-adult trajectories, and then
            by projecting the predicted abundances of hatchlings that would have 
            needed to exist to support such a system. "),
           h5("__________________________________________________________________________"),
           plotOutput("BiannualJuvenile"),
           h4("Experimental validation of the performance of the algorithm in predicting bi-annual abundances using simulated data revealed that the 
           algorithm predictions accurately captured the true value of the unknown abundances in each bi-annual time period."),
           h5("For further information on the experimental validation, please see Figure S8, Supplement III in 
            Hanley et al. (2019)."),
           h5("__________________________________________________________________________"),
           actionButton("HelpboxBiOneA","How do I interpret this from the mathematical modeling perspective?"),
           br(),
           actionButton("HelpboxBiOneABio","How do I interpret this from the biological perspective?"),
           br(),
           actionButton("HelpboxBiOneAEco","How do I interpret this from the ecological perspective?"),
           br(),
           actionButton("HelpboxBiOneAMgmt","How do I interpret this from the resource management perspective?")
      ), #end panel 
      
      tabPanel("Predicted bi-annual immature and non-breeding female abundances", 
           h2("Bi-annual immature and non-breeding female abundances"),
           h5("This graph shows the range of algorithm-predicted bi-annual abundances of 
           (combined) immature and non-breeding females in the Northeast, 
           USA from 1990-2018. 
           "),
           h5("The information displayed in this graph was generated by deriving a 
            symbolic stage-structured life history of the Bald Eagle, 
            identifying the set of vital rates that would have resulted 
            in similar breeding-adult trajectories, and then
            by projecting the abundances of immature and non-breeding individuals
            that would have 
            needed to exist to support such a system."),
           h5("__________________________________________________________________________"),
           plotOutput("BiannualSubadult"),
           h4("Experimental validation of the performance of the algorithm in predicting bi-annual abundances using simulated data revealed that the 
           algorithm predictions accurately captured the true value of the unknown abundances in each bi-annual time period."),
           h5("For further information on the experimental validation, please see Figure S9, Supplement III in 
            Hanley et al. (2019)."),
           h5("__________________________________________________________________________"),
           actionButton("HelpboxBiTwoA","How do I interpret this from the mathematical modeling perspective?"),
           br(),
           actionButton("HelpboxBiTwoABio","How do I interpret this from the biological perspective?"),
           br(),
           actionButton("HelpboxBiTwoAEco","How do I interpret this from the ecological perspective?"),
           br(),
           actionButton("HelpboxBiTwoAMgmt","How do I interpret this from the resource management perspective?")
      ), #end panel 
      
      tabPanel("Predicted bi-annual breeding female abundances", 
           h2("Bi-annual breeding female abundances"),
           h5("This graph shows the range of algorithm-predicted bi-annual 
           abundances of 
           breeding females in the Northeast, USA from 1990-2018. We 
           expect the algorithm to capture empirical 
           abundances of breeding females. 
           Afterall, empirical data of breeding females 
           was the data that was used to train the algorithm."),
          h5("The information displayed in this graph was generated by deriving a 
            symbolic stage-structured life history of the Bald Eagle, 
            identifying the set of vital rates that would have resulted 
            in similar breeding-adult trajectories, and then
            by projecting the abundances of breeding individuals
            that would have 
            needed to exist to support such a system."),
          h5("__________________________________________________________________________"),
           plotOutput("BiannualAdult"),
          h4("Experimental validation of the performance of the algorithm in predicting bi-annual abundances using simulated data revealed that the 
           algorithm predictions accurately captured the true value of the unknown abundances in each bi-annual time period."),
          h5("For further information on the experimental validation, please see Figure S10, Supplement III in 
            Hanley et al. (2019)."),
          h5("__________________________________________________________________________"),
           actionButton("HelpboxBiThreeA","How do I interpret this from the mathematical perspective?"),
           br(),
           actionButton("HelpboxBiThreeABio","How do I interpret this from the biological perspective?"),
           br(),
           actionButton("HelpboxBiThreeAEco","How do I interpret this from the ecological perspective?"),
           br(),
           actionButton("HelpboxBiThreeAMgmt","How do I interpret this from the resource management perspective?")
      ), #end panel
      
      tabPanel("Predicted abundances during the breeding period", 
           h2("Breeding period abundances"),
           h5("This graph shows the ranges of algorithm-predicted abundances of 
            breeding females (grey) and the (combined) immature and non-breeding 
            females (blue) in the 
            Northeast, USA during the breeding periods."),
           h5("Reproduction is parameterized as birth-pulse 
            (e.g. see the foundational vital rate 
            button on the introduction tab), so hatchling abundances 
            are not measured until mid-year. The abundance of the spring's hatchlings 
            will first register in population projections in 
            the fall of their hatch year, during which hatchlings will fledge and 
            transition to immatures, or perish."),
           h5("__________________________________________________________________________"),
           plotOutput("BreedingAll"),
           h4("Experimental validation of the performance of the algorithm in predicting bi-annual abundances using simulated data revealed that the 
           algorithm predictions accurately captured the true value of the unknown abundances for each life stage in each bi-annual time period."),
           h5("For further information on the experimental validation, please see Figure S8-S10, Supplement III in 
            Hanley et al. (2019)."),
           h5("__________________________________________________________________________"),
           actionButton("HelpboxBreedA","How do I interpret this from the mathematical modeling perspective?"),
           br(),
           actionButton("HelpboxBreedABio","How do I interpret this from the biological perspective?"),
           br(),
           actionButton("HelpboxBreedAEco","How do I interpret this from the ecological perspective?"),
           br(),
           actionButton("HelpboxBreedAMgmt","How do I interpret this from the resource resource management perspective?")
           ), #end panel
      
      tabPanel("Predicted abundances during the non-breeding period", 
           h2("Non-breeding period abundances"),
           h5("This graph shows the ranges of algorithm-predicted abundances of 
           breeding females (grey), the (combined) immature and 
           non-breeding females (light blue), and hatchlings 
           (dark blue) in the Northeast, 
           USA during the non-breeding periods. "),
           h5("Reproduction is parameterized as birth-pulse, so hatchling abundances 
            are not recorded until mid-year. The abundance of the spring's hatchlings 
            will first register in population projections in the 
            fall of their hatch year, during which they will fledge and 
            transition to immatures, or perish."),
           h5("__________________________________________________________________________"),
           plotOutput("NonBreedingAll"),
           h4("Experimental validation of the performance of the algorithm in predicting bi-annual abundances using simulated data revealed that the 
           algorithm predictions accurately captured the true value of the unknown abundances for each life stage in each bi-annual time period."),
           h5("For further information on the experimental validation, please see Figure S8-S10, Supplement III in 
            Hanley et al. (2019)."),
           h5("__________________________________________________________________________"),
           actionButton("HelpboxNonA","How do I interpret this from the mathematical modeling perspective?"),
           br(),
           actionButton("HelpboxNonABio","How do I interpret this from the biological perspective?"),
           br(),
           actionButton("HelpboxNonAEco","How do I interpret this from the ecological perspective?"),
           br(),
           actionButton("HelpboxNonAMgmt","How do I interpret this from the resource resource management perspective?")
      ), #end panel 
      
      tabPanel("Migration and dispersal", 
           h2("Migration parameters"),
           h5("This display shows the algorithm-predicted summary statistics 
           for the proportion of female birds that migrate and disperse in the Northeast, USA."),
           h5("For information on the experimental validation of the algorithm, please see Figure S14-S15, Supplement III in 
           Hanley et al. (2019)."),
           
           h5("__________________________________________________________________________"),
           h3("Migrations out of the Northeast"),
           h4("The proportion of immature females and non-breeding females that reside in the Northeast during the breeding period then temporarily vacate the Northeast to spend the non-breeding period elsewhere is:"),
           verbatimTextOutput("PS"),
           h5("The performance of the algorithm in predicting the true value of this migration was accurate when tested with simulated data."),
           h4("The proportion of breeding females that breed in the Northeast then temporarily vacate the Northeast to spend the non-breeding period elsewhere is:"),
           verbatimTextOutput("PA"),
           h5("The performance of the algorithm in predicting the true value of this migration was accurate when tested with simulated data."),
           h5("__________________________________________________________________________"),
           h3("Migrations into the Northeast"),
           h4("The proportion of immature females and non-breeding females that reside outside of the Northeast for the breeding period but spend the non-breeding period in the Northeast is:"),
           verbatimTextOutput("SA"),
           h5("The performance of the algorithm in predicting this migration using simulated data revealed that the algorithm predictions are biased to the high side. The true value is likely lower than what is shown here."),
           h4("The proportion of breeding adult females that breed outside of the Northeast but spend the non-breeding period in the Northeast is:"),
           verbatimTextOutput("AA"),
           h5("The performance of the algorithm in predicting the true value of this migration was accurate when tested with simulated data."),
           h5("__________________________________________________________________________"),
           h3("Dispersals out of the Northeast"),
           h4("The proportion of immature females and non-breeding females that emigrate from the Northeast:"),
           verbatimTextOutput("PurgeS"),
           h5("The performance of the algorithm in predicting the true value of this dispersal was accurate when tested with simulated data."),
           h4("The proportion of breeding females that emigrate from the Northeast is:"),
           verbatimTextOutput("PurgeA"),
           h5("The performance of the algorithm in predicting the true value of this dispersal was accurate when tested with simulated data."),
           h5("__________________________________________________________________________"),
           h3("Dispersals into the Northeast"),
           h4("The proportion of immature females and non-breeding females that immigrate to the Northeast is:"),
           verbatimTextOutput("AbsorbS"),
           h5("The performance of the algorithm in predicting this dispersal using simulated data revealed that the 
           algorithm predictions are biased to the high side. The true value is likely lower than what is shown here."),
           h4("The proportion of breeding females that immigrate to the Northeast is:"),
           verbatimTextOutput("AbsorbA"),
           h5("The performance of the algorithm in predicting the true value of this migration was accurate when tested with simulated data."),
           h5("__________________________________________________________________________"),
           actionButton("HelpboxMigrationA","How do I interpret this from the mathematical modeling perspective?"),
           br(),
           actionButton("HelpboxMigrationABio","How do I interpret this from the biological perspective?"),
           br(),
           actionButton("HelpboxMigrationAEco","How do I interpret this from the ecological perspective?"),
           br(),
           actionButton("HelpboxMigrationAMgmt","How do I interpret this from the resource management perspective?")
           ), #end panel
      
      tabPanel("Asymptotic growth rates", 
           h2("Determinisitic asymptotic growth rate for the annual matrix 
            (Dominant eigenvalue)"),
           h5("The regular purpose of a matrix model is to represent the 
            life history of a species so 
            that the asymptotic growth rate can be estimated (Caswell, 2001)."),
           h5("The magnitude of the asymptotic growth rate 
            has been used to support the listing or 
            delisting of species in national and global conservation applications, 
            making it one of 
            the most influential quantities arising from any 
            demographic model (Morris & Doak, 2002, Stott et al., 2011, IUCN, 2017). "),
           h5("These plots illustrate the summary statistics of the 
            algorithm-predicted asymptotic growth rates in the Northeast, USA. "),
           h5("The interpretation of the growth rate is straightforward; 
            an asymptotic growth rate above one means the population is increasing, below
            one means the population is decreasing, 
            and equal to one means that the population is stable."),
           h5("Migration and dispersal will impact the growth rate, as 
            will the choice of the 
            distance formula in the combinatorial optimization algorithm.
            The combinatorial optimization algorithm assumed demographic 
            stochasticity was present
            in the time series data, so the square root distance transform 
            was used (Dennis et al., 2001)."),
           h5("For information on the experimental validation, please see Figure S17, Supplement III in 
           Hanley et al. (2019)."),
           h5("__________________________________________________________________________"),
           h3("Year-round Northeast residents"),
           plotOutput("TuljaRhist"),
           h4("Experimental validation of the performance of the algorithm in predicting the eigenvalue using simulated data revealed that the 
           algorithm predictions are biased to the low side. The true value is likely higher than what is shown here."),
           h5("__________________________________________________________________________"),
           h3("Part-year Northeast residents"),
           plotOutput("TuljaMhist"),
           h4("Experimental validation of the performance of the algorithm in predicting the eigenvalue using simulated data revealed that the 
           algorithm predictions are biased to the low side. The true value is likely higher than what is shown here."),
           h5("__________________________________________________________________________"),
           actionButton("HelpboxGrowthRatesA","How do I interpret this from the mathematical modeling perspective?"),
           br(),
           actionButton("HelpboxGrowthRatesABio","How do I interpret this from the biological perspective?"),
           br(),
           actionButton("HelpboxGrowthRatesAEco","How do I interpret this from the ecological perspective?"),
           br(),
           actionButton("HelpboxGrowthRatesAMgmt","How do I interpret this from the resource management perspective?")         
           ), #end panel
      
      tabPanel("Survival rates", 
           h2("Stagewise survival rates"),
           h5("These graphs show the algorithm-predicted distributions of 
            survival probabilities for each life stage in each 
            bi-annual time period for the candidate models. "),
           h5("The top row shows 
            stage-wise survival distributions in the Northeast during the breeding period, 
            the middle row shows stage-wise survival
            distributions in the Northeast during the non-breeding
            period, and the bottom row shows the stage-wise
            survival distributions for the non-breeding period outside of the Northeast."),
           h5("These survival rates were generated by 
            identifying the plausible sets of vital rates in a symbolic life history 
            that could have generated the 
            empirical trajectories in the Northeast, USA from 1990-2018. 
            These distributions illustrate the variation in magnitude and the frequency 
            in stage-wise values of survival that could have existed in the Northeast from 1990-2018."),
           h5("For information on the experimental validation, please see Figure S16, Supplement III in 
           Hanley et al. (2019)."),
           h5("__________________________________________________________________________"),
           h3("Breeding period for all Northeast residents"),
           plotOutput("SurvivalB"),
           h4("The performance of the algorithm in predicting the true value of this survival was accurate when tested with simulated data."),
           h5("__________________________________________________________________________"),
           h3("Non-breeding period for year-round Northeast residents"),
           plotOutput("SurvivalNB"),
           h4("The performance of the algorithm in predicting the true value of this survival was accurate when tested with simulated data."),
           h5("__________________________________________________________________________"),
           h3("Non-breeding period for part-year Northeast residents"),
           plotOutput("SurvivalNBE"),
           h4("The performance of the algorithm in predicting the true value of this survival was accurate when tested with simulated data."),
           h5("__________________________________________________________________________"),
           actionButton("HelpboxSurvivalA","How do I interpret this from the mathematical modeling perspective?"),
           br(),
           actionButton("HelpboxSurvivalABio","How do I interpret this from the biological perspective?"),
           br(),
           actionButton("HelpboxSurvivalAEco","How do I interpret this from the ecological perspective?"),
           br(),
           actionButton("HelpboxSurvivalAMgmt","How do I interpret this from the resource management perspective?")
      ), #end panel
      
      tabPanel("Stable stage distribution",
           h2("Asymptotic stable stage distribution for the annual matrix"),
           h5("Matrix models assess population abundances under stable population 
            theory (Lebreton, 2005), which connects 
            a fixed set of fertility, migration, and mortality rates with the 
            population dynamics that they generate (Tuljapukar, 2008)."), 
           h5("The Strong Ergodic Theorem of Demography states that 
            if the stage-specific fertility 
            and mortality patterns remain unchanged over time, 
            its stage composition 
            will converge to a fixed form, regardless of initial 
            shape (Arthur, 1982). This fixed form 
            is called the Stable Stage Distribution (SSD)."),
           h5("When the allocation of individiuals in the SSD is standardized 
            into percentages, the result is the 
            Stable Stage Proportion (SSP). The SSP represents the percentages that 
            must exist in each stage for the population to 
            grow at its stable, asymptotic rate. "),
           h5("The summary statistics show the algorithm-predicted annual stable 
            stage proportions for the candidate trajectories 
            in the Northeast, USA from 1990-2018. 
            Notice that the hatchling stage is not represented in the SSP. 
            The omission lies in the fact that maturation into an immature bird occurs at 
            intervals shorter than one calendar year."),
           h5("For information on the experimental validation, please see Figure S18, Supplement III in 
           Hanley et al. (2019)."),
           h5("__________________________________________________________________________"),
           h3("Year-round Northeast residents"),
           h4("The stable stage proportion for the immature and non-breeding adult stage has a mean of:"),
           verbatimTextOutput("SSDRSmean"),
           h4("with a standard deviation of:"),
           verbatimTextOutput("SSDRSsd"),
           h4("The stable stage proportion for the breeding adult stage has a mean of:"),
           verbatimTextOutput("SSDRAmean"),
           h4("with a standard deviation of:"),
           verbatimTextOutput("SSDRAsd"),
           plotOutput("SSDRpie"),   
           plotOutput("SSDRboxplot"),
           h5("Experimental validation of the performance of the algorithm in predicting the SSD using simulated data revealed that the 
           algorithm predictions for SIII are biased to the low side. The true value of SIII is likely higher than what is shown here."),
           h5("__________________________________________________________________________"),
           h3("Part-year Northeast residents"),
           h4("The stable stage proportion for the immature and non-breeding 
            adult stage has a mean of:"),
           verbatimTextOutput("SSDMSmean"),
           h4("with a standard deviation of:"),
           verbatimTextOutput("SSDMSsd"),
           h4("The stable stage proportion for the breeding adult stage has a mean of:"),
           verbatimTextOutput("SSDMAmean"),
           h4("with a standard deviation of:"),
           verbatimTextOutput("SSDMAsd"),
           plotOutput("SSDMpie"), 
           plotOutput("SSDMboxplot"),
           h5("Experimental validation of the performance of the algorithm in predicting the SSD using simulated data revealed that the 
           algorithm predictions for SIII are biased to the low side. The true value of SIII is likely higher than what is shown here."),
           h5("__________________________________________________________________________"),
           actionButton("HelpboxSSDA","How do I interpret this from the mathematical modeling perspective?"),
           br(),
           actionButton("HelpboxSSDABio","How do I interpret this from the biological perspective?"),
           br(),
           actionButton("HelpboxSSDAEco","How do I interpret this from the ecological perspective?"),
           br(),
           actionButton("HelpboxSSDAMgmt","How do I interpret this from the resource management perspective?")
           ), #end panel 
      
      tabPanel("Reproductive value",
           h2("Asymptotic reproductive value for the annual matrix"),
           h5("The reproductive value measures the per individual contribution to
            future offspring when the population is growing in its stable growth rate."),
           h5("The summary statistics show the algorithm-predicted annual 
            reproductive value for the candidate trajectories 
            in the Northeast, USA. 
            Notice that the hatchling stage is not represented in the reproductive value graph. 
            The omission lies in the fact that maturation into an immature bird occurs at 
            intervals shorter than one calendar year."),
           h5("For information on the experimental validation, please see Figure S19, Supplement III in 
           Hanley et al. (2019)."),
           h5("__________________________________________________________________________"),
           h3("Year-round Northeast residents"),
           h4("The reproductive value for individuals in the immature and non-breeding 
            adult stage has a mean of:"),
           verbatimTextOutput("ReprodRSmean"),
           h4("with a standard deviation of:"),
           verbatimTextOutput("ReprodRSsd"),
           h4("The reproductive value for individuals in the breeding adult stage 
            has a mean of:"),
           verbatimTextOutput("ReprodRAmean"),
           h4("with a standard deviation of:"),
           verbatimTextOutput("ReprodRAsd"),
           plotOutput("ReprodRpie"),   
           plotOutput("ReprodResidents"),
           h5("Experimental validation of the performance of the algorithm in predicting the SSD using simulated data revealed that the 
           algorithm predictions for SIII are biased to the low side. The true value of SIII is likely slightly higher than what is shown here."),
           h5("__________________________________________________________________________"),
           h3("Part-year Northeast residents"),
           h4("The reproductive value for individuals in the immature and non-breeding 
            adult stage has a mean of:"),
           verbatimTextOutput("ReprodMSmean"),
           h4("with a standard deviation of:"),
           verbatimTextOutput("ReprodMSsd"),
           h4("The reproductive value for individuals in the breeding adult stage 
            has a mean of:"),
           verbatimTextOutput("ReprodMAmean"),
           h4("with a standard deviation of:"),
           verbatimTextOutput("ReprodMAsd"),
           plotOutput("ReprodMpie"), 
           plotOutput("ReprodMigrants"),
           h5("Experimental validation of the performance of the algorithm in predicting the SSD using simulated data revealed that the 
           algorithm predictions for SIII are biased to the low side. The true value of SIII is likely slightly higher than what is shown here."),
           h5("__________________________________________________________________________"),
           actionButton("HelpboxReprodA","How do I interpret this from the mathematical modeling perspective?"),
           br(),
           actionButton("HelpboxReprodABio","How do I interpret this from the biological perspective?"),
           br(),
           actionButton("HelpboxReprodAEco","How do I interpret this from the ecological perspective?"),
           br(),
           actionButton("HelpboxReprodAMgmt","How do I interpret this from the resource management perspective?")
           ), #end panel 
 
      tabPanel("Sensitivities",
           h2("Asymptotic sensitivity of the growth rate with respect to annual matrix elements"),
           h5("Population matrix models provide methods to assess the desirability of 
            resource management actions, plans, or hypothetical alternatives (de Kroon, van Groenendael, & Ehrlen, 2000)."),
           h5("Sensitivities 
            specify the rate of change in the growth rate 
            from a perturbation to a life history transition. Sensitivities are used to 
            assess the effects of life history changes
            due to environmental or management perturbations, uncertainty in parameter 
            estimates, or in phenotypic evolution (Shyu & Caswell, 2014)."),
           h5("When the growth rate is used as 
            a fitness measure, the sensitivity of the growth rate 
            with respect to a vital rate is the selection gradient on that 
            vital rate (Lande, 1988; van Groenendael, 
            de Kroon, & Caswell, 1988)."),
            h5("Sensitivities appear in expressions arising 
            when the error of 
            estimation of vital rates is propagated to the variance in the 
            estimation of functions of the vital 
            rates (the delta method; see Knight 2000; Sibly, Hansen & Forbes, 2000)."),
            h5("The product of sensitivities and the 
            genetic variance 
            in demographic parameters gives the rate of 
            change of the phenotypic mean of the parameters under 
            selection (Lande, 1982; Caswell, 1985; van 
            Groenendael, de Kroon, & Caswell, 1988; van Tienderen, 1995, 2000; de Kroon, van Groenendael & 
            Ehrlen, 2000). "),
           h5("These summary statistics show the algorithm-predicted sensitivities 
            for each element in the annual matrix in the Northeast, USA. 
            Notice that the hatchling stage is not represented in the sensitivities. 
            The omission lies in the fact that maturation into an immature bird occurs at 
            intervals shorter than one calendar year."),
           h5("For information on the experimental validation, please see Figure S20, Supplement III in 
           Hanley et al. (2019)."),
           h5("__________________________________________________________________________"),
           h3("Year-round Northeast residents"),
           h4("The sensitivity for the transition represented by 
             immature and non-breeding females remaining immature and non-breeding females (a22) 
            has a mean of:"),
           verbatimTextOutput("SensitivityRTwoTwomean"),
           h4("with a standard deviation of:"),
           verbatimTextOutput("SensitivityRTwoTwosd"),
           h5("Experimental validation of the performance of the algorithm using simulated data revealed that this 
           algorithm prediction is biased to the high side. The true value is likely lower than what is shown here."),
           h5("__________________________________________________________________________"),
           h4("The sensitivity for the transition represented by breeding 
            females regressing to immature and non-breeding females (a23) has a mean of:"),
           verbatimTextOutput("SensitivityRTwoThreemean"),
           h4("with a standard deviation of:"),
           verbatimTextOutput("SensitivityRTwoThreesd"),
           h5("Experimental validation of the performance of the algorithm using simulated data revealed that this 
           algorithm prediction is slightly biased to the low side. The true value is likely slightly higher than what is shown here."),
           h5("__________________________________________________________________________"),
           h4("The sensitivity for the transition represented by 
            immature and non-breeding females advancing to breeding females (a32) has a mean of:"),
           verbatimTextOutput("SensitivityRThreeTwomean"),
           h4("with a standard deviation of:"),
           verbatimTextOutput("SensitivityRThreeTwosd"),
           h5("Experimental validation of the performance of the algorithm using simulated data revealed that this prediction is accurate."),
           h5("__________________________________________________________________________"),
           h4("The sensitivity for the transition represented by breeding females staying 
            breeding females (a33) has a mean of:"),
           verbatimTextOutput("SensitivityRThreeThreemean"),
           h4("with a standard deviation of:"),
           verbatimTextOutput("SensitivityRThreeThreesd"),
           h5("Experimental validation of the performance of the algorithm using simulated data revealed that this 
           algorithm prediction is slightly biased to the low side. The true value is likely slightly higher than what is shown here."),
           h5("__________________________________________________________________________"),
           plotOutput("SensitivityResidents"), 
           h5("__________________________________________________________________________"),
           h3("Part-year Northeast residents"),
           h4("The sensitivity for the transition represented by immature and 
           non-breeding females remaining immature and non-breeding females (a22) has a mean of:"),
           verbatimTextOutput("SensitivityMTwoTwomean"),
           h4("with a standard deviation of:"),
           verbatimTextOutput("SensitivityMTwoTwosd"),
           h5("Experimental validation of the performance of the algorithm using simulated data revealed that this 
           algorithm prediction is biased to the high side. The true value is likely lower than what is shown here."),
           h5("__________________________________________________________________________"),
           h4("The sensitivity for the transition represented by breeding 
           females regressing to non-breeding females (a23) has a mean of:"),
           verbatimTextOutput("SensitivityMTwoThreemean"),
           h4("with a standard deviation of:"),
           verbatimTextOutput("SensitivityMTwoThreesd"),
           h5("Experimental validation of the performance of the algorithm using simulated data revealed that this 
           algorithm prediction is slightly biased to the low side. The true value is likely slightly higher than what is shown here."),
           h5("__________________________________________________________________________"),
           h4("The sensitivity for the transition represented by immature 
           and non-breeding females advancing to breeding females (a32) has a mean of:"),
           verbatimTextOutput("SensitivityMThreeTwomean"),
           h4("with a standard deviation of:"),
           verbatimTextOutput("SensitivityMThreeTwosd"),
           h5("Experimental validation of the performance of the algorithm using simulated data revealed that this prediction is accurate."),
           h5("__________________________________________________________________________"),
           h4("The sensitivity for the transition represented by breeding 
           females staying in breeding females (a33) has a mean of:"),
           verbatimTextOutput("SensitivityMThreeThreemean"),
           h4("with a standard deviation of:"),
           verbatimTextOutput("SensitivityMThreeThreesd"),
           h5("Experimental validation of the performance of the algorithm using simulated data revealed that this 
           algorithm prediction is biased to the low side. The true value is likely higher than what is shown here."),
           h5("__________________________________________________________________________"),
           plotOutput("SensitivityMigrants"),
           h5("__________________________________________________________________________"),
           actionButton("HelpboxSenseA","How do I interpret this from the mathematical modeling perspective?"),
           br(),
           actionButton("HelpboxSenseABio","How do I interpret this from the biological perspective?"),
           br(),
           actionButton("HelpboxSenseAEco","How do I interpret this from the ecological perspective?"),
           br(),
           actionButton("HelpboxSenseAMgmt","How do I interpret this from the resource management perspective?")
      ), #end panel 
      
      tabPanel("Elasticities",
           h2("Asymptotic elasticity of the growth rate with respect to annual matrix elements"),
           h5("Population matrix models are capable of ranking the relative desirability of 
            resource management actions, plans, or hypothetical alternatives (de Kroon, van Groenendael, & Ehrlen, 2000). 
            Through techniques of sensitivity analysis (Saltelli et al., 2004), 
            matrix models provide machinery to diagnose the source of undesirable 
            abundance issues 
            and to suggest alternatives that can be used to achieve a 
            management goal (Caswell, 2001)."), 
            h5("Elasticities sum to one, and therefore quantify the relative 
            importance of each transition to the population 
            growth rate (de Kroon, van Groenendael, & Ehrlen, 2000). Targeted modification to the 
           transition with the highest elasticity will produce the largest 
           response in the growth rate (de Kroon, Van Groenendael & 
            Ehrlen, 2000; Morris & Doak, 2002)."),
           h5("Traditional management focuses on the transition 
            with the largest elasticity (de Kroon, van Groenendael
            & Ehrlen, 2000), 
            although this interpretation is controversial in 
            light of new genetic and mathematical considerations (Ezard et al., 2010)."),
           h5("These summary statistics show the algorithm-predicted elasticities 
            for each element in the annual matrix in the Northeast, USA. 
            Notice that the hatchling stage is not represented in the elasticities. 
            The omission lies in the fact that maturation into an immature bird occurs at 
            intervals shorter than one calendar year."),
           h5("For information on the experimental validation, please see Figure S21, Supplement III in 
           Hanley et al. (2019)."),
           h5("__________________________________________________________________________"),
           h3("Year-round Northeast residents"),
           h4("The elasticity for the transition represented by immature and non-breeding 
            females remaining immature and non-breeding females (a22) has a mean of:"),
           verbatimTextOutput("ElasticityRTwoTwomean"),
           h4("with a standard deviation of:"),
           h5("Experimental validation of the performance of the algorithm using simulated data revealed that this 
           algorithm prediction is biased to the high side. The true value is likely lower than what is shown here."),
           h5("__________________________________________________________________________"),
           verbatimTextOutput("ElasticityRTwoTwosd"),
           h4("The elasticity for the transition represented by breeding 
           females regressing to non-breeding females (a23) has a mean of:"),
           verbatimTextOutput("ElasticityRTwoThreemean"),
           h4("with a standard deviation of:"),
           verbatimTextOutput("ElasticityRTwoThreesd"),
           h5("Experimental validation of the performance of the algorithm using simulated data revealed that this prediction is accurate."),
           h5("__________________________________________________________________________"),
           h4("The elasticity for the transition represented by non-breeding females 
            advancing to breeding females (a32) has a mean of:"),
           verbatimTextOutput("ElasticityRThreeTwomean"),
           h4("with a standard deviation of:"),
           verbatimTextOutput("ElasticityRThreeTwosd"),
           h5("Experimental validation of the performance of the algorithm using simulated data revealed that this prediction is accurate."),
           h5("__________________________________________________________________________"),
           h4("The elasticity for the transition represented by breeding females staying 
            breeding females (a33) has a mean of:"),
           verbatimTextOutput("ElasticityRThreeThreemean"),
           h4("with a standard deviation of:"),
           verbatimTextOutput("ElasticityRThreeThreesd"),
           h5("Experimental validation of the performance of the algorithm using simulated data revealed that this 
           algorithm prediction is biased to the low side. The true value is likely higher than what is shown here."),
           h5("__________________________________________________________________________"),
           plotOutput("ElasticityResidents"), 
           h5("__________________________________________________________________________"),
           h3("Part-year Northeast residents"),
           h4("The elasticity for the transition represented by immature and 
           non-breeding females remaining immature and non-breeding females (a22) has a mean of:"),
           verbatimTextOutput("ElasticityMTwoTwomean"),
           h4("with a standard deviation of:"),
           verbatimTextOutput("ElasticityMTwoTwosd"),
           h5("Experimental validation of the performance of the algorithm using simulated data revealed that this 
           algorithm prediction is biased to the high side. The true value is likely lower than what is shown here."),
           h5("__________________________________________________________________________"),
           h4("The elasticity for the transition represented by breeding 
           females regressing to non-breeding females (a23) has a mean of:"),
           verbatimTextOutput("ElasticityMTwoThreemean"),
           h4("with a standard deviation of:"),
           verbatimTextOutput("ElasticityMTwoThreesd"),
           h5("Experimental validation of the performance of the algorithm using simulated data revealed that this prediction is accurate."),
           h5("__________________________________________________________________________"),
           h4("The elasticity for the transition represented by non-breeding females 
            transitioning to breeding females (a32) has a mean of:"),
           verbatimTextOutput("ElasticityMThreeTwomean"),
           h4("with a standard deviation of:"),
           verbatimTextOutput("ElasticityMThreeTwosd"),
           h5("Experimental validation of the performance of the algorithm using simulated data revealed that this prediction is accurate."),
           h5("__________________________________________________________________________"),
           h4("The elasticity for the transition represented by breeding females staying 
            breeding females (a33) has a mean of:"),
           verbatimTextOutput("ElasticityMThreeThreemean"),
           h4("with a standard deviation of:"),
           verbatimTextOutput("ElasticityMThreeThreesd"),
           h5("Experimental validation of the performance of the algorithm using simulated data revealed that this 
           algorithm prediction is biased to the low side. The true value is likely higher than what is shown here."),
           h5("__________________________________________________________________________"),
           plotOutput("ElasticityMigrants"),
           h5("__________________________________________________________________________"),
           actionButton("HelpboxElastA","How do I interpret this from the mathematical modeling perspective?"),
           br(),
           actionButton("HelpboxElastABio","How do I interpret this from the biological perspective?"),
           br(),
           actionButton("HelpboxElastAEco","How do I interpret this from the ecological perspective?"),
           br(),
           actionButton("HelpboxElastAMgmt","How do I interpret this from the resource management perspective?")
      ), #end panel 
      
      tabPanel("Damping ratio and convergence time",
           h2("Asymptotic damping ratio and time of convergence of the annual matrix"),
           h5("When conditions remain static for long periods of time, populations 
            exhibit system-level dynamics
            that naturally tend towards stability. However, fluctuations in environmental, biological, or managerial 
            conditions result in temporary system-level instability."),
           h5("The damping ratio is a unitless measure that 
            specifies the relative rate at which population abundances 
            return to the stable-status after a pertubation (Caswell, 2001). A damping ratio much greater 
           than one is the mark of a system that will quickly snap back to stable-status, while a damping ratio near one 
            indicates a more sluggish return to stability. A damping ratio equal to one means that 
            stability might never return."),
          h5("The time to convergence in this annual matrix is the number of years it will take for a 
             disrupted population to return to its stable status 
            (Stott et al., 2011). A shorter
            convergence time corresponds to a higher damping ratio."),
          h5("For information on the experimental validation, please see Figure S22, Supplement III in 
           Hanley et al. (2019)."),
          h5("__________________________________________________________________________"),
           h3("Year-round Northeast residents"),
           h4("The damping ratio for year-round residents has a mean of:"),
           verbatimTextOutput("DampingRatioMeanResidents"),
           h4("with a standard deviation of:"),
           verbatimTextOutput("DampingRatioSDResidents"),
           plotOutput("DampingRatioResidents"),
          h5("Experimental validation of the performance of the algorithm using simulated data revealed that this 
           algorithm prediction is biased to the high side. The true value is likely lower than what is shown here."),
          h5("__________________________________________________________________________"),
           h4("The time to convergence for year-round residents has a mean of:"),
           verbatimTextOutput("ConvergenceResidentMean"),
           h4("with a standard deviation of:"),
           verbatimTextOutput("ConvergenceResidentSD"),
          h5("__________________________________________________________________________"),
           h3("Part-year Northeast residents"),
           h4("The damping ratio for part-year residents has a mean of:"),
           verbatimTextOutput("DampingRatioMeanMigrants"),
           h4("with a standard deviation of:"),
           verbatimTextOutput("DampingRatioSDMigrants"),
           plotOutput("DampingRatioMigrants"),
          h5("Experimental validation of the performance of the algorithm using simulated data revealed that this 
           algorithm prediction is biased to the high side. The true value is likely lower than what is shown here."),
          h5("__________________________________________________________________________"),
           h4("The time to convergence for part-year residents has a mean of:"),
           verbatimTextOutput("ConvergenceMigrantMean"),
           h4("with a standard deviation of:"),
           verbatimTextOutput("ConvergenceMigrantSD"),
          h5("__________________________________________________________________________"),
           actionButton("HelpboxDampA","How do I interpret this from the mathematical modeling perspective?"),
           br(),
           actionButton("HelpboxDampABio","How do I interpret this from the biological perspective?"),
           br(),
           actionButton("HelpboxDampAEco","How do I interpret this from the ecological perspective?"),
           br(),
           actionButton("HelpboxDampAMgmt","How do I interpret this from the resource management perspective?")
           ), #end panel 
      
      tabPanel("Cumulative growth", 
           h2("Cumulative growth of the annual matrix"),
           h5("The cumulative growth is the ratio between the total population at any 
            time (t=T) and the population 
            at the onset of the projection (t=0; Caswell, 2001). "),
           h5("This graph displays the algorithm-predicted cumulative growth rate in 
            the Northeast from 1990-2018. Each color represents 
            the cumulative growth of a 
            matrix model that was identified by the algorithm to be a 
            plausible representation of the empirical data."),
           h5("For information on the experimental validation, please see Figure S23, Supplement III in 
           Hanley et al. (2019)."),
           h5("__________________________________________________________________________"),
           plotOutput("Cumulative"),
           h5("Experimental validation of the performance of the algorithm using simulated data revealed that this 
           algorithm prediction is biased to the high side. The true value is likely slightly lower than what is shown here."),
           h5("__________________________________________________________________________"),
           actionButton("HelpboxCumuA","How do I interpret this from the mathematical modeling perspective?"),
           br(),
           actionButton("HelpboxCumuABio","How do I interpret this from the biological perspective?"),
           br(),
           actionButton("HelpboxCumuAEco","How do I interpret this from the ecological perspective?"),
           br(),
           actionButton("HelpboxCumuAMgmt","How do I interpret this from the resource management perspective?")
           ), #end panel
      
    
       tabPanel("Stochastic growth rate", 
           h2("Stochastic growth rate for the annual matrix"),
           h5("In variable environments, a population does not achieve a constant 
            rate of change, 
            but it instead approaches a long-run average called the stochastic 
            growth rate (Tuljapurkar, 1990). The 
            stochastic growth rate is calculated using observed abundances through time, 
            so it captures 
            information from vital rates as well as information from gains and losses through dispersal."),
           h5("A stochastic growth rate above one means that the population is 
            increasing; below one means the population is decreasing; 
            and equal to one means the population is stable."),
           h5("For information on the experimental validation, please see Figure S24, Supplement III in 
           Hanley et al. (2019)."),
           h5("__________________________________________________________________________"),
           h5("The stochastic growth rates has a mean of:"),
           verbatimTextOutput("StochMean"),
           h5("with a standard deviation of:"),
           verbatimTextOutput("StochSD"),
           plotOutput("Stoch"),
           h5("Experimental validation of the performance of the algorithm using simulated data revealed that this prediction is accurate."),
           h5("__________________________________________________________________________"),
           actionButton("HelpboxStochA","How do I interpret this from the mathematical modeling perspective?"),
           br(),
           actionButton("HelpboxStochABio","How do I interpret this from the biological perspective?"),
           br(),
           actionButton("HelpboxStochAEco","How do I interpret this from the ecological perspective?"),
           br(),
           actionButton("HelpboxStochAMgmt","How do I interpret this from the resource management perspective?")
      ), #end panel
      
      tabPanel("Transient growth rate", 
           h2("Transient growth rate for the annual matrix"),
           h5("The transient growth rate is the near-term growth rate, defined as the log of 
            the ratio between the population at time (t=T) and the population at the 
            previous time unit (t=T-1; Caswell, 2007). "),
           h5("This graph displays the algorithm-predicted transient growth rate 
            for Bald Eagles in 
            Northeast, USA from 1990-2018. Each color represents 
            the transient growth rate through time for a 
            matrix model that was identified by the algorithm to be a 
            plausible representation of the empirical data."),
           h5(" Notice that there is a period of instability, after which the 
            transient growth rate settles into its stable pattern. This is the most striking 
            illustration of the transition from transient to stable dynamics, and 
           the change occurs at about year four. This time frame for convergence to stability 
            is consistent with the calculations on the damping ratio tab."),
           h5("For information on the experimental validation, please see Figure S25, Supplement III in 
           Hanley et al. (2019)."),
           h5("__________________________________________________________________________"),
           plotOutput("TransGR"),
           h5("Experimental validation of the performance of the algorithm using simulated data revealed that this 
           algorithm prediction is biased to the high side. The true value is likely slightly lower than what is shown here."),
           h5("__________________________________________________________________________"),
           actionButton("HelpboxTransGrowA","How do I interpret this from the mathematical modeling perspective?"),
           br(),
           actionButton("HelpboxTransGrowABio","How do I interpret this from the biological perspective?"),
           br(),
           actionButton("HelpboxTransGrowAEco","How do I interpret this from the ecological perspective?"),
           br(),
           actionButton("HelpboxTransGrowAMgmt","How do I interpret this from the resource management perspective?")
           ), #end panel
      
      tabPanel("Harmonic vs. arithmetic mean abundances", 
           h2("Census population size compared to the effective population size"),
           h5("Population census size and effective population size may not agree in the same 
            group of individuals, especially if the group of individuals has 
            undergone population
            bottlenecks, founder events, or population oscillations (Gotelli, 2004)."),
          h5("The census population may be summarized by the arithmetic mean, which is the 
           average abundance of individuals through time (Gotelli, 2004), while the 
            effective population size (Ne) is a measure of evolutionary 
            preparedness in that same group of individuals (Gotelli, 2004). 
            Although Ne has several definitions, 
            one way to calculate Ne is to find 
            the harmonic mean of the population size of the group
            (Gotelli, 2004; Kliman, Sheehy, & Schultz, 2008). "),
          h5("Population bottlenecks, founder events, and oscillations
            are known to reduce the ability for a 
            population to evolve (Frankham et al., 1999; Frankham et al.,2002; Frankham, 2005). 
            In particular, Ne
            is sensitive to and will plummet in response to instable population dynamics.
            Perilously low Ne means that the population 
            is at risk from an evolutionary perspective, even if the census 
            size is high (Frankham et al., 1999; Frankham et al., 2002; Frankham, 2005). "),
          h5("The low initial abundances of eagles in the Northeast
            constitute a genetic founder event. Ne can increase through recombination and mutation, 
           and in the case of an open population (as we have here), through migration or dispersion. 
            The discrepancy
            between the harmonic and arithmetic means 
            in the candidate models exists because 
            the harmonic mean is especially sensitive to the low abundances of eagles in
            the early years of the recovery. However, gene flow 
            between populations may be underestimated in these calculations. 
            No genetic information was used in this assessment,
            only analytical equations that assume closed systems."),
          h5("For information on the experimental validation, please see Figure S26, Supplement III in 
           Hanley et al. (2019)."),
          h5("__________________________________________________________________________"),
           h5("The harmonic mean for the candidate models in the Northeast has a mean of:"),
           verbatimTextOutput("NeMean"),
           h5("with a standard deviation of:"),
           verbatimTextOutput("NeSD"),
          h5("Experimental validation of the performance of the algorithm using simulated data revealed that this 
           algorithm prediction is biased to the low side. The true value is likely higher than what is shown here."),
          h5("__________________________________________________________________________"),
           h5("The arithmetic mean population size for the candidate models in the Northeast has a mean of:"),
           verbatimTextOutput("NbarMean"),
           h5("with a standard deviation of:"),
           verbatimTextOutput("NbarSD"),
          h5("Experimental validation of the performance of the algorithm using simulated data revealed that this prediction is accurate."),
          h5("__________________________________________________________________________"),
           plotOutput("Effective"),
          h5("__________________________________________________________________________"),
           actionButton("HelpboxEffectiveA","How do I interpret this from the mathematical modeling perspective?"),
           br(),
           actionButton("HelpboxEffectiveABio","How do I interpret this from the biological perspective?"),
           br(),
           actionButton("HelpboxEffectiveAEco","How do I interpret this from the ecological perspective?"),
           br(),
           actionButton("HelpboxEffectiveAMgmt","How do I interpret this from the resource management perspective?")
      ), #end panel
      
      tabPanel("Loss of genetic diversity", 
           h2("Loss of genetic diversity for the annual matrix"),
           h5("Genetic drift is the reason why biologists worry about small, isolated wildlife 
            populations (Kliman, Sheehy, & Schultz, 2008). Although the dispersion
            tendencies of Bald Eagles create genetic connectivity 
            into and out of Northeast, calculations to assess
            potential perils in allele frequency may be helpful in thwarting 
            potential genetic-based risks to conservation and sustainability."),
           h5("The loss of genetic diversity occurs in a closed population when allele 
            frequencies are fixed or lost. The rate of fixation is well represented 
            as a function of population size when the system is closed to migration 
            and dispersion (Frankham, 2005)."),
           h5("This graph displays the algorithm-predicted loss of genetic diversity 
             for Bald Eagles in 
            Northeast from 1990-2018 had the region been closed to migration and 
            dispersion during that time. Each color represents 
            the loss of genetic diversity of a 
            matrix model that was identified by the algorithm to be a 
            plausible representation of the empirical data."),
           h5("For information on the experimental validation, please see Figure S27, Supplement III in 
           Hanley et al. (2019)."),
           h5("__________________________________________________________________________"),
           plotOutput("LGD"),
           h5("Experimental validation of the performance of the algorithm using simulated data revealed that this 
           algorithm prediction is biased to the low side. The true value is likely higher than what is shown here."),
           h5("__________________________________________________________________________"),
           actionButton("HelpboxLGDA","How do I interpret this from the mathematical modeling perspective?"),
           br(),
           actionButton("HelpboxLGDABio","How do I interpret this from the biological perspective?"),
           br(),
           actionButton("HelpboxLGDAEco","How do I interpret this from the ecological perspective?"),
           br(),
           actionButton("HelpboxLGDAMgmt","How do I interpret this from the resource management perspective?")
      ), #end panel
      
      tabPanel("Population inertia", 
           h2("Transient population inertia for the annual matrix"),
           h5("Population inertia is defined as the relative difference in 
            long-term abundance between populations, where one has stayed at stable-status and the other has a non-stable structure in its history (Koons, Holmes, & Grand, 2007; 
            Stott et al., 2011). "),
           h5("Inertia quantifies the impacts in today's population from historic departures in stable-status. 
            Large magnitudes of population inertia (differing greatly from one) 
            signify populations whose long-term abundance is greatly affected 
            by historical non-stable structure (Koons, Holmes, & Grand, 2007). 
            Population inertia is a standardized measure 
            and thus can be compared across different models (Stott, 2012)."),
           h5("For information on the experimental validation, please see Figure S28, Supplement III in 
           Hanley et al. (2019)."),
           h5("__________________________________________________________________________"),
           h3("Year-round Northeast residents"),
           h4("The population inertia for year-round residents has a mean of:"),
          verbatimTextOutput("InertiaResidentMean"),
          h4("with a standard deviation of:"),
          verbatimTextOutput("InertiaResidentSD"),
          plotOutput("InertiaResidents"),
          h5("Experimental validation of the performance of the algorithm using simulated data revealed that this 
           algorithm prediction is biased to the high side. The true value is likely lower than what is shown here."),
          h5("__________________________________________________________________________"),
          h3("Part-year Northeast residents"),
          h4("The population inertia for part-year residents has a mean of:"),
          verbatimTextOutput("InertiaMigrantMean"),
          h4("with a standard deviation of:"),
          verbatimTextOutput("InertiaMigrantSD"),
          h5("Experimental validation of the performance of the algorithm using simulated data revealed that this 
           algorithm prediction is biased to the high side. The true value is likely lower than what is shown here."),
          plotOutput("InertiaMigrants"),
          h5("__________________________________________________________________________"),
           actionButton("HelpboxPopInA","How do I interpret this from the mathematical modeling perspective?"),
           br(),
           actionButton("HelpboxPopInABio","How do I interpret this from the biological perspective?"),
           br(),
           actionButton("HelpboxPopInAEco","How do I interpret this from the ecological perspective?"),
           br(),
           actionButton("HelpboxPopInAMgmt","How do I interpret this from the resource management perspective?")
      ), #end panel
      
      tabPanel("Reactivity", 
           h2("Transient reactivity for the annual matrix"),
           h5("Reactivity is a measure of how 
            responsive population dyanmics are to acute changes in conditions. 
            Reactivity is defined as the maximum population size of a 
            structured population not in equilibrium
            in a single time step, relative to the population at equilibrium 
            (Neubert & Caswell 1997, Stott et al., 2011)."),
           h5("For information on the experimental validation, please see Figure S29, Supplement III in 
           Hanley et al. (2019)."),
           h5("__________________________________________________________________________"),
           h3("Year-round Northeast residents"),
           h4("The reactivity for year-round residents has a mean of:"),
           verbatimTextOutput("ReacResidentMean"),
           h4("with a standard deviation of:"),
           verbatimTextOutput("ReacResidentSD"),
           plotOutput("ReactR"),
           h5("Experimental validation of the performance of the algorithm using simulated data revealed that this 
           algorithm prediction is biased to the high side. The true value is likely lower than what is shown here."),
           h5("__________________________________________________________________________"),
           h3("Part-year Northeast residents"),
           h4("The reactivity for part-year residents has a mean of:"),
           verbatimTextOutput("ReacMigrantMean"),
           h4("with a standard deviation of:"),
           verbatimTextOutput("ReacMigrantSD"),
           plotOutput("ReactM"),
           h5("Experimental validation of the performance of the algorithm using simulated data revealed that this 
           algorithm prediction is biased to the high side. The true value is likely lower than what is shown here."),
           h5("__________________________________________________________________________"),
           actionButton("HelpboxReactA","How do I interpret this from the mathematical modeling perspective?"),
           br(),
           actionButton("HelpboxReactABio","How do I interpret this from the biological perspective?"),
           br(),
           actionButton("HelpboxReactAEco","How do I interpret this from the ecological perspective?"),
           br(),
           actionButton("HelpboxReactAMgmt","How do I interpret this from the resource management perspective?")
           ), #end panel
      
      tabPanel("Maximum amplification", 
           h2("Transient maximum amplification for the annual matrix"),
           h5("Depending on the relative overabundance vs. underabundance of individuals in 
           each stage, the initial transient reaction to an unstable population structure can 
           lead to sudden and 
            substantial increases or decreases in population size (Caswell & Neubert 2005; 
            Koons, Holmes, & Grand, 2007)."),
           h5("Maximum amplification is defined as the maximum population 
             size achievable for all time periods 
            initialized not at equilibrium, relative to a population initialized 
            at the same population 
            size and at equilibrium (Stott et al., 2011), and therefore quantifies the 
            maximum possible immediate increase in population size that could 
            occur from deviations to the stable
            stage distribution."),
           h5("For information on the experimental validation, please see Figure S30, Supplement III in 
           Hanley et al. (2019)."),
           h5("__________________________________________________________________________"),
           h3("Year-round Northeast residents"),
           h4("The maximum amplification for year-round residents has a mean of:"),
           verbatimTextOutput("MAXAMPResidentMean"),
           h4("with a standard deviation of:"),
           verbatimTextOutput("MAXAMPResidentSD"),
           plotOutput("MAXAMPR"),
           h5("__________________________________________________________________________"),
           h3("Part-year Northeast residents"),
           h4("The maximum amplification for part-year residents has a mean of:"),
           verbatimTextOutput("MAXAMPMigrantMean"),
           h4("with a standard deviation of:"),
           verbatimTextOutput("MAXAMPMigrantSD"),
           plotOutput("MAXAMPM"),
           h5("__________________________________________________________________________"),
           actionButton("HelpboxMaxAmpA","How do I interpret this from the mathematical modeling perspective?"),
           br(),
           actionButton("HelpboxMaxAmpABio","How do I interpret this from the biological perspective?"),
           br(),
           actionButton("HelpboxMaxAmpAEco","How do I interpret this from the ecological perspective?"),
           br(),
           actionButton("HelpboxMaxAmpAMgmt","How do I interpret this from the resource management perspective?")
      ), #end panel

      tabPanel("Maximum attenuation", 
           h2("Transient maximum attenuation for the annual matrix"),
           h5("Maximum attenuation is defined as the minimum population size 
           achievable for all time periods
           initialized not at equilibrium, relative to a population 
           initialized at the same population size 
            and at equilibrium (Stott et al., 2011). Maximum attenuation 
            specifies the lowest
            possible population size that may arise from a structure that 
            deviates from stable status.
            To this end, maximum attenuation reveals potential consequential 
            genetic risks that 
            are capable of arising from 
            temporarily low populations in closed systems."),
           h5("For information on the experimental validation, please see Figure S31, Supplement III in 
           Hanley et al. (2019)."),
           h5("__________________________________________________________________________"),
           h3("Year-round Northeast residents"),
           h4("The maximum attenuation for year-round residents has a mean of:"),
           verbatimTextOutput("MAXattResidentMean"),
           h4("with a standard deviation of:"),
           verbatimTextOutput("MAXattResidentSD"),
           plotOutput("MAXattR"),
           h5("Experimental validation of the performance of the algorithm using simulated data revealed that this 
           algorithm prediction is accurate."),
           h5("__________________________________________________________________________"),
           h3("Part-year Northeast residents"),
           h4("The maximum attenuation for part-year residents has a mean of:"),
           verbatimTextOutput("MAXattMigrantMean"),
           h4("with a standard deviation of:"),
           verbatimTextOutput("MAXattMigrantSD"),
           plotOutput("MAXattM"),
           h5("Experimental validation of the performance of the algorithm using simulated data revealed that this 
           algorithm prediction is biased to the high side. The true value is likely lower than what is shown here."),
           h5("__________________________________________________________________________"),
           actionButton("HelpboxMaxAttA","How do I interpret this from the mathematical modeling perspective?"),
           br(),
           actionButton("HelpboxMaxAttABio","How do I interpret this from the biological perspective?"),
           br(),
           actionButton("HelpboxMaxAttAEco","How do I interpret this from the ecological perspective?"),
           br(),
           actionButton("HelpboxMaxAttAMgmt","How do I interpret this from the resource management perspective?")
      ) #end panel
      ) # end tab panels
  ) # end ui
      
server=function(input,output,session) {
 toggleModal(session, "startupModal", toggle = "open")
 
 # HELPBOX NARRATIVES
 observeEvent(input$Foundational,{
  showModal(modalDialog(
   title="Population matrix models are important for assessing wildlife populations",
   HTML("
      <p> Organisms reproduce. Demography is the study of 
      how abundances of organisms change over time. A population matrix model is a type of
      mathematical representation of this change. </p>

      <p> Population matrix models are rooted in stable population theory, 
       which links life history characteristics
       to the system-level dynamics that they produce (Tuljapurkar, 2008). 
       A life history is broadly defined to 
       include not only the age-specific fecundity and mortality rates, 
       but the entire sequence of changes through which an organism 
       passes in its development from conception to death (Lande, 1982). 
       Familiar vital rates include
       the number of offspring per female, age at first breeding, life 
       expectancy, and survival probabilty of the first year of life. 
       We use life history characteristics such as breeding and non-breeding behavior, 
       migration and dispersion tendencies, density dependence, and 
       overall life expectancy to symbolically parameterize a matrix model for Bald Eagles. </p>

      <p>The population matrix model is used to project stage abundances of 
      age- or stage-structured populations in 
      discrete time (van Groenendael, de Kroon, & Caswell, 1988). Developed first by P. H. 
      Leslie, the first generation 
      of population matrix models used age to assign individuals to a model 
      class (Leslie, 1945). Lefkovitch later adapted 
      Leslies' population matrix models to accommodate measurements 
      such as size or stage in lieu of age (Lefkovitch, 1965). 
      Lefkovitch's important contribution extended the use of population matrix models 
      to systems whose individuals seemingly follow 
      transitions through biological stages (such as seed, 
      rosette, flowering plant, etc.; Lebreton, 2005). </p>

      <p>For Bald Eagles, we mapped the life history
      based on age, then pooled early sequential ages into 
      characteristic-based stages. Our projection matrix is a Lefkovitch matrix,
      although age plays a role in some parameterizations. This stage-based 
      model was chosen because it 
      allows for regression of breeding-age eagles (stage III) into a pooled 
      immature and non-breeding adult class (stage II). 
      The regressing eagles are not getting younger, rather their lack of 
      reproduction means that they are pooled (in a mathematical sense) with 
      other non-reproducing individuals. This capacity for stage regression 
      has been modeled into the symbolic life history because 
      density dependence is known to exist in the life history of this raptor (Buehler, 2000).</p>

      <p> The life history characteristics of the species govern the structure of 
      its population matrix model. 
      Matrix models are square matrices, with dimension corresponding to the number 
      of stages that an individual can experience 
      in its lifetime (Caswell, 2001). Linkages between stages form the configuration of the matrix. </p>

     <p> The structure and configuration of the matrix 
      will vary according to species-specific life history traits. Should this 
      interactive application be used with a species other than Bald Eagles, 
      the life history skeleton would have to be modified.
      To this end, information contained in this 
      interactive is unique to the Bald Eagles in the Northeastern USA.</p>"),
   easyClose=TRUE))})
 observeEvent(input$HelpboxT1,{
  showModal(modalDialog(
   title="Matrix models compartmentalize the natural progression of individuals through their life cycle",
   HTML("
      <p> Matrix models are constructed using vital rates. </p>
      <p> Two basic types of vital rates underlie the transitions in a life history: 
      survival of individuals from one time-step 
      to the next (which may or may not be accompanied by growth, shrinkage, change 
      in demographic status, etc.) 
      and reproduction events by which new individuals are formed (de Kroon, 
      van Groenendael, & Ehrlen, 2000). </p>

      <p> This interactive app contains two types of matrices: two (bi-annual) 3x3 matrices 
      and one combined 3x3 annual matrix. The breeding period matrix contains 
      reproductive and transition
      vital rates, while the non-breeding period matrix only contains transitional vital rates.</p>
      <p>Reproduction events rate may be parameterized as either fertility 
      (realized reproduction) or fecundity (maximum possible reproduction; Caswell, 2001). The 
      unit of reproduction is the number of 
      female offspring per breeding female, per time unit (Caswell, 2001). Reproductive 
      events are parameterized as post-census 
      birth-pulse, meaning that the census of the offspring was taken only after survival 
      in the first bi-annual time period had been determined (Caswell, 2001). To this end, 
      counts of hatchlings in this app do not represent 
      the number of eggs that hatched, but rather the number of hatchlings that 
      survived through the end of the breeding period. </p>
      <p>Transitional vital rate entries represent average conditions 
      for stage-wise transitions through a life cycle. These entries are 
      combined survival and transition probabilities (Doak, Kareiva, & Klepetka, 1994), and 
      are constrained by the Law of Total Probability (Caswell, 2001). 

      <p>The life cycle for Bald Eagles generally 
      begins at hatchling, moves through an immature stage and then on to 
      breeding adult. However, Bald Eagles exhibit density dependence, 
      so some eagles may reach breeding age but fail to breed for several years or longer. 
      In these cases, breeding-age adults that do not reproduce regress 
      (in a mathematical sense) into the pooled immature/non-breeding adult stage, 
      where they remain until they 
      begin to participate in reproduction.</p>

      <p>For additional information on how life histories are distilled into matrix 
      models, refer to Caswell (2001).</p>
      "),
   easyClose=TRUE))})
 
 observeEvent(input$HelpboxLifeTableA,{
  showModal(modalDialog(
   title="How do I interpret this from the mathematical modeling perspective?",
   HTML("
      <p>The algorithm produced matrix vital rates for 
     various stages across a life history, from which the probability of reaching
     any given age was calculated.</p>

      <p>Lifetime probabilities are constrained by unity, so they 
      provide information on the relative likelihood that 
      any given bird will live to see any given birthday. For example, 
      this life table shows that it is about twice as likely that a 
      bird will live to age five than to age 10.</p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxLifeTableABio,{
  showModal(modalDialog(
   title="How do I interpret this from the biological perspective?",
   HTML("
     <p> A life table shows the probability that any given individual will 
     make it to each age. </p>
     <p> The probability of being hatched is 1, with declining 
     probabilties of survival as individuals move through their lifetime. </p>
     <p> Survival to any given age requires individuals to 
     navigate through the gauntlet of life. 
     Predation, lack of resources, 
     differing genetic fitness, disease, competition, differential harvest, 
     or any other variable may influence 
     how long any given indivdiual will live. At any rate, rapidly 
     declining life tables mean that survival to 
     old age is rare, while gentle slopes indicate that survival 
     to old age might be more likely. </p>

     <p> Because survival is the amalgamation of daily life, 
      different subpopulations in the same species 
      may have differing life tables. Life 
     tables may also differ among sexes.</p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxLifeTableAEco,{
  showModal(modalDialog(
   title="How do I interpret this from the ecological perspective?",
   HTML("
     <p>The probability of being hatched is 1.
     A certain percentage of individuals will 
     die before their first birthday. Of the ones that 
     survived to their first birthday, some subset will die 
     before their second birthday. The pattern repeats, clear 
     up to senescence, where the probability of living to a 
      ripe old age is the lowest.</p> 

     <p> Significant cliffs in the steepness of the life table 
     reveal problematic ages for individuals. </p> 
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxLifeTableAMgmt,{
  showModal(modalDialog(
   title="How do I interpret this from the resource management perspective?",
   HTML("
     <p>The probability of being hatched is 1.
     A certain percentage of individuals will 
      die before their first birthday, meaning that the probability 
     of surviving to age 1 is less than one. Similarly, others 
     that survived to their first birthday will die before their second birthday, and so on.
      The probabilty of surviving to senescence is the lowest on the entire life table.</p> 
      
      <p> Significant cliffs in the steepness of the life table 
      reveal problematic ages for individuals. Management that 
     is designed to relieve mortality at certain ages can 
    increase the number of animals that live to old age. </p> 
      "),
   easyClose=TRUE))})
 
 observeEvent(input$HelpboxAnnualA,{
  showModal(modalDialog(
   title="How do I interpret this from the mathematical modeling perspective?",
   HTML("
      <p>The combinatorial algorithm was programmed to collect all models with 
      trajectories that generated total sum
      distances that fell within 16 eagles. Empirical auxiliary information was used to 
      pare down the list of plausible models to those conditions known to be true in the Northeast. </p>
      <p> The graph shows the 
      high and low range of stage-wise abundances of eagles at the onset of 
      each January for the set of algorithm-predicted models. Notice that hatchlings are not 
      present in January because the previous 
      year's hatchlings would have already fledged and joined the immature stage (blue). </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxAnnualABio,{
  showModal(modalDialog(
   title="How do I interpret this from the biological perspective?",
   HTML("
      <p>Change in abundance is of primary concern 
      in biology, ecology, and conservation (Morris & Doak, 2004). 
      Quantification of changes to population abundances aids in identifying 
      whether populations are of conservation concern, in peril of extinction, growing too
      quickly, replenishing, recolonizing, recovered, or in need of targeted
      management. </p>
      <p>This graph shows that the recovery of Bald Eagle populations in the Northeast have 
      produced a surplus
      of non-breeding adult and immature eagles. Today, we have an order of magnitude more 
      non-breeding eagles than breeding eagles. Despite this discrepancy in ages, the overall abundances
      continue to rise. Such surplus of non-breeding adults are not rare in this life history; 
      similar dynamics have been recorded in the species in other areas of North America (Hansen & Forbes, 1985).</p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxAnnualAEco,{
  showModal(modalDialog(
   title="How do I interpret this from the ecological perspective?",
   HTML("
      <p>Ecologists are often interested in the relationships among demographic rates, life-history 
      variation, and natural selection processes, which often involve the study of population 
       change due to vital rate variation over time and/or space 
      (Caughley, 1977; Gerber & Kendall, 2016). </p>
      
      <p> The shape of the curve that represents population abundance through time 
      is an important indicator of habitat quality and condition. When habitat resources are 
      limitless, unimpeded growth may ensue, resulting an an exponential growth curve. When habitat
      resources begin to dwindle, growth may taper, resulting in a logistic S-shaped curve. The top
      of the S shape provides a rough estimate of the quality of the habitat.</> 

      <p> This graph suggests that the 
      population of eagles in the Northeast has 
      increased dramatically since 1990. </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxAnnualAMgmt,{
  showModal(modalDialog(
   title="How do I interpret this from the resource management perspective?",
   HTML("
      <p>Biologists, ecologists, and resource managers
      pay special attention to population size when trying to 
      understand ecological processes, keep small populations from going extinct, 
      controlling pest populations, and in the management of populations that provide hunting, 
      fishing, and viewing opportunities as well as world-market food resources (Caughley, 1977). </p>
      <p>The change in population size over time describes the average 
      fitness and performance of the population (Fisher, 1930; Sibly, Forbes, & Hansen, 2002; Koons, Holmes, & Grand, 2007) and is therefore critically important in conservation and 
      management (Koons, Grand, & Arnold, 2006). </p>
      <p>In the case of Bald Eagles, this increase in population abundance 
     may have arisen from reproduction events of Northeast residents, 
      dispersion of immigrating eagles into the Northeast, or by some combination of both. </p>

      <p> This graph suggests that the 
      population of eagles in the Northeast has 
      increased dramatically since 1990. </p>
      "),
   easyClose=TRUE))})
 
 observeEvent(input$HelpboxBiannualA,{
  showModal(modalDialog(
   title="How do I interpret this from the mathematical modeling perspective?",
   HTML("<p>Having direct information on stage abundances in certain time periods
     can be beneficial in predicting dynamics that 
      can help guide management decisions (Hauser et al., 2006); 
      but for many animals this information is 
      not easily obtained (Stott et al., 2011). </p>
      <p>Recall that a population matrix model assumes that species can be 
      fruitfully subdivided into classes of individuals (ages & stages) 
      that share certain values of transitions and that these subdivisions represent important 
      transitions for the species as a 
      whole (Leslie, 1945; Lefkovitch, 1970; Caswell 1989; de Kroon et al. 2000). </p>
      <p> We
      derived the life history skeleton to have stage-structured bi-annual time periods, from which we calculated
      bi-annual stage-wise abundances across the time. This parameterization aids in 
      understanding how Bald Eagle populations in the Northeast shrink and swell over the 
      calendar year.</p>
      <p>This graph breaks the annual model matrix into three submatrices: one breeding
      period matrix and two non-breeding period matrices. The 
      breeding matrix represents conditions in the Northeast. 
      The first non-breeding period matrix
      represents the conditions in the Northeast, while the second non-breeding period matrix
      represents the conditions outside of Northeast. </p>
      <p> The 
      stage-wise abundances display the number of eagles that the algorithm predicted to have
      existed in the Northeast across each calendar year. </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxBiannualABio,{
  showModal(modalDialog(
   title="How do I interpret this from the biological perspective?",
   HTML("
      <p>This graph displays the number of eagles that the algorithm predicted to have
      existed in each life history stage across each calendar year. </p>
      <p>The accordian-like pattern in abundances arise
      from the fact that eagles migrate into and out of the Northeast 
      for the non-breeding period.</p>
      <p>The total number of individuals in any year is 
      obtained by adding all stage-wise abundances, although 
      common applications of population size consider abundances 
      in the adult stage only (IUCN, 2017).</p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxBiannualAEco,{
  showModal(modalDialog(
   title="How do I interpret this from the ecological perspective?",
   HTML("
      <p> The importance of oscillations in abundance of structured populations is 
      recognized in understanding wholistic ecology (Gerber & Kendall, 2016). </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxBiannualAMgmt,{
  showModal(modalDialog(
   title="How do I interpret this from the resource management perspective?",
   HTML("
      <p>Knowledge of seasonal fluctuations in abundances 
      aids managers in conducting proper inventory and in 
      identifying strategies to best manage wildlife populations.</p>

      <p>Biologists pay special attention to population size when 
      trying to understand ecological processes, keep small populations 
      from going extinct, controlling pest populations, and in the management 
      of populations that are used for hunting, fishing, and viewing opportunities (Caughley 1977; Koons, Holmes, & Grand 2007). </p>
      "),
   easyClose=TRUE))})
 
 observeEvent(input$HelpboxBiOneA,{
  showModal(modalDialog(
   title="How do I interpret this from the mathematical modeling perspective?",
   HTML("

      <p>The Bald Eagle life history is subdivided into three stages: a hatchling stage, an 
      immature and non-reproducing adult stage, and a breeding adult stage.</p>
      <p>Due to the discrete time parameterization of the matrix,
      and the birth-pulse designation of the reproduction events (Caswell, 2001), 
      hatchlings hatch, but these individuals are not counted
      during the breeding period. Rather, surviving hatchlings are
      censused for the first time during the subsequent non-breeding period. 
      Abundances of
      individuals in the first stage of life are therefore 
      recorded only in the non-breeding period of
      their first year. During the non-breeding period, surviving 
      hatchlings will fledge and join the
      immature stage, where they will be censused as stage 
      two individuals in the annual matrix.</p>
      <p> This reproductive parameterization means that hatchlings are not explicitly
      represented in the annual matrix, as hatchling census occurs at 
      mid-year (instead of the onset
      of each calendar year).</p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxBiOneABio,{
  showModal(modalDialog(
   title="How do I interpret this from the biological perspective?",
   HTML("
      <p>This graph shows the algorithm-predicted ranges in abundance of 
     hatchling eagles during the first non-breeding season of their lives. </p>

      <p>Due to the discrete time parameterization of the matrix,
      and the birth-pulse designation of the reproduction events (Caswell, 2001), 
      surviving hatchlings are
      censused for the first time during the subsequent non-breeding period. 
      During the non-breeding period, surviving hatchlings will fledge and join the
      immature stage. </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxBiOneAEco,{
  showModal(modalDialog(
   title="How do I interpret this from the ecological perspective?",
   HTML("
      <p>The entire breeding season lasts approximately 6 months. 
      This graph shows the number of algorithm-predicted hatchlings thought 
      to have survived to the onset of their first non-breeding period. </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxBiOneAMgmt,{
  showModal(modalDialog(
   title="How do I interpret this from the resource management perspective?",
   HTML("
      <p>Appropriate parameterization of a matrix model is a 
      challenging task; even with rich data sets, some 
      parameters may not be rigorously estimated (Mills, 2002). </p>
      <p>The combinatorial optimization algorithm yields predictions for hatchling
      abundances by drawing on correlations and dependencies in the life 
      history. Such information mining could not have been done 
      without detailed knowledge of the life history of the Bald Eagle and therefore, without excruciatingly 
      careful parameterizaton of the corresponding
      model matrix.</p>

      <p> Although these modeled abundances come from a model that is known to be 
      a parsimonious representation of reality,
      even imperfect information regarding hatchling abundances might be 
      helpful when and where empirical information does not exist.</p>
      "),
   easyClose=TRUE))})
 
 observeEvent(input$HelpboxBiTwoA,{
  showModal(modalDialog(
   title="How do I interpret this from the mathematical modeling perspective?",
   HTML("
      <p>A population matrix model assumes that species can be 
      fruitfully subdivided into classes of individuals (ages & stages) 
      that share certain values of transitions, as reflected in the structure of 
      the life cycles, and that these subdivisions represent important 
      transitions for the species as a 
      whole (Leslie, 1945; Lefkovitch, 1970; Caswell 1989; de Kroon et al., 2000; Caswell, 2001). </p>
      <p>Our Bald Eagle life history is subdivided into three stages: a hatchling stage, an 
      immature and non-reproducing adult stage, and a breeding adult stage.</p>
      <p> We assume that immature eagles are those individuals that are 
      in their second, third, or fourth
      years of life (USFWS, 2018). Once an individual reaches its fifth year, it may either 
      transition into stage three (breeding-adult stage) or remain in stage two. At any rate, 
      a stage two eagle is one that does not reproduce. </p>
      <p> In the model, there is no limit to the number of years that an adult-aged 
      eagle may remain in stage two. However, regression of a breeding eagle into 
     non-breeding status is limited; eagles that have previously paired and bred 
     tend to continue doing so each sequential year 
    until their death. Previously paired eagles can regress when one mate is killed (USFWS, 2018). </p>
     <p> This parameterization means that the previous year's hatchlings will be pooled into 
       the immature class in the next breeding season. This second stage of eagles can therefore 
     contain birds of any age.</p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxBiTwoABio,{
  showModal(modalDialog(
   title="How do I interpret this from the biological perspective?",
   HTML("
      <p>This second stage of eagles can contain birds of any age.</p>
     <p> The bi-annual parameterization means that the previous year's hatchlings will be pooled into 
       the immature class as early as the breeding season in their second year of life. Similarly, breeding-aged adults
       that do not breed may inhabit stage two in any year of their life. </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxBiTwoAEco,{
  showModal(modalDialog(
   title="How do I interpret this from the ecological perspective?",
   HTML("
      <p>Matrix models have multiple applications that make 
      them flexible and useful tools for extending biological scale dynamics into 
     ecological scale 
      questions (Alberts & Altmann, 2003).
      <p> Population dynamics are notoriously difficult to predict, even when those populations are not 
      strongly influenced by density-dependent processes (Townley & Hodgson, 2008). 
      External drivers of variation, 
      such as unpredictable climates, natural disturbances, fluctuations in resource 
      availability and attack by natural enemies, interact with internal drivers that 
      include demographic stochasticity, age- and stage-structuring, and short-term 
      (transient) responses to disturbance (Townley & Hodgson, 2008). </p>

      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxBiTwoAMgmt,{
  showModal(modalDialog(
   title="How do I interpret this from the resource management perspective?",
   HTML("
      <p> When wildlife managers engage in targeted management, an important task is to identify 
      the ecological-scale effect of such activities.</p>
      <p> Bald eagles underwent professional reintroduction in the NE USA in the 1990's. 
       The model shows that changes to their abundances started out slowly, but then abundances
       began soaring only a few years later, leading to their region-wide recovery. 
      Today, the model predicts continued population growth and a surplus of non-breeding
       adults. Could this structure be a function of our management, a function of the life history
       of the eagle, or some combination of both? </p>
      "),
   easyClose=TRUE))})
 
 observeEvent(input$HelpboxBiThreeA,{
  showModal(modalDialog(
   title="How do I interpret this from the mathematical modeling perspective?",
   HTML("

      <p>The Bald Eagle life history is subdivided into three stages: a hatchling stage, an 
      immature and non-reproducing adult stage, and a breeding adult stage.
      This graph shows the algorithm-predicted abundances of the breeding adult stage.</p>
     <p> We assume that adults may begin breeding in their fifth year of life (USFWS, 2018), 
     although our model allows for younger eagles to reproduce in some situations,
      as has been observed in empirical systems in North America. </p>
      <p> Once an individual reaches its fifth year, it may either 
      transition into stage three (breeding adult stage) or remain in stage two (pooled immature
      and non-breeding adult stage). </p>
      <p> In the model, there is no limit to the number of years that an adult-aged 
      eagle may remain in the non-breeding adult stage before reproducing. </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxBiThreeABio,{
  showModal(modalDialog(
   title="How do I interpret this from the biological perspective?",
   HTML("
      <p> Bald Eagles generally begin reproducing in their fifth year of life 
      (USFWS, 2018), at which time they pair up and breed for life. Bald Eagles may choose a second mate if their original partner is killed (USFWS, 2018).</p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxBiThreeAEco,{
  showModal(modalDialog(
   title="How do I interpret this from the ecological perspective?",
   HTML("
      <p>Breeding eagles may or may not migrate. Regardless of where they spend the non-breeding season, 
     breeding pairs tend to return each year to their preferred nesting territories, where
      they co-raise their young and defend habitat resources from other eagles (USFWS, 2018).</p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxBiThreeAMgmt,{
  showModal(modalDialog(
   title="How do I interpret this from the resource management perspective?",
   HTML("
      <p>Fidelity to nesting territories, life-long nesting behavior, 
     and unmistakable plumage of eagles make
     annual counts of breeding females reliable estimates of reproduction. Indeed, such 
     desireable characteristics aid in the collection of accurate annual counts of the species. 
    Although most annual counts of females are conducted by professional biologists, several 
     citizen organizations have also been successful in producing reliable counts of 
     breeding adults. Thank you to everyone who has participated in eagle counts!</p>
      "),
   easyClose=TRUE))})
 
 observeEvent(input$HelpboxBreedA,{
  showModal(modalDialog(
   title="How do I interpret this from the mathematical modeling perspective?",
   HTML("
      <p>Although counts of breeding females in the breeding period were used to train the algorithm, 
    this graph still compares algorithm-predicted abundances of breeding females (grey) to 
     empirical counts (green). Superimposed on 
    this graph are algorithm-predicted abundances of all other non-reproducing females that are also present during the breeding season. </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxBreedABio,{
  showModal(modalDialog(
   title="How do I interpret this from the biological perspective?",
   HTML("
      <p>Not all eagles breed, even if they are 
     perfectly capable of doing so. Behavior, habitat, resource, 
     disease, inter- or intra-specific competition, or 
    other biological or environmental factors may cause some 
    subset of fecund individuals to forgo reproduction. </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxBreedAEco,{
  showModal(modalDialog(
   title="How do I interpret this from the ecological perspective?",
   HTML("
      <p>Not all eagles breed, even if they are 
     perfectly capable of doing so. Behavior, habitat, resource, 
      disease, inter- or intra-specific competition, or 
      other biological or environmental factors may cause some 
      subset of fecund individuals to forgo reproduction. </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxBreedAMgmt,{
  showModal(modalDialog(
   title="How do I interpret this from the resource management perspective?",
   HTML("
      <p>Not all females breed, even if they are 
     perfectly capable of doing so. This graph shows that relative 
     abundances of breeding females is much smaller than 
     relative abundances of non-breeding females. Management that modifies survival of one 
    class over the other may have a disproportionate effect on population dynamics.</p>
      "),
   easyClose=TRUE))})
 
 observeEvent(input$HelpboxNonA,{
  showModal(modalDialog(
   title="How do I interpret this from the mathematical modeling perspective?",
   HTML("
      <p>The non-breeding period contains two segments of a population: year-round
      residents of the Northeast and those migrating eagles that spent the breeding season 
      elsewhere but the non-breeding season in the Northeast. The graph treats this latter 
      segment of birds as a single group of incoming migrants,
      regardless of where they 
      originate. </p>
      <p> Information on the abundances of seasonal incoming migrants is not contained 
      in the resident time series, so abundances in this 
    segment of the population are challenging to quantify (hence the imprecise estimation of individuals).</p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxNonABio,{
  showModal(modalDialog(
   title="How do I interpret this from the biological perspective?",
   HTML("
      <p>Migration is foundational in the life cycle of Bald Eagles, yet patterns 
     of migration are notoriously hard to quantify. In our study area alone, 
     eagles have been observed to disperse or migrate in every cardinal direction, 
     while some don't migrate at all. </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxNonAEco,{
  showModal(modalDialog(
   title="How do I interpret this from the ecological perspective?",
   HTML("
      <p>Migration is foundational in the life cycle of Bald Eagles. 
      Much literature exists on the pros and cons of migration.</p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxNonAMgmt,{
  showModal(modalDialog(
   title="How do I interpret this from the resource management perspective?",
   HTML("
      <p> This graph shows the algorithm-predicted abundances of females in the 
      non-breeding season. These abundances may be helpful to managers in 
      identifying whether season-specific protections should be enacted, 
     whether development permits should be written to mitigate for 
     seasonal influx of females, or for advertising bird 
     watching or other recreational activities.</p>
       "),
   easyClose=TRUE))})
 
 observeEvent(input$HelpboxMigrationA,{
  showModal(modalDialog(
   title="How do I interpret this from the mathematical modeling perspective?",
   HTML("
      <p>Year-round residents spend the breeding and non-breeding periods in the Northeast, so any impact made to 
      these eagles will influence the Northeast growth rates.</p>

      <p>Part-year residents spend the breeding period in the Northeast and the non-breeding period 
      outside of the Northeast.
      In the model, these migrating eagles contribute to the growth rate in the Northeast, so any impact made to 
      these eagles will influence the Northeast growth rates.</p>
      
      <p>Some eagles that originate in the Northeast will disperse from their natal territories. 
      These eagles will contribute to the growth rate in their recipient area. </p>
      
      <p>Eagles that breed (or otherwise spend the breeding period) outside of the Northeast 
      but temporarily visit the Northeast during the non-breeding period may temporary 
      increase count abundances in the Northeast, but otherwise do not impact the 
      growth rate in the Northeast. </p>
      
      <p>Eagles that relocate to the Northeast will 
      begin influencing the Northeast growth rate during the breeding period that follows their arrival.</p>
      
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxMigrationABio,{
  showModal(modalDialog(
   title="How do I interpret this from the biological perspective?",
   HTML("
      <p>Once adult eagles select their desired breeding territory, they tend to 
      return to the same nest year after year (USFWS, 2018). In our model, 
      all birds are allowed to migrate, 
      but to simplify the accounting of population growth, 
      any contribution made by a bird to the growth of the population 
      is allocated to the area in which that bird spends the breeding period.</p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxMigrationAEco,{
  showModal(modalDialog(
   title="How do I interpret this from the ecological perspective?",
   HTML("
      <p>Population dynamics are the result of losses and gains of 
      individuals in the population and therefore result from key demographic 
      processes that include emigration and immigration 
      (Sibly & Hone, 2002; Schaub & Abadi, 2011). </p>
      <p>Dispersal occurs when an eagle permanently departs 
      its natal territory, while migration occurs when eagles 
      depart and return in a cyclical (typically seasonal) pattern. Bald Eagles are observed to 
      participate in both types of movements.</p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxMigrationAMgmt,{
  showModal(modalDialog(
   title="How do I interpret this from the resource management perspective?",
   HTML("
      <p>Inventory, management, and study of Bald Eagle ecology 
     follow seasonal cycles that are often timed with regional migrational patterns. </p>
      "),
   easyClose=TRUE))})
 
 observeEvent(input$HelpboxGrowthRatesA,{
  showModal(modalDialog(
   title="How do I interpret this from the mathematical modeling perspective?",
   HTML("
      <p> The dominant eigenvalue suggests growth or decline of a 
     population over long time frames.</p>
      <p> Matrix models assess population abundances under 
      stable population theory (Lebreton, 2005), which connects a fixed set of fertility, 
      migration, and mortality rates with the population dynamics 
      that they generate (Tuljapukar, 2008). 
      In a system with three stages, the population matrix will have three 
      (typically) distinct eigenvalues, the largest of which is defined as dominant. The dominant 
      eigenvalue of the matrix is the finite rate of growth of the system 
      and is used to trace causes and 
      consequences of population change over long-term, or asymptotic, time scales (Caswell, 2001).</p>
      
      <p> The magnitude of the dominant eigenvalue does not project what will happen, rather 
      it demonstrates what can be expected if the vital rate magnitudes 
      were to remain static across long time frames. A dominant eigenvalue greater than one means 
      the population can be expected to increase, less than one means that 
      the population can be expected
      to decline to extinction, and a dominant eigenvalue equal to one 
      means the population will neither
      increase nor decrease.</p>
      <p> The mathematical nature of the eigenvalue also gives information about population cycles.
      Provided that the matrix elements are nonzero (i.e.: that every reproduction event 
      and transition are biologically plausible), the dominant eigenvalue is 
      guaranteed by the Perron-Frobenius theorem to be real. If at least one matrix element 
      is equal to zero, 
      the dominant eigenvalue may be a complex number. If the dominant eigenvalue is 
     real, the asymptotic growth 
      will exhibit a monotonic trend, but if it is complex, cyclic 
      long-term population dynamics can be expected to ensue.</p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxGrowthRatesABio,{
  showModal(modalDialog(
   title="How do I interpret this from the biological perspective?",
   HTML("
      <p>The dominant eigenvalue is the long term growth rate.</p>
      <p>The interpretation of the growth rate is straightforward. Provided that the relative 
      abundance of each stage is at its stable stage distribution, a dominant eigenvalue greater 
      than one means that the population can be expected to increase indefinitely; 
      a dominant eigenvalue less than one indicates the
      population can be expected to decrease to extinction; a dominant eigenvalue 
      equal to one signals that the population 
      abundance can be expected to remain static. </p>
      
      <p>In addition to giving information on how such a stable population would grow, 
      the population growth rate also describes the average fitness and performance of the 
      population (Fisher, 1930; Sibly, Forbes, & Hansen 2002; Koons, Holmes, & Grand, 2007). </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxGrowthRatesAEco,{
  showModal(modalDialog(
   title="How do I interpret this from the ecological perspective?",
   HTML("
      <p>The magnitude of the dominant eigenvalue does not project what will happen; 
      it demonstrates what can be expected if the vital rate magnitudes 
      were to remain static across long time frames. 
      The asymptotic growth rate therefore provides information about 
      the conditions under which the observed population arose, and not about
      any future environment. </p> 
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxGrowthRatesAMgmt,{
  showModal(modalDialog(
   title="How do I interpret this from the resource management perspective?",
   HTML("
      <p>The dominant eigenvalue (finite growth rate) of the population 
      is of seminal importance in resource inventory, management, and policy. 
      For example, the dominant eigenvalue has been used by decision makers for national 
      and international protections (IUCN 2018), and has played an instrumental role in 
      prompting actions to reverse population declines in threatened or endangered species 
      (Morris & Doak, 2002; Salguero-Gomez et al., 2014; Salguero-Gomez et al., 2016). </p>
      <p> Formal recommendations for national and global conservation require quantified biological 
      justification (IUCN 2018). It is common for biologists to cite results arising from their 
      population viability analyses as justification for such recommendations (McGowan et al., 2017).
      Ominous dominant eigenvalues 
      have been cited when management decisions are assessed or finalized (e.g. Noon & Biles, 1990). </p>
      <p>Despite its importance, the dominant eigenavlue might not adequately describe 
     the condition of the species. Transient 
     population analysis 
     can reveal the possible effects of initial age or stage structure (Fox & Gurevitch, 
      2000), colonization (Caswell & Werner, 1978), life history (DeAngelis et al., 1980), 
     harvest, and especially pulse perturbations to the environment (e.g., catastrophic mortality) 
     on population dynamics (Koons et al., 2005). Because the dominant eigenvalue specifies 
     growth of a static and stable system over the long term, it can be a 
     biased estimate of population growth when short-term population 
     pertubations exist (Koons et al., 2005).</p>
      "),
   easyClose=TRUE))})
 
 observeEvent(input$HelpboxSurvivalA,{
  showModal(modalDialog(
   title="How do I interpret this from the mathematical modeling perspective?",
   HTML("
      <p>The equations that map the vital rates to the eigenvalues are not
      one-to-one, meaning that several sets of vital rates can produce identical eigenvalues.</p>
     <p> The combinatorial optimization algorithm was trained to identify several sets of 
      matrix elements that could have produced the empirical time series data of the breeding stage.</p>
     <p> Recall that each matrix element is a compound number containing vital rates and transition
       probabilities. Given the algorithm-predicted magnitude of the 
       matrix elements, the corresponding survival rate for that stage may be calculated.</p>
     <p> The graphs show the distribution of survival rates for each period. 
      Notice that high values of some vital rates may be balanced by low values of others. 
       Also notice that there are a few vital rates that must fall within certain values. </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxSurvivalABio,{
  showModal(modalDialog(
   title="How do I interpret this from the biological perspective?",
   HTML("
     <p> There is an entire scientific discipline dedicated to identifying evolutionary 
     trade-offs in life history stategy. Life history strategies evolve in much the same way
     that populations evolve. For example, is it better for a species to 
     reproduce earlier in the life cycle or later in the life cycle? Shall
     low survival of early stages be balanced out by long-lived iteroparous adults? 
     Among the variety of uses, matrix models have also been 
      used to study these types of life history 
      trade-offs (Caswell, 2001). </p>
     <p>These graphs show the distribution of plausible survival rates 
     for each life history stage. These graphs suggest that certain 
     vital rate values may be a hallmark of this life 
    history strategy, while others vital rates are more likely to vary 
    across the entire spectrum of possibilities.</p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxSurvivalAEco,{
  showModal(modalDialog(
   title="How do I interpret this from the ecological perspective?",
   HTML("
     <p> There is an entire scientific discipline dedicated to identifying evolutionary 
     trade-offs in life history stategy. Life history strategies evolve in much the same way
      that populations evolve. For example, is it better for a species to 
      reproduce earlier in the life cycle or later in the life cycle? Shall
      low survival of early stages be balanced out by long-lived iteroparous adults? 
      Among the variety of uses, matrix models have also been 
      used to study these types of life history 
      trade-offs (Caswell, 2001). </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxSurvivalAMgmt,{
  showModal(modalDialog(
   title="How do I interpret this from the resource management perspective?",
   HTML("
      <p>Accurate estimates of survival are essential in almost all 
      branches of ecology (Gilroy, Virzi, Boulton, & Lockwood, 2012). 
      Projections of abundances hinge on reliable estimates of 
      survival, as even small errors in estimation 
      will be propagated through time. </p>
      "),
   easyClose=TRUE))})
 
 observeEvent(input$HelpboxSSDA,{
  showModal(modalDialog(
   title="How do I interpret this from the mathematical modeling perspective?",
   HTML("
      <p> A theory and three theorems describe population dynamics when biological and environmental 
      conditions remain static in the long term. Stable population
      theory states that a fixed set of vital rates give rise to 
      population-scale dynamics that they generate (Tuljapurkar, 2008). Stable population theory yields 
      the Fundamental Theorem of 
      Demography and the Strong and Weak Theorems of Ergodicity (Arthur, 1982). </p>
      
      <p>The Fundamental Theorem of Demography states that a matrix can be spectrally decomposed 
      into eigenvalues and vectors, from which arise the equations 
      to determine the asymptotic (long term) 
      behavior and non-asymptotic 
      (transient) system-scale behavior (Fox & Gurevitch, 2000; Stott et al., 2011). </p> 
      
      <p>The Strong Ergodic Theorem of Demography 
      states that if survival and fertility remain static, the population growth will 
      stabilize to an asymptotic growth rate, and the population dynamics will become 
      independent of initial conditions (Arthur, 1982). </p>
      
      <p>The Weak Ergodic Theorem of 
      Demography states that if two populations with the same architecture are subject to 
      the same conditions - even if they start out with different age compositions - they 
      will converge to have identical asymptotic dynamics (Arthur, 1982).</p> 
      
      <p>All three theorems form the foundation of the stable stage distribution. 
      In the math, the stable stage distribution 
      is the dominant right 
      eigenvector corresponding to the dominant eigenvalue (Caswell, 2001). 
      When the dominant eigenvector is standardized to 1, the elements of this vector 
      specify the proportion of individuals in each stage that must exist 
      for the system to grow (or decline) at the stable growth rate. </p>

      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxSSDABio,{
  showModal(modalDialog(
   title="How do I interpret this from the biological perspective?",
   HTML("
      <p>The stable stage distribution gives the proportion of 
      individuals that need to exist in each
      stage of the life history in order for the population to grow at the stable growth rate. </p>
      
      <p>The stable stage distribution is often scaled into stable 
      stage proportion (SSP) so that the elements sum to one. 
      For example, an SSP of .3, .5, and .2, suggests that the system 
     needs to contain 30% stage I individuals, 
      50% stage II individuals, and 20% stage III individuals in order to 
      grow at the stable asymptotic growth rate.</p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxSSDAEco,{
  showModal(modalDialog(
   title="How do I interpret this from the ecological perspective?",
   HTML("
     <p>The stable stage distribution may be used to assess whether growth 
     is stable and controlled through natural 
      population dynamics rather than by transient influences of historic 
      population structure or by other influences
      such as management or environmental stochasticity (Stott et al., 2011).</p>

      <p> Deviations from stable stage structure may be used to identify if and to what extent
      environmental changes have influenced population growth. A long period of one structure followed
      by a shift to a different stable-structure may indicate a shift in environmental 
      conditions, a shift in the life cycle of the organism, or a simultaneous shift in both (Stott et al., 2011).</p>

      <p> Deviations from the stable stage distribution can be used to understand the impact of
      external mechanisms to natural population dynamics. For example, an excess of individuals in 
      one stage may indicate that survival is unnaturally high in that population. Similarly, a dearth
      of individuals in one stage might indicate a targeted issue with survival. </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxSSDAMgmt,{
  showModal(modalDialog(
   title="How do I interpret this from the resource management perspective?",
   HTML("
      <p> Stable stage distributions can be thought of as a baseline 
      reference for the population. </p>

      <p>Among other uses, the stable stage distribution may be used for reintroduction 
      planning to ensure that anthropogenic reintroduction activities are not antagonistic to 
      natural population dyanmics (Koons, Holmes, & Grand, 2007; Kissel et al., 
      2014; Hanley et al., 2019).</p>

      <p>A population that is reintroduced in SSD will exhibit stable, 
      monotonic population growth, 
      while a population that is reintroduced out of SSD may 
      exhibit transient dynamics such as 
      amplification and attenuation. Attenuation may produce synthetic 
      bottlenecks which
      result in dispartities between the effective and census population sizes.</p>

      <p> Genetic diversity is crucial in ensuring a population is well 
      equipped to overcome a change in conditions or an 
      oubreak of a disease in wild populations. Reintroduction in 
      concert with the SSD ensures that managerial actions are not antagonistic to the
      the population's evolutionary readiness.</p>
      "),
   easyClose=TRUE))})
 
 observeEvent(input$HelpboxReprodA,{
  showModal(modalDialog(
   title="How do I interpret this from the mathematical modeling perspective?",
   HTML("
      <p>Eigenvectors arise through spectral decomposition of the model matrix (Lax, 1997). </p> 
      <p>Associated with the dominant eigenvalue is the dominant left eigenvector, which 
      specifies the stage-wise reproductive value for members of that life stage (Caswell, 2001). </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxReprodABio,{
  showModal(modalDialog(
   title="How do I interpret this from the biological perspective?",
   HTML("
      <p>The reproductive value vector gives the reproductive contribution of individuals in each
      stage when the population is growing at the stable growth rate. </p>
      
      <p>The reproductive value vector is frequently scaled so that the elements sum to one. 
      A reproductive value vector of
      .2, .5, and .3, suggests that members of stage I contribute .2, members of stage II 
     contribute .5, and members of stage III contribute .3 
      individuals to the next generation. </p> 
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxReprodAEco,{
  showModal(modalDialog(
   title="How do I interpret this from the ecological perspective?",
   HTML("
      <p>The reproductive value vector gives the reproductive 
      contribution of individuals in each
      stage when the population is growing at the stable growth rate. </p>
     <p>Breeding adults have the highest reproductive value, followed by 
      individuals that are arriving at reproductive age. Although youthful individuals
      have reproductive potential, they must survive additional time units prior to 
      contributing to the next generation, so their value is lower. To this end, reproductive value of a 
     single individual changes over the course of its own lifetime. </p>
     <p>Changes in life history strategies can impact the reproductive value 
      of individuals. For example, early reproduction is 
      advantageous in expanding populations, while 
      delayed reproduction is selected in declining populations 
      (Mertz, 1971; Charlesworth, 1980; Lande, 1982).</p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxReprodAMgmt,{
  showModal(modalDialog(
   title="How do I interpret this from the resource management perspective?",
   HTML("
      <p>Targeted management must be tailored to the management goals, situation, and 
      life history of the species of interest. 
      Reproduction of wild individuals is only desirable if managers wish to grow or 
      maintain a population. In the case of noxious species, reproduction is undesireable.</p>

      <p> Knowledge of reproductive value may aid managers in identifying how best to increase, halt, or 
      stall population growth. For example, should managers wish to increase population growth,
      they may install protections to ensure that the individuals that are actively breeding 
      (or near to breeding age) are able to continue. Similarly, if managers wish to ensure that 
      sufficient reproduction will occur in several years from now, it behooves managers to enact
      protections for young, up-and-coming individuals.</p>
      "),
   easyClose=TRUE))})

 observeEvent(input$HelpboxSenseA,{
  showModal(modalDialog(
   title="How do I interpret this from the mathematical modeling perspective?",
   HTML("
      <p>The sensitivity of the dominant eigenvalue with respect to a matrix element 
      is defined as the change exhibited by the dominant eigenvalue consequent to an 
      instantaneous change to the matrix element while all other matrix elements 
      are held constant (de Kroon, van Groenendael, & Ehrlen 2000; Caswell 2001). In other words, it is a partial derivative.</p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxSenseABio,{
  showModal(modalDialog(
   title="How do I interpret this from the biological perspective?",
   HTML("      
     <p> Sensitivity analysis is used to determine the functional 
      relationship between the growth rate and the constituent vital rates 
      (e.g. Pinero, 
      Martinez-Ramos, & Sarukhan, 1984; Crouse, Crowder, & Caswell, 1987; 
      de Kroon, van Groenendael, & Ehrlen 2000; & Koons et al., 2005, and others).</p> 
      <p>When the dominant eigenvalue is interpreted as a measure of 
      population fitness, the sensitivity of each vital rate can be interpreted
      as the selection gradient on that trait (Lande, 1982; Shyu & Caswell, 2014).</p>

      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxSenseAEco,{
  showModal(modalDialog(
   title="How do I interpret this from the ecological perspective?",
   HTML("
      <p>Matrix models are frequently used to identify management activities that may 
      be used to attain desired population goals. Managers deliberately alter a 
      life history characteristic to achieve a desired growth rate. But these targeted 
      management activities do not equate to clear-cut cause and effect. </p>

      <p> The characteristic balance equation of the model matrix 
      suggests that for every action, there is 
      an equal reaction. This means that changes to vital rates in one area of the system
      will change the magnitude and direction of the functional relationship of other vital rates
      with the dominant eigenvalue. Small changes in environmental conditions may reveal 
      vulnerabilities in the system to changing environmental conditions.</p>
      <p> To see how changes in vital rates may generate vulnerabilities in other 
      areas,interact with the IsoPoPd app, located on the Cornell tools page. </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxSenseAMgmt,{
  showModal(modalDialog(
   title="How do I interpret this from the resource management perspective?",
   HTML("<p> Matrix models are helpful in identifying suitable 
      management alternatives and evaluating the effectiveness of those 
      alternatives (Caswell 2001; Morris & Doak, 
      2002; Gerber & Kendall, 2016). </p>
      <p>Investigations into how a single transition influences 
      the dominant eigenvalue have settled on the conclusion that the magnitude 
      and direction of influence of a biological transition is situational 
      (de Kroon, van Groenendael, & Ehrlen 2000; Shyu & Caswell, 2014). 
      It follows that there is no
      single decision rule when selecting management strategies 
      that minimize undesirable population dynamics. 
      The full system-level impact of each hypothetical pertubation 
      must be assessed on a case-by-case basis.</p>
      "),
   easyClose=TRUE))})
 
 observeEvent(input$HelpboxElastA,{
  showModal(modalDialog(
   title="How do I interpret this from the mathematical modeling perspective?",
   HTML("
      <p>Asymptotic elasticities are defined as the proportional change in the dominant 
      eigenvalue produced by a proportional infinitesimal change in one 
      vital rate (de Kroon, van Groenendael, & Ehrlen, 2000). This measurement 
     identifies the rank of 
      relative importance of each vital rate to the dominant eigenvalue, 
      and therefore pinpoints the vital 
      rate that has the highest functional influence on population trajectories 
     (de Kroon, van Groenendael & Ehrlen, 2000; Morris & Doak, 2002). </p>

      
      <p>The equations show that the magnitude of the elasticity is situational; it
      depends on all the values of the entire set of vital rates (de Kroon, van Groenendael, & Ehrlen, 2000).</p>
      
      <p>The elasticities sum to one, so elasticities may be compared. </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxElastABio,{
  showModal(modalDialog(
   title="How do I interpret this from the biological perspective?",
   HTML("
      <p>Variation in the magnitude of a single vital rate will 
      differentially influence long term growth rates of biotic systems 
      (de Kroon, van Groenendael, & Ehrlen, 2000). 
      The elasticity of the dominant eigenvalue reveals the response of the dominant 
      eigenvalue by percent changes to matrix elements, and therefore identifies 
      life history characteristics that disproportionally influence population trajectories.</p>
      
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxElastAEco,{
  showModal(modalDialog(
   title="How do I interpret this from the ecological perspective?",
   HTML("
      <p>Life history strategies are shaped in part by the biology and in part by
      the conditions in the environment. Elasticity rankings provide insight
      into evolutionary forces that mold the life history strategy.</p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxElastAMgmt,{
  showModal(modalDialog(
   title="How do I interpret this from the resource management perspective?",
   HTML("
      <p>Sensitivity and elasticity are long-established, widely used tools for 
      pinpointing influential places in a life history
      (e.g., Crouse et al., 1987; Caswell, 2001; Saltelli et al., 2004; Lee, 2017). </p>
      
      <p> Dominant elasticities 
      are popular tools among resource managers; these demographic quantities go 
      beyond identifying a problem and help 
      define the most effective solution (Mills, 2002). For example, sensitivity 
      calculations are useful in ranking prescription alternatives 
      (Kissel et al., 2014), accessing 
      adaption regimes to theoretical perturbations (Mills, 2002; Lee, 2017), justifying harvest 
      management decisions (de Kroon, van Groenendael, & Ehrlen, 2000), updating management 
      strategies (eg: Crouse et al., 1987), establishing control measures 
      of pest and invasive species (Shea, 1998), providing conservation assessment 
      (McGowan et al., 2017; IUCN 2018), 
      guiding policy (McGowan et al., 2017; IUCN 2018), and more. </p>
      
      <p> Elasticities identify the rank of relative importance of each vital rate 
      to the dominant eigenvalue, 
      and therefore pinpoint the vital rate that has the highest functional 
     influence on the asymptotic growth rate 
      (de Kroon, van Groenendael & Ehrlen, 2000; Morris & Doak, 2002). Because elasticities 
      sum to one, elasticities provide for comparisons of the relative importance 
      of vital rate transitions, and illustrate the relative susceptibility 
      of the population to targeted management 
      activities (de Kroon, van Groenendael & Ehrlen, 2000). </p>
      "),
   easyClose=TRUE))})
 
 observeEvent(input$HelpboxDampA,{
  showModal(modalDialog(
   title="How do I interpret this from the mathematical modeling perspective?",
   HTML("
     <p>Disturbances to population structure cause bumps or declines in abundances. 
      In the absence of further 
      disturbance, such transient dynamics would 
      dampen and the population would settle back to stable state 
      (Stott et al., 2011). The time taken for a 
      system to regain stable status is called the transient period (Stott et al., 2011). </p>
      <p>A model matrix can be spectrally decomposed into a series of eigenvalues.
      The ratio between the dominant eigenvalue modulus 
      and the subdominant eigenvalue modulus is the damping 
      ratio, which measures the scope of the transient period (Caswell, 2001). </p>

      <p>A damping ratio >>1 
      indicates a rapid return to stable-status (Caswell, 2001), while a ratio of 1 means 
      that the effects of the disturbance are long-lived. </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxDampABio,{
  showModal(modalDialog(
   title="How do I interpret this from the biological perspective?",
   HTML("
      <p>The damping ratio provides a natural link between individual-scale and genetic-scale dynamics. </p>
      <p> Population abundance is usually defined as the total number of adult individuals 
      of the taxon (Graur & Li 2000; IUCN 2018). But a high number of 
      animals does not automatically imply population viability 
      (Gotelli, 2004; Kliman, Sheehy, & Schultz, 2008). </p> 
      
      <p> The level of genetic variation in a population reflects an ever-changing 
      balance between processes that increase and remove genetic variation 
      (Kliman, Sheehy, & Schultz, 2008). 
      Fluctuations of abundances at the individual scale impact the 
      level of genetic variation in the population 
      (Graur & Li, 2000; Kliman, Sheehy, & Schultz, 2008). </p>
      
      <p> Transient population oscillations cause arithmetic and effective 
      population sizes to diverge, a 
      discrepancy often magnified by only a few low abundance years (Gotelli 2004). 
      The arithmetic mean is defined as the average number of 
      individuals in a population across time (Gotelli, 2004),
      while the harmonic mean is the equivalent size of the population with completely 
      random mating (Graur & Li, 2000; Gotelli, 2004). The magnitude of 
     the effective population size determines the vulnerability of 
      the population to genetic variability removal by drift (Graur & Li 2000). </p>
      
      <p>Genetic drift is 
      the reason conservation biologists worry about species with small populations; 
      low effective population 
      sizes increase the probability that a deleterious allele will become fixed 
      (Graur & Li, 2000; Kliman, Sheehy, & Schultz, 2008; Charlesworth, 2009). </p>
      <p> The damping ratio
      can alert managers to elongated transient dynamics, increased fluctuations in stage-wise
      abundances, and therefore increase genetic risk. </p> 
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxDampAEco,{
  showModal(modalDialog(
   title="How do I interpret this from the ecological perspective?",
   HTML("
      <p>The damping ratio is a measure of how quickly fluctuations in abundances 
      resettle into their stable distributions (Caswell 2001). 
      The higher the damping ratio, the faster the system will recover from a disturbance. </p>

     <p> The damping ratio can be considered as a measure of the intrinsic 
       resilience of the population (O'Connor, 1993; Mollet & Cailliet, 2002; 
       Salguero-Gomez & Casper, 2010; Stott et al., 2011). </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxDampAMgmt,{
  showModal(modalDialog(
   title="How do I interpret this from the resource management perspective?",
   HTML("
      <p> Most sensitivity analyses have focused on long-term (i.e., asymptotic) 
      dynamics (see studies in Salguero-Gomez et al., 2014; Salguero-Gomez et al., 2016; 
      Gerber & Kendall, 2016). 
      For example, it is attractive to calculate 
      elasticities, and then enact the management alternative 
      that has the highest functional influence on the growth rate. </p>
      
      <p>However, vital rates with low elasticity rankings 
      have strong potential to influence transient dynamics (Yearsley, 2004; Gerber 
      & Kendall, 2016). The damping ratio may be used to 
      assess whether a targeted management activity will 
      impact system behavior beyond the growth rate. </p>
      
      <p>Targeted management under the asymptotic paradigm can incite damaging 
      effects on the effective population size. 
      Since management actions are themselves perturbations, management alternatives 
      may incite population fluctuations that draw down genetic variability. 
    For example, it is possible to increase the growth rate while simultaneously 
      inducing severe transient fluctuations. Because the rate of 
      decay in genetic diversity depends on the effective population size, rather than 
      the actual or census size (Graur & Li 2000; Frankham 2005), any management 
      alternative that causes a discrepancy between the harmonic and arithmetic means may undermine recovery efforts.
      It is prudent to consider both asymptotic and transient 
      dynamics when selecting managment strategies (Frankam, 2005).</p>
      
      "),
   easyClose=TRUE))})
 
 observeEvent(input$HelpboxCumuA,{
  showModal(modalDialog(
   title="How do I interpret this from the mathematical modeling perspective?",
   HTML("
      <p>Cumulative growth measures growth at each time step. The cumulative growth rate 
     depends on the sequence of habitat states where the states are
      not assumed to be constant through time (Tuljapurkar, 2003). </p>
"),
   easyClose=TRUE))})
 observeEvent(input$HelpboxCumuABio,{
  showModal(modalDialog(
   title="How do I interpret this from the biological perspective?",
   HTML("
      <p> Cumulative growth is used to assess whether realized population growth is smooth, 
      stair-stepped, or some combination of both. 
      Stair-stepped growth could indicate
      acute changes in environmental or management conditions, 
      changes in vital rates, or mortality events that function to produce 
      temporary disturbances in system behavior. Alternatively, smooth growth indicates stability of conditions. </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxCumuAEco,{
  showModal(modalDialog(
   title="How do I interpret this from the ecological perspective?",
   HTML("
      <p>Cumulative growth depends on the sequence of habitat states, and how those
      habitat conditions change through time (Tuljapurkar, 2003). </p>
     <p>The slope of the cumulative growth reveals whether the population is experiencing 
      exponential or logistic growth patterns. Exponential growth occurs when 
      ample resources fuel unimpeded population growth (Verhulst, 1838; Volterra, 
      1926; Lotka, 1932), while logistic growth occurs when 
      population abundances growth unimpeded at first, but then begin to deplete 
      availablility of resources 
      as abundances approach carrying 
      capacity (Verhulst, 1838; Volterra, 1926; Lotka, 1932). Changes 
in cumulative growth are used to detect such patterns through time. </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxCumuAMgmt,{
  showModal(modalDialog(
   title="How do I interpret this from the resource management perspective?",
   HTML("
      <p>To truly understand population dynamics, it is necessary to look 
     at the entire life history (Koons, Grand, & Arnold, 2006), 
      which includes how the life history
      behaves and 
      interacts with its natural or human-modified environments. </p>
      <p>Cumulative population growth shows the incremental step-wise changes in abundances and is used to pinpoint time units that experienced significant change. These 
      diagnostics help managers
      quantify cause and effect of management activites or environmental events.</p>
      "),
   easyClose=TRUE))})
 
 observeEvent(input$HelpboxStochA,{
  showModal(modalDialog(
   title="How do I interpret this from the mathematical modeling perspective?",
   HTML("
     <p> The stochastic growth rate is the time average cumulative growth
     over many time steps in one particular area (Tuljapurkar, 2003).</p>
      <p>Because any average is pulled in the direction of the outlier 
      (Ott, 2016), transient dynamics with temporarily large or small 
      growth rates will differentially influence the stochastic growth rate. However, long
      periods of stability will wash out this temporary effect.</p>
      <p>A stochastic growth rate above one means that the 
      population is increasing, below one means the population 
      is decreasing, and equal to one means the population is stable.</p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxStochABio,{
  showModal(modalDialog(
   title="How do I interpret this from the biological perspective?",
   HTML("
      <p>Although asymptotic analyses provide helpful information for population viability,
      such measures assume a population is in stable-status (Morris & Doak, 2002). However, 
      vital rates frequently change in reality (Citta & Mills, 1999; Mills et al., 
      1999; Mills et al.,2001, Koons, Rockwell, & Grand, 2006). The stochastic growth rate reliably integrates information from 
      all time frames into the single measure of contextual and situational growth.</p>
      <p>Any perturbation to stable status may cause fits and starts in step-wise growth rates. These temporary 
      periods of accelerated change are not necessarily captured in the asymptotic measures. 
       The degree to which asymptotic dynamics are a poor proxy to actual dynamics depends 
      on several aspects of the population and its situational ecology, such as the 
      magnitudes of vital rates, generation time, and life history characteristics 
      (Koons et al., 2005). </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxStochAEco,{
  showModal(modalDialog(
   title="How do I interpret this from the ecological perspective?",
   HTML("
      <p>The stochastic growth rate is best understood as a geometric mean growth rate 
     for a particular patch, where the realized cumulative growth of the patch is the result of a 
     long temporal sequence of habitats (Tuljapurkar, 2003). The stochastic growth rate is also 
     the geometric mean 
     growth rate for a collection of patches if there is high spatial correlation between the 
     patches in the habitat sequences they experience (Tuljapurkar, 2003). </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxStochAMgmt,{
  showModal(modalDialog(
   title="How do I interpret this from the resource management perspective?",
   HTML("
     <p>US environmental legislation mandates the development of impact statements and 
      assessments of alternatives designed to mitigate the impacts of proposed 
      anthropogenic activities (NEPA 1970; ESA 1973). </p>
     <p> Because the stochastic growth rate is the time average cumulative growth
     over many time steps in one particular area (Tuljapurkar, 2003), this measure of growth is tailored
      to populations that fall on a project footprint or in a project zone of influence. </p>
      "),
   easyClose=TRUE))})
 
 observeEvent(input$HelpboxTransGrowA,{
  showModal(modalDialog(
   title="How do I interpret this from the mathematical modeling perspective?",
   HTML("
      <p>The near-term growth rate shows the immediate rate of change in abundances 
      in the 
      isolated years of interest. </p>
      <p> Transient dynamics incorporate all the 
      eigenvectors, and each of these vectors contribute their own influence to 
      temporary population peaks and valleys (Yearsley, 2004). The transient 
      growth rate is calculated 
      using the sum of these peaks and valleys through time, 
      so it captures information from near- and long-term processes, as 
      well as information from changes in abundances from 
      migration and dispersion.</p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxTransGrowABio,{
  showModal(modalDialog(
   title="How do I interpret this from the biological perspective?",
   HTML("
      <p>Environmental catastrophes, natural disturbances, selective harvest regimes, 
     and animal release and relocation programs can significantly 
     alter a population's state, causing unstable states (Koons et al., 2005). 
      Near-term transient demographic analyses focus 
      on the timeframe that exists after a population is perturbed but prior to the 
      population re-attaining stability (Koons et al., 2005). </p>

      <p>The transient growth rate measures growth not just from the life history processes,
      but also from the situational manifestations of those life history process in their 
      environment in real time.</p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxTransGrowAEco,{
  showModal(modalDialog(
   title="How do I interpret this from the ecological perspective?",
   HTML("
      <p>The transient behavior specifies the extent to which the 
      system will react to an instantaneous change in 
      matrix element or stage abundances, or both. </p>

      <p> The transient growth rate captures information on both the transient and asymptotic
      trends in the trajectories. Unlike the asymptotic growth rate, the transient
      growth rate will capture relevant information that is contained in the rapid peaks and valleys
      of the trajectories. </p>
      <p> The changes in growth in the near-term period is likely to be 
      the fundamental period of interest because it considers explicitly 
      the ramifications 
      of disturbance originating from abiotic, biotic and or anthropogenic processes 
      (Ezard et al., 2010). </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxTransGrowAMgmt,{
  showModal(modalDialog(
   title="How do I interpret this from the resource management perspective?",
   HTML("
      <p>A clear distinction may be drawn between inference arising from 
      asymptotic and transient analyses; focusing solely on asymptotic dynamics can 
      lead to misleading results that affect management recommendations (Ezard et al., 
      2010). For example, environmental catastrophes, natural disturbances, selective 
      harvest regimes, and animal release and relocation programs can significantly alter 
      a population's state, causing unstable states that influence future population trajectories
      (Koons et al., 2005). Asymptotic sensitivities might 
      not be informative for making management prescriptions in particular areas of interest in the
      immediate future (Koons et al., 2005). </p>
      
      <p>Formal listing opinions for national and global conservation protection plans 
      require objectively quantified biological justification (IUCN 2017). 
      Area specific demographic status assessments have frequently included abundance estimation, 
      recent population trends, and sensitivity calculations (McGowan, 2017). 
      In addition to long-term projection evidence, 
     localized or quantifiable drops in 
      population abundance over certain time periods can also trigger 
      protection measures under both the 
      US Fish and Wildlife Service Endangered Species Act and the International Union 
      on Conservation of Nature Red List (IUCN 2017). The transient growth rate may be used
      to identify alarming drops that may support eligibility 
      for emergency protections or regulation.</p>
      "),
   easyClose=TRUE))})
 
 observeEvent(input$HelpboxEffectiveA,{
  showModal(modalDialog(
   title="How do I interpret this from the mathematical modeling perspective?",
   HTML("
      <p> It is mathematically proven that the 
      harmonic mean will always be less than or equal to the arithmetic mean. This means
      that the amount of inheritable genetic variabilty is 
      limited to the genetic variability of the parents. </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxEffectiveABio,{
  showModal(modalDialog(
   title="How do I interpret this from the biological perspective?",
   HTML("
      <p>Population may be measured in several ways. The arithmetic mean is the average number of individuals in 
      a population across time (Gotelli, 2004), while (among numerous definitions) the effective 
      population size (Ne) is the equivalent size of the population 
      with completely random mating (Gotelli, 2004). </p>

      <p>The harmonic mean may diverge from the arithmetic mean for many reasons, 
     and this divergence drives a wedge between effective and census population sizes.</p>

      <p> The effective population size is especially sensitive in low abundance years (Gotelli, 2004). </p>

      <p>Unequal number of reproductive males and females, or a discrepency in the 
      number of males or females that reproduce, will also lower Ne (Kliman, Sheehy, & Schultz, 2008).</p>

      <p> If parents are not equally likely to produce offspring, or the number of offspring 
      that each produces varies by more than chance, Ne will be lowered 
       (Kliman, Sheehy, & Schultz, 2008).</p>

      <p> If mating is not random, Ne will be lowered (Kliman, Sheehy, & Schultz, 2008).</p>

      <p> If the number of breeding individuals is not constant from one generation to the next,
      then Ne will be lowered (Kliman, Sheehy, & Schultz, 2008).</p>

      <p> Essentially, anything that increases the variance among 
      individuals in reproductive success will 
       reduce Ne (Kliman, Sheehy, & Schultz, 2008). </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxEffectiveAEco,{
  showModal(modalDialog(
   title="How do I interpret this from the ecological perspective?",
   HTML("
      <p>Transient population oscillations 
      have important effects on effective population sizes. </p>

      <p> The effective population size is typically much smaller than the number of 
      potentially breeding adults in populations (Frankham, 2005). 
     In particular, one or two time units with 
      low population abundances are all that it takes to cause the harmonic 
      mean to plunge in comparison 
      to the arithmetic mean (Gotelli, 2004).</p>

     <p>Ecological events can cause mortality that functions to bottleneck the
     surviving population. The effects of this reduction on genetic 
      variation depend on both the size of the population during the reduction 
      phase and the duration of the reduction phase (Kliman, Sheehy, & Schultz, 2008). </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxEffectiveAMgmt,{
  showModal(modalDialog(
   title="How do I interpret this from the resource management perspective?",
   HTML("
      <p>The effective population size is measure of population 
      health at the genetic scale, while the
      arithmetic population size 
      is a measure of population health at the individual scale. </p> 

      <p> Prior to 1970, genetic factors were rarely mentioned 
       as causes of extinction but increasing research 
      attention has changed this result (e.g. Frankel, 1970; Frankel, 1974, Frankel & Soule, 
      1981; Lande, 1995; Lynch et al., 1995; Frankham et al., 2002; Frankham, 2005). 
      Indeed, the IUCN now designates genetic diversity as one of the three levels of biodiversity 
      that requires conservation (Frankham, 2005). Populations with low effective population sizes are 
      eligible for protection alongside populations with few individuals.</p> 

      <p> The IUCN has specified how to treat such 
      situations where the harmonic and arithmetic means differ; where the 
      population size fluctuates, use a lower estimate 
      (IUCN, 2017). Due to mathematical properties between the two types of means, this decision rule 
      means that the genetic scale will outrank the individual scale in importance should a discrepancy emerge.</p>

      <p>A species that loses genetic variation 
      to drift (e.g., because its census population has gone through a severe 
      bottleneck) will have a 
      very hard time recovering the lost variation, even if the 
      census size of the population is expanding (Kliman, Sheehy, & Schultz, 2008).</p>
      "),
   easyClose=TRUE))})
 
 observeEvent(input$HelpboxLGDA,{
  showModal(modalDialog(
   title="How do I interpret this from the mathematical modeling perspective?",
   HTML("
      <p> Bald Eagle populations experience dispersion, so they are not 
      considered closed populations. The assumptions of this measure are violated. Never-the-less, this is a unique opportunity to see what could be expected 
      if the Northeast was a closed system.</p>
      <p>In a closed system, the proportion of 
      individuals expected to be heterozygous is expected to decline by 
      a factor of 1/2Ne in each generation (Kliman, Sheehy, & Schultz, 2008).</p>
      <p>The mathematical equation that describes the loss of genetic diversity 
      involves the Hardy-Weinberg expected heterozygosity 
      (gene diversity), the genetically effective population size, 
       and the inbreeding coefficient (F). The mathematics suggest that 
       the decay occurs at greater rates 
      in smaller populations (Frankham, 2005). <p>

      <p>In these calculations, we have used the harmonic mean in 
      lieu of a measure of heterozygosity. </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxLGDABio,{
  showModal(modalDialog(
   title="How do I interpret this from the biological perspective?",
   HTML("
      <p> Bald eagles tend to disperse from their natal territories, 
      so their population is not considered closed. 
      However, this equation specifies the general relationship between 
      effective population size (genetic readiness), loss of genetic diversity 
      and inbreeding in a closed, randomly mating population. </p>
      <p>Given a closed population, the total genetic variability in the 
      short term is limited to the heterozygosity that is present in the
      set of breeding indivduals. The genetic diversity in each subsequent 
       generation will be limited by the total genetic variability 
      that was passed down from their parents. </p>
      <p> Prior to 1970, genetic factors 
        were rarely mentioned as causes of extinction. Frankel (1970, 1974) 
      was primarily responsible for proposing that loss of genetic diversity elevated 
      extinction risk, especially by compromising 
      evolutionary response to environmental change. </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxLGDAEco,{
  showModal(modalDialog(
   title="How do I interpret this from the ecological perspective?",
   HTML("
       <p> Biological extinctions are due to the combined effects of 
       deterministic (habitat loss, over exploitation, 
       introduced species and pollution) and stochastic (demographic, environmental, 
       genetic and catastrophic) factors (Shaffer, 1981). </p>
      <p>Interbreeding leads to a loss of genetic diversity in systems that do not experience 
      migration or dispersion (Frankham, 2005) . In such closed systems, 
      allele frequencies may reach levels 
      where fixation or loss may occur, causing an overall loss in genetic 
      diversity (Frankham, 2005). In small 
      closed populations, such losses constitute extreme peril 
       for the evolutionary readiness of the species (Frankham, 2005). </p>
      <p>The higher the growth rate, the more genetic factors 
      are going to take a hold (Frankham, 2005). </p>
      <p> Many avian species (like the Bald Eagle) are not closed systems.</p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxLGDAMgmt,{
  showModal(modalDialog(
   title="How do I interpret this from the resource management perspective?",
   HTML("
      <p>Evolutionary changes have been documented in many species in 
      natural or human affected habitats (Briggs & Walters, 1997; Thompson, 1998; 
      Mousseau et al., 2000; Bradshaw & Holzapfel, 2001; Umina et al., 2005, 
      Frankham, 2005). Loss of genetic diversity in small populations could 
       increase extinction risk by adversely affecting the ability of populations to evolve 
     and cope with environmental change, which may diminish 
      the evolutionary potential of the species (Frankham, 2005).</p>

      <p> Although more precise measures of heterozygosity may be attained 
      using techniques in genomics, the use of this parsimonious equation demonstrates that it
      is possible to improve the quantitative basis for decisions regarding 
      alternative recovery actions when even limited demographic information 
      is available (Kissel et al., 2014). 

      <p> In general, if genetic factors are ignored in population 
      viability analyses, extinction risk will be 
      underestimated and inappropriate management strategies may be implemented 
      (Frankham, 2005). We add this
      measure of evolutionary readiness but remark that this consideration is of 
      lesser importance in the open Bald Eagle population than it is in other closed wildlife systems.</p>
      "),
   easyClose=TRUE))})
 
 observeEvent(input$HelpboxPopInA,{
  showModal(modalDialog(
   title="How do I interpret this from the mathematical modeling perspective?",
   HTML("
     <p> Population inertia is the 
     ratio where non-stable population achieves 
      long-term population densities at a fixed magnitude either above or below 
     that of an equivalent stable population (Stott, 2012). </p>

     <p> A population with inertia greater than 1 becomes and remains larger 
     than had it started out with a stable demographic distribution, 
      whilst a population with inertia smaller than 1 becomes and 
      remains smaller (Stott, 2012). </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxPopInABio,{
  showModal(modalDialog(
   title="How do I interpret this from the biological perspective?",
   HTML("
     <p> Early demographic studies of human populations considered population 
     momentum, the tendency for changes in population growth rates to lag behind changes 
     in childbearing behavior and mortality conditions (Keyfitz, 1971). 
      Population inertia 
      is a logical extension of momentum; a population with any given demographic 
     distribution, following any disturbance or perturbation, 
      will settle asymptotically to a fixed ratio above or below what is 
      expected from a similar population growing at an asymptotic rate (Stott et al. 2011). </p>
      
     <p>Population inertia occurs because non-stable populations exhibit 
      very different patterns of 
      transient growth (or decline) before eventually settling into a stable 
      geometric rate (Stott, 2012). </p>

      <p>Inertia operates through the population age distribution (Keyfitz, 1971). 
     When the population is highly skewed away from the productive stages there 
     is a short population decline until enough individuals become productive for 
      the population to start growing (Gerber & Kendall, 2016). </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxPopInAEco,{
  showModal(modalDialog(
   title="How do I interpret this from the ecological perspective?",
   HTML("
      <p>Population inertia measures the long-term abundance of a population with 
      any historical structure relative to the expected abundance of an 
      otherwise equivalent population growing 
      according to its stable population structure (Stott et al., 2011). </p>
     <p> Populations experience a changeable and heterogeneous world, 
      where extrinsic disruptions to population structure of 
      biotic origin (e.g. disease, predation pressure or competition), 
      abiotic origin (e.g. changing climate, extreme weather events or fire) 
      and anthropogenic origin (e.g. harvesting or 
      management intervention) lead to a demographic distribution 
      that is different from the population's stable demographic distribution 
     (Stott et al., 2011). Population inertia is capable of quantifying these dynamical consequences 
     (Tuljapurkar & Lee, 1997; Koons, Holmes, & Grand, 2007).</p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxPopInAMgmt,{
  showModal(modalDialog(
   title="How do I interpret this from the resource management perspective?",
   HTML("
     <p> Population with inertia greater than 1 becomes and remains larger 
     than had it started out with a stable demographic distribution, 
      whilst a population with inertia smaller than 1 becomes and 
      remains smaller (Stott, 2012). </p>
      <p>Population inertia could shorten or lengthen the time it takes 
      for a population to go extinct, recover from depletion, or grow to levels 
      that become a nuisance 
      (Koons et al., 2006). Similarly, population inertia could move a population past 
      defined management objectives or 
      influence the time it takes for a population to reach a 
      population objective (Koons et al., 2006).</p>
      "),
   easyClose=TRUE))})
 
 observeEvent(input$HelpboxReactA,{
  showModal(modalDialog(
   title="How do I interpret this from the mathematical modeling perspective?",
   HTML("
      <p>Reactivity is a measurement of the maximum size of 
      the total population in any time step 
      out of stable status relative to the maximum size of 
      the total population in that same time step 
      in stable status (Stott et al. 2011). </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxReactABio,{
  showModal(modalDialog(
   title="How do I interpret this from the biological perspective?",
   HTML("
      <p> A historical population structure that acts on the newly changed vital 
      rates will produce a large surplus or deficit of breeding adults 
      (Koons, Grand, & Arnold, 2006). Reactivity 
      assesses the extent to which these excess 
      individuals influence overall 
      population dynamics.</p> 

      <p> A population that experiences unpredictable disturbance may 
      evolve to become resistant to 
      disturbance, as an insurance against 
      population decline (Stott et al. 2011). Conversely, a population that 
      experiences regular disturbance of a 
      particular type may evolve to have a 
      larger transient dynamical response to that disturbance, maximizing 
      amplification to exploit opportunity to 
      outcompete other genotypes (Stott et al. 2011). </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxReactAEco,{
  showModal(modalDialog(
   title="How do I interpret this from the ecological perspective?",
   HTML("
      <p>Situational environmental conditions differentially 
      impact survival in life stages. Reactivity may be used 
      to assess whether and to what extent these differential impacts
      instill lasting ripples or impressions on future population dynamics (Stott et al., 2011).</p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxReactAMgmt,{
  showModal(modalDialog(
   title="How do I interpret this from the resource management perspective?",
   HTML("
     <p>Reactivity is the maximal possible amplification 
     and attenuation in the first timestep (Neubert & Caswell, 1997). 
     It describes how big 
     or small a population can become in the short term (Stott et al., 2011).</p>

      <p>It is necessary to explore how potential management actions may impact population 
      growth to evaluate the most ecologically and economically 
      effective means of achieving management goals (Baxter et al. 2006; Stott, 2012). 
     Information about reactivity may aid managers in ruling out alternatives that may 
     cause undesirable near-term population explosions
      or alternatives that cause severe near-term attentuations. </p>
      "),
   easyClose=TRUE))})
 
 observeEvent(input$HelpboxMaxAmpA,{
  showModal(modalDialog(
   title="How do I interpret this from the mathematical modeling perspective?",
   HTML("
      <p>Recall that the stable stage proportions sum to one. Imagine a distrbution of abundances 
      that is as far away from that stable stage distribution as possible. 
      Now generate the projection 
      of abundances from that vector. What will the projection do? Will 
      it have oscillations? Will it 
      have trajectories similar to the SSD? Now imagine the most 
      egregiously different trajectory; 
      one with the highest peak in abundance of any possible vector. That peak is the 
      maximum amplification 
      that can arise from any deviation from the stable stage vector.</p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxMaxAmpABio,{
  showModal(modalDialog(
   title="How do I interpret this from the biological perspective?",
   HTML("
      <p> Long-lived animal species 
      with slow reproduction have been shown to 
      have greater variability in potential transient growth 
      than short-lived species with fast 
      reproduction (Koons et al., 2005; Stott et al., 2011). </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxMaxAmpAEco,{
  showModal(modalDialog(
   title="How do I interpret this from the ecological perspective?",
   HTML("
      <p>Populations with rapid asymptotic growth are 
     likely to harbor the potential for greater magnitudes 
     of both transient amplification and attenuation (Stott et al., 2011). </p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxMaxAmpAMgmt,{
  showModal(modalDialog(
   title="How do I interpret this from the resource management perspective?",
   HTML("
      <p>Relative measures of transient population density describe how 
      big or small a population can become in the short term, relative to 
      asymptotic dynamics (Stott et al., 2011). </p>
      <p> The ability to understand 
      and quantify such transient dynamics 
      enable managers to both ameliorate adverse transient 
      responses to natural disturbance and perturbation 
      or to deliberately manipulate transient 
      responses through anthropogenic disturbance 
      and perturbation (Stott et al., 2011). </p>
      "),
   easyClose=TRUE))})

 observeEvent(input$HelpboxMaxAttA,{
  showModal(modalDialog(
   title="How do I interpret this from the mathematical modeling perspective?",
   HTML("
      <p>Recall that the stable stage proportions sum to one. Imagine a distrbution of abundances 
      that is as close to that stable stage distribution as possible. 
      Now generate the projection 
      of abundances from that vector. What will the projection do? Will 
      it have oscillations? Will it 
      have trajectories similar to the SSD? Now imagine the most 
      egregiously different trajectory; 
      one with the lowest valley in abundance of any possible vector. That valley is the 
      maximum attenuation
      that can arise from any deviation from the stable stage vector.</p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxMaxAttABio,{
  showModal(modalDialog(
   title="How do I interpret this from the biological perspective?",
   HTML("
      <p>Transient response to disturbances aid in 
       understanding life-history evolution 
       from a new perspective (Stott et al., 2011).</p> 
       <p> For example, a population that regularly experiences unpredictable 
       disturbance may need to evolve to be resistant to 
       disturbance through having smaller transients, 
       as an insurance against population decline (Stott et al., 2011). 
       Conversely, a population that experiences regular 
       disturbance of a particular type may evolve to have a larger transient 
       dynamical response to that disturbance, 
       maximizing amplification to exploit 
       opportunity to outcompete other genotypes (Stott et al., 2011).</p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxMaxAttAEco,{
  showModal(modalDialog(
   title="How do I interpret this from the ecological perspective?",
   HTML("
      <p>Although organisms cannot plan for environmental change, 
       the more variation that exists in a population, 
       the better prepared that population will be 
       to adapt to change when it does occur (Kliman, Sheehy, & Schultz, 2008). </p>
       <p> Attenuation may function to cleave genetic variability out of
       the population, as harmonic mean is especially sensitive to 
       low abundances in even a few years (Gotelli, 2004).</p>
      "),
   easyClose=TRUE))})
 observeEvent(input$HelpboxMaxAttAMgmt,{
  showModal(modalDialog(
   title="How do I interpret this from the resource management perspective?",
   HTML("
       <p> The varieties of demographic calculations show that short- 
       and long-term analyses are complementary; 
        combinations of these quantities give 
        valuable information to specific application 
        of population conservation and 
        management (Yearsley, 2004; Salguero-Gomez et al., 
        2014; Salguero-Gomez et al., 2016). 
        Unfortunately, there is no simple prescription as to which analysis 
        is most informative; this depends on the questions 
        being asked (Fox & Gurevitch, 2000).</p>
       <p> Transient bounds that quantify maximum attenuation and amplification
       provide an alternative approach to population management when 
       the demographic distribution of the population is 
       unknown; they provide best- and worst-case scenarios 
       of transient change in population density (Townley & Hodgson, 2008; 
       Stott et al., 2011). The realized dynamics of the population 
       will lie anywhere between the transient bounds (Stott et al., 2011). </p>
      "),
   easyClose=TRUE))})

# TURN ON THE PANELS
observe({
  if (input$Lambda_done1 > 0) {
   session$sendCustomMessage('activeNavs', 'Life table')}})
observe({
 if (input$Lambda_done1 > 0) {
  session$sendCustomMessage('activeNavs', 'Predicted annual abundances')}})
observe({
 if (input$Lambda_done1 > 0) {
  session$sendCustomMessage('activeNavs', 'Predicted bi-annual abundances')}})
observe({
 if (input$Lambda_done1 > 0) {
  session$sendCustomMessage('activeNavs', 'Predicted bi-annual hatchling abundances')}})
observe({
 if (input$Lambda_done1 > 0) {
  session$sendCustomMessage('activeNavs', 'Predicted bi-annual immature and non-breeding female abundances')}})
observe({
 if (input$Lambda_done1 > 0) {
  session$sendCustomMessage('activeNavs', 'Predicted bi-annual breeding female abundances')}})
observe({
 if (input$Lambda_done1 > 0) {
  session$sendCustomMessage('activeNavs', 'Predicted abundances during the breeding period')}}) 
observe({
 if (input$Lambda_done1 > 0) {
  session$sendCustomMessage('activeNavs', 'Predicted abundances during the non-breeding period')}}) 
observe({
 if (input$Lambda_done1 > 0) {
  session$sendCustomMessage('activeNavs', 'Migration and dispersal')}}) 
observe({
 if (input$Lambda_done1 > 0) {
  session$sendCustomMessage('activeNavs', 'Survival rates')}}) 
observe({
 if (input$Lambda_done1 > 0) {
  session$sendCustomMessage('activeNavs', 'Asymptotic growth rates')}}) 
observe({
 if (input$Lambda_done1 > 0) {
  session$sendCustomMessage('activeNavs', 'Stable stage distribution')}})
observe({
 if (input$Lambda_done1 > 0) {
  session$sendCustomMessage('activeNavs', 'Reproductive value')}})
observe({
 if (input$Lambda_done1 > 0) {
  session$sendCustomMessage('activeNavs', 'Sensitivities')}})
observe({
 if (input$Lambda_done1 > 0) {
  session$sendCustomMessage('activeNavs', 'Elasticities')}})
observe({
if (input$Lambda_done1 > 0) {
 session$sendCustomMessage('activeNavs', 'Damping ratio and convergence time')}})
observe({
 if (input$Lambda_done1 > 0) {
  session$sendCustomMessage('activeNavs', 'Stochastic growth rate')}})
observe({
 if (input$Lambda_done1 > 0) {
  session$sendCustomMessage('activeNavs', 'Transient growth rate')}})
observe({
 if (input$Lambda_done1 > 0) {
  session$sendCustomMessage('activeNavs', 'Cumulative growth')}})
observe({
 if (input$Lambda_done1 > 0) {
  session$sendCustomMessage('activeNavs', 'Harmonic vs. arithmetic mean abundances')}})
observe({
 if (input$Lambda_done1 > 0) {
  session$sendCustomMessage('activeNavs', 'Loss of genetic diversity')}}) 
observe({
 if (input$Lambda_done1 > 0) {
  session$sendCustomMessage('activeNavs', 'Population inertia')}}) 
observe({
 if (input$Lambda_done1 > 0) {
  session$sendCustomMessage('activeNavs', 'Reactivity')}})
observe({
 if (input$Lambda_done1 > 0) {
  session$sendCustomMessage('activeNavs', 'Maximum amplification')}})
observe({
 if (input$Lambda_done1 > 0) {
  session$sendCustomMessage('activeNavs', 'Maximum attenuation')}})

# CALCULATED OUTPUTS

output$LifeTable=renderPlot({
 # Create 0-row data frame which will be used to store data
 dat <- data.frame(x = numeric(0), y = numeric(0))
 
 withProgress(message = 'Calculating', value = 0, {
  # Number of times we'll go through the loop
  n <- 40
  
  for (i in 1:n) {
   # Each time through the loop, add another row of data. This is
   # a stand-in for a long-running computation.
   dat <- rbind(dat, data.frame(x = rnorm(1), y = rnorm(1)))
   
   # Increment the progress bar, and update the detail text.
   incProgress(1/n, detail = paste("", i))
   
   # Pause for 0.1 seconds to simulate a long computation.
   Sys.sleep(0.1)
  }
 })
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 # CREATE THE PARED DOWN VERSION OF THE PROBABILITY DISTRIBUTIONS 
 
 # INITIALIZE STORAGE FOR SURVIVAL OF EACH STAGE IN BREEDING PERIODS
 Surv2b=numeric(length(MODELS[,1]))
 Surv3b=numeric(length(MODELS[,1]))
 # INITALIZE STORAGE FOR SURVIVAL OF EACH STAGE IN NON-BREEDING PERIODS
 Surv1nb=numeric(length(MODELS[,1]))
 Surv2nb=numeric(length(MODELS[,1]))
 Surv3nb=numeric(length(MODELS[,1]))
 # INITIALIZE STORAGE FOR SURVIVAL OF EACH STAGE IN NON-BREEDING OTHER
 Surv1nbe=numeric(length(MODELS[,1]))
 Surv2nbe=numeric(length(MODELS[,1]))
 Surv3nbe=numeric(length(MODELS[,1]))
 # REMOVE THE TRANSITION PROBABILITIES FROM MATRIX ELEMENTS
 # TO LEAVE ONLY THE SURVIVAL IN EACH STAGE 
 for (iii in 1:length(MODELS[,1])){
  Surv2b[iii]=(6*MODELS[iii,9])/5		# Trans Prob = 1/6
  Surv1nb[iii]=MODELS[iii,13]			# Trans Prob = 1
  Surv2nb[iii]=(6*MODELS[iii,14])/5		# Trans Prob = 1/6
  Surv1nbe[iii]=MODELS[iii,18]			# Trans Prob = 1
  Surv2nbe[iii]=(6*MODELS[iii,19])/5		# Trans Prob = 1/6
  Surv2b[iii]=(6*MODELS[iii,9])/5
  x3=1+(1/12)*(Surv2b[iii])-(1/2)*sqrt((24*Surv2b[iii]^2)/(36))
  Surv3b[iii]=MODELS[iii,12]/(1-x3)		# Trans Prob = x3
  xx3=1+(1/12)*(Surv2nb[iii])-(1/2)*sqrt((24*Surv2nb[iii]^2)/(36))
  Surv3nb[iii]=MODELS[iii,17]/(1-xx3)		# Trans Prob = xx3
  xxx3=1+(1/12)*(Surv2nbe[iii])-(1/2)*sqrt((24*Surv2nbe[iii]^2)/(36))
  Surv3nbe[iii]=MODELS[iii,22]/(1-xxx3)	# Trans Prob = xxx3
 }
 for (i in 1:length(Surv3b)){if (Surv3b[i]>=1){Surv3b[i]=.999}}
 for (i in 1:length(Surv3nb)){if (Surv3nb[i]>=1){Surv3nb[i]=.999}}
 for (i in 1:length(Surv3nbe)){if (Surv3nbe[i]>=1){Surv3nbe[i]=.999}}
 
 # XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

 Surv1NB=Surv1nb
 Surv1NBE=Surv1nbe
 Surv2B=Surv2b
 Surv2NB=Surv2nb
 Surv2NBE=Surv2nbe
 Surv3B=Surv3b
 Surv3NB=Surv3nb
 Surv3NBE=Surv3nbe
 
 P1=numeric(length(MODELS[,1]))
 P2=numeric(length(MODELS[,1]))
 P3=numeric(length(MODELS[,1]))
 P4=numeric(length(MODELS[,1]))
 P5=numeric(length(MODELS[,1]))
 P6=numeric(length(MODELS[,1]))
 P7=numeric(length(MODELS[,1]))
 P8=numeric(length(MODELS[,1]))
 P9=numeric(length(MODELS[,1]))
 P10=numeric(length(MODELS[,1]))
 P11=numeric(length(MODELS[,1]))
 P12=numeric(length(MODELS[,1]))
 P13=numeric(length(MODELS[,1]))
 P13=numeric(length(MODELS[,1]))
 P14=numeric(length(MODELS[,1]))
 P15=numeric(length(MODELS[,1]))
 P16=numeric(length(MODELS[,1]))
 P17=numeric(length(MODELS[,1]))
 P18=numeric(length(MODELS[,1]))
 P19=numeric(length(MODELS[,1]))
 P20=numeric(length(MODELS[,1]))
 P21=numeric(length(MODELS[,1]))
 P22=numeric(length(MODELS[,1]))
 P23=numeric(length(MODELS[,1]))
 P24=numeric(length(MODELS[,1]))
 P25=numeric(length(MODELS[,1]))
 P26=numeric(length(MODELS[,1]))
 P27=numeric(length(MODELS[,1]))
 P28=numeric(length(MODELS[,1]))
 P29=numeric(length(MODELS[,1]))
 P30=numeric(length(MODELS[,1]))
 P31=numeric(length(MODELS[,1]))
 P32=numeric(length(MODELS[,1]))
 P33=numeric(length(MODELS[,1]))
 P33=numeric(length(MODELS[,1]))
 P34=numeric(length(MODELS[,1]))
 P35=numeric(length(MODELS[,1]))
 P36=numeric(length(MODELS[,1]))
 P37=numeric(length(MODELS[,1]))
 P38=numeric(length(MODELS[,1]))
 P39=numeric(length(MODELS[,1]))
 P40=numeric(length(MODELS[,1]))
 P41=numeric(length(MODELS[,1]))
 P42=numeric(length(MODELS[,1]))
 P43=numeric(length(MODELS[,1]))
 P44=numeric(length(MODELS[,1]))
 P45=numeric(length(MODELS[,1]))
 P46=numeric(length(MODELS[,1]))
 P47=numeric(length(MODELS[,1]))
 P48=numeric(length(MODELS[,1]))
 P49=numeric(length(MODELS[,1]))
 P50=numeric(length(MODELS[,1]))
 
 #################################
 #################################
 for (i in 1:length(MODELS[,1])){
  P1[i]=
   (Surv1NB[i]+Surv1NBE[i])/(2^1)
 }
 
 #################################
 #################################
 
 for (i in 1:length(MODELS[,1])){
  P2[i]=
   # LIVE TO END OF YEAR 2
   (
    Surv1NB[i]*Surv2B[i]*Surv2NB[i]+
     Surv1NB[i]*Surv2B[i]*Surv2NBE[i]+
     
     Surv1NBE[i]*Surv2B[i]*Surv2NB[i]+
     Surv1NBE[i]*Surv2B[i]*Surv2NBE[i]
   )/(2^2)
 }
 
 #################################
 #################################
 
 for (i in 1:length(MODELS[,1])){
  P3[i]=
   # LIVE TO END OF YEAR 3
   (
    Surv1NB[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NB[i]+
     Surv1NB[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NB[i]+
     Surv1NB[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NBE[i]+
     Surv1NB[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NBE[i]+
     
     Surv1NBE[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NB[i]+
     Surv1NBE[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NB[i]+
     Surv1NBE[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NBE[i]+
     Surv1NBE[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NBE[i]
   )/(2^3)
 }
 
 #################################
 #################################
 
 for (i in 1:length(MODELS[,1])){
  P4[i]=
   # LIVE TO END OF YEAR 4
   (
    Surv1NB[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NB[i]+
     Surv1NB[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NB[i]+
     Surv1NB[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NB[i]+
     Surv1NB[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NB[i]+
     Surv1NB[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NBE[i]+
     Surv1NB[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NBE[i]+
     Surv1NB[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NBE[i]+
     Surv1NB[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NBE[i]+
     
     Surv1NBE[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NB[i]+
     Surv1NBE[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NB[i]+
     Surv1NBE[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NB[i]+
     Surv1NBE[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NB[i]+
     Surv1NBE[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NBE[i]+
     Surv1NBE[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NBE[i]+
     Surv1NBE[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NBE[i]+
     Surv1NBE[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NBE[i]
   )/(2^4)
 }
 
 #################################
 #################################
 
 # P5
 for (i in 1:length(MODELS[,1])){
  P5[i]=
   (
    # LIVE TO END OF YEAR 5 BUT SPEND 5TH YEAR IN STAGE II
    P4[i]*Surv2B[i]*Surv2NB[i]+
     P4[i]*Surv2B[i]*Surv2NBE[i]+
     
     # LIVE TO END OF YEAR 5 BUT SPEND 5TH YEAR IN STAGE III
     P4[i]*Surv3B[i]*Surv3NB[i]+
     P4[i]*Surv3B[i]*Surv3NBE[i]+
     
     #LIVE TO END OF YEAR 5 BUT SPEND 1/2 5TH YEAR IN STAGE II AND 1/2 IN STAGE III
     P4[i]*Surv3B[i]*Surv2NB[i]+
     P4[i]*Surv3B[i]*Surv2NBE[i]+
     
     P4[i]*Surv2B[i]*Surv3NB[i]+
     P4[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 
 #################################
 #################################
 
 # P6
 for (i in 1:length(MODELS[,1])){
  P6[i]=
   (
    # LIVE TO END OF YEAR 6 BUT SPEND 5TH YEAR IN STAGE II
    P5[i]*Surv2B[i]*Surv2NB[i]+
     P5[i]*Surv2B[i]*Surv2NBE[i]+
     
     # LIVE TO END OF YEAR 6 BUT SPEND 5TH YEAR IN STAGE III
     P5[i]*Surv3B[i]*Surv3NB[i]+
     P5[i]*Surv3B[i]*Surv3NBE[i]+
     
     #LIVE TO END OF YEAR 6 BUT SPEND 1/2 5TH YEAR IN STAGE II AND 1/2 IN STAGE III
     P5[i]*Surv3B[i]*Surv2NB[i]+
     P5[i]*Surv3B[i]*Surv2NBE[i]+
     
     P5[i]*Surv2B[i]*Surv3NB[i]+
     P5[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 
 #################################
 #################################
 
 # P7
 for (i in 1:length(MODELS[,1])){
  P7[i]=
   (
    P6[i]*Surv2B[i]*Surv2NB[i]+
     P6[i]*Surv2B[i]*Surv2NBE[i]+
     
     P6[i]*Surv3B[i]*Surv3NB[i]+
     P6[i]*Surv3B[i]*Surv3NBE[i]+
     
     P6[i]*Surv3B[i]*Surv2NB[i]+
     P6[i]*Surv3B[i]*Surv2NBE[i]+
     
     P6[i]*Surv2B[i]*Surv3NB[i]+
     P6[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 
 #################################
 #################################
 
 # P8
 for (i in 1:length(MODELS[,1])){
  P8[i]=
   (
    P7[i]*Surv2B[i]*Surv2NB[i]+
     P7[i]*Surv2B[i]*Surv2NBE[i]+
     
     P7[i]*Surv3B[i]*Surv3NB[i]+
     P7[i]*Surv3B[i]*Surv3NBE[i]+
     
     P7[i]*Surv3B[i]*Surv2NB[i]+
     P7[i]*Surv3B[i]*Surv2NBE[i]+
     
     P7[i]*Surv2B[i]*Surv3NB[i]+
     P7[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 
 #################################
 #################################
 
 # P9
 for (i in 1:length(MODELS[,1])){
  P9[i]=
   (
    P8[i]*Surv2B[i]*Surv2NB[i]+
     P8[i]*Surv2B[i]*Surv2NBE[i]+
     
     P8[i]*Surv3B[i]*Surv3NB[i]+
     P8[i]*Surv3B[i]*Surv3NBE[i]+
     
     P8[i]*Surv3B[i]*Surv2NB[i]+
     P8[i]*Surv3B[i]*Surv2NBE[i]+
     
     P8[i]*Surv2B[i]*Surv3NB[i]+
     P8[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 
 #################################
 #################################
 
 # P10
 for (i in 1:length(MODELS[,1])){
  P10[i]=
   (
    P9[i]*Surv2B[i]*Surv2NB[i]+
     P9[i]*Surv2B[i]*Surv2NBE[i]+
     
     P9[i]*Surv3B[i]*Surv3NB[i]+
     P9[i]*Surv3B[i]*Surv3NBE[i]+
     
     P9[i]*Surv3B[i]*Surv2NB[i]+
     P9[i]*Surv3B[i]*Surv2NBE[i]+
     
     P9[i]*Surv2B[i]*Surv3NB[i]+
     P9[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 
 #################################
 #################################
 
 # P11
 for (i in 1:length(MODELS[,1])){
  P11[i]=
   (
    P10[i]*Surv2B[i]*Surv2NB[i]+
     P10[i]*Surv2B[i]*Surv2NBE[i]+
     
     P10[i]*Surv3B[i]*Surv3NB[i]+
     P10[i]*Surv3B[i]*Surv3NBE[i]+
     
     P10[i]*Surv3B[i]*Surv2NB[i]+
     P10[i]*Surv3B[i]*Surv2NBE[i]+
     
     P10[i]*Surv2B[i]*Surv3NB[i]+
     P10[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 
 #################################
 #################################
 
 # P12
 for (i in 1:length(MODELS[,1])){
  P12[i]=
   (
    P11[i]*Surv2B[i]*Surv2NB[i]+
     P11[i]*Surv2B[i]*Surv2NBE[i]+
     
     P11[i]*Surv3B[i]*Surv3NB[i]+
     P11[i]*Surv3B[i]*Surv3NBE[i]+
     
     P11[i]*Surv3B[i]*Surv2NB[i]+
     P11[i]*Surv3B[i]*Surv2NBE[i]+
     
     P11[i]*Surv2B[i]*Surv3NB[i]+
     P11[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 
 #################################
 #################################
 
 # P13
 for (i in 1:length(MODELS[,1])){
  P13[i]=
   (
    P12[i]*Surv2B[i]*Surv2NB[i]+
     P12[i]*Surv2B[i]*Surv2NBE[i]+
     
     P12[i]*Surv3B[i]*Surv3NB[i]+
     P12[i]*Surv3B[i]*Surv3NBE[i]+
     
     P12[i]*Surv3B[i]*Surv2NB[i]+
     P12[i]*Surv3B[i]*Surv2NBE[i]+
     
     P12[i]*Surv2B[i]*Surv3NB[i]+
     P12[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 
 #################################
 #################################
 
 # P14
 for (i in 1:length(MODELS[,1])){
  P14[i]=
   (
    P13[i]*Surv2B[i]*Surv2NB[i]+
     P13[i]*Surv2B[i]*Surv2NBE[i]+
     
     P13[i]*Surv3B[i]*Surv3NB[i]+
     P13[i]*Surv3B[i]*Surv3NBE[i]+
     
     P13[i]*Surv3B[i]*Surv2NB[i]+
     P13[i]*Surv3B[i]*Surv2NBE[i]+
     
     P13[i]*Surv2B[i]*Surv3NB[i]+
     P13[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 
 #################################
 #################################
 
 # P15
 for (i in 1:length(MODELS[,1])){
  P15[i]=
   (
    P14[i]*Surv2B[i]*Surv2NB[i]+
     P14[i]*Surv2B[i]*Surv2NBE[i]+
     
     P14[i]*Surv3B[i]*Surv3NB[i]+
     P14[i]*Surv3B[i]*Surv3NBE[i]+
     
     P14[i]*Surv3B[i]*Surv2NB[i]+
     P14[i]*Surv3B[i]*Surv2NBE[i]+
     
     P14[i]*Surv2B[i]*Surv3NB[i]+
     P14[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 
 #################################
 #################################
 
 # P16
 for (i in 1:length(MODELS[,1])){
  P16[i]=
   (
    P15[i]*Surv2B[i]*Surv2NB[i]+
     P15[i]*Surv2B[i]*Surv2NBE[i]+
     
     P15[i]*Surv3B[i]*Surv3NB[i]+
     P15[i]*Surv3B[i]*Surv3NBE[i]+
     
     P15[i]*Surv3B[i]*Surv2NB[i]+
     P15[i]*Surv3B[i]*Surv2NBE[i]+
     
     P15[i]*Surv2B[i]*Surv3NB[i]+
     P15[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 
 #################################
 #################################
 
 # P17
 for (i in 1:length(MODELS[,1])){
  P17[i]=
   (
    P16[i]*Surv2B[i]*Surv2NB[i]+
     P16[i]*Surv2B[i]*Surv2NBE[i]+
     
     P16[i]*Surv3B[i]*Surv3NB[i]+
     P16[i]*Surv3B[i]*Surv3NBE[i]+
     
     P16[i]*Surv3B[i]*Surv2NB[i]+
     P16[i]*Surv3B[i]*Surv2NBE[i]+
     
     P16[i]*Surv2B[i]*Surv3NB[i]+
     P16[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 
 #################################
 #################################
 
 # P18
 for (i in 1:length(MODELS[,1])){
  P18[i]=
   (
    P17[i]*Surv2B[i]*Surv2NB[i]+
     P17[i]*Surv2B[i]*Surv2NBE[i]+
     
     P17[i]*Surv3B[i]*Surv3NB[i]+
     P17[i]*Surv3B[i]*Surv3NBE[i]+
     
     P17[i]*Surv3B[i]*Surv2NB[i]+
     P17[i]*Surv3B[i]*Surv2NBE[i]+
     
     P17[i]*Surv2B[i]*Surv3NB[i]+
     P17[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 
 #################################
 #################################
 
 # P19
 for (i in 1:length(MODELS[,1])){
  P19[i]=
   (
    P18[i]*Surv2B[i]*Surv2NB[i]+
     P18[i]*Surv2B[i]*Surv2NBE[i]+
     
     P18[i]*Surv3B[i]*Surv3NB[i]+
     P18[i]*Surv3B[i]*Surv3NBE[i]+
     
     P18[i]*Surv3B[i]*Surv2NB[i]+
     P18[i]*Surv3B[i]*Surv2NBE[i]+
     
     P18[i]*Surv2B[i]*Surv3NB[i]+
     P18[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 
 #################################
 #################################
 
 # P20
 for (i in 1:length(MODELS[,1])){
  P20[i]=
   (
    P19[i]*Surv2B[i]*Surv2NB[i]+
     P19[i]*Surv2B[i]*Surv2NBE[i]+
     
     P19[i]*Surv3B[i]*Surv3NB[i]+
     P19[i]*Surv3B[i]*Surv3NBE[i]+
     
     P19[i]*Surv3B[i]*Surv2NB[i]+
     P19[i]*Surv3B[i]*Surv2NBE[i]+
     
     P19[i]*Surv2B[i]*Surv3NB[i]+
     P19[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 
 #################################
 #################################
 
 # P21
 for (i in 1:length(MODELS[,1])){
  P21[i]=
   (
    P20[i]*Surv2B[i]*Surv2NB[i]+
     P20[i]*Surv2B[i]*Surv2NBE[i]+
     
     P20[i]*Surv3B[i]*Surv3NB[i]+
     P20[i]*Surv3B[i]*Surv3NBE[i]+
     
     P20[i]*Surv3B[i]*Surv2NB[i]+
     P20[i]*Surv3B[i]*Surv2NBE[i]+
     
     P20[i]*Surv2B[i]*Surv3NB[i]+
     P20[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 
 #################################
 #################################
 
 # P22
 for (i in 1:length(MODELS[,1])){
  P22[i]=
   (
    P21[i]*Surv2B[i]*Surv2NB[i]+
     P21[i]*Surv2B[i]*Surv2NBE[i]+
     
     P21[i]*Surv3B[i]*Surv3NB[i]+
     P21[i]*Surv3B[i]*Surv3NBE[i]+
     
     P21[i]*Surv3B[i]*Surv2NB[i]+
     P21[i]*Surv3B[i]*Surv2NBE[i]+
     
     P21[i]*Surv2B[i]*Surv3NB[i]+
     P21[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 
 #################################
 #################################
 
 # P23
 for (i in 1:length(MODELS[,1])){
  P23[i]=
   (
    P22[i]*Surv2B[i]*Surv2NB[i]+
     P22[i]*Surv2B[i]*Surv2NBE[i]+
     
     P22[i]*Surv3B[i]*Surv3NB[i]+
     P22[i]*Surv3B[i]*Surv3NBE[i]+
     
     P22[i]*Surv3B[i]*Surv2NB[i]+
     P22[i]*Surv3B[i]*Surv2NBE[i]+
     
     P22[i]*Surv2B[i]*Surv3NB[i]+
     P22[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 
 #################################
 #################################
 
 # P24
 for (i in 1:length(MODELS[,1])){
  P24[i]=
   (
    P23[i]*Surv2B[i]*Surv2NB[i]+
     P23[i]*Surv2B[i]*Surv2NBE[i]+
     
     P23[i]*Surv3B[i]*Surv3NB[i]+
     P23[i]*Surv3B[i]*Surv3NBE[i]+
     
     P23[i]*Surv3B[i]*Surv2NB[i]+
     P23[i]*Surv3B[i]*Surv2NBE[i]+
     
     P23[i]*Surv2B[i]*Surv3NB[i]+
     P23[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 
 #################################
 #################################
 
 # P25
 for (i in 1:length(MODELS[,1])){
  P25[i]=
   (
    P24[i]*Surv2B[i]*Surv2NB[i]+
     P24[i]*Surv2B[i]*Surv2NBE[i]+
     
     P24[i]*Surv3B[i]*Surv3NB[i]+
     P24[i]*Surv3B[i]*Surv3NBE[i]+
     
     P24[i]*Surv3B[i]*Surv2NB[i]+
     P24[i]*Surv3B[i]*Surv2NBE[i]+
     
     P24[i]*Surv2B[i]*Surv3NB[i]+
     P24[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 #################################
 #################################
 
 # P26
 for (i in 1:length(MODELS[,1])){
  P26[i]=
   (
     P25[i]*Surv2B[i]*Surv2NB[i]+
     P25[i]*Surv2B[i]*Surv2NBE[i]+
     P25[i]*Surv3B[i]*Surv3NB[i]+
     P25[i]*Surv3B[i]*Surv3NBE[i]+
     
     P25[i]*Surv3B[i]*Surv2NB[i]+
     P25[i]*Surv3B[i]*Surv2NBE[i]+
     
     P25[i]*Surv2B[i]*Surv3NB[i]+
     P25[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 #################################
 #################################
 
 # P27
 for (i in 1:length(MODELS[,1])){
  P27[i]=
   (
    P26[i]*Surv2B[i]*Surv2NB[i]+
     P26[i]*Surv2B[i]*Surv2NBE[i]+
     
     P26[i]*Surv3B[i]*Surv3NB[i]+
     P26[i]*Surv3B[i]*Surv3NBE[i]+
     
     P26[i]*Surv3B[i]*Surv2NB[i]+
     P26[i]*Surv3B[i]*Surv2NBE[i]+
     
     P26[i]*Surv2B[i]*Surv3NB[i]+
     P26[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }

 #################################
 #################################
 
 # P28
 for (i in 1:length(MODELS[,1])){
  P28[i]=
   (
    P27[i]*Surv2B[i]*Surv2NB[i]+
     P27[i]*Surv2B[i]*Surv2NBE[i]+
     
     P27[i]*Surv3B[i]*Surv3NB[i]+
     P27[i]*Surv3B[i]*Surv3NBE[i]+
     
     P27[i]*Surv3B[i]*Surv2NB[i]+
     P27[i]*Surv3B[i]*Surv2NBE[i]+
     
     P27[i]*Surv2B[i]*Surv3NB[i]+
     P27[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }

 #################################
 #################################
 
 # P29
 for (i in 1:length(MODELS[,1])){
  P29[i]=
   (
     P28[i]*Surv2B[i]*Surv2NB[i]+
     P28[i]*Surv2B[i]*Surv2NBE[i]+
     P28[i]*Surv3B[i]*Surv3NB[i]+
     P28[i]*Surv3B[i]*Surv3NBE[i]+
     P28[i]*Surv3B[i]*Surv2NB[i]+
     P28[i]*Surv3B[i]*Surv2NBE[i]+
     P28[i]*Surv2B[i]*Surv3NB[i]+
     P28[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 #################################
 #################################
 
 # P30
 for (i in 1:length(MODELS[,1])){
  P30[i]=
   (
     P29[i]*Surv2B[i]*Surv2NB[i]+
     P29[i]*Surv2B[i]*Surv2NBE[i]+
     P29[i]*Surv3B[i]*Surv3NB[i]+
     P29[i]*Surv3B[i]*Surv3NBE[i]+
     P29[i]*Surv3B[i]*Surv2NB[i]+
     P29[i]*Surv3B[i]*Surv2NBE[i]+
     P29[i]*Surv2B[i]*Surv3NB[i]+
     P29[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 #################################
 #################################
 
 # P31
 for (i in 1:length(MODELS[,1])){
  P31[i]=
   (
     P30[i]*Surv2B[i]*Surv2NB[i]+
     P30[i]*Surv2B[i]*Surv2NBE[i]+
     P30[i]*Surv3B[i]*Surv3NB[i]+
     P30[i]*Surv3B[i]*Surv3NBE[i]+
     P30[i]*Surv3B[i]*Surv2NB[i]+
     P30[i]*Surv3B[i]*Surv2NBE[i]+
     P30[i]*Surv2B[i]*Surv3NB[i]+
     P30[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 #################################
 #################################
 
 # P32
 for (i in 1:length(MODELS[,1])){
  P32[i]=
   (
     P31[i]*Surv2B[i]*Surv2NB[i]+
     P31[i]*Surv2B[i]*Surv2NBE[i]+
     P31[i]*Surv3B[i]*Surv3NB[i]+
     P31[i]*Surv3B[i]*Surv3NBE[i]+
     P31[i]*Surv3B[i]*Surv2NB[i]+
     P31[i]*Surv3B[i]*Surv2NBE[i]+
     P31[i]*Surv2B[i]*Surv3NB[i]+
     P31[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 #################################
 #################################
 
 # P33
 for (i in 1:length(MODELS[,1])){
  P33[i]=
   (
     P32[i]*Surv2B[i]*Surv2NB[i]+
     P32[i]*Surv2B[i]*Surv2NBE[i]+
     P32[i]*Surv3B[i]*Surv3NB[i]+
     P32[i]*Surv3B[i]*Surv3NBE[i]+
     P32[i]*Surv3B[i]*Surv2NB[i]+
     P32[i]*Surv3B[i]*Surv2NBE[i]+
     P32[i]*Surv2B[i]*Surv3NB[i]+
     P32[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 #################################
 #################################
 
 # P34
 for (i in 1:length(MODELS[,1])){
  P34[i]=
   (
     P33[i]*Surv2B[i]*Surv2NB[i]+
     P33[i]*Surv2B[i]*Surv2NBE[i]+
     P33[i]*Surv3B[i]*Surv3NB[i]+
     P33[i]*Surv3B[i]*Surv3NBE[i]+
     P33[i]*Surv3B[i]*Surv2NB[i]+
     P33[i]*Surv3B[i]*Surv2NBE[i]+
     P33[i]*Surv2B[i]*Surv3NB[i]+
     P33[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 #################################
 #################################
 
 # P35
 for (i in 1:length(MODELS[,1])){
  P35[i]=
   (
     P34[i]*Surv2B[i]*Surv2NB[i]+
     P34[i]*Surv2B[i]*Surv2NBE[i]+
     P34[i]*Surv3B[i]*Surv3NB[i]+
     P34[i]*Surv3B[i]*Surv3NBE[i]+
     P34[i]*Surv3B[i]*Surv2NB[i]+
     P34[i]*Surv3B[i]*Surv2NBE[i]+
     P34[i]*Surv2B[i]*Surv3NB[i]+
     P34[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 #################################
 #################################
 
 # P36
 for (i in 1:length(MODELS[,1])){
  P36[i]=
   (
     P35[i]*Surv2B[i]*Surv2NB[i]+
     P35[i]*Surv2B[i]*Surv2NBE[i]+
     P35[i]*Surv3B[i]*Surv3NB[i]+
     P35[i]*Surv3B[i]*Surv3NBE[i]+
     P35[i]*Surv3B[i]*Surv2NB[i]+
     P35[i]*Surv3B[i]*Surv2NBE[i]+
     P35[i]*Surv2B[i]*Surv3NB[i]+
     P35[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 #################################
 #################################
 
 # P37
 for (i in 1:length(MODELS[,1])){
  P37[i]=
   (
     P36[i]*Surv2B[i]*Surv2NB[i]+
     P36[i]*Surv2B[i]*Surv2NBE[i]+
     P36[i]*Surv3B[i]*Surv3NB[i]+
     P36[i]*Surv3B[i]*Surv3NBE[i]+
     P36[i]*Surv3B[i]*Surv2NB[i]+
     P36[i]*Surv3B[i]*Surv2NBE[i]+
     P36[i]*Surv2B[i]*Surv3NB[i]+
     P36[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 #################################
 #################################
 
 # P38
 for (i in 1:length(MODELS[,1])){
  P38[i]=
   (
     P37[i]*Surv2B[i]*Surv2NB[i]+
     P37[i]*Surv2B[i]*Surv2NBE[i]+
     P37[i]*Surv3B[i]*Surv3NB[i]+
     P37[i]*Surv3B[i]*Surv3NBE[i]+
     P37[i]*Surv3B[i]*Surv2NB[i]+
     P37[i]*Surv3B[i]*Surv2NBE[i]+
     P37[i]*Surv2B[i]*Surv3NB[i]+
     P37[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 #################################
 #################################
 
 # P39
 for (i in 1:length(MODELS[,1])){
  P39[i]=
   (
     P38[i]*Surv2B[i]*Surv2NB[i]+
     P38[i]*Surv2B[i]*Surv2NBE[i]+
     P38[i]*Surv3B[i]*Surv3NB[i]+
     P38[i]*Surv3B[i]*Surv3NBE[i]+
     P38[i]*Surv3B[i]*Surv2NB[i]+
     P38[i]*Surv3B[i]*Surv2NBE[i]+
     P38[i]*Surv2B[i]*Surv3NB[i]+
     P38[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 #################################
 #################################
 
 # P40
 for (i in 1:length(MODELS[,1])){
  P40[i]=
   (
     P39[i]*Surv2B[i]*Surv2NB[i]+
     P39[i]*Surv2B[i]*Surv2NBE[i]+
     P39[i]*Surv3B[i]*Surv3NB[i]+
     P39[i]*Surv3B[i]*Surv3NBE[i]+
     P39[i]*Surv3B[i]*Surv2NB[i]+
     P39[i]*Surv3B[i]*Surv2NBE[i]+
     P39[i]*Surv2B[i]*Surv3NB[i]+
     P39[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 #################################
 #################################
 
 # P41
 for (i in 1:length(MODELS[,1])){
  P41[i]=
   (
     P40[i]*Surv2B[i]*Surv2NB[i]+
     P40[i]*Surv2B[i]*Surv2NBE[i]+
     P40[i]*Surv3B[i]*Surv3NB[i]+
     P40[i]*Surv3B[i]*Surv3NBE[i]+
     P40[i]*Surv3B[i]*Surv2NB[i]+
     P40[i]*Surv3B[i]*Surv2NBE[i]+
     P40[i]*Surv2B[i]*Surv3NB[i]+
     P40[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 #################################
 #################################
 
 # P42
 for (i in 1:length(MODELS[,1])){
  P42[i]=
   (
     P41[i]*Surv2B[i]*Surv2NB[i]+
     P41[i]*Surv2B[i]*Surv2NBE[i]+
     P41[i]*Surv3B[i]*Surv3NB[i]+
     P41[i]*Surv3B[i]*Surv3NBE[i]+
     P41[i]*Surv3B[i]*Surv2NB[i]+
     P41[i]*Surv3B[i]*Surv2NBE[i]+
     P41[i]*Surv2B[i]*Surv3NB[i]+
     P41[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 #################################
 #################################
 
 # P43
 for (i in 1:length(MODELS[,1])){
  P43[i]=
   (
     P42[i]*Surv2B[i]*Surv2NB[i]+
     P42[i]*Surv2B[i]*Surv2NBE[i]+
     P42[i]*Surv3B[i]*Surv3NB[i]+
     P42[i]*Surv3B[i]*Surv3NBE[i]+
     P42[i]*Surv3B[i]*Surv2NB[i]+
     P42[i]*Surv3B[i]*Surv2NBE[i]+
     P42[i]*Surv2B[i]*Surv3NB[i]+
     P42[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 #################################
 #################################
 
 # P44
 for (i in 1:length(MODELS[,1])){
  P44[i]=
   (
     P43[i]*Surv2B[i]*Surv2NB[i]+
     P43[i]*Surv2B[i]*Surv2NBE[i]+
     P43[i]*Surv3B[i]*Surv3NB[i]+
     P43[i]*Surv3B[i]*Surv3NBE[i]+
     P43[i]*Surv3B[i]*Surv2NB[i]+
     P43[i]*Surv3B[i]*Surv2NBE[i]+
     P43[i]*Surv2B[i]*Surv3NB[i]+
     P43[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 #################################
 #################################
 
 # P45
 for (i in 1:length(MODELS[,1])){
  P45[i]=
   (
     P44[i]*Surv2B[i]*Surv2NB[i]+
     P44[i]*Surv2B[i]*Surv2NBE[i]+
     P44[i]*Surv3B[i]*Surv3NB[i]+
     P44[i]*Surv3B[i]*Surv3NBE[i]+
     P44[i]*Surv3B[i]*Surv2NB[i]+
     P44[i]*Surv3B[i]*Surv2NBE[i]+
     P44[i]*Surv2B[i]*Surv3NB[i]+
     P44[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 #################################
 #################################
 
 # P46
 for (i in 1:length(MODELS[,1])){
  P46[i]=
   (
     P45[i]*Surv2B[i]*Surv2NB[i]+
     P45[i]*Surv2B[i]*Surv2NBE[i]+
     P45[i]*Surv3B[i]*Surv3NB[i]+
     P45[i]*Surv3B[i]*Surv3NBE[i]+
     P45[i]*Surv3B[i]*Surv2NB[i]+
     P45[i]*Surv3B[i]*Surv2NBE[i]+
     P45[i]*Surv2B[i]*Surv3NB[i]+
     P45[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 #################################
 #################################
 
 # P47
 for (i in 1:length(MODELS[,1])){
  P47[i]=
   (
     P46[i]*Surv2B[i]*Surv2NB[i]+
     P46[i]*Surv2B[i]*Surv2NBE[i]+
     P46[i]*Surv3B[i]*Surv3NB[i]+
     P46[i]*Surv3B[i]*Surv3NBE[i]+
     P46[i]*Surv3B[i]*Surv2NB[i]+
     P46[i]*Surv3B[i]*Surv2NBE[i]+
     P46[i]*Surv2B[i]*Surv3NB[i]+
     P46[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 #################################
 #################################
 
 # P48
 for (i in 1:length(MODELS[,1])){
  P48[i]=
   (
     P47[i]*Surv2B[i]*Surv2NB[i]+
     P47[i]*Surv2B[i]*Surv2NBE[i]+
     P47[i]*Surv3B[i]*Surv3NB[i]+
     P47[i]*Surv3B[i]*Surv3NBE[i]+
     P47[i]*Surv3B[i]*Surv2NB[i]+
     P47[i]*Surv3B[i]*Surv2NBE[i]+
     P47[i]*Surv2B[i]*Surv3NB[i]+
     P47[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 #################################
 #################################
 
 # P49
 for (i in 1:length(MODELS[,1])){
  P49[i]=
   (
     P48[i]*Surv2B[i]*Surv2NB[i]+
     P48[i]*Surv2B[i]*Surv2NBE[i]+
     P48[i]*Surv3B[i]*Surv3NB[i]+
     P48[i]*Surv3B[i]*Surv3NBE[i]+
     P48[i]*Surv3B[i]*Surv2NB[i]+
     P48[i]*Surv3B[i]*Surv2NBE[i]+
     P48[i]*Surv2B[i]*Surv3NB[i]+
     P48[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }
 #################################
 #################################
 
 # P50
 for (i in 1:length(MODELS[,1])){
  P50[i]=
   (
     P49[i]*Surv2B[i]*Surv2NB[i]+
     P49[i]*Surv2B[i]*Surv2NBE[i]+
     P49[i]*Surv3B[i]*Surv3NB[i]+
     P49[i]*Surv3B[i]*Surv3NBE[i]+
     P49[i]*Surv3B[i]*Surv2NB[i]+
     P49[i]*Surv3B[i]*Surv2NBE[i]+
     P49[i]*Surv2B[i]*Surv3NB[i]+
     P49[i]*Surv2B[i]*Surv3NBE[i]
   )/(2^3)
 }

 #################################
 #################################
 Time=1:50
 Prob=cbind(P1,P2,P3,P4,P5,P6,P7,P8,P9,P10,P11,P12,P13,P14,P15,P16,P17,P18,P19,P20,P21,P22,P23,P24,P25,
P26,P27,P28,P29,P30,P31,P32,P33,P34,P35,P36,P37,P38,P39,P40,P41,P42,P43,P44,P45,P46,P47,P48,P49,P50)
 matplot(Time,t(Prob),type="l",main="Life table", xlab="Age",ylab="Probability of reaching that age")
})
# MIGRATION PARAMETERS
output$PA=renderPrint({
 PA1=read.table("NEW_PA_Northeast.txt")
 PA=PA1[["x"]];
 summary(PA)
})
output$PS=renderPrint({
 PS1=read.table("NEW_PS_Northeast.txt")
 PS=PS1[["x"]]; 
 summary(PS)
})
output$AA=renderPrint({
 AA1=read.table("NEW_AA_Northeast.txt")
 AA=AA1[["x"]];
 summary(AA)
})
output$SA=renderPrint({
 SA1=read.table("NEW_SA_Northeast.txt")
 SA=SA1[["x"]];
 summary(SA)
})
output$PurgeA=renderPrint({
 PurgeA1=read.table("NEW_AdultsPurgePercent_Northeast.txt")
 PurgeA=PurgeA1[["x"]];
 summary(PurgeA)
})
output$PurgeS=renderPrint({
 PurgeS1=read.table("NEW_SubadultsPurgePercent_Northeast.txt")
 PurgeS=PurgeS1[["x"]];
 summary(PurgeS)
})
output$AbsorbA=renderPrint({
 AbsorbA1=read.table("NEW_AdultsAbsorbPercent_Northeast.txt")
 AbsorbA=AbsorbA1[["x"]];
 summary(AbsorbA)
})
output$AbsorbS=renderPrint({
 # Create 0-row data frame which will be used to store data
 dat <- data.frame(x = numeric(0), y = numeric(0))
 
 withProgress(message = 'Calculating', value = 0, {
  # Number of times we'll go through the loop
  n <- 40
  
  for (i in 1:n) {
   # Each time through the loop, add another row of data. This is
   # a stand-in for a long-running computation.
   dat <- rbind(dat, data.frame(x = rnorm(1), y = rnorm(1)))
   
   # Increment the progress bar, and update the detail text.
   incProgress(1/n, detail = paste("", i))
   
   # Pause for 0.1 seconds to simulate a long computation.
   Sys.sleep(0.1)
  }
 })
 AbsorbS1=read.table("NEW_SubadultsAbsorbPercent_Northeast.txt")
 AbsorbS=AbsorbS1[["x"]];
 summary(AbsorbS)
})

# ANNUAL PLOTS
output$Annual=renderPlot({
 # Create 0-row data frame which will be used to store data
 dat <- data.frame(x = numeric(0), y = numeric(0))
 
 withProgress(message = 'Calculating', value = 0, {
  # Number of times we'll go through the loop
  n <- 40
  
  for (i in 1:n) {
   # Each time through the loop, add another row of data. This is
   # a stand-in for a long-running computation.
   dat <- rbind(dat, data.frame(x = rnorm(1), y = rnorm(1)))
   
   # Increment the progress bar, and update the detail text.
   incProgress(1/n, detail = paste("", i))
   
   # Pause for 0.1 seconds to simulate a long computation.
   Sys.sleep(0.1)
  }
 })
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TIMESERIES.1=read.table("NEW_TIMESERIES_Northeast.txt")
 TIMESERIES=TIMESERIES.1[["x"]]
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
 TRAJECTORY_ADULTS_JUNE=read.table("NEW_Adults_June_Northeast.txt")
 TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
 TRAJECTORY_SUBADULTS_JUNE=read.table("NEW_Subadults_June_Northeast.txt")
 TRAJECTORY_JUVENILES_JUNE=read.table("NEW_Juveniles_June_Northeast.txt")
 AnnualMean=matrix(0,2,29)	
 AnnualVar=matrix(0,2,29)		
 for (k in 1:29){
  AnnualMean[1,k]=mean(TRAJECTORY_SUBADULTS_JAN[,k])
  AnnualMean[2,k]=mean(TRAJECTORY_ADULTS_JAN[,k]);
  AnnualVar[1,k]=var(TRAJECTORY_SUBADULTS_JAN[,k])
  AnnualVar[2,k]=var(TRAJECTORY_ADULTS_JAN[,k])}
 # PLOT THE MEANS OF EACH TIME STEP
 plot(1:29,AnnualMean[1,],type="l",xlim=c(1,29),
    ylab="Algorithm-predicted abundances",xlab="Year",
    ylim=c(0,max(max(AnnualMean[1,]),
          max(AnnualMean[2,]))),col="skyblue4",lwd=3,
    main="Algorithm-predicted female abundances for the Northeast, USA",
    xaxt="n")
 year=seq(1990,2018,1)
 axis(1, at=seq(1,29,1), labels=year)
 points(1:29,AnnualMean[2,],type="l",xlim=c(1,29),
     ylab="",xlab="",ylim="",col="grey31",lwd=3)
 BOOT.UPPER.SUB=numeric(28);BOOT.LOWER.SUB=numeric(28);
 BOOT.UPPER.AD=numeric(28);BOOT.LOWER.AD=numeric(28);
 for (w in 1:29){
  VectorS=sort(TRAJECTORY_SUBADULTS_JAN[,w])
  VectorA=sort(TRAJECTORY_ADULTS_JAN[,w])
  Index=1
  BOOT.UPPER.SUB[w]=VectorS[(length(TRAJECTORY_SUBADULTS_JAN[,w]))]
  BOOT.LOWER.SUB[w]=VectorS[Index]
  BOOT.UPPER.AD[w]=VectorA[(length(TRAJECTORY_ADULTS_JAN[,w]))]
  BOOT.LOWER.AD[w]=VectorA[Index]}
 x=c(1:29,29:1)
 y=c(BOOT.LOWER.SUB,rev(BOOT.UPPER.SUB))
 polygon(x,y,col="skyblue",border="skyblue")
 yy=c(BOOT.LOWER.AD,rev(BOOT.UPPER.AD))
 polygon(x,yy,col="grey",border="grey")
 points(1:29,AnnualMean[1,],type="l",xlim="",ylab="",
     xlab="",lty=3,col="skyblue4",lwd=2)
 points(1:29,AnnualMean[2,],type="l",xlim="",ylab="",
     xlab="",lty=3,col="grey31",lwd=2)
 legend(0,max(max(AnnualMean[1,]),max(AnnualMean[2,])),
     box.lty = 0,lty=c(1,3,1,3,1),
     c("Empirical breeding adult females",
      "Predicted mean of immature and non-breeding adult females",
      "Predicted range of immature and non-breeding adult females",
      "Predicted mean of breeding adult females","Predicted range of breeding adult females"),
     lwd=c(2,2,2,2,2),col=c("green","skyblue4","skyblue", "grey31", "grey"))	
 points(1:29,TIMESERIES,type="l",lwd=2,col="green")
})
output$BreedingAll=renderPlot({
 # Create 0-row data frame which will be used to store data
 dat <- data.frame(x = numeric(0), y = numeric(0))
 
 withProgress(message = 'Calculating', value = 0, {
  # Number of times we'll go through the loop
  n <- 40
  
  for (i in 1:n) {
   # Each time through the loop, add another row of data. This is
   # a stand-in for a long-running computation.
   dat <- rbind(dat, data.frame(x = rnorm(1), y = rnorm(1)))
   
   # Increment the progress bar, and update the detail text.
   incProgress(1/n, detail = paste("", i))
   
   # Pause for 0.1 seconds to simulate a long computation.
   Sys.sleep(0.1)
  }
 })
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TIMESERIES.1=read.table("NEW_TIMESERIES_Northeast.txt")
 TIMESERIES=TIMESERIES.1[["x"]]
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
 TRAJECTORY_ADULTS_JUNE=read.table("NEW_Adults_June_Northeast.txt")
 TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
 TRAJECTORY_SUBADULTS_JUNE=read.table("NEW_Subadults_June_Northeast.txt")
 TRAJECTORY_JUVENILES_JUNE=read.table("NEW_Juveniles_June_Northeast.txt")
 NzMeanH=matrix(0,3,29)		
 NzVarH=matrix(0,3,29)
 NzMean=matrix(0,2,29)		
 NzVar=matrix(0,2,29)
 ANNUAL.ADULTS=TRAJECTORY_ADULTS_JAN
 ANNUAL.SUBADULTS=TRAJECTORY_SUBADULTS_JAN
 BIANNUAL.JUVENILES=TRAJECTORY_JUVENILES_JUNE
 BIANNUAL.SUBADULTS=TRAJECTORY_SUBADULTS_JUNE
 BIANNUAL.ADULTS=TRAJECTORY_ADULTS_JUNE
 for (k in 1:29){
  NzMean[1,k]=mean(ANNUAL.SUBADULTS[,k])
  NzMean[2,k]=mean(ANNUAL.ADULTS[,k])
  NzVar[1,k]=var(ANNUAL.SUBADULTS[,k])
  NzVar[2,k]=var(ANNUAL.ADULTS[,k])
  NzMeanH[1,k]=mean(BIANNUAL.JUVENILES[,k])
  NzMeanH[2,k]=mean(BIANNUAL.SUBADULTS[,k])
  NzMeanH[3,k]=mean(BIANNUAL.ADULTS[,k])
  NzVarH[1,k]=var(BIANNUAL.JUVENILES[,k])
  NzVarH[2,k]=var(BIANNUAL.SUBADULTS[,k])
  NzVarH[3,k]=var(BIANNUAL.ADULTS[,k])
 } # END AT EACH TIME LOOP [k]
 NzMeanS=numeric(58)
 NzMeanS=c(NzMean[1,1],-5000,NzMean[1,2],-5000,NzMean[1,3],
      -5000,NzMean[1,4],-5000,NzMean[1,5],-5000,NzMean[1,6],
      -5000,NzMean[1,7],-5000,NzMean[1,8],-5000,NzMean[1,9],
      -5000,NzMean[1,10],-5000,NzMean[1,11],-5000,NzMean[1,12],
      -5000,NzMean[1,13],-5000,NzMean[1,14],-5000,NzMean[1,15],
      -5000,NzMean[1,16],-5000,NzMean[1,17],-5000,NzMean[1,18],
      -5000,NzMean[1,19],-5000,NzMean[1,20],-5000,NzMean[1,21],
      -5000,NzMean[1,22],-5000,NzMean[1,23],-5000,NzMean[1,24],
      -5000,NzMean[1,25],-5000,NzMean[1,26],-5000,NzMean[1,27],
      -5000,NzMean[1,28],-5000,NzMean[1,29],-5000)
 NzMeanA=numeric(58)
 NzMeanA=c(NzMean[2,1],-5000,NzMean[2,2],-5000,NzMean[2,3],
      -5000,NzMean[2,4],-5000,NzMean[2,5],-5000,NzMean[2,6],
      -5000,NzMean[2,7],-5000,NzMean[2,8],-5000,NzMean[2,9],
      -5000,NzMean[2,10],-5000,NzMean[2,11],-5000,NzMean[2,12],
      -5000,NzMean[2,13],-5000,NzMean[2,14],-5000,NzMean[2,15],
      -5000,NzMean[2,16],-5000,NzMean[2,17],-5000,NzMean[2,18],
      -5000,NzMean[2,19],-5000,NzMean[2,20],-5000,NzMean[2,21],
      -5000,NzMean[2,22],-5000,NzMean[2,23],-5000,NzMean[2,24],
      -5000,NzMean[2,25],-5000,NzMean[2,26],-5000,NzMean[2,27],
      -5000,NzMean[2,28],-5000,NzMean[2,29],-5000)
 NzSlong=matrix(0,length(MODELS[,1]),58)
 NzAlong=matrix(0,length(MODELS[,1]),58)
 NzJHlong=matrix(0,length(MODELS[,1]),58)
 NzSHlong=matrix(0,length(MODELS[,1]),58)
 NzAHlong=matrix(0,length(MODELS[,1]),58)
 ANNUAL.ADULTS=TRAJECTORY_ADULTS_JAN
 ANNUAL.SUBADULTS=TRAJECTORY_SUBADULTS_JAN
 BIANNUAL.JUVENILES=TRAJECTORY_JUVENILES_JUNE
 BIANNUAL.SUBADULTS=TRAJECTORY_SUBADULTS_JUNE
 BIANNUAL.ADULTS=TRAJECTORY_ADULTS_JUNE
 ELONGATEDTIMESERIES=numeric(58)
 ELONGATEDTIMESERIES[1]=TIMESERIES[1]
 loop=1
 for (u in 2:58){
  if (u%%2==0){
   ELONGATEDTIMESERIES[u]=-5000}
  if (u%%2!=0){
   loop=loop+1
   ELONGATEDTIMESERIES[u]=TIMESERIES[loop]}}
 for (j in 1:length(ANNUAL.SUBADULTS[,1])){
  NzSlong[j,]=c(ANNUAL.SUBADULTS[j,1],BIANNUAL.SUBADULTS[j,1],
         ANNUAL.SUBADULTS[j,2],BIANNUAL.SUBADULTS[j,2],ANNUAL.SUBADULTS[j,3],BIANNUAL.SUBADULTS[j,3],
         ANNUAL.SUBADULTS[j,4],BIANNUAL.SUBADULTS[j,4],ANNUAL.SUBADULTS[j,5],BIANNUAL.SUBADULTS[j,5],
         ANNUAL.SUBADULTS[j,6],BIANNUAL.SUBADULTS[j,6],ANNUAL.SUBADULTS[j,7],BIANNUAL.SUBADULTS[j,7],
         ANNUAL.SUBADULTS[j,8],BIANNUAL.SUBADULTS[j,8],ANNUAL.SUBADULTS[j,9],BIANNUAL.SUBADULTS[j,9],
         ANNUAL.SUBADULTS[j,10],BIANNUAL.SUBADULTS[j,10],ANNUAL.SUBADULTS[j,11],BIANNUAL.SUBADULTS[j,11],
         ANNUAL.SUBADULTS[j,12],BIANNUAL.SUBADULTS[j,12],ANNUAL.SUBADULTS[j,13],BIANNUAL.SUBADULTS[j,13],
         ANNUAL.SUBADULTS[j,14],BIANNUAL.SUBADULTS[j,14],ANNUAL.SUBADULTS[j,15],BIANNUAL.SUBADULTS[j,15],
         ANNUAL.SUBADULTS[j,16],BIANNUAL.SUBADULTS[j,16],ANNUAL.SUBADULTS[j,17],BIANNUAL.SUBADULTS[j,17],
         ANNUAL.SUBADULTS[j,18],BIANNUAL.SUBADULTS[j,18],ANNUAL.SUBADULTS[j,19],BIANNUAL.SUBADULTS[j,19],
         ANNUAL.SUBADULTS[j,20],BIANNUAL.SUBADULTS[j,20],ANNUAL.SUBADULTS[j,21],BIANNUAL.SUBADULTS[j,21],
         ANNUAL.SUBADULTS[j,22],BIANNUAL.SUBADULTS[j,22],ANNUAL.SUBADULTS[j,23],BIANNUAL.SUBADULTS[j,23],
         ANNUAL.SUBADULTS[j,24],BIANNUAL.SUBADULTS[j,24],ANNUAL.SUBADULTS[j,25],BIANNUAL.SUBADULTS[j,25],
         ANNUAL.SUBADULTS[j,26],BIANNUAL.SUBADULTS[j,26],ANNUAL.SUBADULTS[j,27],BIANNUAL.SUBADULTS[j,27],
         ANNUAL.SUBADULTS[j,28],BIANNUAL.SUBADULTS[j,28],ANNUAL.SUBADULTS[j,29],BIANNUAL.SUBADULTS[j,29])}
 for (j in 1:length(BIANNUAL.ADULTS[,1])){
  NzAlong[j,]=c(ANNUAL.ADULTS[j,1],BIANNUAL.ADULTS[j,1],
         ANNUAL.ADULTS[j,2],BIANNUAL.ADULTS[j,2],ANNUAL.ADULTS[j,3],BIANNUAL.ADULTS[j,3],
         ANNUAL.ADULTS[j,4],BIANNUAL.ADULTS[j,4],ANNUAL.ADULTS[j,5],BIANNUAL.ADULTS[j,5],
         ANNUAL.ADULTS[j,6],BIANNUAL.ADULTS[j,6],ANNUAL.ADULTS[j,7],BIANNUAL.ADULTS[j,7],
         ANNUAL.ADULTS[j,8],BIANNUAL.ADULTS[j,8],ANNUAL.ADULTS[j,9],BIANNUAL.ADULTS[j,9],
         ANNUAL.ADULTS[j,10],BIANNUAL.ADULTS[j,10],ANNUAL.ADULTS[j,11],BIANNUAL.ADULTS[j,11],
         ANNUAL.ADULTS[j,12],BIANNUAL.ADULTS[j,12],ANNUAL.ADULTS[j,13],BIANNUAL.ADULTS[j,13],
         ANNUAL.ADULTS[j,14],BIANNUAL.ADULTS[j,14],ANNUAL.ADULTS[j,15],BIANNUAL.ADULTS[j,15],
         ANNUAL.ADULTS[j,16],BIANNUAL.ADULTS[j,16],ANNUAL.ADULTS[j,17],BIANNUAL.ADULTS[j,17],
         ANNUAL.ADULTS[j,18],BIANNUAL.ADULTS[j,18],ANNUAL.ADULTS[j,19],BIANNUAL.ADULTS[j,19],
         ANNUAL.ADULTS[j,20],BIANNUAL.ADULTS[j,20],ANNUAL.ADULTS[j,21],BIANNUAL.ADULTS[j,21],
         ANNUAL.ADULTS[j,22],BIANNUAL.ADULTS[j,22],ANNUAL.ADULTS[j,23],BIANNUAL.ADULTS[j,23],
         ANNUAL.ADULTS[j,24],BIANNUAL.ADULTS[j,24],ANNUAL.ADULTS[j,25],BIANNUAL.ADULTS[j,25],
         ANNUAL.ADULTS[j,26],BIANNUAL.ADULTS[j,26],ANNUAL.ADULTS[j,27],BIANNUAL.ADULTS[j,27],
         ANNUAL.ADULTS[j,28],BIANNUAL.ADULTS[j,28],ANNUAL.ADULTS[j,29],BIANNUAL.ADULTS[j,29])}
 hsBOOT.UPPER.SUB=numeric(58);hsBOOT.LOWER.SUB=numeric(58);
 hsBOOT.UPPER.AD=numeric(58);hsBOOT.LOWER.AD=numeric(58);
 for (w in 1:58){
  Index=1
  VectorS=sort(NzSlong[,w])
  VectorA=sort(NzAlong[,w])
  hsBOOT.UPPER.SUB[w]=VectorS[(length(NzSlong[,w]))]
  hsBOOT.LOWER.SUB[w]=VectorS[Index]
  hsBOOT.UPPER.AD[w]=VectorA[(length(NzAlong[,w]))]
  hsBOOT.LOWER.AD[w]=VectorA[Index]}
 for (b in 1:58){if (hsBOOT.UPPER.SUB[b]<0){hsBOOT.UPPER.SUB[b]=0}}
 for (b in 1:58){if (hsBOOT.LOWER.SUB[b]<0){hsBOOT.LOWER.SUB[b]=0}}
 plot(1.4:58.4,NzMeanA,type="p",xlim=c(1,58),
    ylab="Algorithm-predicted abundances",xlab="Bi-annual periods",
    ylim=c(0,max(max(hsBOOT.UPPER.SUB),max(hsBOOT.UPPER.AD))),
    col="grey",lwd=1,lty=3,pch=20,
    main="Algorithm-predicted female abundances for the Northeast, USA",xaxt="n")
 year=seq(1990,2018,1)
 axis(1,at=seq(1,57,2), labels=year)
 segments(1.2,hsBOOT.LOWER.SUB[1],1.2,hsBOOT.UPPER.SUB[1],lwd=3,col="skyblue")
 segments(3.2,hsBOOT.LOWER.SUB[3],3.2,hsBOOT.UPPER.SUB[3],lwd=3,col="skyblue")
 segments(5.2,hsBOOT.LOWER.SUB[5],5.2,hsBOOT.UPPER.SUB[5],lwd=3,col="skyblue")
 segments(7.2,hsBOOT.LOWER.SUB[7],7.2,hsBOOT.UPPER.SUB[7],lwd=3,col="skyblue")
 segments(9.2,hsBOOT.LOWER.SUB[9],9.2,hsBOOT.UPPER.SUB[9],lwd=3,col="skyblue")
 segments(11.2,hsBOOT.LOWER.SUB[11],11.2,hsBOOT.UPPER.SUB[11],lwd=3,col="skyblue")
 segments(13.2,hsBOOT.LOWER.SUB[13],13.2,hsBOOT.UPPER.SUB[13],lwd=3,col="skyblue")
 segments(15.2,hsBOOT.LOWER.SUB[15],15.2,hsBOOT.UPPER.SUB[15],lwd=3,col="skyblue")
 segments(17.2,hsBOOT.LOWER.SUB[17],17.2,hsBOOT.UPPER.SUB[17],lwd=3,col="skyblue")
 segments(19.2,hsBOOT.LOWER.SUB[19],19.2,hsBOOT.UPPER.SUB[19],lwd=3,col="skyblue")
 segments(21.2,hsBOOT.LOWER.SUB[21],21.2,hsBOOT.UPPER.SUB[21],lwd=3,col="skyblue")
 segments(23.2,hsBOOT.LOWER.SUB[23],23.2,hsBOOT.UPPER.SUB[23],lwd=3,col="skyblue")
 segments(25.2,hsBOOT.LOWER.SUB[25],25.2,hsBOOT.UPPER.SUB[25],lwd=3,col="skyblue")
 segments(27.2,hsBOOT.LOWER.SUB[27],27.2,hsBOOT.UPPER.SUB[27],lwd=3,col="skyblue")
 segments(29.2,hsBOOT.LOWER.SUB[29],29.2,hsBOOT.UPPER.SUB[29],lwd=3,col="skyblue")
 segments(31.2,hsBOOT.LOWER.SUB[31],31.2,hsBOOT.UPPER.SUB[31],lwd=3,col="skyblue")
 segments(33.2,hsBOOT.LOWER.SUB[33],33.2,hsBOOT.UPPER.SUB[33],lwd=3,col="skyblue")
 segments(35.2,hsBOOT.LOWER.SUB[35],35.2,hsBOOT.UPPER.SUB[35],lwd=3,col="skyblue")
 segments(37.2,hsBOOT.LOWER.SUB[37],37.2,hsBOOT.UPPER.SUB[37],lwd=3,col="skyblue")
 segments(39.2,hsBOOT.LOWER.SUB[39],39.2,hsBOOT.UPPER.SUB[39],lwd=3,col="skyblue")
 segments(41.2,hsBOOT.LOWER.SUB[41],41.2,hsBOOT.UPPER.SUB[41],lwd=3,col="skyblue")
 segments(43.2,hsBOOT.LOWER.SUB[43],43.2,hsBOOT.UPPER.SUB[43],lwd=3,col="skyblue")
 segments(45.2,hsBOOT.LOWER.SUB[45],45.2,hsBOOT.UPPER.SUB[45],lwd=3,col="skyblue")
 segments(47.2,hsBOOT.LOWER.SUB[47],47.2,hsBOOT.UPPER.SUB[47],lwd=3,col="skyblue")
 segments(49.2,hsBOOT.LOWER.SUB[49],49.2,hsBOOT.UPPER.SUB[49],lwd=3,col="skyblue")
 segments(51.2,hsBOOT.LOWER.SUB[51],51.2,hsBOOT.UPPER.SUB[51],lwd=3,col="skyblue")
 segments(53.2,hsBOOT.LOWER.SUB[53],53.2,hsBOOT.UPPER.SUB[53],lwd=3,col="skyblue")
 segments(55.2,hsBOOT.LOWER.SUB[55],55.2,hsBOOT.UPPER.SUB[55],lwd=3,col="skyblue")
 segments(57.2,hsBOOT.LOWER.SUB[57],57.2,hsBOOT.UPPER.SUB[57],lwd=3,col="skyblue")
 segments(1.4,hsBOOT.LOWER.AD[1],1.4,hsBOOT.UPPER.AD[1],lwd=3,col="GREY")
 segments(3.4,hsBOOT.LOWER.AD[3],3.4,hsBOOT.UPPER.AD[3],lwd=3,col="GREY")
 segments(5.4,hsBOOT.LOWER.AD[5],5.4,hsBOOT.UPPER.AD[5],lwd=3,col="GREY")
 segments(7.4,hsBOOT.LOWER.AD[7],7.4,hsBOOT.UPPER.AD[7],lwd=3,col="GREY")
 segments(9.4,hsBOOT.LOWER.AD[9],9.4,hsBOOT.UPPER.AD[9],lwd=3,col="GREY")
 segments(11.4,hsBOOT.LOWER.AD[11],11.4,hsBOOT.UPPER.AD[11],lwd=3,col="GREY")
 segments(13.4,hsBOOT.LOWER.AD[13],13.4,hsBOOT.UPPER.AD[13],lwd=3,col="GREY")
 segments(15.4,hsBOOT.LOWER.AD[15],15.4,hsBOOT.UPPER.AD[15],lwd=3,col="GREY")
 segments(17.4,hsBOOT.LOWER.AD[17],17.4,hsBOOT.UPPER.AD[17],lwd=3,col="GREY")
 segments(19.4,hsBOOT.LOWER.AD[19],19.4,hsBOOT.UPPER.AD[19],lwd=3,col="GREY")
 segments(21.4,hsBOOT.LOWER.AD[21],21.4,hsBOOT.UPPER.AD[21],lwd=3,col="GREY")
 segments(23.4,hsBOOT.LOWER.AD[23],23.4,hsBOOT.UPPER.AD[23],lwd=3,col="GREY")
 segments(25.4,hsBOOT.LOWER.AD[25],25.4,hsBOOT.UPPER.AD[25],lwd=3,col="GREY")
 segments(27.4,hsBOOT.LOWER.AD[27],27.4,hsBOOT.UPPER.AD[27],lwd=3,col="GREY")
 segments(29.4,hsBOOT.LOWER.AD[29],29.4,hsBOOT.UPPER.AD[29],lwd=3,col="GREY")
 segments(31.4,hsBOOT.LOWER.AD[31],31.4,hsBOOT.UPPER.AD[31],lwd=3,col="GREY")
 segments(33.4,hsBOOT.LOWER.AD[33],33.4,hsBOOT.UPPER.AD[33],lwd=3,col="GREY")
 segments(35.4,hsBOOT.LOWER.AD[35],35.4,hsBOOT.UPPER.AD[35],lwd=3,col="GREY")
 segments(37.4,hsBOOT.LOWER.AD[37],37.4,hsBOOT.UPPER.AD[37],lwd=3,col="GREY")
 segments(39.4,hsBOOT.LOWER.AD[39],39.4,hsBOOT.UPPER.AD[39],lwd=3,col="GREY")
 segments(41.4,hsBOOT.LOWER.AD[41],41.4,hsBOOT.UPPER.AD[41],lwd=3,col="GREY")
 segments(43.4,hsBOOT.LOWER.AD[43],43.4,hsBOOT.UPPER.AD[43],lwd=3,col="GREY")
 segments(45.4,hsBOOT.LOWER.AD[45],45.4,hsBOOT.UPPER.AD[45],lwd=3,col="GREY")
 segments(47.4,hsBOOT.LOWER.AD[47],47.4,hsBOOT.UPPER.AD[47],lwd=3,col="GREY")
 segments(49.4,hsBOOT.LOWER.AD[49],49.4,hsBOOT.UPPER.AD[49],lwd=3,col="GREY")
 segments(51.4,hsBOOT.LOWER.AD[51],51.4,hsBOOT.UPPER.AD[51],lwd=3,col="GREY")
 segments(53.4,hsBOOT.LOWER.AD[53],53.4,hsBOOT.UPPER.AD[53],lwd=3,col="GREY")
 segments(55.4,hsBOOT.LOWER.AD[55],55.4,hsBOOT.UPPER.AD[55],lwd=3,col="GREY")
 segments(57.4,hsBOOT.LOWER.AD[57],57.4,hsBOOT.UPPER.AD[57],lwd=3,col="GREY")
 # ADD EMPIRCAL DATA TO THE PLOT
 points(1.4:58.4, ELONGATEDTIMESERIES,col="green",pch=19)
 legend(0,max(max(hsBOOT.UPPER.SUB),max(hsBOOT.UPPER.AD)),
     c("Empirical breeding adult females", 
      "Predicted range for immature and non-breeding adult females during the breeding period",
      "Predicted range for breeding-adult females during the breeding period"),
     box.lty = 0,lty=c(1,1,1),lwd=c(3,3,3),pch=c(19,20,20),
     col=c("green","skyblue","grey"))
})

# BI-ANNUAL PLOTS
output$BiannualAll=renderPlot({
 # Create 0-row data frame which will be used to store data
 dat <- data.frame(x = numeric(0), y = numeric(0))
 
 withProgress(message = 'Calculating', value = 0, {
  # Number of times we'll go through the loop
  n <- 40
  
  for (i in 1:n) {
   # Each time through the loop, add another row of data. This is
   # a stand-in for a long-running computation.
   dat <- rbind(dat, data.frame(x = rnorm(1), y = rnorm(1)))
   
   # Increment the progress bar, and update the detail text.
   incProgress(1/n, detail = paste("", i))
   
   # Pause for 0.1 seconds to simulate a long computation.
   Sys.sleep(0.1)
  }
 })
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TIMESERIES.1=read.table("NEW_TIMESERIES_Northeast.txt")
 TIMESERIES=TIMESERIES.1[["x"]]
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
 TRAJECTORY_ADULTS_JUNE=read.table("NEW_Adults_June_Northeast.txt")
 TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
 TRAJECTORY_SUBADULTS_JUNE=read.table("NEW_Subadults_June_Northeast.txt")
 TRAJECTORY_JUVENILES_JUNE=read.table("NEW_Juveniles_June_Northeast.txt")
 NzMeanH=matrix(0,3,29)		
 NzVarH=matrix(0,3,29)
 NzMean=matrix(0,2,29)		
 NzVar=matrix(0,2,29)
 ANNUAL.ADULTS=TRAJECTORY_ADULTS_JAN
 ANNUAL.SUBADULTS=TRAJECTORY_SUBADULTS_JAN
 BIANNUAL.JUVENILES=TRAJECTORY_JUVENILES_JUNE
 BIANNUAL.SUBADULTS=TRAJECTORY_SUBADULTS_JUNE
 BIANNUAL.ADULTS=TRAJECTORY_ADULTS_JUNE
 for (k in 1:29){
  NzMean[1,k]=mean(ANNUAL.SUBADULTS[,k])
  NzMean[2,k]=mean(ANNUAL.ADULTS[,k])
  NzVar[1,k]=var(ANNUAL.SUBADULTS[,k])
  NzVar[2,k]=var(ANNUAL.ADULTS[,k])
  NzMeanH[1,k]=mean(BIANNUAL.JUVENILES[,k])
  NzMeanH[2,k]=mean(BIANNUAL.SUBADULTS[,k])
  NzMeanH[3,k]=mean(BIANNUAL.ADULTS[,k])
  NzVarH[1,k]=var(BIANNUAL.JUVENILES[,k])
  NzVarH[2,k]=var(BIANNUAL.SUBADULTS[,k])
  NzVarH[3,k]=var(BIANNUAL.ADULTS[,k])
 } # END AT EACH TIME LOOP [k]
 ELONGATEDTIMESERIES=numeric(58)
 ELONGATEDTIMESERIES[1]=TIMESERIES[1]
 loop=1
 for (u in 2:58){
  if (u%%2==0){
   ELONGATEDTIMESERIES[u]=-5000}
  if (u%%2!=0){
   loop=loop+1
   ELONGATEDTIMESERIES[u]=TIMESERIES[loop]}}
 NzSlong=matrix(0,length(MODELS[,1]),58)
 NzAlong=matrix(0,length(MODELS[,1]),58)
 NzJHlong=matrix(0,length(MODELS[,1]),58)
 NzSHlong=matrix(0,length(MODELS[,1]),58)
 NzAHlong=matrix(0,length(MODELS[,1]),58)
 ANNUAL.ADULTS=TRAJECTORY_ADULTS_JAN
 ANNUAL.SUBADULTS=TRAJECTORY_SUBADULTS_JAN
 BIANNUAL.JUVENILES=TRAJECTORY_JUVENILES_JUNE
 BIANNUAL.SUBADULTS=TRAJECTORY_SUBADULTS_JUNE
 BIANNUAL.ADULTS=TRAJECTORY_ADULTS_JUNE
 for (j in 1:length(BIANNUAL.JUVENILES[,1])){
  NzJHlong[j,]=c(-500,BIANNUAL.JUVENILES[j,1],
          -500,BIANNUAL.JUVENILES[j,2],
          -500,BIANNUAL.JUVENILES[j,3],-500,BIANNUAL.JUVENILES[j,4],
          -500,BIANNUAL.JUVENILES[j,5],
          -500,BIANNUAL.JUVENILES[j,6],-500,BIANNUAL.JUVENILES[j,7],
          -500,BIANNUAL.JUVENILES[j,8],
          -500,BIANNUAL.JUVENILES[j,9],-500,BIANNUAL.JUVENILES[j,10],
          -500,BIANNUAL.JUVENILES[j,11],-500,BIANNUAL.JUVENILES[j,12],
          -500,BIANNUAL.JUVENILES[j,13],-500,BIANNUAL.JUVENILES[j,14],
          -500,BIANNUAL.JUVENILES[j,15],-500,BIANNUAL.JUVENILES[j,16],
          -500,BIANNUAL.JUVENILES[j,17],-500,BIANNUAL.JUVENILES[j,18],
          -500,BIANNUAL.JUVENILES[j,19],-500,BIANNUAL.JUVENILES[j,20],
          -500,BIANNUAL.JUVENILES[j,21],-500,BIANNUAL.JUVENILES[j,22],
          -500,BIANNUAL.JUVENILES[j,23],-500,BIANNUAL.JUVENILES[j,24],
          -500,BIANNUAL.JUVENILES[j,25],-500,BIANNUAL.JUVENILES[j,26],
          -500,BIANNUAL.JUVENILES[j,27],-500,BIANNUAL.JUVENILES[j,28],
          -500,BIANNUAL.JUVENILES[j,29])}
 for (j in 1:length(BIANNUAL.SUBADULTS[,1])){
  NzSHlong[j,]=c(-500,BIANNUAL.SUBADULTS[j,1],-500,BIANNUAL.SUBADULTS[j,2],
          -500,BIANNUAL.SUBADULTS[j,3],-500,BIANNUAL.SUBADULTS[j,4],-500,BIANNUAL.SUBADULTS[j,5],
          -500,BIANNUAL.SUBADULTS[j,6],-500,BIANNUAL.SUBADULTS[j,7],-500,BIANNUAL.SUBADULTS[j,8],
          -500,BIANNUAL.SUBADULTS[j,9],-500,BIANNUAL.SUBADULTS[j,10],-500,BIANNUAL.SUBADULTS[j,11],
          -500,BIANNUAL.SUBADULTS[j,12],-500,BIANNUAL.SUBADULTS[j,13],-500,BIANNUAL.SUBADULTS[j,14],
          -500,BIANNUAL.SUBADULTS[j,15],-500,BIANNUAL.SUBADULTS[j,16],-500,BIANNUAL.SUBADULTS[j,17],
          -500,BIANNUAL.SUBADULTS[j,18],-500,BIANNUAL.SUBADULTS[j,19],-500,BIANNUAL.SUBADULTS[j,20],
          -500,BIANNUAL.SUBADULTS[j,21],-500,BIANNUAL.SUBADULTS[j,22],-500,BIANNUAL.SUBADULTS[j,23],
          -500,BIANNUAL.SUBADULTS[j,24],-500,BIANNUAL.SUBADULTS[j,25],-500,BIANNUAL.SUBADULTS[j,26],
          -500,BIANNUAL.SUBADULTS[j,27],-500,BIANNUAL.SUBADULTS[j,28],-500,BIANNUAL.SUBADULTS[j,29])}
 for (j in 1:length(BIANNUAL.ADULTS[,1])){
  NzAHlong[j,]=c(-500,BIANNUAL.ADULTS[j,1],
          -500,BIANNUAL.ADULTS[j,2],
          -500,BIANNUAL.ADULTS[j,3],-500,BIANNUAL.ADULTS[j,4],
          -500,BIANNUAL.ADULTS[j,5],-500,BIANNUAL.ADULTS[j,6],
          -500,BIANNUAL.ADULTS[j,7],-500,BIANNUAL.ADULTS[j,8],
          -500,BIANNUAL.ADULTS[j,9],-500,BIANNUAL.ADULTS[j,10],
          -500,BIANNUAL.ADULTS[j,11],-500,BIANNUAL.ADULTS[j,12],
          -500,BIANNUAL.ADULTS[j,13],-500,BIANNUAL.ADULTS[j,14],
          -500,BIANNUAL.ADULTS[j,15],-500,BIANNUAL.ADULTS[j,16],
          -500,BIANNUAL.ADULTS[j,17],-500,BIANNUAL.ADULTS[j,18],
          -500,BIANNUAL.ADULTS[j,19],-500,BIANNUAL.ADULTS[j,20],
          -500,BIANNUAL.ADULTS[j,21],-500,BIANNUAL.ADULTS[j,22],
          -500,BIANNUAL.ADULTS[j,23],-500,BIANNUAL.ADULTS[j,24],
          -500,BIANNUAL.ADULTS[j,25],-500,BIANNUAL.ADULTS[j,26],
          -500,BIANNUAL.ADULTS[j,27],-500,BIANNUAL.ADULTS[j,28],
          -500,BIANNUAL.ADULTS[j,29])}
 for (j in 1:length(ANNUAL.SUBADULTS[,1])){
  NzSlong[j,]=c(ANNUAL.SUBADULTS[j,1],BIANNUAL.SUBADULTS[j,1],
         ANNUAL.SUBADULTS[j,2],BIANNUAL.SUBADULTS[j,2],ANNUAL.SUBADULTS[j,3],BIANNUAL.SUBADULTS[j,3],
         ANNUAL.SUBADULTS[j,4],BIANNUAL.SUBADULTS[j,4],ANNUAL.SUBADULTS[j,5],BIANNUAL.SUBADULTS[j,5],
         ANNUAL.SUBADULTS[j,6],BIANNUAL.SUBADULTS[j,6],ANNUAL.SUBADULTS[j,7],BIANNUAL.SUBADULTS[j,7],
         ANNUAL.SUBADULTS[j,8],BIANNUAL.SUBADULTS[j,8],ANNUAL.SUBADULTS[j,9],BIANNUAL.SUBADULTS[j,9],
         ANNUAL.SUBADULTS[j,10],BIANNUAL.SUBADULTS[j,10],ANNUAL.SUBADULTS[j,11],BIANNUAL.SUBADULTS[j,11],
         ANNUAL.SUBADULTS[j,12],BIANNUAL.SUBADULTS[j,12],ANNUAL.SUBADULTS[j,13],BIANNUAL.SUBADULTS[j,13],
         ANNUAL.SUBADULTS[j,14],BIANNUAL.SUBADULTS[j,14],ANNUAL.SUBADULTS[j,15],BIANNUAL.SUBADULTS[j,15],
         ANNUAL.SUBADULTS[j,16],BIANNUAL.SUBADULTS[j,16],ANNUAL.SUBADULTS[j,17],BIANNUAL.SUBADULTS[j,17],
         ANNUAL.SUBADULTS[j,18],BIANNUAL.SUBADULTS[j,18],ANNUAL.SUBADULTS[j,19],BIANNUAL.SUBADULTS[j,19],
         ANNUAL.SUBADULTS[j,20],BIANNUAL.SUBADULTS[j,20],ANNUAL.SUBADULTS[j,21],BIANNUAL.SUBADULTS[j,21],
         ANNUAL.SUBADULTS[j,22],BIANNUAL.SUBADULTS[j,22],ANNUAL.SUBADULTS[j,23],BIANNUAL.SUBADULTS[j,23],
         ANNUAL.SUBADULTS[j,24],BIANNUAL.SUBADULTS[j,24],ANNUAL.SUBADULTS[j,25],BIANNUAL.SUBADULTS[j,25],
         ANNUAL.SUBADULTS[j,26],BIANNUAL.SUBADULTS[j,26],ANNUAL.SUBADULTS[j,27],BIANNUAL.SUBADULTS[j,27],
         ANNUAL.SUBADULTS[j,28],BIANNUAL.SUBADULTS[j,28],ANNUAL.SUBADULTS[j,29],BIANNUAL.SUBADULTS[j,29])}
 for (j in 1:length(BIANNUAL.ADULTS[,1])){
  NzAlong[j,]=c(ANNUAL.ADULTS[j,1],BIANNUAL.ADULTS[j,1],
         ANNUAL.ADULTS[j,2],BIANNUAL.ADULTS[j,2],ANNUAL.ADULTS[j,3],BIANNUAL.ADULTS[j,3],
         ANNUAL.ADULTS[j,4],BIANNUAL.ADULTS[j,4],ANNUAL.ADULTS[j,5],BIANNUAL.ADULTS[j,5],
         ANNUAL.ADULTS[j,6],BIANNUAL.ADULTS[j,6],ANNUAL.ADULTS[j,7],BIANNUAL.ADULTS[j,7],
         ANNUAL.ADULTS[j,8],BIANNUAL.ADULTS[j,8],ANNUAL.ADULTS[j,9],BIANNUAL.ADULTS[j,9],
         ANNUAL.ADULTS[j,10],BIANNUAL.ADULTS[j,10],ANNUAL.ADULTS[j,11],BIANNUAL.ADULTS[j,11],
         ANNUAL.ADULTS[j,12],BIANNUAL.ADULTS[j,12],ANNUAL.ADULTS[j,13],BIANNUAL.ADULTS[j,13],
         ANNUAL.ADULTS[j,14],BIANNUAL.ADULTS[j,14],ANNUAL.ADULTS[j,15],BIANNUAL.ADULTS[j,15],
         ANNUAL.ADULTS[j,16],BIANNUAL.ADULTS[j,16],ANNUAL.ADULTS[j,17],BIANNUAL.ADULTS[j,17],
         ANNUAL.ADULTS[j,18],BIANNUAL.ADULTS[j,18],ANNUAL.ADULTS[j,19],BIANNUAL.ADULTS[j,19],
         ANNUAL.ADULTS[j,20],BIANNUAL.ADULTS[j,20],ANNUAL.ADULTS[j,21],BIANNUAL.ADULTS[j,21],
         ANNUAL.ADULTS[j,22],BIANNUAL.ADULTS[j,22],ANNUAL.ADULTS[j,23],BIANNUAL.ADULTS[j,23],
         ANNUAL.ADULTS[j,24],BIANNUAL.ADULTS[j,24],ANNUAL.ADULTS[j,25],BIANNUAL.ADULTS[j,25],
         ANNUAL.ADULTS[j,26],BIANNUAL.ADULTS[j,26],ANNUAL.ADULTS[j,27],BIANNUAL.ADULTS[j,27],
         ANNUAL.ADULTS[j,28],BIANNUAL.ADULTS[j,28],ANNUAL.ADULTS[j,29],BIANNUAL.ADULTS[j,29])}
 NzMeanS=numeric(58)
 NzMeanS=c(NzMean[1,1],-500,NzMean[1,2],-500,NzMean[1,3],
      -500,NzMean[1,4],-500,NzMean[1,5],-500,NzMean[1,6],
      -500,NzMean[1,7],-500,NzMean[1,8],-500,NzMean[1,9],
      -500,NzMean[1,10],-500,NzMean[1,11],-500,NzMean[1,12],
      -500,NzMean[1,13],-500,NzMean[1,14],-500,NzMean[1,15],
      -500,NzMean[1,16],-500,NzMean[1,17],-500,NzMean[1,18],
      -500,NzMean[1,19],-500,NzMean[1,20],-500,NzMean[1,21],
      -500,NzMean[1,22],-500,NzMean[1,23],-500,NzMean[1,24],
      -500,NzMean[1,25],-500,NzMean[1,26],-500,NzMean[1,27],
      -500,NzMean[1,28],-500,NzMean[1,29],-500)
 NzMeanA=numeric(58)
 NzMeanA=c(NzMean[2,1],-5000,NzMean[2,2],-5000,NzMean[2,3],
      -5000,NzMean[2,4],-5000,NzMean[2,5],-5000,NzMean[2,6],
      -5000,NzMean[2,7],-5000,NzMean[2,8],-5000,NzMean[2,9],
      -5000,NzMean[2,10],-5000,NzMean[2,11],-5000,NzMean[2,12],
      -5000,NzMean[2,13],-5000,NzMean[2,14],-5000,NzMean[2,15],
      -5000,NzMean[2,16],-5000,NzMean[2,17],-5000,NzMean[2,18],
      -5000,NzMean[2,19],-5000,NzMean[2,20],-5000,NzMean[2,21],
      -5000,NzMean[2,22],-5000,NzMean[2,23],-5000,NzMean[2,24],
      -5000,NzMean[2,25],-5000,NzMean[2,26],-5000,NzMean[2,27],
      -5000,NzMean[2,28],-5000,NzMean[2,29],-5000)
 hsBOOT.UPPER.SUB=numeric(58);hsBOOT.LOWER.SUB=numeric(58);
 hsBOOT.UPPER.AD=numeric(58);hsBOOT.LOWER.AD=numeric(58);
 hhsBOOT.UPPER.JUV=numeric(58);hhsBOOT.LOWER.JUV=numeric(58);
 hhsBOOT.UPPER.SUB=numeric(58);hhsBOOT.LOWER.SUB=numeric(58);
 hhsBOOT.UPPER.AD=numeric(58);hhsBOOT.LOWER.AD=numeric(58);
 for (w in 1:58){
  Index=1
  VectorS=sort(NzSlong[,w])
  VectorA=sort(NzAlong[,w])
  hsBOOT.UPPER.SUB[w]=VectorS[(length(NzSlong[,w]))]
  hsBOOT.LOWER.SUB[w]=VectorS[Index]
  hsBOOT.UPPER.AD[w]=VectorA[(length(NzAlong[,w]))]
  hsBOOT.LOWER.AD[w]=VectorA[Index]
  VectorJH=sort(NzJHlong[,w])
  VectorSH=sort(NzSHlong[,w])
  VectorAH=sort(NzAHlong[,w])
  hhsBOOT.UPPER.JUV[w]=VectorJH[(length(NzJHlong[,w]))]
  hhsBOOT.LOWER.JUV[w]=VectorJH[Index]
  hhsBOOT.UPPER.SUB[w]=VectorSH[(length(NzSHlong[,w]))]
  hsBOOT.LOWER.SUB[w]=VectorSH[Index]
  hhsBOOT.UPPER.AD[w]=VectorAH[(length(NzAHlong[,w]))]
  hhsBOOT.LOWER.AD[w]=VectorAH[Index]}
 for (b in 1:58){if (hhsBOOT.UPPER.JUV[b]<0){hhsBOOT.UPPER.JUV[b]=0}}
 for (b in 1:58){if (hhsBOOT.LOWER.JUV[b]<0){hhsBOOT.LOWER.JUV[b]=0}}
 for (b in 1:58){if (hsBOOT.UPPER.SUB[b]<0){hsBOOT.UPPER.SUB[b]=0}}
 for (b in 1:58){if (hsBOOT.LOWER.SUB[b]<0){hsBOOT.LOWER.SUB[b]=0}}
 for (b in 1:58){if (hhsBOOT.UPPER.SUB[b]<0){hhsBOOT.UPPER.SUB[b]=0}}
 for (b in 1:58){if (hhsBOOT.LOWER.SUB[b]<0){hhsBOOT.LOWER.SUB[b]=0}}
 for (b in 1:58){if (hsBOOT.UPPER.AD[b]<0){hsBOOT.UPPER.AD[b]=0}}
 for (b in 1:58){if (hsBOOT.LOWER.AD[b]<0){hsBOOT.LOWER.AD[b]=0}}
 for (b in 1:58){if (hhsBOOT.UPPER.AD[b]<0){hhsBOOT.UPPER.AD[b]=0}}
 for (b in 1:58){if (hhsBOOT.LOWER.AD[b]<0){hhsBOOT.LOWER.AD[b]=0}}
 plot(1.4:58.4,NzMeanA,type="p",xlim=c(1,58),
    ylab="Algorithm-predicted abundances",xlab="Bi-annual periods",
    ylim=c(0,max(max(hhsBOOT.UPPER.SUB),max(hhsBOOT.UPPER.JUV),max(hhsBOOT.UPPER.AD),
          max(hsBOOT.UPPER.SUB),max(hsBOOT.UPPER.AD))),
    col="grey",lwd=1,lty=3,pch=20,
    main="Algorithm-predicted female abundances for the Northeast, USA",xaxt="n")
 year=seq(1990,2018,1)
 axis(1,at=seq(1,57,2), labels=year)
 segments(2,hhsBOOT.LOWER.JUV[2],2,hhsBOOT.UPPER.JUV[2],lwd=3,col="darkcyan")
 segments(4,hhsBOOT.LOWER.JUV[4],4,hhsBOOT.UPPER.JUV[4],lwd=3,col="darkcyan")
 segments(6,hhsBOOT.LOWER.JUV[6],6,hhsBOOT.UPPER.JUV[6],lwd=3,col="darkcyan")
 segments(8,hhsBOOT.LOWER.JUV[8],8,hhsBOOT.UPPER.JUV[8],lwd=3,col="darkcyan")
 segments(10,hhsBOOT.LOWER.JUV[10],10,hhsBOOT.UPPER.JUV[10],lwd=3,col="darkcyan")
 segments(12,hhsBOOT.LOWER.JUV[12],12,hhsBOOT.UPPER.JUV[12],lwd=3,col="darkcyan")
 segments(14,hhsBOOT.LOWER.JUV[14],14,hhsBOOT.UPPER.JUV[14],lwd=3,col="darkcyan")
 segments(16,hhsBOOT.LOWER.JUV[16],16,hhsBOOT.UPPER.JUV[16],lwd=3,col="darkcyan")
 segments(18,hhsBOOT.LOWER.JUV[18],18,hhsBOOT.UPPER.JUV[18],lwd=3,col="darkcyan")
 segments(20,hhsBOOT.LOWER.JUV[20],20,hhsBOOT.UPPER.JUV[20],lwd=3,col="darkcyan")
 segments(22,hhsBOOT.LOWER.JUV[22],22,hhsBOOT.UPPER.JUV[22],lwd=3,col="darkcyan")
 segments(24,hhsBOOT.LOWER.JUV[24],24,hhsBOOT.UPPER.JUV[24],lwd=3,col="darkcyan")
 segments(26,hhsBOOT.LOWER.JUV[26],26,hhsBOOT.UPPER.JUV[26],lwd=3,col="darkcyan")
 segments(28,hhsBOOT.LOWER.JUV[28],28,hhsBOOT.UPPER.JUV[28],lwd=3,col="darkcyan")
 segments(30,hhsBOOT.LOWER.JUV[30],30,hhsBOOT.UPPER.JUV[30],lwd=3,col="darkcyan")
 segments(32,hhsBOOT.LOWER.JUV[32],32,hhsBOOT.UPPER.JUV[32],lwd=3,col="darkcyan")
 segments(34,hhsBOOT.LOWER.JUV[34],34,hhsBOOT.UPPER.JUV[34],lwd=3,col="darkcyan")
 segments(36,hhsBOOT.LOWER.JUV[36],36,hhsBOOT.UPPER.JUV[36],lwd=3,col="darkcyan")
 segments(38,hhsBOOT.LOWER.JUV[38],38,hhsBOOT.UPPER.JUV[38],lwd=3,col="darkcyan")
 segments(40,hhsBOOT.LOWER.JUV[40],40,hhsBOOT.UPPER.JUV[40],lwd=3,col="darkcyan")
 segments(42,hhsBOOT.LOWER.JUV[42],42,hhsBOOT.UPPER.JUV[42],lwd=3,col="darkcyan")
 segments(44,hhsBOOT.LOWER.JUV[44],44,hhsBOOT.UPPER.JUV[44],lwd=3,col="darkcyan")
 segments(46,hhsBOOT.LOWER.JUV[46],46,hhsBOOT.UPPER.JUV[46],lwd=3,col="darkcyan")
 segments(48,hhsBOOT.LOWER.JUV[48],48,hhsBOOT.UPPER.JUV[48],lwd=3,col="darkcyan")
 segments(50,hhsBOOT.LOWER.JUV[50],50,hhsBOOT.UPPER.JUV[50],lwd=3,col="darkcyan")
 segments(52,hhsBOOT.LOWER.JUV[52],52,hhsBOOT.UPPER.JUV[52],lwd=3,col="darkcyan")
 segments(54,hhsBOOT.LOWER.JUV[54],54,hhsBOOT.UPPER.JUV[54],lwd=3,col="darkcyan")
 segments(56,hhsBOOT.LOWER.JUV[56],56,hhsBOOT.UPPER.JUV[56],lwd=3,col="darkcyan")
 segments(58,hhsBOOT.LOWER.JUV[58],58,hhsBOOT.UPPER.JUV[58],lwd=3,col="darkcyan")
 segments(2.2,hhsBOOT.LOWER.SUB[2],2.2,hhsBOOT.UPPER.SUB[2],lwd=3,col="skyblue")
 segments(4.2,hhsBOOT.LOWER.SUB[4],4.2,hhsBOOT.UPPER.SUB[4],lwd=3,col="skyblue")
 segments(6.2,hhsBOOT.LOWER.SUB[6],6.2,hhsBOOT.UPPER.SUB[6],lwd=3,col="skyblue")
 segments(8.2,hhsBOOT.LOWER.SUB[8],8.2,hhsBOOT.UPPER.SUB[8],lwd=3,col="skyblue")
 segments(10.2,hhsBOOT.LOWER.SUB[10],10.2,hhsBOOT.UPPER.SUB[10],lwd=3,col="skyblue")
 segments(12.2,hhsBOOT.LOWER.SUB[12],12.2,hhsBOOT.UPPER.SUB[12],lwd=3,col="skyblue")
 segments(14.2,hhsBOOT.LOWER.SUB[14],14.2,hhsBOOT.UPPER.SUB[14],lwd=3,col="skyblue")
 segments(16.2,hhsBOOT.LOWER.SUB[16],16.2,hhsBOOT.UPPER.SUB[16],lwd=3,col="skyblue")
 segments(18.2,hhsBOOT.LOWER.SUB[18],18.2,hhsBOOT.UPPER.SUB[18],lwd=3,col="skyblue")
 segments(20.2,hhsBOOT.LOWER.SUB[20],20.2,hhsBOOT.UPPER.SUB[20],lwd=3,col="skyblue")
 segments(22.2,hhsBOOT.LOWER.SUB[22],22.2,hhsBOOT.UPPER.SUB[22],lwd=3,col="skyblue")
 segments(24.2,hhsBOOT.LOWER.SUB[24],24.2,hhsBOOT.UPPER.SUB[24],lwd=3,col="skyblue")
 segments(26.2,hhsBOOT.LOWER.SUB[26],26.2,hhsBOOT.UPPER.SUB[26],lwd=3,col="skyblue")
 segments(28.2,hhsBOOT.LOWER.SUB[28],28.2,hhsBOOT.UPPER.SUB[28],lwd=3,col="skyblue")
 segments(30.2,hhsBOOT.LOWER.SUB[30],30.2,hhsBOOT.UPPER.SUB[30],lwd=3,col="skyblue")
 segments(32.2,hhsBOOT.LOWER.SUB[32],32.2,hhsBOOT.UPPER.SUB[32],lwd=3,col="skyblue")
 segments(34.2,hhsBOOT.LOWER.SUB[34],34.2,hhsBOOT.UPPER.SUB[34],lwd=3,col="skyblue")
 segments(36.2,hhsBOOT.LOWER.SUB[36],36.2,hhsBOOT.UPPER.SUB[36],lwd=3,col="skyblue")
 segments(38.2,hhsBOOT.LOWER.SUB[38],38.2,hhsBOOT.UPPER.SUB[38],lwd=3,col="skyblue")
 segments(40.2,hhsBOOT.LOWER.SUB[40],40.2,hhsBOOT.UPPER.SUB[40],lwd=3,col="skyblue")
 segments(42.2,hhsBOOT.LOWER.SUB[42],42.2,hhsBOOT.UPPER.SUB[42],lwd=3,col="skyblue")
 segments(44.2,hhsBOOT.LOWER.SUB[44],44.2,hhsBOOT.UPPER.SUB[44],lwd=3,col="skyblue")
 segments(46.2,hhsBOOT.LOWER.SUB[46],46.2,hhsBOOT.UPPER.SUB[46],lwd=3,col="skyblue")
 segments(48.2,hhsBOOT.LOWER.SUB[48],48.2,hhsBOOT.UPPER.SUB[48],lwd=3,col="skyblue")
 segments(50.2,hhsBOOT.LOWER.SUB[50],50.2,hhsBOOT.UPPER.SUB[50],lwd=3,col="skyblue")
 segments(52.2,hhsBOOT.LOWER.SUB[52],52.2,hhsBOOT.UPPER.SUB[52],lwd=3,col="skyblue")
 segments(54.2,hhsBOOT.LOWER.SUB[54],54.2,hhsBOOT.UPPER.SUB[54],lwd=3,col="skyblue")
 segments(56.2,hhsBOOT.LOWER.SUB[56],56.2,hhsBOOT.UPPER.SUB[56],lwd=3,col="skyblue")
 segments(58.2,hhsBOOT.LOWER.SUB[58],58.2,hhsBOOT.UPPER.SUB[58],lwd=3,col="skyblue")
 segments(1.2,hsBOOT.LOWER.SUB[1],1.2,hsBOOT.UPPER.SUB[1],lwd=3,col="skyblue")
 segments(3.2,hsBOOT.LOWER.SUB[3],3.2,hsBOOT.UPPER.SUB[3],lwd=3,col="skyblue")
 segments(5.2,hsBOOT.LOWER.SUB[5],5.2,hsBOOT.UPPER.SUB[5],lwd=3,col="skyblue")
 segments(7.2,hsBOOT.LOWER.SUB[7],7.2,hsBOOT.UPPER.SUB[7],lwd=3,col="skyblue")
 segments(9.2,hsBOOT.LOWER.SUB[9],9.2,hsBOOT.UPPER.SUB[9],lwd=3,col="skyblue")
 segments(11.2,hsBOOT.LOWER.SUB[11],11.2,hsBOOT.UPPER.SUB[11],lwd=3,col="skyblue")
 segments(13.2,hsBOOT.LOWER.SUB[13],13.2,hsBOOT.UPPER.SUB[13],lwd=3,col="skyblue")
 segments(15.2,hsBOOT.LOWER.SUB[15],15.2,hsBOOT.UPPER.SUB[15],lwd=3,col="skyblue")
 segments(17.2,hsBOOT.LOWER.SUB[17],17.2,hsBOOT.UPPER.SUB[17],lwd=3,col="skyblue")
 segments(19.2,hsBOOT.LOWER.SUB[19],19.2,hsBOOT.UPPER.SUB[19],lwd=3,col="skyblue")
 segments(21.2,hsBOOT.LOWER.SUB[21],21.2,hsBOOT.UPPER.SUB[21],lwd=3,col="skyblue")
 segments(23.2,hsBOOT.LOWER.SUB[23],23.2,hsBOOT.UPPER.SUB[23],lwd=3,col="skyblue")
 segments(25.2,hsBOOT.LOWER.SUB[25],25.2,hsBOOT.UPPER.SUB[25],lwd=3,col="skyblue")
 segments(27.2,hsBOOT.LOWER.SUB[27],27.2,hsBOOT.UPPER.SUB[27],lwd=3,col="skyblue")
 segments(29.2,hsBOOT.LOWER.SUB[29],29.2,hsBOOT.UPPER.SUB[29],lwd=3,col="skyblue")
 segments(31.2,hsBOOT.LOWER.SUB[31],31.2,hsBOOT.UPPER.SUB[31],lwd=3,col="skyblue")
 segments(33.2,hsBOOT.LOWER.SUB[33],33.2,hsBOOT.UPPER.SUB[33],lwd=3,col="skyblue")
 segments(35.2,hsBOOT.LOWER.SUB[35],35.2,hsBOOT.UPPER.SUB[35],lwd=3,col="skyblue")
 segments(37.2,hsBOOT.LOWER.SUB[37],37.2,hsBOOT.UPPER.SUB[37],lwd=3,col="skyblue")
 segments(39.2,hsBOOT.LOWER.SUB[39],39.2,hsBOOT.UPPER.SUB[39],lwd=3,col="skyblue")
 segments(41.2,hsBOOT.LOWER.SUB[41],41.2,hsBOOT.UPPER.SUB[41],lwd=3,col="skyblue")
 segments(43.2,hsBOOT.LOWER.SUB[43],43.2,hsBOOT.UPPER.SUB[43],lwd=3,col="skyblue")
 segments(45.2,hsBOOT.LOWER.SUB[45],45.2,hsBOOT.UPPER.SUB[45],lwd=3,col="skyblue")
 segments(47.2,hsBOOT.LOWER.SUB[47],47.2,hsBOOT.UPPER.SUB[47],lwd=3,col="skyblue")
 segments(49.2,hsBOOT.LOWER.SUB[49],49.2,hsBOOT.UPPER.SUB[49],lwd=3,col="skyblue")
 segments(51.2,hsBOOT.LOWER.SUB[51],51.2,hsBOOT.UPPER.SUB[51],lwd=3,col="skyblue")
 segments(53.2,hsBOOT.LOWER.SUB[53],53.2,hsBOOT.UPPER.SUB[53],lwd=3,col="skyblue")
 segments(55.2,hsBOOT.LOWER.SUB[55],55.2,hsBOOT.UPPER.SUB[55],lwd=3,col="skyblue")
 segments(57.2,hsBOOT.LOWER.SUB[57],57.2,hsBOOT.UPPER.SUB[57],lwd=3,col="skyblue")
 segments(2.4,hhsBOOT.LOWER.AD[2],2.4,hhsBOOT.UPPER.AD[2],lwd=3,col="GREY")
 segments(4.4,hhsBOOT.LOWER.AD[4],4.4,hhsBOOT.UPPER.AD[4],lwd=3,col="GREY")
 segments(6.4,hhsBOOT.LOWER.AD[6],6.4,hhsBOOT.UPPER.AD[6],lwd=3,col="GREY")
 segments(8.4,hhsBOOT.LOWER.AD[8],8.4,hhsBOOT.UPPER.AD[8],lwd=3,col="GREY")
 segments(10.4,hhsBOOT.LOWER.AD[10],10.4,hhsBOOT.UPPER.AD[10],lwd=3,col="GREY")
 segments(12.4,hhsBOOT.LOWER.AD[12],12.4,hhsBOOT.UPPER.AD[12],lwd=3,col="GREY")
 segments(14.4,hhsBOOT.LOWER.AD[14],14.4,hhsBOOT.UPPER.AD[14],lwd=3,col="GREY")
 segments(16.4,hhsBOOT.LOWER.AD[16],16.4,hhsBOOT.UPPER.AD[16],lwd=3,col="GREY")
 segments(18.4,hhsBOOT.LOWER.AD[18],18.4,hhsBOOT.UPPER.AD[18],lwd=3,col="GREY")
 segments(20.4,hhsBOOT.LOWER.AD[20],20.4,hhsBOOT.UPPER.AD[20],lwd=3,col="GREY")
 segments(22.4,hhsBOOT.LOWER.AD[22],22.4,hhsBOOT.UPPER.AD[22],lwd=3,col="GREY")
 segments(24.4,hhsBOOT.LOWER.AD[24],24.4,hhsBOOT.UPPER.AD[24],lwd=3,col="GREY")
 segments(26.4,hhsBOOT.LOWER.AD[26],26.4,hhsBOOT.UPPER.AD[26],lwd=3,col="GREY")
 segments(28.4,hhsBOOT.LOWER.AD[28],28.4,hhsBOOT.UPPER.AD[28],lwd=3,col="GREY")
 segments(30.4,hhsBOOT.LOWER.AD[30],30.4,hhsBOOT.UPPER.AD[30],lwd=3,col="GREY")
 segments(32.4,hhsBOOT.LOWER.AD[32],32.4,hhsBOOT.UPPER.AD[32],lwd=3,col="GREY")
 segments(34.4,hhsBOOT.LOWER.AD[34],34.4,hhsBOOT.UPPER.AD[34],lwd=3,col="GREY")
 segments(36.4,hhsBOOT.LOWER.AD[36],36.4,hhsBOOT.UPPER.AD[36],lwd=3,col="GREY")
 segments(38.4,hhsBOOT.LOWER.AD[38],38.4,hhsBOOT.UPPER.AD[38],lwd=3,col="GREY")
 segments(40.4,hhsBOOT.LOWER.AD[40],40.4,hhsBOOT.UPPER.AD[40],lwd=3,col="GREY")
 segments(42.4,hhsBOOT.LOWER.AD[42],42.4,hhsBOOT.UPPER.AD[42],lwd=3,col="GREY")
 segments(44.4,hhsBOOT.LOWER.AD[44],44.4,hhsBOOT.UPPER.AD[44],lwd=3,col="GREY")
 segments(46.4,hhsBOOT.LOWER.AD[46],46.4,hhsBOOT.UPPER.AD[46],lwd=3,col="GREY")
 segments(48.4,hhsBOOT.LOWER.AD[48],48.4,hhsBOOT.UPPER.AD[48],lwd=3,col="GREY")
 segments(50.4,hhsBOOT.LOWER.AD[50],50.4,hhsBOOT.UPPER.AD[50],lwd=3,col="GREY")
 segments(52.4,hhsBOOT.LOWER.AD[52],52.4,hhsBOOT.UPPER.AD[52],lwd=3,col="GREY")
 segments(54.4,hhsBOOT.LOWER.AD[54],54.4,hhsBOOT.UPPER.AD[54],lwd=3,col="GREY")
 segments(56.4,hhsBOOT.LOWER.AD[56],56.4,hhsBOOT.UPPER.AD[56],lwd=3,col="GREY")
 segments(58.4,hhsBOOT.LOWER.AD[58],58.4,hhsBOOT.UPPER.AD[58],lwd=3,col="GREY")
 segments(1.4,hsBOOT.LOWER.AD[1],1.4,hsBOOT.UPPER.AD[1],lwd=3,col="GREY")
 segments(3.4,hsBOOT.LOWER.AD[3],3.4,hsBOOT.UPPER.AD[3],lwd=3,col="GREY")
 segments(5.4,hsBOOT.LOWER.AD[5],5.4,hsBOOT.UPPER.AD[5],lwd=3,col="GREY")
 segments(7.4,hsBOOT.LOWER.AD[7],7.4,hsBOOT.UPPER.AD[7],lwd=3,col="GREY")
 segments(9.4,hsBOOT.LOWER.AD[9],9.4,hsBOOT.UPPER.AD[9],lwd=3,col="GREY")
 segments(11.4,hsBOOT.LOWER.AD[11],11.4,hsBOOT.UPPER.AD[11],lwd=3,col="GREY")
 segments(13.4,hsBOOT.LOWER.AD[13],13.4,hsBOOT.UPPER.AD[13],lwd=3,col="GREY")
 segments(15.4,hsBOOT.LOWER.AD[15],15.4,hsBOOT.UPPER.AD[15],lwd=3,col="GREY")
 segments(17.4,hsBOOT.LOWER.AD[17],17.4,hsBOOT.UPPER.AD[17],lwd=3,col="GREY")
 segments(19.4,hsBOOT.LOWER.AD[19],19.4,hsBOOT.UPPER.AD[19],lwd=3,col="GREY")
 segments(21.4,hsBOOT.LOWER.AD[21],21.4,hsBOOT.UPPER.AD[21],lwd=3,col="GREY")
 segments(23.4,hsBOOT.LOWER.AD[23],23.4,hsBOOT.UPPER.AD[23],lwd=3,col="GREY")
 segments(25.4,hsBOOT.LOWER.AD[25],25.4,hsBOOT.UPPER.AD[25],lwd=3,col="GREY")
 segments(27.4,hsBOOT.LOWER.AD[27],27.4,hsBOOT.UPPER.AD[27],lwd=3,col="GREY")
 segments(29.4,hsBOOT.LOWER.AD[29],29.4,hsBOOT.UPPER.AD[29],lwd=3,col="GREY")
 segments(31.4,hsBOOT.LOWER.AD[31],31.4,hsBOOT.UPPER.AD[31],lwd=3,col="GREY")
 segments(33.4,hsBOOT.LOWER.AD[33],33.4,hsBOOT.UPPER.AD[33],lwd=3,col="GREY")
 segments(35.4,hsBOOT.LOWER.AD[35],35.4,hsBOOT.UPPER.AD[35],lwd=3,col="GREY")
 segments(37.4,hsBOOT.LOWER.AD[37],37.4,hsBOOT.UPPER.AD[37],lwd=3,col="GREY")
 segments(39.4,hsBOOT.LOWER.AD[39],39.4,hsBOOT.UPPER.AD[39],lwd=3,col="GREY")
 segments(41.4,hsBOOT.LOWER.AD[41],41.4,hsBOOT.UPPER.AD[41],lwd=3,col="GREY")
 segments(43.4,hsBOOT.LOWER.AD[43],43.4,hsBOOT.UPPER.AD[43],lwd=3,col="GREY")
 segments(45.4,hsBOOT.LOWER.AD[45],45.4,hsBOOT.UPPER.AD[45],lwd=3,col="GREY")
 segments(47.4,hsBOOT.LOWER.AD[47],47.4,hsBOOT.UPPER.AD[47],lwd=3,col="GREY")
 segments(49.4,hsBOOT.LOWER.AD[49],49.4,hsBOOT.UPPER.AD[49],lwd=3,col="GREY")
 segments(51.4,hsBOOT.LOWER.AD[51],51.4,hsBOOT.UPPER.AD[51],lwd=3,col="GREY")
 segments(53.4,hsBOOT.LOWER.AD[53],53.4,hsBOOT.UPPER.AD[53],lwd=3,col="GREY")
 segments(55.4,hsBOOT.LOWER.AD[55],55.4,hsBOOT.UPPER.AD[55],lwd=3,col="GREY")
 segments(57.4,hsBOOT.LOWER.AD[57],57.4,hsBOOT.UPPER.AD[57],lwd=3,col="GREY")
 points(1.4:58.4, ELONGATEDTIMESERIES,col="green",pch=19)
 legend(0,max(max(hhsBOOT.UPPER.SUB),max(hhsBOOT.UPPER.JUV),max(hhsBOOT.UPPER.AD),
        max(hsBOOT.UPPER.SUB),max(hsBOOT.UPPER.AD)),
     c("Empirical breeding adult females throughout the year", 
      "Predicted range for hatchling females throughout the year",
      "Predicted range for immature and non-breeding adult females throughout the year",
      "Predicted range for breeding adult females throughout the year"),
     box.lty = 0,lty=c(1,1,1,1),lwd=c(3,3,3,3),pch=c(19,20,20,20),
     col=c("green","darkcyan","skyblue","grey"))
})
output$NonBreedingAll=renderPlot({
 # Create 0-row data frame which will be used to store data
 dat <- data.frame(x = numeric(0), y = numeric(0))
 
 withProgress(message = 'Calculating', value = 0, {
  # Number of times we'll go through the loop
  n <- 40
  
  for (i in 1:n) {
   # Each time through the loop, add another row of data. This is
   # a stand-in for a long-running computation.
   dat <- rbind(dat, data.frame(x = rnorm(1), y = rnorm(1)))
   
   # Increment the progress bar, and update the detail text.
   incProgress(1/n, detail = paste("", i))
   
   # Pause for 0.1 seconds to simulate a long computation.
   Sys.sleep(0.1)
  }
 })
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 # GATHER THE PREVIOUSLY SAVED TIME SERIES TRAJECTORIES
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
 TRAJECTORY_ADULTS_JUNE=read.table("NEW_Adults_June_Northeast.txt")
 TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
 TRAJECTORY_SUBADULTS_JUNE=read.table("NEW_Subadults_June_Northeast.txt")
 TRAJECTORY_JUVENILES_JUNE=read.table("NEW_Juveniles_June_Northeast.txt")
 # GENERATE THE TIME SERIES FOR ALL MODELS 
 NzSlong=matrix(0,length(MODELS[,1]),58)
 NzAlong=matrix(0,length(MODELS[,1]),58)
 NzJHlong=matrix(0,length(MODELS[,1]),58)
 NzSHlong=matrix(0,length(MODELS[,1]),58)
 NzAHlong=matrix(0,length(MODELS[,1]),58)
 ANNUAL.ADULTS=TRAJECTORY_ADULTS_JAN
 ANNUAL.SUBADULTS=TRAJECTORY_SUBADULTS_JAN
 BIANNUAL.JUVENILES=TRAJECTORY_JUVENILES_JUNE
 BIANNUAL.SUBADULTS=TRAJECTORY_SUBADULTS_JUNE
 BIANNUAL.ADULTS=TRAJECTORY_ADULTS_JUNE
 for (j in 1:length(BIANNUAL.JUVENILES[,1])){
  NzJHlong[j,]=c(-50,BIANNUAL.JUVENILES[j,1],
          -50,BIANNUAL.JUVENILES[j,2],
          -50,BIANNUAL.JUVENILES[j,3],-50,BIANNUAL.JUVENILES[j,4],
          -50,BIANNUAL.JUVENILES[j,5],
          -50,BIANNUAL.JUVENILES[j,6],-50,BIANNUAL.JUVENILES[j,7],
          -50,BIANNUAL.JUVENILES[j,8],
          -50,BIANNUAL.JUVENILES[j,9],-50,BIANNUAL.JUVENILES[j,10],
          -50,BIANNUAL.JUVENILES[j,11],-50,BIANNUAL.JUVENILES[j,12],
          -50,BIANNUAL.JUVENILES[j,13],-50,BIANNUAL.JUVENILES[j,14],
          -50,BIANNUAL.JUVENILES[j,15],-50,BIANNUAL.JUVENILES[j,16],
          -50,BIANNUAL.JUVENILES[j,17],-50,BIANNUAL.JUVENILES[j,18],
          -50,BIANNUAL.JUVENILES[j,19],-50,BIANNUAL.JUVENILES[j,20],
          -50,BIANNUAL.JUVENILES[j,21],-50,BIANNUAL.JUVENILES[j,22],
          -50,BIANNUAL.JUVENILES[j,23],-50,BIANNUAL.JUVENILES[j,24],
          -50,BIANNUAL.JUVENILES[j,25],-50,BIANNUAL.JUVENILES[j,26],
          -50,BIANNUAL.JUVENILES[j,27],-50,BIANNUAL.JUVENILES[j,28],
          -50,BIANNUAL.JUVENILES[j,29])}
 for (j in 1:length(BIANNUAL.SUBADULTS[,1])){
  NzSHlong[j,]=c(-50,BIANNUAL.SUBADULTS[j,1],-50,BIANNUAL.SUBADULTS[j,2],
          -50,BIANNUAL.SUBADULTS[j,3],-50,BIANNUAL.SUBADULTS[j,4],-50,BIANNUAL.SUBADULTS[j,5],
          -50,BIANNUAL.SUBADULTS[j,6],-50,BIANNUAL.SUBADULTS[j,7],-50,BIANNUAL.SUBADULTS[j,8],
          -50,BIANNUAL.SUBADULTS[j,9],-50,BIANNUAL.SUBADULTS[j,10],-50,BIANNUAL.SUBADULTS[j,11],
          -50,BIANNUAL.SUBADULTS[j,12],-50,BIANNUAL.SUBADULTS[j,13],-50,BIANNUAL.SUBADULTS[j,14],
          -50,BIANNUAL.SUBADULTS[j,15],-50,BIANNUAL.SUBADULTS[j,16],-50,BIANNUAL.SUBADULTS[j,17],
          -50,BIANNUAL.SUBADULTS[j,18],-50,BIANNUAL.SUBADULTS[j,19],-50,BIANNUAL.SUBADULTS[j,20],
          -50,BIANNUAL.SUBADULTS[j,21],-50,BIANNUAL.SUBADULTS[j,22],-50,BIANNUAL.SUBADULTS[j,23],
          -50,BIANNUAL.SUBADULTS[j,24],-50,BIANNUAL.SUBADULTS[j,25],-50,BIANNUAL.SUBADULTS[j,26],
          -50,BIANNUAL.SUBADULTS[j,27],-50,BIANNUAL.SUBADULTS[j,28],-50,BIANNUAL.SUBADULTS[j,29])}
 for (j in 1:length(BIANNUAL.ADULTS[,1])){
  NzAHlong[j,]=c(-50,BIANNUAL.ADULTS[j,1],
          -50,BIANNUAL.ADULTS[j,2],
          -50,BIANNUAL.ADULTS[j,3],-50,BIANNUAL.ADULTS[j,4],
          -50,BIANNUAL.ADULTS[j,5],-50,BIANNUAL.ADULTS[j,6],
          -50,BIANNUAL.ADULTS[j,7],-50,BIANNUAL.ADULTS[j,8],
          -50,BIANNUAL.ADULTS[j,9],-50,BIANNUAL.ADULTS[j,10],
          -50,BIANNUAL.ADULTS[j,11],-50,BIANNUAL.ADULTS[j,12],
          -50,BIANNUAL.ADULTS[j,13],-50,BIANNUAL.ADULTS[j,14],
          -50,BIANNUAL.ADULTS[j,15],-50,BIANNUAL.ADULTS[j,16],
          -50,BIANNUAL.ADULTS[j,17],-50,BIANNUAL.ADULTS[j,18],
          -50,BIANNUAL.ADULTS[j,19],-50,BIANNUAL.ADULTS[j,20],
          -50,BIANNUAL.ADULTS[j,21],-50,BIANNUAL.ADULTS[j,22],
          -50,BIANNUAL.ADULTS[j,23],-50,BIANNUAL.ADULTS[j,24],
          -50,BIANNUAL.ADULTS[j,25],-50,BIANNUAL.ADULTS[j,26],
          -50,BIANNUAL.ADULTS[j,27],-50,BIANNUAL.ADULTS[j,28],
          -50,BIANNUAL.ADULTS[j,29])}
 NzMeanH=matrix(0,3,29)		
 NzVarH=matrix(0,3,29)
 NzMean=matrix(0,2,29)		
 NzVar=matrix(0,2,29)
 for (k in 1:29){
  NzMean[1,k]=mean(ANNUAL.SUBADULTS[,k])
  NzMean[2,k]=mean(ANNUAL.ADULTS[,k])
  NzVar[1,k]=var(ANNUAL.SUBADULTS[,k])
  NzVar[2,k]=var(ANNUAL.ADULTS[,k])
  NzMeanH[1,k]=mean(BIANNUAL.JUVENILES[,k])
  NzMeanH[2,k]=mean(BIANNUAL.SUBADULTS[,k])
  NzMeanH[3,k]=mean(BIANNUAL.ADULTS[,k])
  NzVarH[1,k]=var(BIANNUAL.JUVENILES[,k])
  NzVarH[2,k]=var(BIANNUAL.SUBADULTS[,k])
  NzVarH[3,k]=var(BIANNUAL.ADULTS[,k])
 } 
 NzMeanS=numeric(58)
 NzMeanS=c(NzMean[1,1],-50,NzMean[1,2],-50,NzMean[1,3],
      -50,NzMean[1,4],-50,NzMean[1,5],-50,NzMean[1,6],
      -50,NzMean[1,7],-50,NzMean[1,8],-50,NzMean[1,9],
      -50,NzMean[1,10],-50,NzMean[1,11],-50,NzMean[1,12],
      -50,NzMean[1,13],-50,NzMean[1,14],-50,NzMean[1,15],
      -50,NzMean[1,16],-50,NzMean[1,17],-50,NzMean[1,18],
      -50,NzMean[1,19],-50,NzMean[1,20],-50,NzMean[1,21],
      -50,NzMean[1,22],-50,NzMean[1,23],-50,NzMean[1,24],
      -50,NzMean[1,25],-50,NzMean[1,26],-50,NzMean[1,27],
      -50,NzMean[1,28],-50,NzMean[1,29],-50)
 hhsBOOT.UPPER.JUV=numeric(58);hhsBOOT.LOWER.JUV=numeric(58);
 hhsBOOT.UPPER.SUB=numeric(58);hhsBOOT.LOWER.SUB=numeric(58);
 hhsBOOT.UPPER.AD=numeric(58);hhsBOOT.LOWER.AD=numeric(58);
 for (w in 1:58){
  Index=1
  VectorJH=sort(NzJHlong[,w])
  VectorSH=sort(NzSHlong[,w])
  VectorAH=sort(NzAHlong[,w])
  hhsBOOT.UPPER.JUV[w]=VectorJH[(length(NzJHlong[,w]))]
  hhsBOOT.LOWER.JUV[w]=VectorJH[Index]
  hhsBOOT.UPPER.SUB[w]=VectorSH[(length(NzSHlong[,w]))]
  hhsBOOT.UPPER.AD[w]=VectorAH[(length(NzAHlong[,w]))]
  hhsBOOT.LOWER.AD[w]=VectorAH[Index]}
 for (b in 1:58){if (hhsBOOT.UPPER.SUB[b]<0){hhsBOOT.UPPER.SUB[b]=0}}
 for (b in 1:58){if (hhsBOOT.LOWER.SUB[b]<0){hhsBOOT.LOWER.SUB[b]=0}}
 for (b in 1:58){if (hhsBOOT.UPPER.AD[b]<0){hhsBOOT.UPPER.AD[b]=0}}
 for (b in 1:58){if (hhsBOOT.LOWER.AD[b]<0){hhsBOOT.LOWER.AD[b]=0}}
 plot(2:59,NzMeanS,type="p",xlim=c(1,58),cex=0.01,
    ylab="Algorithm-predicted abundances",xlab="Bi-annual periods",
    ylim=c(0,max(max(hhsBOOT.UPPER.SUB),max(hhsBOOT.UPPER.JUV),max(hhsBOOT.UPPER.AD))),
    col="white",lwd=1,lty=3,pch=20,
    main="Algorithm-predicted female abundances for the Northeast, USA",xaxt="n")
 year=seq(1990,2018,1)
 axis(1,at=seq(1,57,2), labels=year)
 segments(2,hhsBOOT.LOWER.JUV[2],2,hhsBOOT.UPPER.JUV[2],lwd=3,col="darkcyan")
 segments(4,hhsBOOT.LOWER.JUV[4],4,hhsBOOT.UPPER.JUV[4],lwd=3,col="darkcyan")
 segments(6,hhsBOOT.LOWER.JUV[6],6,hhsBOOT.UPPER.JUV[6],lwd=3,col="darkcyan")
 segments(8,hhsBOOT.LOWER.JUV[8],8,hhsBOOT.UPPER.JUV[8],lwd=3,col="darkcyan")
 segments(10,hhsBOOT.LOWER.JUV[10],10,hhsBOOT.UPPER.JUV[10],lwd=3,col="darkcyan")
 segments(12,hhsBOOT.LOWER.JUV[12],12,hhsBOOT.UPPER.JUV[12],lwd=3,col="darkcyan")
 segments(14,hhsBOOT.LOWER.JUV[14],14,hhsBOOT.UPPER.JUV[14],lwd=3,col="darkcyan")
 segments(16,hhsBOOT.LOWER.JUV[16],16,hhsBOOT.UPPER.JUV[16],lwd=3,col="darkcyan")
 segments(18,hhsBOOT.LOWER.JUV[18],18,hhsBOOT.UPPER.JUV[18],lwd=3,col="darkcyan")
 segments(20,hhsBOOT.LOWER.JUV[20],20,hhsBOOT.UPPER.JUV[20],lwd=3,col="darkcyan")
 segments(22,hhsBOOT.LOWER.JUV[22],22,hhsBOOT.UPPER.JUV[22],lwd=3,col="darkcyan")
 segments(24,hhsBOOT.LOWER.JUV[24],24,hhsBOOT.UPPER.JUV[24],lwd=3,col="darkcyan")
 segments(26,hhsBOOT.LOWER.JUV[26],26,hhsBOOT.UPPER.JUV[26],lwd=3,col="darkcyan")
 segments(28,hhsBOOT.LOWER.JUV[28],28,hhsBOOT.UPPER.JUV[28],lwd=3,col="darkcyan")
 segments(30,hhsBOOT.LOWER.JUV[30],30,hhsBOOT.UPPER.JUV[30],lwd=3,col="darkcyan")
 segments(32,hhsBOOT.LOWER.JUV[32],32,hhsBOOT.UPPER.JUV[32],lwd=3,col="darkcyan")
 segments(34,hhsBOOT.LOWER.JUV[34],34,hhsBOOT.UPPER.JUV[34],lwd=3,col="darkcyan")
 segments(36,hhsBOOT.LOWER.JUV[36],36,hhsBOOT.UPPER.JUV[36],lwd=3,col="darkcyan")
 segments(38,hhsBOOT.LOWER.JUV[38],38,hhsBOOT.UPPER.JUV[38],lwd=3,col="darkcyan")
 segments(40,hhsBOOT.LOWER.JUV[40],40,hhsBOOT.UPPER.JUV[40],lwd=3,col="darkcyan")
 segments(42,hhsBOOT.LOWER.JUV[42],42,hhsBOOT.UPPER.JUV[42],lwd=3,col="darkcyan")
 segments(44,hhsBOOT.LOWER.JUV[44],44,hhsBOOT.UPPER.JUV[44],lwd=3,col="darkcyan")
 segments(46,hhsBOOT.LOWER.JUV[46],46,hhsBOOT.UPPER.JUV[46],lwd=3,col="darkcyan")
 segments(48,hhsBOOT.LOWER.JUV[48],48,hhsBOOT.UPPER.JUV[48],lwd=3,col="darkcyan")
 segments(50,hhsBOOT.LOWER.JUV[50],50,hhsBOOT.UPPER.JUV[50],lwd=3,col="darkcyan")
 segments(52,hhsBOOT.LOWER.JUV[52],52,hhsBOOT.UPPER.JUV[52],lwd=3,col="darkcyan")
 segments(54,hhsBOOT.LOWER.JUV[54],54,hhsBOOT.UPPER.JUV[54],lwd=3,col="darkcyan")
 segments(56,hhsBOOT.LOWER.JUV[56],56,hhsBOOT.UPPER.JUV[56],lwd=3,col="darkcyan")
 segments(58,hhsBOOT.LOWER.JUV[58],58,hhsBOOT.UPPER.JUV[58],lwd=3,col="darkcyan")
 segments(2.2,hhsBOOT.LOWER.SUB[2],2.2,hhsBOOT.UPPER.SUB[2],lwd=3,col="skyblue")
 segments(4.2,hhsBOOT.LOWER.SUB[4],4.2,hhsBOOT.UPPER.SUB[4],lwd=3,col="skyblue")
 segments(6.2,hhsBOOT.LOWER.SUB[6],6.2,hhsBOOT.UPPER.SUB[6],lwd=3,col="skyblue")
 segments(8.2,hhsBOOT.LOWER.SUB[8],8.2,hhsBOOT.UPPER.SUB[8],lwd=3,col="skyblue")
 segments(10.2,hhsBOOT.LOWER.SUB[10],10.2,hhsBOOT.UPPER.SUB[10],lwd=3,col="skyblue")
 segments(12.2,hhsBOOT.LOWER.SUB[12],12.2,hhsBOOT.UPPER.SUB[12],lwd=3,col="skyblue")
 segments(14.2,hhsBOOT.LOWER.SUB[14],14.2,hhsBOOT.UPPER.SUB[14],lwd=3,col="skyblue")
 segments(16.2,hhsBOOT.LOWER.SUB[16],16.2,hhsBOOT.UPPER.SUB[16],lwd=3,col="skyblue")
 segments(18.2,hhsBOOT.LOWER.SUB[18],18.2,hhsBOOT.UPPER.SUB[18],lwd=3,col="skyblue")
 segments(20.2,hhsBOOT.LOWER.SUB[20],20.2,hhsBOOT.UPPER.SUB[20],lwd=3,col="skyblue")
 segments(22.2,hhsBOOT.LOWER.SUB[22],22.2,hhsBOOT.UPPER.SUB[22],lwd=3,col="skyblue")
 segments(24.2,hhsBOOT.LOWER.SUB[24],24.2,hhsBOOT.UPPER.SUB[24],lwd=3,col="skyblue")
 segments(26.2,hhsBOOT.LOWER.SUB[26],26.2,hhsBOOT.UPPER.SUB[26],lwd=3,col="skyblue")
 segments(28.2,hhsBOOT.LOWER.SUB[28],28.2,hhsBOOT.UPPER.SUB[28],lwd=3,col="skyblue")
 segments(30.2,hhsBOOT.LOWER.SUB[30],30.2,hhsBOOT.UPPER.SUB[30],lwd=3,col="skyblue")
 segments(32.2,hhsBOOT.LOWER.SUB[32],32.2,hhsBOOT.UPPER.SUB[32],lwd=3,col="skyblue")
 segments(34.2,hhsBOOT.LOWER.SUB[34],34.2,hhsBOOT.UPPER.SUB[34],lwd=3,col="skyblue")
 segments(36.2,hhsBOOT.LOWER.SUB[36],36.2,hhsBOOT.UPPER.SUB[36],lwd=3,col="skyblue")
 segments(38.2,hhsBOOT.LOWER.SUB[38],38.2,hhsBOOT.UPPER.SUB[38],lwd=3,col="skyblue")
 segments(40.2,hhsBOOT.LOWER.SUB[40],40.2,hhsBOOT.UPPER.SUB[40],lwd=3,col="skyblue")
 segments(42.2,hhsBOOT.LOWER.SUB[42],42.2,hhsBOOT.UPPER.SUB[42],lwd=3,col="skyblue")
 segments(44.2,hhsBOOT.LOWER.SUB[44],44.2,hhsBOOT.UPPER.SUB[44],lwd=3,col="skyblue")
 segments(46.2,hhsBOOT.LOWER.SUB[46],46.2,hhsBOOT.UPPER.SUB[46],lwd=3,col="skyblue")
 segments(48.2,hhsBOOT.LOWER.SUB[48],48.2,hhsBOOT.UPPER.SUB[48],lwd=3,col="skyblue")
 segments(50.2,hhsBOOT.LOWER.SUB[50],50.2,hhsBOOT.UPPER.SUB[50],lwd=3,col="skyblue")
 segments(52.2,hhsBOOT.LOWER.SUB[52],52.2,hhsBOOT.UPPER.SUB[52],lwd=3,col="skyblue")
 segments(54.2,hhsBOOT.LOWER.SUB[54],54.2,hhsBOOT.UPPER.SUB[54],lwd=3,col="skyblue")
 segments(56.2,hhsBOOT.LOWER.SUB[56],56.2,hhsBOOT.UPPER.SUB[56],lwd=3,col="skyblue")
 segments(58.2,hhsBOOT.LOWER.SUB[58],58.2,hhsBOOT.UPPER.SUB[58],lwd=3,col="skyblue")
 segments(2.4,hhsBOOT.LOWER.AD[2],2.4,hhsBOOT.UPPER.AD[2],lwd=3,col="GREY")
 segments(4.4,hhsBOOT.LOWER.AD[4],4.4,hhsBOOT.UPPER.AD[4],lwd=3,col="GREY")
 segments(6.4,hhsBOOT.LOWER.AD[6],6.4,hhsBOOT.UPPER.AD[6],lwd=3,col="GREY")
 segments(8.4,hhsBOOT.LOWER.AD[8],8.4,hhsBOOT.UPPER.AD[8],lwd=3,col="GREY")
 segments(10.4,hhsBOOT.LOWER.AD[10],10.4,hhsBOOT.UPPER.AD[10],lwd=3,col="GREY")
 segments(12.4,hhsBOOT.LOWER.AD[12],12.4,hhsBOOT.UPPER.AD[12],lwd=3,col="GREY")
 segments(14.4,hhsBOOT.LOWER.AD[14],14.4,hhsBOOT.UPPER.AD[14],lwd=3,col="GREY")
 segments(16.4,hhsBOOT.LOWER.AD[16],16.4,hhsBOOT.UPPER.AD[16],lwd=3,col="GREY")
 segments(18.4,hhsBOOT.LOWER.AD[18],18.4,hhsBOOT.UPPER.AD[18],lwd=3,col="GREY")
 segments(20.4,hhsBOOT.LOWER.AD[20],20.4,hhsBOOT.UPPER.AD[20],lwd=3,col="GREY")
 segments(22.4,hhsBOOT.LOWER.AD[22],22.4,hhsBOOT.UPPER.AD[22],lwd=3,col="GREY")
 segments(24.4,hhsBOOT.LOWER.AD[24],24.4,hhsBOOT.UPPER.AD[24],lwd=3,col="GREY")
 segments(26.4,hhsBOOT.LOWER.AD[26],26.4,hhsBOOT.UPPER.AD[26],lwd=3,col="GREY")
 segments(28.4,hhsBOOT.LOWER.AD[28],28.4,hhsBOOT.UPPER.AD[28],lwd=3,col="GREY")
 segments(30.4,hhsBOOT.LOWER.AD[30],30.4,hhsBOOT.UPPER.AD[30],lwd=3,col="GREY")
 segments(32.4,hhsBOOT.LOWER.AD[32],32.4,hhsBOOT.UPPER.AD[32],lwd=3,col="GREY")
 segments(34.4,hhsBOOT.LOWER.AD[34],34.4,hhsBOOT.UPPER.AD[34],lwd=3,col="GREY")
 segments(36.4,hhsBOOT.LOWER.AD[36],36.4,hhsBOOT.UPPER.AD[36],lwd=3,col="GREY")
 segments(38.4,hhsBOOT.LOWER.AD[38],38.4,hhsBOOT.UPPER.AD[38],lwd=3,col="GREY")
 segments(40.4,hhsBOOT.LOWER.AD[40],40.4,hhsBOOT.UPPER.AD[40],lwd=3,col="GREY")
 segments(42.4,hhsBOOT.LOWER.AD[42],42.4,hhsBOOT.UPPER.AD[42],lwd=3,col="GREY")
 segments(44.4,hhsBOOT.LOWER.AD[44],44.4,hhsBOOT.UPPER.AD[44],lwd=3,col="GREY")
 segments(46.4,hhsBOOT.LOWER.AD[46],46.4,hhsBOOT.UPPER.AD[46],lwd=3,col="GREY")
 segments(48.4,hhsBOOT.LOWER.AD[48],48.4,hhsBOOT.UPPER.AD[48],lwd=3,col="GREY")
 segments(50.4,hhsBOOT.LOWER.AD[50],50.4,hhsBOOT.UPPER.AD[50],lwd=3,col="GREY")
 segments(52.4,hhsBOOT.LOWER.AD[52],52.4,hhsBOOT.UPPER.AD[52],lwd=3,col="GREY")
 segments(54.4,hhsBOOT.LOWER.AD[54],54.4,hhsBOOT.UPPER.AD[54],lwd=3,col="GREY")
 segments(56.4,hhsBOOT.LOWER.AD[56],56.4,hhsBOOT.UPPER.AD[56],lwd=3,col="GREY")
 segments(58.4,hhsBOOT.LOWER.AD[58],58.4,hhsBOOT.UPPER.AD[58],lwd=3,col="GREY")
 legend(0,max(max(hhsBOOT.UPPER.SUB),max(hhsBOOT.UPPER.JUV),max(hhsBOOT.UPPER.AD)),
     c("Predicted range for hatchling females during the non-breeding period",
      "Predicted range for immature and non-breeding adult females during the non-breeding period",
      "Predicted range for breeding-adult females during the non-breeding period"),
     box.lty = 0,lty=c(1,1,1),lwd=c(3,3,3),pch=c(20,20,20),
     col=c("darkcyan","skyblue","grey"))
})
output$BiannualSubadult=renderPlot({
 # Create 0-row data frame which will be used to store data
 dat <- data.frame(x = numeric(0), y = numeric(0))
 
 withProgress(message = 'Calculating', value = 0, {
  # Number of times we'll go through the loop
  n <- 40
  
  for (i in 1:n) {
   # Each time through the loop, add another row of data. This is
   # a stand-in for a long-running computation.
   dat <- rbind(dat, data.frame(x = rnorm(1), y = rnorm(1)))
   
   # Increment the progress bar, and update the detail text.
   incProgress(1/n, detail = paste("", i))
   
   # Pause for 0.1 seconds to simulate a long computation.
   Sys.sleep(0.1)
  }
 })
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TIMESERIES.1=read.table("NEW_TIMESERIES_Northeast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
 TRAJECTORY_ADULTS_JUNE=read.table("NEW_Adults_June_Northeast.txt")
 TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
 TRAJECTORY_SUBADULTS_JUNE=read.table("NEW_Subadults_June_Northeast.txt")
 TRAJECTORY_JUVENILES_JUNE=read.table("NEW_Juveniles_June_Northeast.txt")
 TIMESERIES=TIMESERIES.1[["x"]]
 NzMeanH=matrix(0,3,29)		
 NzVarH=matrix(0,3,29)
 NzMean=matrix(0,2,29)		
 NzVar=matrix(0,2,29)
 ANNUAL.ADULTS=TRAJECTORY_ADULTS_JAN
 ANNUAL.SUBADULTS=TRAJECTORY_SUBADULTS_JAN
 BIANNUAL.JUVENILES=TRAJECTORY_JUVENILES_JUNE
 BIANNUAL.SUBADULTS=TRAJECTORY_SUBADULTS_JUNE
 BIANNUAL.ADULTS=TRAJECTORY_ADULTS_JUNE
 for (k in 1:29){
  NzMean[1,k]=mean(ANNUAL.SUBADULTS[,k])
  NzMean[2,k]=mean(ANNUAL.ADULTS[,k])
  NzVar[1,k]=var(ANNUAL.SUBADULTS[,k])
  NzVar[2,k]=var(ANNUAL.ADULTS[,k])
  NzMeanH[1,k]=mean(BIANNUAL.JUVENILES[,k])
  NzMeanH[2,k]=mean(BIANNUAL.SUBADULTS[,k])
  NzMeanH[3,k]=mean(BIANNUAL.ADULTS[,k])
  NzVarH[1,k]=var(BIANNUAL.JUVENILES[,k])
  NzVarH[2,k]=var(BIANNUAL.SUBADULTS[,k])
  NzVarH[3,k]=var(BIANNUAL.ADULTS[,k])
 } 
 NzSlong=matrix(0,length(MODELS[,1]),58)
 NzAlong=matrix(0,length(MODELS[,1]),58)
 NzJHlong=matrix(0,length(MODELS[,1]),58)
 NzSHlong=matrix(0,length(MODELS[,1]),58)
 NzAHlong=matrix(0,length(MODELS[,1]),58)
 ANNUAL.ADULTS=TRAJECTORY_ADULTS_JAN
 ANNUAL.SUBADULTS=TRAJECTORY_SUBADULTS_JAN
 BIANNUAL.JUVENILES=TRAJECTORY_JUVENILES_JUNE
 BIANNUAL.SUBADULTS=TRAJECTORY_SUBADULTS_JUNE
 BIANNUAL.ADULTS=TRAJECTORY_ADULTS_JUNE
 for (j in 1:length(BIANNUAL.JUVENILES[,1])){
  NzJHlong[j,]=c(-50,BIANNUAL.JUVENILES[j,1],
          -50,BIANNUAL.JUVENILES[j,2],
          -50,BIANNUAL.JUVENILES[j,3],-50,BIANNUAL.JUVENILES[j,4],
          -50,BIANNUAL.JUVENILES[j,5],
          -50,BIANNUAL.JUVENILES[j,6],-50,BIANNUAL.JUVENILES[j,7],
          -50,BIANNUAL.JUVENILES[j,8],
          -50,BIANNUAL.JUVENILES[j,9],-50,BIANNUAL.JUVENILES[j,10],
          -50,BIANNUAL.JUVENILES[j,11],-50,BIANNUAL.JUVENILES[j,12],
          -50,BIANNUAL.JUVENILES[j,13],-50,BIANNUAL.JUVENILES[j,14],
          -50,BIANNUAL.JUVENILES[j,15],-50,BIANNUAL.JUVENILES[j,16],
          -50,BIANNUAL.JUVENILES[j,17],-50,BIANNUAL.JUVENILES[j,18],
          -50,BIANNUAL.JUVENILES[j,19],-50,BIANNUAL.JUVENILES[j,20],
          -50,BIANNUAL.JUVENILES[j,21],-50,BIANNUAL.JUVENILES[j,22],
          -50,BIANNUAL.JUVENILES[j,23],-50,BIANNUAL.JUVENILES[j,24],
          -50,BIANNUAL.JUVENILES[j,25],-50,BIANNUAL.JUVENILES[j,26],
          -50,BIANNUAL.JUVENILES[j,27],-50,BIANNUAL.JUVENILES[j,28],
          -50,BIANNUAL.JUVENILES[j,29])}
 for (j in 1:length(BIANNUAL.SUBADULTS[,1])){
  NzSHlong[j,]=c(-50,BIANNUAL.SUBADULTS[j,1],-50,BIANNUAL.SUBADULTS[j,2],
          -50,BIANNUAL.SUBADULTS[j,3],-50,BIANNUAL.SUBADULTS[j,4],-50,BIANNUAL.SUBADULTS[j,5],
          -50,BIANNUAL.SUBADULTS[j,6],-50,BIANNUAL.SUBADULTS[j,7],-50,BIANNUAL.SUBADULTS[j,8],
          -50,BIANNUAL.SUBADULTS[j,9],-50,BIANNUAL.SUBADULTS[j,10],-50,BIANNUAL.SUBADULTS[j,11],
          -50,BIANNUAL.SUBADULTS[j,12],-50,BIANNUAL.SUBADULTS[j,13],-50,BIANNUAL.SUBADULTS[j,14],
          -50,BIANNUAL.SUBADULTS[j,15],-50,BIANNUAL.SUBADULTS[j,16],-50,BIANNUAL.SUBADULTS[j,17],
          -50,BIANNUAL.SUBADULTS[j,18],-50,BIANNUAL.SUBADULTS[j,19],-50,BIANNUAL.SUBADULTS[j,20],
          -50,BIANNUAL.SUBADULTS[j,21],-50,BIANNUAL.SUBADULTS[j,22],-50,BIANNUAL.SUBADULTS[j,23],
          -50,BIANNUAL.SUBADULTS[j,24],-50,BIANNUAL.SUBADULTS[j,25],-50,BIANNUAL.SUBADULTS[j,26],
          -50,BIANNUAL.SUBADULTS[j,27],-50,BIANNUAL.SUBADULTS[j,28],-50,BIANNUAL.SUBADULTS[j,29])}
 for (j in 1:length(BIANNUAL.ADULTS[,1])){
  NzAHlong[j,]=c(-50,BIANNUAL.ADULTS[j,1],
          -50,BIANNUAL.ADULTS[j,2],
          -50,BIANNUAL.ADULTS[j,3],-50,BIANNUAL.ADULTS[j,4],
          -50,BIANNUAL.ADULTS[j,5],-50,BIANNUAL.ADULTS[j,6],
          -50,BIANNUAL.ADULTS[j,7],-50,BIANNUAL.ADULTS[j,8],
          -50,BIANNUAL.ADULTS[j,9],-50,BIANNUAL.ADULTS[j,10],
          -50,BIANNUAL.ADULTS[j,11],-50,BIANNUAL.ADULTS[j,12],
          -50,BIANNUAL.ADULTS[j,13],-50,BIANNUAL.ADULTS[j,14],
          -50,BIANNUAL.ADULTS[j,15],-50,BIANNUAL.ADULTS[j,16],
          -50,BIANNUAL.ADULTS[j,17],-50,BIANNUAL.ADULTS[j,18],
          -50,BIANNUAL.ADULTS[j,19],-50,BIANNUAL.ADULTS[j,20],
          -50,BIANNUAL.ADULTS[j,21],-50,BIANNUAL.ADULTS[j,22],
          -50,BIANNUAL.ADULTS[j,23],-50,BIANNUAL.ADULTS[j,24],
          -50,BIANNUAL.ADULTS[j,25],-50,BIANNUAL.ADULTS[j,26],
          -50,BIANNUAL.ADULTS[j,27],-50,BIANNUAL.ADULTS[j,28],
          -50,BIANNUAL.ADULTS[j,29])}
 for (j in 1:length(ANNUAL.SUBADULTS[,1])){
  NzSlong[j,]=c(ANNUAL.SUBADULTS[j,1],BIANNUAL.SUBADULTS[j,1],
         ANNUAL.SUBADULTS[j,2],BIANNUAL.SUBADULTS[j,2],ANNUAL.SUBADULTS[j,3],BIANNUAL.SUBADULTS[j,3],
         ANNUAL.SUBADULTS[j,4],BIANNUAL.SUBADULTS[j,4],ANNUAL.SUBADULTS[j,5],BIANNUAL.SUBADULTS[j,5],
         ANNUAL.SUBADULTS[j,6],BIANNUAL.SUBADULTS[j,6],ANNUAL.SUBADULTS[j,7],BIANNUAL.SUBADULTS[j,7],
         ANNUAL.SUBADULTS[j,8],BIANNUAL.SUBADULTS[j,8],ANNUAL.SUBADULTS[j,9],BIANNUAL.SUBADULTS[j,9],
         ANNUAL.SUBADULTS[j,10],BIANNUAL.SUBADULTS[j,10],ANNUAL.SUBADULTS[j,11],BIANNUAL.SUBADULTS[j,11],
         ANNUAL.SUBADULTS[j,12],BIANNUAL.SUBADULTS[j,12],ANNUAL.SUBADULTS[j,13],BIANNUAL.SUBADULTS[j,13],
         ANNUAL.SUBADULTS[j,14],BIANNUAL.SUBADULTS[j,14],ANNUAL.SUBADULTS[j,15],BIANNUAL.SUBADULTS[j,15],
         ANNUAL.SUBADULTS[j,16],BIANNUAL.SUBADULTS[j,16],ANNUAL.SUBADULTS[j,17],BIANNUAL.SUBADULTS[j,17],
         ANNUAL.SUBADULTS[j,18],BIANNUAL.SUBADULTS[j,18],ANNUAL.SUBADULTS[j,19],BIANNUAL.SUBADULTS[j,19],
         ANNUAL.SUBADULTS[j,20],BIANNUAL.SUBADULTS[j,20],ANNUAL.SUBADULTS[j,21],BIANNUAL.SUBADULTS[j,21],
         ANNUAL.SUBADULTS[j,22],BIANNUAL.SUBADULTS[j,22],ANNUAL.SUBADULTS[j,23],BIANNUAL.SUBADULTS[j,23],
         ANNUAL.SUBADULTS[j,24],BIANNUAL.SUBADULTS[j,24],ANNUAL.SUBADULTS[j,25],BIANNUAL.SUBADULTS[j,25],
         ANNUAL.SUBADULTS[j,26],BIANNUAL.SUBADULTS[j,26],ANNUAL.SUBADULTS[j,27],BIANNUAL.SUBADULTS[j,27],
         ANNUAL.SUBADULTS[j,28],BIANNUAL.SUBADULTS[j,28],ANNUAL.SUBADULTS[j,29],BIANNUAL.SUBADULTS[j,29])}
 for (j in 1:length(BIANNUAL.ADULTS[,1])){
  NzAlong[j,]=c(ANNUAL.ADULTS[j,1],BIANNUAL.ADULTS[j,1],
         ANNUAL.ADULTS[j,2],BIANNUAL.ADULTS[j,2],ANNUAL.ADULTS[j,3],BIANNUAL.ADULTS[j,3],
         ANNUAL.ADULTS[j,4],BIANNUAL.ADULTS[j,4],ANNUAL.ADULTS[j,5],BIANNUAL.ADULTS[j,5],
         ANNUAL.ADULTS[j,6],BIANNUAL.ADULTS[j,6],ANNUAL.ADULTS[j,7],BIANNUAL.ADULTS[j,7],
         ANNUAL.ADULTS[j,8],BIANNUAL.ADULTS[j,8],ANNUAL.ADULTS[j,9],BIANNUAL.ADULTS[j,9],
         ANNUAL.ADULTS[j,10],BIANNUAL.ADULTS[j,10],ANNUAL.ADULTS[j,11],BIANNUAL.ADULTS[j,11],
         ANNUAL.ADULTS[j,12],BIANNUAL.ADULTS[j,12],ANNUAL.ADULTS[j,13],BIANNUAL.ADULTS[j,13],
         ANNUAL.ADULTS[j,14],BIANNUAL.ADULTS[j,14],ANNUAL.ADULTS[j,15],BIANNUAL.ADULTS[j,15],
         ANNUAL.ADULTS[j,16],BIANNUAL.ADULTS[j,16],ANNUAL.ADULTS[j,17],BIANNUAL.ADULTS[j,17],
         ANNUAL.ADULTS[j,18],BIANNUAL.ADULTS[j,18],ANNUAL.ADULTS[j,19],BIANNUAL.ADULTS[j,19],
         ANNUAL.ADULTS[j,20],BIANNUAL.ADULTS[j,20],ANNUAL.ADULTS[j,21],BIANNUAL.ADULTS[j,21],
         ANNUAL.ADULTS[j,22],BIANNUAL.ADULTS[j,22],ANNUAL.ADULTS[j,23],BIANNUAL.ADULTS[j,23],
         ANNUAL.ADULTS[j,24],BIANNUAL.ADULTS[j,24],ANNUAL.ADULTS[j,25],BIANNUAL.ADULTS[j,25],
         ANNUAL.ADULTS[j,26],BIANNUAL.ADULTS[j,26],ANNUAL.ADULTS[j,27],BIANNUAL.ADULTS[j,27],
         ANNUAL.ADULTS[j,28],BIANNUAL.ADULTS[j,28],ANNUAL.ADULTS[j,29],BIANNUAL.ADULTS[j,29])}
 NzMeanS=numeric(58)
 NzMeanS=c(NzMean[1,1],-5000,NzMean[1,2],-5000,NzMean[1,3],
      -5000,NzMean[1,4],-5000,NzMean[1,5],-5000,NzMean[1,6],
      -5000,NzMean[1,7],-5000,NzMean[1,8],-5000,NzMean[1,9],
      -5000,NzMean[1,10],-5000,NzMean[1,11],-5000,NzMean[1,12],
      -5000,NzMean[1,13],-5000,NzMean[1,14],-5000,NzMean[1,15],
      -5000,NzMean[1,16],-5000,NzMean[1,17],-5000,NzMean[1,18],
      -5000,NzMean[1,19],-5000,NzMean[1,20],-5000,NzMean[1,21],
      -5000,NzMean[1,22],-5000,NzMean[1,23],-5000,NzMean[1,24],
      -5000,NzMean[1,25],-5000,NzMean[1,26],-5000,NzMean[1,27],
      -5000,NzMean[1,28],-5000,NzMean[1,29],-5000)
 hsBOOT.UPPER.SUB=numeric(58);hsBOOT.LOWER.SUB=numeric(58);
 hhsBOOT.UPPER.SUB=numeric(58);hhsBOOT.LOWER.SUB=numeric(58);
 for (w in 1:58){
  VectorS=sort(NzSlong[,w])
  Index=1
  hsBOOT.UPPER.SUB[w]=VectorS[(length(NzSlong[,w]))]
  hsBOOT.LOWER.SUB[w]=VectorS[Index]
  VectorSH=sort(NzSHlong[,w])
  hhsBOOT.UPPER.SUB[w]=VectorSH[(length(NzSHlong[,w]))]
  hsBOOT.LOWER.SUB[w]=VectorSH[Index]}
 for (b in 1:58){if (hsBOOT.UPPER.SUB[b]<0){hsBOOT.UPPER.SUB[b]=0}}
 for (b in 1:58){if (hsBOOT.LOWER.SUB[b]<0){hsBOOT.LOWER.SUB[b]=0}}
 for (b in 1:58){if (hhsBOOT.UPPER.SUB[b]<0){hhsBOOT.UPPER.SUB[b]=0}}
 for (b in 1:58){if (hhsBOOT.LOWER.SUB[b]<0){hhsBOOT.LOWER.SUB[b]=0}}
 plot(1.2:58.2,NzMeanS,type="p",xlim=c(1,58),
    ylab="Algorithm-predicted abundances",xlab="Bi-annual periods",
    ylim=c(0,max(max(hhsBOOT.UPPER.SUB),max(hsBOOT.UPPER.SUB))),
    col="skyblue",lwd=1,lty=3,pch=20,
    main="Algorithm-predicted female abundances for the Northeast, USA",xaxt="n")
 year=seq(1990,2018,1)
 axis(1,at=seq(1,57,2), labels=year)
 segments(2.2,hhsBOOT.LOWER.SUB[2],2.2,hhsBOOT.UPPER.SUB[2],lwd=3,col="skyblue")
 segments(4.2,hhsBOOT.LOWER.SUB[4],4.2,hhsBOOT.UPPER.SUB[4],lwd=3,col="skyblue")
 segments(6.2,hhsBOOT.LOWER.SUB[6],6.2,hhsBOOT.UPPER.SUB[6],lwd=3,col="skyblue")
 segments(8.2,hhsBOOT.LOWER.SUB[8],8.2,hhsBOOT.UPPER.SUB[8],lwd=3,col="skyblue")
 segments(10.2,hhsBOOT.LOWER.SUB[10],10.2,hhsBOOT.UPPER.SUB[10],lwd=3,col="skyblue")
 segments(12.2,hhsBOOT.LOWER.SUB[12],12.2,hhsBOOT.UPPER.SUB[12],lwd=3,col="skyblue")
 segments(14.2,hhsBOOT.LOWER.SUB[14],14.2,hhsBOOT.UPPER.SUB[14],lwd=3,col="skyblue")
 segments(16.2,hhsBOOT.LOWER.SUB[16],16.2,hhsBOOT.UPPER.SUB[16],lwd=3,col="skyblue")
 segments(18.2,hhsBOOT.LOWER.SUB[18],18.2,hhsBOOT.UPPER.SUB[18],lwd=3,col="skyblue")
 segments(20.2,hhsBOOT.LOWER.SUB[20],20.2,hhsBOOT.UPPER.SUB[20],lwd=3,col="skyblue")
 segments(22.2,hhsBOOT.LOWER.SUB[22],22.2,hhsBOOT.UPPER.SUB[22],lwd=3,col="skyblue")
 segments(24.2,hhsBOOT.LOWER.SUB[24],24.2,hhsBOOT.UPPER.SUB[24],lwd=3,col="skyblue")
 segments(26.2,hhsBOOT.LOWER.SUB[26],26.2,hhsBOOT.UPPER.SUB[26],lwd=3,col="skyblue")
 segments(28.2,hhsBOOT.LOWER.SUB[28],28.2,hhsBOOT.UPPER.SUB[28],lwd=3,col="skyblue")
 segments(30.2,hhsBOOT.LOWER.SUB[30],30.2,hhsBOOT.UPPER.SUB[30],lwd=3,col="skyblue")
 segments(32.2,hhsBOOT.LOWER.SUB[32],32.2,hhsBOOT.UPPER.SUB[32],lwd=3,col="skyblue")
 segments(34.2,hhsBOOT.LOWER.SUB[34],34.2,hhsBOOT.UPPER.SUB[34],lwd=3,col="skyblue")
 segments(36.2,hhsBOOT.LOWER.SUB[36],36.2,hhsBOOT.UPPER.SUB[36],lwd=3,col="skyblue")
 segments(38.2,hhsBOOT.LOWER.SUB[38],38.2,hhsBOOT.UPPER.SUB[38],lwd=3,col="skyblue")
 segments(40.2,hhsBOOT.LOWER.SUB[40],40.2,hhsBOOT.UPPER.SUB[40],lwd=3,col="skyblue")
 segments(42.2,hhsBOOT.LOWER.SUB[42],42.2,hhsBOOT.UPPER.SUB[42],lwd=3,col="skyblue")
 segments(44.2,hhsBOOT.LOWER.SUB[44],44.2,hhsBOOT.UPPER.SUB[44],lwd=3,col="skyblue")
 segments(46.2,hhsBOOT.LOWER.SUB[46],46.2,hhsBOOT.UPPER.SUB[46],lwd=3,col="skyblue")
 segments(48.2,hhsBOOT.LOWER.SUB[48],48.2,hhsBOOT.UPPER.SUB[48],lwd=3,col="skyblue")
 segments(50.2,hhsBOOT.LOWER.SUB[50],50.2,hhsBOOT.UPPER.SUB[50],lwd=3,col="skyblue")
 segments(52.2,hhsBOOT.LOWER.SUB[52],52.2,hhsBOOT.UPPER.SUB[52],lwd=3,col="skyblue")
 segments(54.2,hhsBOOT.LOWER.SUB[54],54.2,hhsBOOT.UPPER.SUB[54],lwd=3,col="skyblue")
 segments(56.2,hhsBOOT.LOWER.SUB[56],56.2,hhsBOOT.UPPER.SUB[56],lwd=3,col="skyblue")
 segments(58.2,hhsBOOT.LOWER.SUB[58],58.2,hhsBOOT.UPPER.SUB[58],lwd=3,col="skyblue")
 segments(1.2,hsBOOT.LOWER.SUB[1],1.2,hsBOOT.UPPER.SUB[1],lwd=3,col="skyblue")
 segments(3.2,hsBOOT.LOWER.SUB[3],3.2,hsBOOT.UPPER.SUB[3],lwd=3,col="skyblue")
 segments(5.2,hsBOOT.LOWER.SUB[5],5.2,hsBOOT.UPPER.SUB[5],lwd=3,col="skyblue")
 segments(7.2,hsBOOT.LOWER.SUB[7],7.2,hsBOOT.UPPER.SUB[7],lwd=3,col="skyblue")
 segments(9.2,hsBOOT.LOWER.SUB[9],9.2,hsBOOT.UPPER.SUB[9],lwd=3,col="skyblue")
 segments(11.2,hsBOOT.LOWER.SUB[11],11.2,hsBOOT.UPPER.SUB[11],lwd=3,col="skyblue")
 segments(13.2,hsBOOT.LOWER.SUB[13],13.2,hsBOOT.UPPER.SUB[13],lwd=3,col="skyblue")
 segments(15.2,hsBOOT.LOWER.SUB[15],15.2,hsBOOT.UPPER.SUB[15],lwd=3,col="skyblue")
 segments(17.2,hsBOOT.LOWER.SUB[17],17.2,hsBOOT.UPPER.SUB[17],lwd=3,col="skyblue")
 segments(19.2,hsBOOT.LOWER.SUB[19],19.2,hsBOOT.UPPER.SUB[19],lwd=3,col="skyblue")
 segments(21.2,hsBOOT.LOWER.SUB[21],21.2,hsBOOT.UPPER.SUB[21],lwd=3,col="skyblue")
 segments(23.2,hsBOOT.LOWER.SUB[23],23.2,hsBOOT.UPPER.SUB[23],lwd=3,col="skyblue")
 segments(25.2,hsBOOT.LOWER.SUB[25],25.2,hsBOOT.UPPER.SUB[25],lwd=3,col="skyblue")
 segments(27.2,hsBOOT.LOWER.SUB[27],27.2,hsBOOT.UPPER.SUB[27],lwd=3,col="skyblue")
 segments(29.2,hsBOOT.LOWER.SUB[29],29.2,hsBOOT.UPPER.SUB[29],lwd=3,col="skyblue")
 segments(31.2,hsBOOT.LOWER.SUB[31],31.2,hsBOOT.UPPER.SUB[31],lwd=3,col="skyblue")
 segments(33.2,hsBOOT.LOWER.SUB[33],33.2,hsBOOT.UPPER.SUB[33],lwd=3,col="skyblue")
 segments(35.2,hsBOOT.LOWER.SUB[35],35.2,hsBOOT.UPPER.SUB[35],lwd=3,col="skyblue")
 segments(37.2,hsBOOT.LOWER.SUB[37],37.2,hsBOOT.UPPER.SUB[37],lwd=3,col="skyblue")
 segments(39.2,hsBOOT.LOWER.SUB[39],39.2,hsBOOT.UPPER.SUB[39],lwd=3,col="skyblue")
 segments(41.2,hsBOOT.LOWER.SUB[41],41.2,hsBOOT.UPPER.SUB[41],lwd=3,col="skyblue")
 segments(43.2,hsBOOT.LOWER.SUB[43],43.2,hsBOOT.UPPER.SUB[43],lwd=3,col="skyblue")
 segments(45.2,hsBOOT.LOWER.SUB[45],45.2,hsBOOT.UPPER.SUB[45],lwd=3,col="skyblue")
 segments(47.2,hsBOOT.LOWER.SUB[47],47.2,hsBOOT.UPPER.SUB[47],lwd=3,col="skyblue")
 segments(49.2,hsBOOT.LOWER.SUB[49],49.2,hsBOOT.UPPER.SUB[49],lwd=3,col="skyblue")
 segments(51.2,hsBOOT.LOWER.SUB[51],51.2,hsBOOT.UPPER.SUB[51],lwd=3,col="skyblue")
 segments(53.2,hsBOOT.LOWER.SUB[53],53.2,hsBOOT.UPPER.SUB[53],lwd=3,col="skyblue")
 segments(55.2,hsBOOT.LOWER.SUB[55],55.2,hsBOOT.UPPER.SUB[55],lwd=3,col="skyblue")
 segments(57.2,hsBOOT.LOWER.SUB[57],57.2,hsBOOT.UPPER.SUB[57],lwd=3,col="skyblue")
 legend(0,max(max(hhsBOOT.UPPER.SUB),max(hsBOOT.UPPER.SUB)),
     c("Empirical immature females throughout the year (if the information exists)", 
      "Algorithm-predicted range for immature and non-breeding adult females throughout the year"),
     box.lty = 0,lty=c(1,1),lwd=c(3,3),pch=c(19,20),col=c("green","skyblue"))
})
output$BiannualAdult=renderPlot({
 # Create 0-row data frame which will be used to store data
 dat <- data.frame(x = numeric(0), y = numeric(0))
 
 withProgress(message = 'Calculating', value = 0, {
  # Number of times we'll go through the loop
  n <- 40
  
  for (i in 1:n) {
   # Each time through the loop, add another row of data. This is
   # a stand-in for a long-running computation.
   dat <- rbind(dat, data.frame(x = rnorm(1), y = rnorm(1)))
   
   # Increment the progress bar, and update the detail text.
   incProgress(1/n, detail = paste("", i))
   
   # Pause for 0.1 seconds to simulate a long computation.
   Sys.sleep(0.1)
  }
 })
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TIMESERIES.1=read.table("NEW_TIMESERIES_Northeast.txt")
 TIMESERIES=TIMESERIES.1[["x"]]
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
 TRAJECTORY_ADULTS_JUNE=read.table("NEW_Adults_June_Northeast.txt")
 TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
 TRAJECTORY_SUBADULTS_JUNE=read.table("NEW_Subadults_June_Northeast.txt")
 TRAJECTORY_JUVENILES_JUNE=read.table("NEW_Juveniles_June_Northeast.txt")
 NzSlong=matrix(0,length(MODELS[,1]),58)
 NzAlong=matrix(0,length(MODELS[,1]),58)
 NzJHlong=matrix(0,length(MODELS[,1]),58)
 NzSHlong=matrix(0,length(MODELS[,1]),58)
 NzAHlong=matrix(0,length(MODELS[,1]),58)
 ANNUAL.ADULTS=TRAJECTORY_ADULTS_JAN
 ANNUAL.SUBADULTS=TRAJECTORY_SUBADULTS_JAN
 BIANNUAL.JUVENILES=TRAJECTORY_JUVENILES_JUNE
 BIANNUAL.SUBADULTS=TRAJECTORY_SUBADULTS_JUNE
 BIANNUAL.ADULTS=TRAJECTORY_ADULTS_JUNE
 NzMeanH=matrix(0,3,29)		
 NzVarH=matrix(0,3,29)
 NzMean=matrix(0,2,29)		
 NzVar=matrix(0,2,29)
 for (k in 1:29){
  NzMean[1,k]=mean(ANNUAL.SUBADULTS[,k])
  NzMean[2,k]=mean(ANNUAL.ADULTS[,k])
  NzVar[1,k]=var(ANNUAL.SUBADULTS[,k])
  NzVar[2,k]=var(ANNUAL.ADULTS[,k])
  NzMeanH[1,k]=mean(BIANNUAL.JUVENILES[,k])
  NzMeanH[2,k]=mean(BIANNUAL.SUBADULTS[,k])
  NzMeanH[3,k]=mean(BIANNUAL.ADULTS[,k])
  NzVarH[1,k]=var(BIANNUAL.JUVENILES[,k])
  NzVarH[2,k]=var(BIANNUAL.SUBADULTS[,k])
  NzVarH[3,k]=var(BIANNUAL.ADULTS[,k])
 } # END AT EACH TIME LOOP [k]
 NzMeanA=numeric(58)
 NzMeanA=c(NzMean[2,1],-5000,NzMean[2,2],-5000,NzMean[2,3],
      -5000,NzMean[2,4],-5000,NzMean[2,5],-5000,NzMean[2,6],
      -5000,NzMean[2,7],-5000,NzMean[2,8],-5000,NzMean[2,9],
      -5000,NzMean[2,10],-5000,NzMean[2,11],-5000,NzMean[2,12],
      -5000,NzMean[2,13],-5000,NzMean[2,14],-5000,NzMean[2,15],
      -5000,NzMean[2,16],-5000,NzMean[2,17],-5000,NzMean[2,18],
      -5000,NzMean[2,19],-5000,NzMean[2,20],-5000,NzMean[2,21],
      -5000,NzMean[2,22],-5000,NzMean[2,23],-5000,NzMean[2,24],
      -5000,NzMean[2,25],-5000,NzMean[2,26],-5000,NzMean[2,27],
      -5000,NzMean[2,28],-5000,NzMean[2,29],-5000)
 for (j in 1:length(BIANNUAL.JUVENILES[,1])){
  NzJHlong[j,]=c(-50,BIANNUAL.JUVENILES[j,1],
          -50,BIANNUAL.JUVENILES[j,2],
          -50,BIANNUAL.JUVENILES[j,3],-50,BIANNUAL.JUVENILES[j,4],
          -50,BIANNUAL.JUVENILES[j,5],
          -50,BIANNUAL.JUVENILES[j,6],-50,BIANNUAL.JUVENILES[j,7],
          -50,BIANNUAL.JUVENILES[j,8],
          -50,BIANNUAL.JUVENILES[j,9],-50,BIANNUAL.JUVENILES[j,10],
          -50,BIANNUAL.JUVENILES[j,11],-50,BIANNUAL.JUVENILES[j,12],
          -50,BIANNUAL.JUVENILES[j,13],-50,BIANNUAL.JUVENILES[j,14],
          -50,BIANNUAL.JUVENILES[j,15],-50,BIANNUAL.JUVENILES[j,16],
          -50,BIANNUAL.JUVENILES[j,17],-50,BIANNUAL.JUVENILES[j,18],
          -50,BIANNUAL.JUVENILES[j,19],-50,BIANNUAL.JUVENILES[j,20],
          -50,BIANNUAL.JUVENILES[j,21],-50,BIANNUAL.JUVENILES[j,22],
          -50,BIANNUAL.JUVENILES[j,23],-50,BIANNUAL.JUVENILES[j,24],
          -50,BIANNUAL.JUVENILES[j,25],-50,BIANNUAL.JUVENILES[j,26],
          -50,BIANNUAL.JUVENILES[j,27],-50,BIANNUAL.JUVENILES[j,28],
          -50,BIANNUAL.JUVENILES[j,29])}
 for (j in 1:length(BIANNUAL.SUBADULTS[,1])){
  NzSHlong[j,]=c(-50,BIANNUAL.SUBADULTS[j,1],-50,BIANNUAL.SUBADULTS[j,2],
          -50,BIANNUAL.SUBADULTS[j,3],-50,BIANNUAL.SUBADULTS[j,4],-50,BIANNUAL.SUBADULTS[j,5],
          -50,BIANNUAL.SUBADULTS[j,6],-50,BIANNUAL.SUBADULTS[j,7],-50,BIANNUAL.SUBADULTS[j,8],
          -50,BIANNUAL.SUBADULTS[j,9],-50,BIANNUAL.SUBADULTS[j,10],-50,BIANNUAL.SUBADULTS[j,11],
          -50,BIANNUAL.SUBADULTS[j,12],-50,BIANNUAL.SUBADULTS[j,13],-50,BIANNUAL.SUBADULTS[j,14],
          -50,BIANNUAL.SUBADULTS[j,15],-50,BIANNUAL.SUBADULTS[j,16],-50,BIANNUAL.SUBADULTS[j,17],
          -50,BIANNUAL.SUBADULTS[j,18],-50,BIANNUAL.SUBADULTS[j,19],-50,BIANNUAL.SUBADULTS[j,20],
          -50,BIANNUAL.SUBADULTS[j,21],-50,BIANNUAL.SUBADULTS[j,22],-50,BIANNUAL.SUBADULTS[j,23],
          -50,BIANNUAL.SUBADULTS[j,24],-50,BIANNUAL.SUBADULTS[j,25],-50,BIANNUAL.SUBADULTS[j,26],
          -50,BIANNUAL.SUBADULTS[j,27],-50,BIANNUAL.SUBADULTS[j,28],-50,BIANNUAL.SUBADULTS[j,29])}
 for (j in 1:length(BIANNUAL.ADULTS[,1])){
  NzAHlong[j,]=c(-50,BIANNUAL.ADULTS[j,1],
          -50,BIANNUAL.ADULTS[j,2],
          -50,BIANNUAL.ADULTS[j,3],-50,BIANNUAL.ADULTS[j,4],
          -50,BIANNUAL.ADULTS[j,5],-50,BIANNUAL.ADULTS[j,6],
          -50,BIANNUAL.ADULTS[j,7],-50,BIANNUAL.ADULTS[j,8],
          -50,BIANNUAL.ADULTS[j,9],-50,BIANNUAL.ADULTS[j,10],
          -50,BIANNUAL.ADULTS[j,11],-50,BIANNUAL.ADULTS[j,12],
          -50,BIANNUAL.ADULTS[j,13],-50,BIANNUAL.ADULTS[j,14],
          -50,BIANNUAL.ADULTS[j,15],-50,BIANNUAL.ADULTS[j,16],
          -50,BIANNUAL.ADULTS[j,17],-50,BIANNUAL.ADULTS[j,18],
          -50,BIANNUAL.ADULTS[j,19],-50,BIANNUAL.ADULTS[j,20],
          -50,BIANNUAL.ADULTS[j,21],-50,BIANNUAL.ADULTS[j,22],
          -50,BIANNUAL.ADULTS[j,23],-50,BIANNUAL.ADULTS[j,24],
          -50,BIANNUAL.ADULTS[j,25],-50,BIANNUAL.ADULTS[j,26],
          -50,BIANNUAL.ADULTS[j,27],-50,BIANNUAL.ADULTS[j,28],
          -50,BIANNUAL.ADULTS[j,29])}
 for (j in 1:length(ANNUAL.SUBADULTS[,1])){
  NzSlong[j,]=c(ANNUAL.SUBADULTS[j,1],BIANNUAL.SUBADULTS[j,1],
         ANNUAL.SUBADULTS[j,2],BIANNUAL.SUBADULTS[j,2],ANNUAL.SUBADULTS[j,3],BIANNUAL.SUBADULTS[j,3],
         ANNUAL.SUBADULTS[j,4],BIANNUAL.SUBADULTS[j,4],ANNUAL.SUBADULTS[j,5],BIANNUAL.SUBADULTS[j,5],
         ANNUAL.SUBADULTS[j,6],BIANNUAL.SUBADULTS[j,6],ANNUAL.SUBADULTS[j,7],BIANNUAL.SUBADULTS[j,7],
         ANNUAL.SUBADULTS[j,8],BIANNUAL.SUBADULTS[j,8],ANNUAL.SUBADULTS[j,9],BIANNUAL.SUBADULTS[j,9],
         ANNUAL.SUBADULTS[j,10],BIANNUAL.SUBADULTS[j,10],ANNUAL.SUBADULTS[j,11],BIANNUAL.SUBADULTS[j,11],
         ANNUAL.SUBADULTS[j,12],BIANNUAL.SUBADULTS[j,12],ANNUAL.SUBADULTS[j,13],BIANNUAL.SUBADULTS[j,13],
         ANNUAL.SUBADULTS[j,14],BIANNUAL.SUBADULTS[j,14],ANNUAL.SUBADULTS[j,15],BIANNUAL.SUBADULTS[j,15],
         ANNUAL.SUBADULTS[j,16],BIANNUAL.SUBADULTS[j,16],ANNUAL.SUBADULTS[j,17],BIANNUAL.SUBADULTS[j,17],
         ANNUAL.SUBADULTS[j,18],BIANNUAL.SUBADULTS[j,18],ANNUAL.SUBADULTS[j,19],BIANNUAL.SUBADULTS[j,19],
         ANNUAL.SUBADULTS[j,20],BIANNUAL.SUBADULTS[j,20],ANNUAL.SUBADULTS[j,21],BIANNUAL.SUBADULTS[j,21],
         ANNUAL.SUBADULTS[j,22],BIANNUAL.SUBADULTS[j,22],ANNUAL.SUBADULTS[j,23],BIANNUAL.SUBADULTS[j,23],
         ANNUAL.SUBADULTS[j,24],BIANNUAL.SUBADULTS[j,24],ANNUAL.SUBADULTS[j,25],BIANNUAL.SUBADULTS[j,25],
         ANNUAL.SUBADULTS[j,26],BIANNUAL.SUBADULTS[j,26],ANNUAL.SUBADULTS[j,27],BIANNUAL.SUBADULTS[j,27],
         ANNUAL.SUBADULTS[j,28],BIANNUAL.SUBADULTS[j,28],ANNUAL.SUBADULTS[j,29],BIANNUAL.SUBADULTS[j,29])}
 for (j in 1:length(BIANNUAL.ADULTS[,1])){
  NzAlong[j,]=c(ANNUAL.ADULTS[j,1],BIANNUAL.ADULTS[j,1],
         ANNUAL.ADULTS[j,2],BIANNUAL.ADULTS[j,2],ANNUAL.ADULTS[j,3],BIANNUAL.ADULTS[j,3],
         ANNUAL.ADULTS[j,4],BIANNUAL.ADULTS[j,4],ANNUAL.ADULTS[j,5],BIANNUAL.ADULTS[j,5],
         ANNUAL.ADULTS[j,6],BIANNUAL.ADULTS[j,6],ANNUAL.ADULTS[j,7],BIANNUAL.ADULTS[j,7],
         ANNUAL.ADULTS[j,8],BIANNUAL.ADULTS[j,8],ANNUAL.ADULTS[j,9],BIANNUAL.ADULTS[j,9],
         ANNUAL.ADULTS[j,10],BIANNUAL.ADULTS[j,10],ANNUAL.ADULTS[j,11],BIANNUAL.ADULTS[j,11],
         ANNUAL.ADULTS[j,12],BIANNUAL.ADULTS[j,12],ANNUAL.ADULTS[j,13],BIANNUAL.ADULTS[j,13],
         ANNUAL.ADULTS[j,14],BIANNUAL.ADULTS[j,14],ANNUAL.ADULTS[j,15],BIANNUAL.ADULTS[j,15],
         ANNUAL.ADULTS[j,16],BIANNUAL.ADULTS[j,16],ANNUAL.ADULTS[j,17],BIANNUAL.ADULTS[j,17],
         ANNUAL.ADULTS[j,18],BIANNUAL.ADULTS[j,18],ANNUAL.ADULTS[j,19],BIANNUAL.ADULTS[j,19],
         ANNUAL.ADULTS[j,20],BIANNUAL.ADULTS[j,20],ANNUAL.ADULTS[j,21],BIANNUAL.ADULTS[j,21],
         ANNUAL.ADULTS[j,22],BIANNUAL.ADULTS[j,22],ANNUAL.ADULTS[j,23],BIANNUAL.ADULTS[j,23],
         ANNUAL.ADULTS[j,24],BIANNUAL.ADULTS[j,24],ANNUAL.ADULTS[j,25],BIANNUAL.ADULTS[j,25],
         ANNUAL.ADULTS[j,26],BIANNUAL.ADULTS[j,26],ANNUAL.ADULTS[j,27],BIANNUAL.ADULTS[j,27],
         ANNUAL.ADULTS[j,28],BIANNUAL.ADULTS[j,28],ANNUAL.ADULTS[j,29],BIANNUAL.ADULTS[j,29])}
 ELONGATEDTIMESERIES=numeric(58)
 ELONGATEDTIMESERIES[1]=TIMESERIES[1]
 loop=1
 for (u in 2:58){
  if (u%%2==0){
   ELONGATEDTIMESERIES[u]=-500}
  if (u%%2!=0){
   loop=loop+1
   ELONGATEDTIMESERIES[u]=TIMESERIES[loop]}}
 hsBOOT.UPPER.AD=numeric(58);hsBOOT.LOWER.AD=numeric(58);
 hhsBOOT.UPPER.AD=numeric(58);hhsBOOT.LOWER.AD=numeric(58);
 for (w in 1:58){
  VectorA=sort(NzAlong[,w])
  Index=1
  hsBOOT.UPPER.AD[w]=VectorA[(length(NzAlong[,w]))]
  hsBOOT.LOWER.AD[w]=VectorA[Index]
  VectorAH=sort(NzAHlong[,w])
  hhsBOOT.UPPER.AD[w]=VectorAH[(length(NzAHlong[,w]))]
  hhsBOOT.LOWER.AD[w]=VectorAH[Index]}
 for (b in 1:58){if (hsBOOT.UPPER.AD[b]==-50){hsBOOT.UPPER.AD[b]=0}}
 for (b in 1:58){if (hsBOOT.LOWER.AD[b]<0){hsBOOT.LOWER.AD[b]=0}}
 for (b in 1:58){if (hhsBOOT.UPPER.AD[b]==-50){hhsBOOT.UPPER.AD[b]=0}}
 for (b in 1:58){if (hhsBOOT.LOWER.AD[b]<0){hhsBOOT.LOWER.AD[b]=0}}
 plot(1:58,NzMeanA,type="p",xlim=c(1,58),
    ylab="Algorithm-predicted abundances",xlab="Bi-annual periods",
    ylim=c(0,max(max(hhsBOOT.UPPER.AD),max(hsBOOT.UPPER.AD))),
    col="grey",lwd=1,lty=3,pch=20,
    main="Algorithm-predicted female abundances for the Northeast, USA",xaxt="n")
 year=seq(1990,2018,1)
 axis(1,at=seq(1,57,2), labels=year)
 segments(2,hhsBOOT.LOWER.AD[2],2,hhsBOOT.UPPER.AD[2],lwd=3,col="GREY")
 segments(4,hhsBOOT.LOWER.AD[4],4,hhsBOOT.UPPER.AD[4],lwd=3,col="GREY")
 segments(6,hhsBOOT.LOWER.AD[6],6,hhsBOOT.UPPER.AD[6],lwd=3,col="GREY")
 segments(8,hhsBOOT.LOWER.AD[8],8,hhsBOOT.UPPER.AD[8],lwd=3,col="GREY")
 segments(10,hhsBOOT.LOWER.AD[10],10,hhsBOOT.UPPER.AD[10],lwd=3,col="GREY")
 segments(12,hhsBOOT.LOWER.AD[12],12,hhsBOOT.UPPER.AD[12],lwd=3,col="GREY")
 segments(14,hhsBOOT.LOWER.AD[14],14,hhsBOOT.UPPER.AD[14],lwd=3,col="GREY")
 segments(16,hhsBOOT.LOWER.AD[16],16,hhsBOOT.UPPER.AD[16],lwd=3,col="GREY")
 segments(18,hhsBOOT.LOWER.AD[18],18,hhsBOOT.UPPER.AD[18],lwd=3,col="GREY")
 segments(20,hhsBOOT.LOWER.AD[20],20,hhsBOOT.UPPER.AD[20],lwd=3,col="GREY")
 segments(22,hhsBOOT.LOWER.AD[22],22,hhsBOOT.UPPER.AD[22],lwd=3,col="GREY")
 segments(24,hhsBOOT.LOWER.AD[24],24,hhsBOOT.UPPER.AD[24],lwd=3,col="GREY")
 segments(26,hhsBOOT.LOWER.AD[26],26,hhsBOOT.UPPER.AD[26],lwd=3,col="GREY")
 segments(28,hhsBOOT.LOWER.AD[28],28,hhsBOOT.UPPER.AD[28],lwd=3,col="GREY")
 segments(30,hhsBOOT.LOWER.AD[30],30,hhsBOOT.UPPER.AD[30],lwd=3,col="GREY")
 segments(32,hhsBOOT.LOWER.AD[32],32,hhsBOOT.UPPER.AD[32],lwd=3,col="GREY")
 segments(34,hhsBOOT.LOWER.AD[34],34,hhsBOOT.UPPER.AD[34],lwd=3,col="GREY")
 segments(36,hhsBOOT.LOWER.AD[36],36,hhsBOOT.UPPER.AD[36],lwd=3,col="GREY")
 segments(38,hhsBOOT.LOWER.AD[38],38,hhsBOOT.UPPER.AD[38],lwd=3,col="GREY")
 segments(40,hhsBOOT.LOWER.AD[40],40,hhsBOOT.UPPER.AD[40],lwd=3,col="GREY")
 segments(42,hhsBOOT.LOWER.AD[42],42,hhsBOOT.UPPER.AD[42],lwd=3,col="GREY")
 segments(44,hhsBOOT.LOWER.AD[44],44,hhsBOOT.UPPER.AD[44],lwd=3,col="GREY")
 segments(46,hhsBOOT.LOWER.AD[46],46,hhsBOOT.UPPER.AD[46],lwd=3,col="GREY")
 segments(48,hhsBOOT.LOWER.AD[48],48,hhsBOOT.UPPER.AD[48],lwd=3,col="GREY")
 segments(50,hhsBOOT.LOWER.AD[50],50,hhsBOOT.UPPER.AD[50],lwd=3,col="GREY")
 segments(52,hhsBOOT.LOWER.AD[52],52,hhsBOOT.UPPER.AD[52],lwd=3,col="GREY")
 segments(54,hhsBOOT.LOWER.AD[54],54,hhsBOOT.UPPER.AD[54],lwd=3,col="GREY")
 segments(56,hhsBOOT.LOWER.AD[56],56,hhsBOOT.UPPER.AD[56],lwd=3,col="GREY")
 segments(58,hhsBOOT.LOWER.AD[58],58,hhsBOOT.UPPER.AD[58],lwd=3,col="GREY")
 segments(1,hsBOOT.LOWER.AD[1],1,hsBOOT.UPPER.AD[1],lwd=3,col="GREY")
 segments(3,hsBOOT.LOWER.AD[3],3,hsBOOT.UPPER.AD[3],lwd=3,col="GREY")
 segments(5,hsBOOT.LOWER.AD[5],5,hsBOOT.UPPER.AD[5],lwd=3,col="GREY")
 segments(7,hsBOOT.LOWER.AD[7],7,hsBOOT.UPPER.AD[7],lwd=3,col="GREY")
 segments(9,hsBOOT.LOWER.AD[9],9,hsBOOT.UPPER.AD[9],lwd=3,col="GREY")
 segments(11,hsBOOT.LOWER.AD[11],11,hsBOOT.UPPER.AD[11],lwd=3,col="GREY")
 segments(13,hsBOOT.LOWER.AD[13],13,hsBOOT.UPPER.AD[13],lwd=3,col="GREY")
 segments(15,hsBOOT.LOWER.AD[15],15,hsBOOT.UPPER.AD[15],lwd=3,col="GREY")
 segments(17,hsBOOT.LOWER.AD[17],17,hsBOOT.UPPER.AD[17],lwd=3,col="GREY")
 segments(19,hsBOOT.LOWER.AD[19],19,hsBOOT.UPPER.AD[19],lwd=3,col="GREY")
 segments(21,hsBOOT.LOWER.AD[21],21,hsBOOT.UPPER.AD[21],lwd=3,col="GREY")
 segments(23,hsBOOT.LOWER.AD[23],23,hsBOOT.UPPER.AD[23],lwd=3,col="GREY")
 segments(25,hsBOOT.LOWER.AD[25],25,hsBOOT.UPPER.AD[25],lwd=3,col="GREY")
 segments(27,hsBOOT.LOWER.AD[27],27,hsBOOT.UPPER.AD[27],lwd=3,col="GREY")
 segments(29,hsBOOT.LOWER.AD[29],29,hsBOOT.UPPER.AD[29],lwd=3,col="GREY")
 segments(31,hsBOOT.LOWER.AD[31],31,hsBOOT.UPPER.AD[31],lwd=3,col="GREY")
 segments(33,hsBOOT.LOWER.AD[33],33,hsBOOT.UPPER.AD[33],lwd=3,col="GREY")
 segments(35,hsBOOT.LOWER.AD[35],35,hsBOOT.UPPER.AD[35],lwd=3,col="GREY")
 segments(37,hsBOOT.LOWER.AD[37],37,hsBOOT.UPPER.AD[37],lwd=3,col="GREY")
 segments(39,hsBOOT.LOWER.AD[39],39,hsBOOT.UPPER.AD[39],lwd=3,col="GREY")
 segments(41,hsBOOT.LOWER.AD[41],41,hsBOOT.UPPER.AD[41],lwd=3,col="GREY")
 segments(43,hsBOOT.LOWER.AD[43],43,hsBOOT.UPPER.AD[43],lwd=3,col="GREY")
 segments(45,hsBOOT.LOWER.AD[45],45,hsBOOT.UPPER.AD[45],lwd=3,col="GREY")
 segments(47,hsBOOT.LOWER.AD[47],47,hsBOOT.UPPER.AD[47],lwd=3,col="GREY")
 segments(49,hsBOOT.LOWER.AD[49],49,hsBOOT.UPPER.AD[49],lwd=3,col="GREY")
 segments(51,hsBOOT.LOWER.AD[51],51,hsBOOT.UPPER.AD[51],lwd=3,col="GREY")
 segments(53,hsBOOT.LOWER.AD[53],53,hsBOOT.UPPER.AD[53],lwd=3,col="GREY")
 segments(55,hsBOOT.LOWER.AD[55],55,hsBOOT.UPPER.AD[55],lwd=3,col="GREY")
 segments(57,hsBOOT.LOWER.AD[57],57,hsBOOT.UPPER.AD[57],lwd=3,col="GREY")
 points(1:58, ELONGATEDTIMESERIES,col="green",pch=19)
 legend(0,max(max(hhsBOOT.UPPER.AD),max(hsBOOT.UPPER.AD)),
     c("Empirical breeding adult females throughout the year", 
      "Algorithm-predicted range for breeding-adult females throughout the year"),
     box.lty = 0,lty=c(1,1),lwd=c(3,3),pch=c(19,20),col=c("green","grey"))
})
output$BiannualJuvenile=renderPlot({
 # Create 0-row data frame which will be used to store data
 dat <- data.frame(x = numeric(0), y = numeric(0))
 
 withProgress(message = 'Calculating', value = 0, {
  # Number of times we'll go through the loop
  n <- 40
  
  for (i in 1:n) {
   # Each time through the loop, add another row of data. This is
   # a stand-in for a long-running computation.
   dat <- rbind(dat, data.frame(x = rnorm(1), y = rnorm(1)))
   
   # Increment the progress bar, and update the detail text.
   incProgress(1/n, detail = paste("", i))
   
   # Pause for 0.1 seconds to simulate a long computation.
   Sys.sleep(0.1)
  }
 })
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TIMESERIES.1=read.table("NEW_TIMESERIES_Northeast.txt")
 TIMESERIES=TIMESERIES.1[["x"]]
 ELONGATEDTIMESERIES=numeric(58)
 ELONGATEDTIMESERIES[1]=TIMESERIES[1]
 loop=1
 for (u in 2:58){
  if (u%%2==0){
   ELONGATEDTIMESERIES[u]=-500}
  if (u%%2!=0){
   loop=loop+1
   ELONGATEDTIMESERIES[u]=TIMESERIES[loop]}}
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
 TRAJECTORY_ADULTS_JUNE=read.table("NEW_Adults_June_Northeast.txt")
 TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
 TRAJECTORY_SUBADULTS_JUNE=read.table("NEW_Subadults_June_Northeast.txt")
 TRAJECTORY_JUVENILES_JUNE=read.table("NEW_Juveniles_June_Northeast.txt")
 ANNUAL.ADULTS=TRAJECTORY_ADULTS_JAN
 ANNUAL.SUBADULTS=TRAJECTORY_SUBADULTS_JAN
 BIANNUAL.JUVENILES=TRAJECTORY_JUVENILES_JUNE
 BIANNUAL.SUBADULTS=TRAJECTORY_SUBADULTS_JUNE
 BIANNUAL.ADULTS=TRAJECTORY_ADULTS_JUNE
 NzMeanH=matrix(0,3,29)		
 NzVarH=matrix(0,3,29)
 NzMean=matrix(0,2,29)		
 NzVar=matrix(0,2,29)
 for (k in 1:29){
  NzMean[1,k]=mean(ANNUAL.SUBADULTS[,k])
  NzMean[2,k]=mean(ANNUAL.ADULTS[,k])
  NzVar[1,k]=var(ANNUAL.SUBADULTS[,k])
  NzVar[2,k]=var(ANNUAL.ADULTS[,k])
  NzMeanH[1,k]=mean(BIANNUAL.JUVENILES[,k])
  NzMeanH[2,k]=mean(BIANNUAL.SUBADULTS[,k])
  NzMeanH[3,k]=mean(BIANNUAL.ADULTS[,k])
  NzVarH[1,k]=var(BIANNUAL.JUVENILES[,k])
  NzVarH[2,k]=var(BIANNUAL.SUBADULTS[,k])
  NzVarH[3,k]=var(BIANNUAL.ADULTS[,k])
 } # END AT EACH TIME LOOP [k]
 # AUXILLARY INFORMATION FROM THE STATE GOVERNMENT 
 NzJHlong=matrix(0,length(MODELS[,1]),58)
 NzSHlong=matrix(0,length(MODELS[,1]),58)
 NzAHlong=matrix(0,length(MODELS[,1]),58)
 ANNUAL.ADULTS=TRAJECTORY_ADULTS_JAN
 ANNUAL.SUBADULTS=TRAJECTORY_SUBADULTS_JAN
 BIANNUAL.JUVENILES=TRAJECTORY_JUVENILES_JUNE
 BIANNUAL.SUBADULTS=TRAJECTORY_SUBADULTS_JUNE
 BIANNUAL.ADULTS=TRAJECTORY_ADULTS_JUNE
 for (j in 1:length(BIANNUAL.JUVENILES[,1])){
  NzJHlong[j,]=c(-500,BIANNUAL.JUVENILES[j,1],
          -500,BIANNUAL.JUVENILES[j,2],
          -500,BIANNUAL.JUVENILES[j,3],-500,BIANNUAL.JUVENILES[j,4],
          -500,BIANNUAL.JUVENILES[j,5],
          -500,BIANNUAL.JUVENILES[j,6],-500,BIANNUAL.JUVENILES[j,7],
          -500,BIANNUAL.JUVENILES[j,8],
          -500,BIANNUAL.JUVENILES[j,9],-500,BIANNUAL.JUVENILES[j,10],
          -500,BIANNUAL.JUVENILES[j,11],-500,BIANNUAL.JUVENILES[j,12],
          -500,BIANNUAL.JUVENILES[j,13],-500,BIANNUAL.JUVENILES[j,14],
          -500,BIANNUAL.JUVENILES[j,15],-500,BIANNUAL.JUVENILES[j,16],
          -500,BIANNUAL.JUVENILES[j,17],-500,BIANNUAL.JUVENILES[j,18],
          -500,BIANNUAL.JUVENILES[j,19],-500,BIANNUAL.JUVENILES[j,20],
          -500,BIANNUAL.JUVENILES[j,21],-500,BIANNUAL.JUVENILES[j,22],
          -500,BIANNUAL.JUVENILES[j,23],-500,BIANNUAL.JUVENILES[j,24],
          -500,BIANNUAL.JUVENILES[j,25],-500,BIANNUAL.JUVENILES[j,26],
          -500,BIANNUAL.JUVENILES[j,27],-500,BIANNUAL.JUVENILES[j,28],
          -500,BIANNUAL.JUVENILES[j,29])}
 for (k in 1:29){
  NzMean[1,k]=mean(ANNUAL.SUBADULTS[,k])
  NzMean[2,k]=mean(ANNUAL.ADULTS[,k])
  NzVar[1,k]=var(ANNUAL.SUBADULTS[,k])
  NzVar[2,k]=var(ANNUAL.ADULTS[,k])
  NzMeanH[1,k]=mean(BIANNUAL.JUVENILES[,k])
  NzMeanH[2,k]=mean(BIANNUAL.SUBADULTS[,k])
  NzMeanH[3,k]=mean(BIANNUAL.ADULTS[,k])
  NzVarH[1,k]=var(BIANNUAL.JUVENILES[,k])
  NzVarH[2,k]=var(BIANNUAL.SUBADULTS[,k])
  NzVarH[3,k]=var(BIANNUAL.ADULTS[,k])
 } # END AT EACH TIME LOOP [k]
 NzMeanHalfJ=numeric(58)
 NzMeanHalfJ=c(-500,NzMeanH[1,1],-500,NzMeanH[1,2],
        -500,NzMeanH[1,3],-500,NzMeanH[1,4],-500,NzMeanH[1,5],
        -500,NzMeanH[1,6],-500,NzMeanH[1,7],-500,NzMeanH[1,8],
        -500,NzMeanH[1,9],-500,NzMeanH[1,10],-500,NzMeanH[1,11],
        -500,NzMeanH[1,12],-500,NzMeanH[1,13],-500,NzMeanH[1,14],
        -500,NzMeanH[1,15],-500,NzMeanH[1,16],-500,NzMeanH[1,17],
        -500,NzMeanH[1,18],-500,NzMeanH[1,19],-500,NzMeanH[1,20],
        -500,NzMeanH[1,21],-500,NzMeanH[1,22],-500,NzMeanH[1,23],
        -500,NzMeanH[1,24],-500,NzMeanH[1,25],-500,NzMeanH[1,26],
        -500,NzMeanH[1,27],-500,NzMeanH[1,28],-500,NzMeanH[1,29])
 hhsBOOT.UPPER.JUV=numeric(58);hhsBOOT.LOWER.JUV=numeric(58);
 for (w in 1:58){
  Index=1
  VectorJH=sort(NzJHlong[,w])
  hhsBOOT.UPPER.JUV[w]=VectorJH[(length(NzJHlong[,w]))]
  hhsBOOT.LOWER.JUV[w]=VectorJH[Index]}
 for (b in 1:58){if (hhsBOOT.UPPER.JUV[b]<0){hhsBOOT.UPPER.JUV[b]=0}}
 for (b in 1:58){if (hhsBOOT.LOWER.JUV[b]<0){hhsBOOT.LOWER.JUV[b]=0}}
 plot(1:58,NzMeanHalfJ,type="p",xlim=c(1,58),
    ylab="Algorithm-predicted abundances",xlab="Bi-annual periods",
    ylim=c(0,max(hhsBOOT.UPPER.JUV)),
    col="darkcyan",lwd=1,lty=3,pch=20,
    main="Algorithm-predicted female abundances for the Northeast, USA",xaxt="n")
 year=seq(1990,2018,1)
 axis(1,at=seq(1,57,2), labels=year)
 segments(2,hhsBOOT.LOWER.JUV[2],2,hhsBOOT.UPPER.JUV[2],lwd=3,col="darkcyan")
 segments(4,hhsBOOT.LOWER.JUV[4],4,hhsBOOT.UPPER.JUV[4],lwd=3,col="darkcyan")
 segments(6,hhsBOOT.LOWER.JUV[6],6,hhsBOOT.UPPER.JUV[6],lwd=3,col="darkcyan")
 segments(8,hhsBOOT.LOWER.JUV[8],8,hhsBOOT.UPPER.JUV[8],lwd=3,col="darkcyan")
 segments(10,hhsBOOT.LOWER.JUV[10],10,hhsBOOT.UPPER.JUV[10],lwd=3,col="darkcyan")
 segments(12,hhsBOOT.LOWER.JUV[12],12,hhsBOOT.UPPER.JUV[12],lwd=3,col="darkcyan")
 segments(14,hhsBOOT.LOWER.JUV[14],14,hhsBOOT.UPPER.JUV[14],lwd=3,col="darkcyan")
 segments(16,hhsBOOT.LOWER.JUV[16],16,hhsBOOT.UPPER.JUV[16],lwd=3,col="darkcyan")
 segments(18,hhsBOOT.LOWER.JUV[18],18,hhsBOOT.UPPER.JUV[18],lwd=3,col="darkcyan")
 segments(20,hhsBOOT.LOWER.JUV[20],20,hhsBOOT.UPPER.JUV[20],lwd=3,col="darkcyan")
 segments(22,hhsBOOT.LOWER.JUV[22],22,hhsBOOT.UPPER.JUV[22],lwd=3,col="darkcyan")
 segments(24,hhsBOOT.LOWER.JUV[24],24,hhsBOOT.UPPER.JUV[24],lwd=3,col="darkcyan")
 segments(26,hhsBOOT.LOWER.JUV[26],26,hhsBOOT.UPPER.JUV[26],lwd=3,col="darkcyan")
 segments(28,hhsBOOT.LOWER.JUV[28],28,hhsBOOT.UPPER.JUV[28],lwd=3,col="darkcyan")
 segments(30,hhsBOOT.LOWER.JUV[30],30,hhsBOOT.UPPER.JUV[30],lwd=3,col="darkcyan")
 segments(32,hhsBOOT.LOWER.JUV[32],32,hhsBOOT.UPPER.JUV[32],lwd=3,col="darkcyan")
 segments(34,hhsBOOT.LOWER.JUV[34],34,hhsBOOT.UPPER.JUV[34],lwd=3,col="darkcyan")
 segments(36,hhsBOOT.LOWER.JUV[36],36,hhsBOOT.UPPER.JUV[36],lwd=3,col="darkcyan")
 segments(38,hhsBOOT.LOWER.JUV[38],38,hhsBOOT.UPPER.JUV[38],lwd=3,col="darkcyan")
 segments(40,hhsBOOT.LOWER.JUV[40],40,hhsBOOT.UPPER.JUV[40],lwd=3,col="darkcyan")
 segments(42,hhsBOOT.LOWER.JUV[42],42,hhsBOOT.UPPER.JUV[42],lwd=3,col="darkcyan")
 segments(44,hhsBOOT.LOWER.JUV[44],44,hhsBOOT.UPPER.JUV[44],lwd=3,col="darkcyan")
 segments(46,hhsBOOT.LOWER.JUV[46],46,hhsBOOT.UPPER.JUV[46],lwd=3,col="darkcyan")
 segments(48,hhsBOOT.LOWER.JUV[48],48,hhsBOOT.UPPER.JUV[48],lwd=3,col="darkcyan")
 segments(50,hhsBOOT.LOWER.JUV[50],50,hhsBOOT.UPPER.JUV[50],lwd=3,col="darkcyan")
 segments(52,hhsBOOT.LOWER.JUV[52],52,hhsBOOT.UPPER.JUV[52],lwd=3,col="darkcyan")
 segments(54,hhsBOOT.LOWER.JUV[54],54,hhsBOOT.UPPER.JUV[54],lwd=3,col="darkcyan")
 segments(56,hhsBOOT.LOWER.JUV[56],56,hhsBOOT.UPPER.JUV[56],lwd=3,col="darkcyan")
 segments(58,hhsBOOT.LOWER.JUV[58],58,hhsBOOT.UPPER.JUV[58],lwd=3,col="darkcyan")
 legend(0,max(max(hhsBOOT.UPPER.JUV)),
     c("Empirical female hatchlings (if the information exists)", 
      "Algorithm-predicted range for hatchling females"),
     box.lty = 0,lty=c(1,1),lwd=c(3,3),pch=c(19,20),
     col=c("green","darkcyan"))	
})

# STABLE STAGE DISTRIUBTION
output$SSDRboxplot=renderPlot({
 # Create 0-row data frame which will be used to store data
 dat <- data.frame(x = numeric(0), y = numeric(0))
 
 withProgress(message = 'Calculating', value = 0, {
  # Number of times we'll go through the loop
  n <- 40
  
  for (i in 1:n) {
   # Each time through the loop, add another row of data. This is
   # a stand-in for a long-running computation.
   dat <- rbind(dat, data.frame(x = rnorm(1), y = rnorm(1)))
   
   # Increment the progress bar, and update the detail text.
   incProgress(1/n, detail = paste("", i))
   
   # Pause for 0.1 seconds to simulate a long computation.
   Sys.sleep(0.1)
  }
 })
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 EVECTORS=matrix(0,3,length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot1=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  EVECTORS[,i]=eigen(Annual)$vector[,1]}
 totalR=matrix(0,2,length(EVECTORS[1,]))
 proportionSR=numeric(length(EVECTORS[1,]))
 proportionAR=numeric(length(EVECTORS[1,]))
 for (k in 1:length(proportionSR)){
  totalR[k]=abs(sum(EVECTORS[,k]))
  proportionSR[k]=abs(EVECTORS[2,k])/totalR[k]
  proportionAR[k]=abs(EVECTORS[3,k])/totalR[k]} 
 par(mfrow=c(1,2))
 boxplot(proportionSR,ylim=c(0,1),main="Immature and non-breeding adult")
 boxplot(proportionAR,ylim=c(0,1),main="Breeding adult")
})
output$SSDRAmean=renderPrint({
  MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
  EVECTORS=matrix(0,3,length(MODELS[,1]))
  for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot1=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  EVECTORS[,i]=eigen(Annual)$vector[,1]}
  totalR=matrix(0,2,length(EVECTORS[1,]))
  proportionSR=numeric(length(EVECTORS[1,]))
  proportionAR=numeric(length(EVECTORS[1,]))
  for (k in 1:length(proportionSR)){
  totalR[k]=abs(sum(EVECTORS[,k]))
  proportionSR[k]=abs(EVECTORS[2,k])/totalR[k]
  proportionAR[k]=abs(EVECTORS[3,k])/totalR[k]}
  mean(proportionAR)
})
output$SSDRAsd=renderPrint({
  MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
  EVECTORS=matrix(0,3,length(MODELS[,1]))
  for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot1=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  EVECTORS[,i]=eigen(Annual)$vector[,1]}
  totalR=matrix(0,2,length(EVECTORS[1,]))
  proportionSR=numeric(length(EVECTORS[1,]))
  proportionAR=numeric(length(EVECTORS[1,]))
  for (k in 1:length(proportionSR)){
  totalR[k]=abs(sum(EVECTORS[,k]))
  proportionSR[k]=abs(EVECTORS[2,k])/totalR[k]
  proportionAR[k]=abs(EVECTORS[3,k])/totalR[k]}
  sd(proportionAR)
})
output$SSDRSmean=renderPrint({
  MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
  EVECTORS=matrix(0,3,length(MODELS[,1]))
  for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot1=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  EVECTORS[,i]=eigen(Annual)$vector[,1]}
  totalR=matrix(0,2,length(EVECTORS[1,]))
  proportionSR=numeric(length(EVECTORS[1,]))
  proportionAR=numeric(length(EVECTORS[1,]))
  for (k in 1:length(proportionSR)){
  totalR[k]=abs(sum(EVECTORS[,k]))
  proportionSR[k]=abs(EVECTORS[2,k])/totalR[k]
  proportionAR[k]=abs(EVECTORS[3,k])/totalR[k]}
  mean(proportionSR)
})
output$SSDRSsd=renderPrint({
  MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
  EVECTORS=matrix(0,3,length(MODELS[,1]))
  for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot1=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  EVECTORS[,i]=eigen(Annual)$vector[,1]}
  totalR=matrix(0,2,length(EVECTORS[1,]))
  proportionSR=numeric(length(EVECTORS[1,]))
  proportionAR=numeric(length(EVECTORS[1,]))
  for (k in 1:length(proportionSR)){
  totalR[k]=abs(sum(EVECTORS[,k]))
  proportionSR[k]=abs(EVECTORS[2,k])/totalR[k]
  proportionAR[k]=abs(EVECTORS[3,k])/totalR[k]}
  sd(proportionSR)
})
output$SSDMAmean=renderPrint({
  MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
  EVECTORSM=matrix(0,3,length(MODELS[,1]))
  for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top2=c(0,0,0)
  mid2=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot2=c(0,MODELS[i,21],MODELS[i,22])
  BNB=rbind(top2,mid2,bot2)
  AnnualM=BNB%*%AB
  EVECTORSM[,i]=eigen(AnnualM)$vector[,1]}
  totalM=matrix(0,2,length(EVECTORSM[1,]))
  proportionSM=numeric(length(EVECTORSM[1,]))
  proportionAM=numeric(length(EVECTORSM[1,]))
  for (k in 1:length(proportionSM)){
  totalM[k]=abs(sum(EVECTORSM[,k]))
  proportionSM[k]=abs(EVECTORSM[2,k])/totalM[k]
  proportionAM[k]=abs(EVECTORSM[3,k])/totalM[k]}
  mean(proportionAM)
})
output$SSDMAsd=renderPrint({
  MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
  EVECTORSM=matrix(0,3,length(MODELS[,1]))
  for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top2=c(0,0,0)
  mid2=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot2=c(0,MODELS[i,21],MODELS[i,22])
  BNB=rbind(top2,mid2,bot2)
  AnnualM=BNB%*%AB
  EVECTORSM[,i]=eigen(AnnualM)$vector[,1]}
  totalM=matrix(0,2,length(EVECTORSM[1,]))
  proportionSM=numeric(length(EVECTORSM[1,]))
  proportionAM=numeric(length(EVECTORSM[1,]))
  for (k in 1:length(proportionSM)){
  totalM[k]=abs(sum(EVECTORSM[,k]))
  proportionSM[k]=abs(EVECTORSM[2,k])/totalM[k]
  proportionAM[k]=abs(EVECTORSM[3,k])/totalM[k]}
  sd(proportionAM)
})
output$SSDMSmean=renderPrint({
  MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
  EVECTORSM=matrix(0,3,length(MODELS[,1]))
  for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top2=c(0,0,0)
  mid2=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot2=c(0,MODELS[i,21],MODELS[i,22])
  BNB=rbind(top2,mid2,bot2)
  AnnualM=BNB%*%AB
  EVECTORSM[,i]=eigen(AnnualM)$vector[,1]}
  totalM=matrix(0,2,length(EVECTORSM[1,]))
  proportionSM=numeric(length(EVECTORSM[1,]))
  proportionAM=numeric(length(EVECTORSM[1,]))
  for (k in 1:length(proportionSM)){
  totalM[k]=abs(sum(EVECTORSM[,k]))
  proportionSM[k]=abs(EVECTORSM[2,k])/totalM[k]
  proportionAM[k]=abs(EVECTORSM[3,k])/totalM[k]}
  mean(proportionSM)
})
output$SSDMSsd=renderPrint({
  MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
  EVECTORSM=matrix(0,3,length(MODELS[,1]))
  for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top2=c(0,0,0)
  mid2=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot2=c(0,MODELS[i,21],MODELS[i,22])
  BNB=rbind(top2,mid2,bot2)
  AnnualM=BNB%*%AB
  EVECTORSM[,i]=eigen(AnnualM)$vector[,1]}
  totalM=matrix(0,2,length(EVECTORSM[1,]))
  proportionSM=numeric(length(EVECTORSM[1,]))
  proportionAM=numeric(length(EVECTORSM[1,]))
  for (k in 1:length(proportionSM)){
  totalM[k]=abs(sum(EVECTORSM[,k]))
  proportionSM[k]=abs(EVECTORSM[2,k])/totalM[k]
  proportionAM[k]=abs(EVECTORSM[3,k])/totalM[k]}
  sd(proportionSM)
})
output$SSDMboxplot=renderPlot({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
  EVECTORSM=matrix(0,3,length(MODELS[,1]))
  for (i in 1:length(MODELS[,1])){
  # THE SHARED BREEDING PERIOD
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top2=c(0,0,0)
  mid2=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot2=c(0,MODELS[i,21],MODELS[i,22])
  BNB=rbind(top2,mid2,bot2)
  AnnualM=BNB%*%AB
  EVECTORSM[,i]=eigen(AnnualM)$vector[,1]}
  totalM=matrix(0,2,length(EVECTORSM[1,]))
  proportionSM=numeric(length(EVECTORSM[1,]))
  proportionAM=numeric(length(EVECTORSM[1,]))
  for (k in 1:length(proportionSM)){
  totalM[k]=abs(sum(EVECTORSM[,k]))
  proportionSM[k]=abs(EVECTORSM[2,k])/totalM[k]
  proportionAM[k]=abs(EVECTORSM[3,k])/totalM[k]}
  par(mfrow=c(1,2))
  boxplot(proportionSM,ylim=c(0,1),main="Immature and non-breeding adult")
  boxplot(proportionAM,ylim=c(0,1),main="Breeding adult")
})
output$SSDRpie=renderPlot({
  MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
  EVECTORS=matrix(0,3,length(MODELS[,1]))
  for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot1=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  EVECTORS[,i]=eigen(Annual)$vector[,1]}
  totalR=matrix(0,2,length(EVECTORS[1,]))
  proportionSR=numeric(length(EVECTORS[1,]))
  proportionAR=numeric(length(EVECTORS[1,]))
  for (k in 1:length(proportionSR)){
  totalR[k]=abs(sum(EVECTORS[,k]))
  proportionSR[k]=abs(EVECTORS[2,k])/totalR[k]
  proportionAR[k]=abs(EVECTORS[3,k])/totalR[k]}
  pie(c(mean(proportionSR),mean(proportionAR)),
   labels=c("Immature and non-breeding adult", "Breeding adult"),
   main="Annual cycle")
})
output$SSDMpie=renderPlot({
  MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
  EVECTORSM=matrix(0,3,length(MODELS[,1]))
  for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top2=c(0,0,0)
  mid2=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot2=c(0,MODELS[i,21],MODELS[i,22])
  BNB=rbind(top2,mid2,bot2)
  AnnualM=BNB%*%AB
  EVECTORSM[,i]=eigen(AnnualM)$vector[,1]}
  totalM=matrix(0,2,length(EVECTORSM[1,]))
  proportionSM=numeric(length(EVECTORSM[1,]))
  proportionAM=numeric(length(EVECTORSM[1,]))
  for (k in 1:length(proportionSM)){
  totalM[k]=abs(sum(EVECTORSM[,k]))
  proportionSM[k]=abs(EVECTORSM[2,k])/totalM[k]
  proportionAM[k]=abs(EVECTORSM[3,k])/totalM[k]}
  pie(c(mean(proportionSM),mean(proportionAM)),
   labels=c("Immature and non-breeding adult","Breeding adult"),
   main="Annual cycle")
})

# EIGENVALUES
output$TuljaRhist=renderPlot({
 # Create 0-row data frame which will be used to store data
 dat <- data.frame(x = numeric(0), y = numeric(0))
 
 withProgress(message = 'Calculating', value = 0, {
  # Number of times we'll go through the loop
  n <- 50
  
  for (i in 1:n) {
   # Each time through the loop, add another row of data. This is
   # a stand-in for a long-running computation.
   dat <- rbind(dat, data.frame(x = rnorm(1), y = rnorm(1)))
   
   # Increment the progress bar, and update the detail text.
   incProgress(1/n, detail = paste("", i))
   
   # Pause for 0.1 seconds to simulate a long computation.
   Sys.sleep(0.1)
  }
 })
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 # TULPURKAR CORRECTION FOR RESIDENTS AND MIGRANTS
 EVALUE.STAR.RESIDENTS=numeric(length(MODELS[,1]))
 EVALUE.STAR.MIGRANTS=numeric(length(MODELS[,1]))
 EVALUES=numeric(length(MODELS[,1]))
 EVALUESM=numeric(length(MODELS[,1]))
 ANNUAL.A22=numeric(length(MODELS[,1]))
 ANNUAL.A23=numeric(length(MODELS[,1]))
 ANNUAL.A32=numeric(length(MODELS[,1]))
 ANNUAL.A33=numeric(length(MODELS[,1]))
 M.ANNUAL.A22=numeric(length(MODELS[,1]))
 M.ANNUAL.A23=numeric(length(MODELS[,1]))
 M.ANNUAL.A32=numeric(length(MODELS[,1]))
 M.ANNUAL.A33=numeric(length(MODELS[,1]))
 # CALCULATE THE BI-ANNUAL MATRICES AND EIGENVALUES
 
 for (i in 1:length(MODELS[,1])){
  # THE SHARED BREEDING PERIOD
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  # THE SPLIT MIGRATION PERIOD
  top1=c(0,0,0)
  mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot1=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  ANNUAL.A22[i]=Annual[2,2]
  ANNUAL.A23[i]=Annual[2,3]
  ANNUAL.A32[i]=Annual[3,2]
  ANNUAL.A33[i]=Annual[3,3]
  EVALUES[i]=c(eigen(Annual)$value[1])
  top2=c(0,0,0)
  mid2=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot2=c(0,MODELS[i,21],MODELS[i,22])
  BNB=rbind(top2,mid2,bot2)
  AnnualM=BNB%*%AB
  M.ANNUAL.A22[i]=AnnualM[2,2]
  M.ANNUAL.A23[i]=AnnualM[2,3]
  M.ANNUAL.A32[i]=AnnualM[3,2]
  M.ANNUAL.A33[i]=AnnualM[3,3]
  EVALUESM[i]=c(eigen(AnnualM)$value[1])}
 
 # HERE IS THE CORRECTION FOR THE YEAR ROUND RESIDENTS
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot1=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top1,mid1,bot1)
  L=ANB%*%AB
  # GET SENSITIVITY MATRIX
  S=matrix(0,3,3)
  W=numeric(3)
  V=numeric(3)
  for (k in 1:3){
   for (j in 1:3){
    V[k]=eigen(t(L))$vector[k,1]/eigen(t(L))$vector[2,1]
    W[j]=eigen(L)$vector[j,1]/(eigen(L)$vector[2,1]+eigen(L)$vector[3,1])}}
  S[2,2]=Re((V[2]%*%W[2])/(V%*%W))
  S[2,3]=Re((V[2]%*%W[3])/(V%*%W))
  S[3,2]=Re((V[3]%*%W[2])/(V%*%W))
  S[3,3]=Re((V[3]%*%W[3])/(V%*%W))
  # GET COVARIANCE MATRIX
  a22=ANNUAL.A22
  a23=ANNUAL.A23
  a32=ANNUAL.A32
  a33=ANNUAL.A33
  Tau=
   (cov(a22,a22)*S[2,2]*S[2,2])+
   (cov(a22,a23)*S[2,2]*S[2,3])+
   (cov(a22,a32)*S[2,2]*S[3,2])+
   (cov(a22,a33)*S[2,2]*S[3,3])+
   (cov(a23,a22)*S[2,3]*S[2,2])+
   (cov(a23,a23)*S[2,3]*S[2,3])+
   (cov(a23,a32)*S[2,3]*S[3,2])+
   (cov(a23,a33)*S[2,3]*S[3,3])+
   (cov(a32,a22)*S[3,2]*S[2,2])+
   (cov(a32,a23)*S[3,2]*S[2,3])+
   (cov(a32,a32)*S[3,2]*S[3,2])+
   (cov(a32,a33)*S[3,2]*S[3,3])+
   (cov(a33,a22)*S[3,3]*S[2,2])+
   (cov(a33,a23)*S[3,3]*S[2,3])+
   (cov(a33,a32)*S[3,3]*S[3,2])+
   (cov(a33,a33)*S[3,3]*S[3,3])
  EVALUE.STAR.RESIDENTS[i]=exp(log(EVALUES[i])-(1/2)*(Tau/(EVALUES[i]^2)))}
 # HERE IS THE CORRECTION FOR THE MIGRATING RESIDENTS
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot1=c(0,MODELS[i,21],MODELS[i,22])
  ANBE=rbind(top1,mid1,bot1)
  LE=ANBE%*%AB
  # GET SENSITIVITY MATRIX
  S=matrix(0,3,3)
  W=numeric(3)
  V=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    V[k]=eigen(t(LE))$vector[k,1]/eigen(t(LE))$vector[2,1]
    W[j]=eigen(LE)$vector[j,1]/(eigen(LE)$vector[2,1]+eigen(LE)$vector[3,1])}}
  S[2,2]=Re((V[2]%*%W[2])/(V%*%W))
  S[2,3]=Re((V[2]%*%W[3])/(V%*%W))
  S[3,2]=Re((V[3]%*%W[2])/(V%*%W))
  S[3,3]=Re((V[3]%*%W[3])/(V%*%W))
  # GET COVARIANCE MATRIX
  a22=M.ANNUAL.A22
  a23=M.ANNUAL.A23
  a32=M.ANNUAL.A32
  a33=M.ANNUAL.A33
  Tau=
   (cov(a22,a22)*S[2,2]*S[2,2])+
   (cov(a22,a23)*S[2,2]*S[2,3])+
   (cov(a22,a32)*S[2,2]*S[3,2])+
   (cov(a22,a33)*S[2,2]*S[3,3])+
   (cov(a23,a22)*S[2,3]*S[2,2])+
   (cov(a23,a23)*S[2,3]*S[2,3])+
   (cov(a23,a32)*S[2,3]*S[3,2])+
   (cov(a23,a33)*S[2,3]*S[3,3])+
   (cov(a32,a22)*S[3,2]*S[2,2])+
   (cov(a32,a23)*S[3,2]*S[2,3])+
   (cov(a32,a32)*S[3,2]*S[3,2])+
   (cov(a32,a33)*S[3,2]*S[3,3])+
   (cov(a33,a22)*S[3,3]*S[2,2])+
   (cov(a33,a23)*S[3,3]*S[2,3])+
   (cov(a33,a32)*S[3,3]*S[3,2])+
   (cov(a33,a33)*S[3,3]*S[3,3])
  EVALUE.STAR.MIGRANTS[i]=exp(log(EVALUESM[i])-(1/2)*(Tau/(EVALUESM[i]^2)))}
 par(mfrow=c(2,1))
 boxplot(EVALUE.STAR.RESIDENTS,xlab="Eigenvalues",main="Corrected annual growth for Northeast residents",ylim=c(.80,1.1))
 abline(h=1,lty=2,col="blue")
 hist(EVALUE.STAR.RESIDENTS,xlim=c(.80,1.1),xlab="Eigenvalues",main="Corrected annual growth for Northeast residents")
})
output$TuljaMhist=renderPlot({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 # TULPURKAR CORRECTION FOR RESIDENTS AND MIGRANTS
 EVALUE.STAR.RESIDENTS=numeric(length(MODELS[,1]))
 EVALUE.STAR.MIGRANTS=numeric(length(MODELS[,1]))
 EVALUES=numeric(length(MODELS[,1]))
 EVALUESM=numeric(length(MODELS[,1]))
 ANNUAL.A22=numeric(length(MODELS[,1]))
 ANNUAL.A23=numeric(length(MODELS[,1]))
 ANNUAL.A32=numeric(length(MODELS[,1]))
 ANNUAL.A33=numeric(length(MODELS[,1]))
 M.ANNUAL.A22=numeric(length(MODELS[,1]))
 M.ANNUAL.A23=numeric(length(MODELS[,1]))
 M.ANNUAL.A32=numeric(length(MODELS[,1]))
 M.ANNUAL.A33=numeric(length(MODELS[,1]))
 # CALCULATE THE BI-ANNUAL MATRICES AND EIGENVALUES
 
 for (i in 1:length(MODELS[,1])){
  # THE SHARED BREEDING PERIOD
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  # THE SPLIT MIGRATION PERIOD
  top1=c(0,0,0)
  mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot1=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  ANNUAL.A22[i]=Annual[2,2]
  ANNUAL.A23[i]=Annual[2,3]
  ANNUAL.A32[i]=Annual[3,2]
  ANNUAL.A33[i]=Annual[3,3]
  EVALUES[i]=c(eigen(Annual)$value[1])
  top2=c(0,0,0)
  mid2=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot2=c(0,MODELS[i,21],MODELS[i,22])
  BNB=rbind(top2,mid2,bot2)
  AnnualM=BNB%*%AB
  M.ANNUAL.A22[i]=AnnualM[2,2]
  M.ANNUAL.A23[i]=AnnualM[2,3]
  M.ANNUAL.A32[i]=AnnualM[3,2]
  M.ANNUAL.A33[i]=AnnualM[3,3]
  EVALUESM[i]=c(eigen(AnnualM)$value[1])}
 
 # HERE IS THE CORRECTION FOR THE YEAR ROUND RESIDENTS
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot1=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top1,mid1,bot1)
  L=ANB%*%AB
  # GET SENSITIVITY MATRIX
  S=matrix(0,3,3)
  W=numeric(3)
  V=numeric(3)
  for (k in 1:3){
   for (j in 1:3){
    V[k]=eigen(t(L))$vector[k,1]/eigen(t(L))$vector[2,1]
    W[j]=eigen(L)$vector[j,1]/(eigen(L)$vector[2,1]+eigen(L)$vector[3,1])}}
  S[2,2]=Re((V[2]%*%W[2])/(V%*%W))
  S[2,3]=Re((V[2]%*%W[3])/(V%*%W))
  S[3,2]=Re((V[3]%*%W[2])/(V%*%W))
  S[3,3]=Re((V[3]%*%W[3])/(V%*%W))
  # GET COVARIANCE MATRIX
  a22=ANNUAL.A22
  a23=ANNUAL.A23
  a32=ANNUAL.A32
  a33=ANNUAL.A33
  Tau=
   (cov(a22,a22)*S[2,2]*S[2,2])+
   (cov(a22,a23)*S[2,2]*S[2,3])+
   (cov(a22,a32)*S[2,2]*S[3,2])+
   (cov(a22,a33)*S[2,2]*S[3,3])+
   (cov(a23,a22)*S[2,3]*S[2,2])+
   (cov(a23,a23)*S[2,3]*S[2,3])+
   (cov(a23,a32)*S[2,3]*S[3,2])+
   (cov(a23,a33)*S[2,3]*S[3,3])+
   (cov(a32,a22)*S[3,2]*S[2,2])+
   (cov(a32,a23)*S[3,2]*S[2,3])+
   (cov(a32,a32)*S[3,2]*S[3,2])+
   (cov(a32,a33)*S[3,2]*S[3,3])+
   (cov(a33,a22)*S[3,3]*S[2,2])+
   (cov(a33,a23)*S[3,3]*S[2,3])+
   (cov(a33,a32)*S[3,3]*S[3,2])+
   (cov(a33,a33)*S[3,3]*S[3,3])
  EVALUE.STAR.RESIDENTS[i]=exp(log(EVALUES[i])-(1/2)*(Tau/(EVALUES[i]^2)))}
 # HERE IS THE CORRECTION FOR THE MIGRATING RESIDENTS
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot1=c(0,MODELS[i,21],MODELS[i,22])
  ANBE=rbind(top1,mid1,bot1)
  LE=ANBE%*%AB
  # GET SENSITIVITY MATRIX
  S=matrix(0,3,3)
  W=numeric(3)
  V=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    V[k]=eigen(t(LE))$vector[k,1]/eigen(t(LE))$vector[2,1]
    W[j]=eigen(LE)$vector[j,1]/(eigen(LE)$vector[2,1]+eigen(LE)$vector[3,1])}}
  S[2,2]=Re((V[2]%*%W[2])/(V%*%W))
  S[2,3]=Re((V[2]%*%W[3])/(V%*%W))
  S[3,2]=Re((V[3]%*%W[2])/(V%*%W))
  S[3,3]=Re((V[3]%*%W[3])/(V%*%W))
  # GET COVARIANCE MATRIX
  a22=M.ANNUAL.A22
  a23=M.ANNUAL.A23
  a32=M.ANNUAL.A32
  a33=M.ANNUAL.A33
  Tau=
   (cov(a22,a22)*S[2,2]*S[2,2])+
   (cov(a22,a23)*S[2,2]*S[2,3])+
   (cov(a22,a32)*S[2,2]*S[3,2])+
   (cov(a22,a33)*S[2,2]*S[3,3])+
   (cov(a23,a22)*S[2,3]*S[2,2])+
   (cov(a23,a23)*S[2,3]*S[2,3])+
   (cov(a23,a32)*S[2,3]*S[3,2])+
   (cov(a23,a33)*S[2,3]*S[3,3])+
   (cov(a32,a22)*S[3,2]*S[2,2])+
   (cov(a32,a23)*S[3,2]*S[2,3])+
   (cov(a32,a32)*S[3,2]*S[3,2])+
   (cov(a32,a33)*S[3,2]*S[3,3])+
   (cov(a33,a22)*S[3,3]*S[2,2])+
   (cov(a33,a23)*S[3,3]*S[2,3])+
   (cov(a33,a32)*S[3,3]*S[3,2])+
   (cov(a33,a33)*S[3,3]*S[3,3])
  EVALUE.STAR.MIGRANTS[i]=exp(log(EVALUESM[i])-(1/2)*(Tau/(EVALUESM[i]^2)))}
 par(mfrow=c(2,1))
 boxplot(EVALUE.STAR.MIGRANTS,xlab="Eigenvalues",main="Corrected annual growth for Northeast migrants",ylim=c(.80,1.1))
 abline(h=1,lty=2,col="blue")
 hist(EVALUE.STAR.MIGRANTS,xlim=c(.80,1.1),xlab="Eigenvalues",main="Corrected annual growth for Northeast migrants")
})

# SENSITIVITIES
output$SensitivityMigrants=renderPlot({
 # Create 0-row data frame which will be used to store data
 dat <- data.frame(x = numeric(0), y = numeric(0))
 
 withProgress(message = 'Calculating', value = 0, {
  # Number of times we'll go through the loop
  n <- 50
  
  for (i in 1:n) {
   # Each time through the loop, add another row of data. This is
   # a stand-in for a long-running computation.
   dat <- rbind(dat, data.frame(x = rnorm(1), y = rnorm(1)))
   
   # Increment the progress bar, and update the detail text.
   incProgress(1/n, detail = paste("", i))
   
   # Pause for 0.1 seconds to simulate a long computation.
   Sys.sleep(0.1)
  }
 })
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 S.M.TWO.TWO=numeric(length(MODELS[,1]))
 S.M.TWO.THREE=numeric(length(MODELS[,1]))
 S.M.THREE.THREE=numeric(length(MODELS[,1]))
 S.M.THREE.TWO=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot1=c(0,MODELS[i,21],MODELS[i,22])
  ANBE=rbind(top1,mid1,bot1)
  LE=ANBE%*%AB
  W=numeric(3);V=numeric(3)
  Ww=numeric(3);Vv=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    V[k]=eigen(t(LE))$vector[k,1]/eigen(t(LE))$vector[2,1]
    W[j]=eigen(LE)$vector[j,1]/(eigen(LE)$vector[2,1]+eigen(LE)$vector[3,1])}}
  S.M.TWO.TWO[i]=Re((V[2]%*%W[2])/(V%*%W))
  S.M.TWO.THREE[i]=Re((V[2]%*%W[3])/(V%*%W))
  S.M.THREE.TWO[i]=Re((V[3]%*%W[2])/(V%*%W))
  S.M.THREE.THREE[i]=Re((V[3]%*%W[3])/(V%*%W))}
 par(mfrow=c(2,2))
 boxplot(S.M.TWO.TWO,main="Sensitivity of a22 for migrants in the Northeast, USA")
 boxplot(S.M.TWO.THREE,main="Sensitivity of a23 for migrants in the Northeast, USAt")
 boxplot(S.M.THREE.TWO,main="Sensitivity of a32 for migrants in the Northeast, USA")
 boxplot(S.M.THREE.THREE,main="Sensitivity of a33 for migrants in the Northeast, USA")
})
output$SensitivityResidents=renderPlot({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 S.R.TWO.TWO=numeric(length(MODELS[,1]))
 S.R.TWO.THREE=numeric(length(MODELS[,1]))
 S.R.THREE.THREE=numeric(length(MODELS[,1]))
 S.R.THREE.TWO=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top=c(0,0,0)
  mid=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top,mid,bot)
  L=ANB%*%AB
  W=numeric(3);V=numeric(3)
  Ww=numeric(3);Vv=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    Vv[k]=eigen(t(L))$vector[k,1]/eigen(t(L))$vector[2,1]
    Ww[j]=eigen(L)$vector[j,1]/(eigen(L)$vector[2,1]+eigen(L)$vector[3,1])}}
  S.R.TWO.TWO[i]=Re((Vv[2]%*%Ww[2])/(Vv%*%Ww))
  S.R.TWO.THREE[i]=Re((Vv[2]%*%Ww[3])/(Vv%*%Ww))
  S.R.THREE.TWO[i]=Re((Vv[3]%*%Ww[2])/(Vv%*%Ww))
  S.R.THREE.THREE[i]=Re((Vv[3]%*%Ww[3])/(Vv%*%Ww))}
 par(mfrow=c(2,2))
 boxplot(S.R.TWO.TWO,main="Sensitivity of a22 for residents in the Northeast, USA")
 boxplot(S.R.TWO.THREE,main="Sensitivity of a23 for residents in the Northeast, USA")
 boxplot(S.R.THREE.TWO,main="Sensitivity of a32 for residents in the Northeast, USA")
 boxplot(S.R.THREE.THREE,main="Sensitivity of a33 for residents in the Northeast, USA")
})
output$SensitivityRTwoTwomean=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 S.R.TWO.TWO=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top=c(0,0,0)
  mid=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top,mid,bot)
  L=ANB%*%AB
  Ww=numeric(3);Vv=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    Vv[k]=eigen(t(L))$vector[k,1]/eigen(t(L))$vector[2,1]
    Ww[j]=eigen(L)$vector[j,1]/(eigen(L)$vector[2,1]+eigen(L)$vector[3,1])}}
  S.R.TWO.TWO[i]=Re((Vv[2]%*%Ww[2])/(Vv%*%Ww))}
 mean(S.R.TWO.TWO)
})
output$SensitivityRTwoTwosd=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 S.R.TWO.TWO=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top=c(0,0,0)
  mid=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top,mid,bot)
  L=ANB%*%AB
  Ww=numeric(3);Vv=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    Vv[k]=eigen(t(L))$vector[k,1]/eigen(t(L))$vector[2,1]
    Ww[j]=eigen(L)$vector[j,1]/(eigen(L)$vector[2,1]+eigen(L)$vector[3,1])}}
  S.R.TWO.TWO[i]=Re((Vv[2]%*%Ww[2])/(Vv%*%Ww))}
 sd(S.R.TWO.TWO)
})
output$SensitivityMTwoTwomean=renderPrint({
  MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
  
  S.M.TWO.TWO=numeric(length(MODELS[,1]))
  for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot1=c(0,MODELS[i,21],MODELS[i,22])
  ANBE=rbind(top1,mid1,bot1)
  LE=ANBE%*%AB
  W=numeric(3);V=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    V[k]=eigen(t(LE))$vector[k,1]/eigen(t(LE))$vector[2,1]
    W[j]=eigen(LE)$vector[j,1]/(eigen(LE)$vector[2,1]+eigen(LE)$vector[3,1])}}
  S.M.TWO.TWO[i]=Re((V[2]%*%W[2])/(V%*%W))}
  mean(S.M.TWO.TWO)
})
output$SensitivityMTwoTwosd=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 S.M.TWO.TWO=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot1=c(0,MODELS[i,21],MODELS[i,22])
  ANBE=rbind(top1,mid1,bot1)
  LE=ANBE%*%AB
  W=numeric(3);V=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    V[k]=eigen(t(LE))$vector[k,1]/eigen(t(LE))$vector[2,1]
    W[j]=eigen(LE)$vector[j,1]/(eigen(LE)$vector[2,1]+eigen(LE)$vector[3,1])}}
  S.M.TWO.TWO[i]=Re((V[2]%*%W[2])/(V%*%W))}
 sd(S.M.TWO.TWO)
})
output$SensitivityRTwoThreemean=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 S.R.TWO.THREE=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top=c(0,0,0)
  mid=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top,mid,bot)
  L=ANB%*%AB
  Ww=numeric(3);Vv=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    Vv[k]=eigen(t(L))$vector[k,1]/eigen(t(L))$vector[2,1]
    Ww[j]=eigen(L)$vector[j,1]/(eigen(L)$vector[2,1]+eigen(L)$vector[3,1])}}
  S.R.TWO.THREE[i]=Re((Vv[2]%*%Ww[3])/(Vv%*%Ww))}
 mean(S.R.TWO.THREE)
})
output$SensitivityRTwoThreesd=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 S.R.TWO.THREE=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top=c(0,0,0)
  mid=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top,mid,bot)
  L=ANB%*%AB
  Ww=numeric(3);Vv=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    Vv[k]=eigen(t(L))$vector[k,1]/eigen(t(L))$vector[2,1]
    Ww[j]=eigen(L)$vector[j,1]/(eigen(L)$vector[2,1]+eigen(L)$vector[3,1])}}
  S.R.TWO.THREE[i]=Re((Vv[2]%*%Ww[3])/(Vv%*%Ww))}
 sd(S.R.TWO.THREE)
})
output$SensitivityMTwoThreemean=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 S.M.TWO.THREE=numeric(length(MODELS[,1]))
 EVALUESM=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot1=c(0,MODELS[i,21],MODELS[i,22])
  ANBE=rbind(top1,mid1,bot1)
  LE=ANBE%*%AB
  EVALUESM[i]=c(eigen(LE)$value[1])
  W=numeric(3);V=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    V[k]=eigen(t(LE))$vector[k,1]/eigen(t(LE))$vector[2,1]
    W[j]=eigen(LE)$vector[j,1]/(eigen(LE)$vector[2,1]+eigen(LE)$vector[3,1])}}
  S.M.TWO.THREE[i]=Re((V[2]%*%W[3])/(V%*%W))}
  mean(S.M.TWO.THREE)
})
output$SensitivityMTwoThreesd=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 S.M.TWO.THREE=numeric(length(MODELS[,1]))
 EVALUESM=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot1=c(0,MODELS[i,21],MODELS[i,22])
  ANBE=rbind(top1,mid1,bot1)
  LE=ANBE%*%AB
  EVALUESM[i]=c(eigen(LE)$value[1])
  W=numeric(3);V=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    V[k]=eigen(t(LE))$vector[k,1]/eigen(t(LE))$vector[2,1]
    W[j]=eigen(LE)$vector[j,1]/(eigen(LE)$vector[2,1]+eigen(LE)$vector[3,1])}}
  S.M.TWO.THREE[i]=Re((V[2]%*%W[3])/(V%*%W))}
 mean(S.M.TWO.THREE)
 sd(S.M.TWO.THREE)
})
output$SensitivityRThreeThreemean=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 S.R.THREE.THREE=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top=c(0,0,0)
  mid=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top,mid,bot)
  L=ANB%*%AB
  Ww=numeric(3);Vv=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    Vv[k]=eigen(t(L))$vector[k,1]/eigen(t(L))$vector[2,1]
    Ww[j]=eigen(L)$vector[j,1]/(eigen(L)$vector[2,1]+eigen(L)$vector[3,1])}}
  S.R.THREE.THREE[i]=Re((Vv[3]%*%Ww[3])/(Vv%*%Ww))}
  mean(S.R.THREE.THREE)
})
output$SensitivityRThreeThreesd=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 S.R.THREE.THREE=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top=c(0,0,0)
  mid=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top,mid,bot)
  L=ANB%*%AB
  Ww=numeric(3);Vv=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    Vv[k]=eigen(t(L))$vector[k,1]/eigen(t(L))$vector[2,1]
    Ww[j]=eigen(L)$vector[j,1]/(eigen(L)$vector[2,1]+eigen(L)$vector[3,1])}}
  S.R.THREE.THREE[i]=Re((Vv[3]%*%Ww[3])/(Vv%*%Ww))}
 sd(S.R.THREE.THREE)
})
output$SensitivityMThreeThreemean=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 S.M.THREE.THREE=numeric(length(MODELS[,1]))
 EVALUESM=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot1=c(0,MODELS[i,21],MODELS[i,22])
  ANBE=rbind(top1,mid1,bot1)
  LE=ANBE%*%AB
  EVALUESM[i]=c(eigen(LE)$value[1])
  W=numeric(3);V=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    V[k]=eigen(t(LE))$vector[k,1]/eigen(t(LE))$vector[2,1]
    W[j]=eigen(LE)$vector[j,1]/(eigen(LE)$vector[2,1]+eigen(LE)$vector[3,1])}}
  S.M.THREE.THREE[i]=Re((V[3]%*%W[3])/(V%*%W))}
 mean(S.M.THREE.THREE)
})
output$SensitivityMThreeThreesd=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 S.M.THREE.THREE=numeric(length(MODELS[,1]))
 EVALUESM=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot1=c(0,MODELS[i,21],MODELS[i,22])
  ANBE=rbind(top1,mid1,bot1)
  LE=ANBE%*%AB
  EVALUESM[i]=c(eigen(LE)$value[1])
  W=numeric(3);V=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    V[k]=eigen(t(LE))$vector[k,1]/eigen(t(LE))$vector[2,1]
    W[j]=eigen(LE)$vector[j,1]/(eigen(LE)$vector[2,1]+eigen(LE)$vector[3,1])}}
  S.M.THREE.THREE[i]=Re((V[3]%*%W[3])/(V%*%W))}
 sd(S.M.THREE.THREE)
})
output$SensitivityRThreeTwomean=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 S.R.THREE.TWO=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top=c(0,0,0)
  mid=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top,mid,bot)
  L=ANB%*%AB
  W=numeric(3);V=numeric(3)
  Ww=numeric(3);Vv=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    Vv[k]=eigen(t(L))$vector[k,1]/eigen(t(L))$vector[2,1]
    Ww[j]=eigen(L)$vector[j,1]/(eigen(L)$vector[2,1]+eigen(L)$vector[3,1])}}
  S.R.THREE.TWO[i]=Re((Vv[3]%*%Ww[2])/(Vv%*%Ww))}
  mean(S.R.THREE.TWO)
})
output$SensitivityRThreeTwosd=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 S.R.THREE.TWO=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top=c(0,0,0)
  mid=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top,mid,bot)
  L=ANB%*%AB
  Ww=numeric(3);Vv=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    Vv[k]=eigen(t(L))$vector[k,1]/eigen(t(L))$vector[2,1]
    Ww[j]=eigen(L)$vector[j,1]/(eigen(L)$vector[2,1]+eigen(L)$vector[3,1])}}
  S.R.THREE.TWO[i]=Re((Vv[3]%*%Ww[2])/(Vv%*%Ww))}
 sd(S.R.THREE.TWO)
})
output$SensitivityMThreeTwomean=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 S.M.THREE.TWO=numeric(length(MODELS[,1]))
 EVALUESM=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot1=c(0,MODELS[i,21],MODELS[i,22])
  ANBE=rbind(top1,mid1,bot1)
  LE=ANBE%*%AB
  EVALUESM[i]=c(eigen(LE)$value[1])
  W=numeric(3);V=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    V[k]=eigen(t(LE))$vector[k,1]/eigen(t(LE))$vector[2,1]
    W[j]=eigen(LE)$vector[j,1]/(eigen(LE)$vector[2,1]+eigen(LE)$vector[3,1])}}
  S.M.THREE.TWO[i]=Re((V[3]%*%W[2])/(V%*%W))}
   mean(S.M.THREE.TWO)
})
output$SensitivityMThreeTwosd=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 S.M.THREE.TWO=numeric(length(MODELS[,1]))
 EVALUESM=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot1=c(0,MODELS[i,21],MODELS[i,22])
  ANBE=rbind(top1,mid1,bot1)
  LE=ANBE%*%AB
  EVALUESM[i]=c(eigen(LE)$value[1])
  W=numeric(3);V=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    V[k]=eigen(t(LE))$vector[k,1]/eigen(t(LE))$vector[2,1]
    W[j]=eigen(LE)$vector[j,1]/(eigen(LE)$vector[2,1]+eigen(LE)$vector[3,1])}}
  S.M.THREE.TWO[i]=Re((V[3]%*%W[2])/(V%*%W))}
 mean(S.M.THREE.TWO)
 sd(S.M.THREE.TWO)
})

# SURVIVAL RATE PLOTS
output$SurvivalB=renderPlot({
 # Create 0-row data frame which will be used to store data
 dat <- data.frame(x = numeric(0), y = numeric(0))
 
 withProgress(message = 'Calculating', value = 0, {
  # Number of times we'll go through the loop
  n <- 40
  
  for (i in 1:n) {
   # Each time through the loop, add another row of data. This is
   # a stand-in for a long-running computation.
   dat <- rbind(dat, data.frame(x = rnorm(1), y = rnorm(1)))
   
   # Increment the progress bar, and update the detail text.
   incProgress(1/n, detail = paste("", i))
   
   # Pause for 0.1 seconds to simulate a long computation.
   Sys.sleep(0.1)
  }
 })
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 Surv2b=numeric(length(MODELS[,1]))
 Surv3b=numeric(length(MODELS[,1]))
 Surv1nb=numeric(length(MODELS[,1]))
 Surv2nb=numeric(length(MODELS[,1]))
 Surv3nb=numeric(length(MODELS[,1]))
 Surv1nbe=numeric(length(MODELS[,1]))
 Surv2nbe=numeric(length(MODELS[,1]))
 Surv3nbe=numeric(length(MODELS[,1]))
 for (iii in 1:length(MODELS[,1])){
  Surv2b[iii]=(6*MODELS[iii,9])/5		# Trans Prob = 1/6
  Surv1nb[iii]=MODELS[iii,13]			# Trans Prob = 1
  Surv2nb[iii]=(6*MODELS[iii,14])/5		# Trans Prob = 1/6
  Surv1nbe[iii]=MODELS[iii,18]			# Trans Prob = 1
  Surv2nbe[iii]=(6*MODELS[iii,19])/5		# Trans Prob = 1/6
  Surv2b[iii]=(6*MODELS[iii,9])/5
  x3=1+(1/12)*(Surv2b[iii])-(1/2)*sqrt((24*Surv2b[iii]^2)/(36))
  Surv3b[iii]=MODELS[iii,12]/(1-x3)		# Trans Prob = x3
  xx3=1+(1/12)*(Surv2nb[iii])-(1/2)*sqrt((24*Surv2nb[iii]^2)/(36))
  Surv3nb[iii]=MODELS[iii,17]/(1-xx3)		# Trans Prob = xx3
  xxx3=1+(1/12)*(Surv2nbe[iii])-(1/2)*sqrt((24*Surv2nbe[iii]^2)/(36))
  Surv3nbe[iii]=MODELS[iii,22]/(1-xxx3)	# Trans Prob = xxx3
 }
 for (i in 1:length(Surv3b)){if (Surv3b[i]>=1){Surv3b[i]=.999}}
 for (i in 1:length(Surv3nb)){if (Surv3nb[i]>=1){Surv3nb[i]=.999}}
 for (i in 1:length(Surv3nbe)){if (Surv3nbe[i]>=1){Surv3nbe[i]=.999}}

 type=c(rep("Stage II",length(Surv2b)),rep("Stage III",length(Surv2b)))
 boxplot(c(Surv2b,Surv3b)~type,main="Survival during the breeding period")
})  
output$SurvivalNB=renderPlot({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 # CREATE THE PARED DOWN VERSION OF THE PROBABILITY DISTRIBUTIONS 
 # INITIALIZE STORAGE FOR SURVIVAL OF EACH STAGE IN BREEDING PERIODS
 Surv2b=numeric(length(MODELS[,1]))
 Surv3b=numeric(length(MODELS[,1]))
 # INITALIZE STORAGE FOR SURVIVAL OF EACH STAGE IN NON-BREEDING PERIODS
 Surv1nb=numeric(length(MODELS[,1]))
 Surv2nb=numeric(length(MODELS[,1]))
 Surv3nb=numeric(length(MODELS[,1]))
 # INITIALIZE STORAGE FOR SURVIVAL OF EACH STAGE IN NON-BREEDING OTHER
 Surv1nbe=numeric(length(MODELS[,1]))
 Surv2nbe=numeric(length(MODELS[,1]))
 Surv3nbe=numeric(length(MODELS[,1]))
 # REMOVE THE TRANSITION PROBABILITIES FROM MATRIX ELEMENTS
 # TO LEAVE ONLY THE SURVIVAL IN EACH STAGE 
 for (iii in 1:length(MODELS[,1])){
  Surv2b[iii]=(6*MODELS[iii,9])/5		# Trans Prob = 1/6
  Surv1nb[iii]=MODELS[iii,13]			# Trans Prob = 1
  Surv2nb[iii]=(6*MODELS[iii,14])/5		# Trans Prob = 1/6
  Surv1nbe[iii]=MODELS[iii,18]			# Trans Prob = 1
  Surv2nbe[iii]=(6*MODELS[iii,19])/5		# Trans Prob = 1/6
  Surv2b[iii]=(6*MODELS[iii,9])/5
  x3=1+(1/12)*(Surv2b[iii])-(1/2)*sqrt((24*Surv2b[iii]^2)/(36))
  Surv3b[iii]=MODELS[iii,12]/(1-x3)		# Trans Prob = x3
  xx3=1+(1/12)*(Surv2nb[iii])-(1/2)*sqrt((24*Surv2nb[iii]^2)/(36))
  Surv3nb[iii]=MODELS[iii,17]/(1-xx3)		# Trans Prob = xx3
  xxx3=1+(1/12)*(Surv2nbe[iii])-(1/2)*sqrt((24*Surv2nbe[iii]^2)/(36))
  Surv3nbe[iii]=MODELS[iii,22]/(1-xxx3)	# Trans Prob = xxx3
 }
 for (i in 1:length(Surv3b)){if (Surv3b[i]>=1){Surv3b[i]=.999}}
 for (i in 1:length(Surv3nb)){if (Surv3nb[i]>=1){Surv3nb[i]=.999}}
 for (i in 1:length(Surv3nbe)){if (Surv3nbe[i]>=1){Surv3nbe[i]=.999}}
 type=c(rep("Stage I",length(Surv2b)),rep("Stage II",length(Surv2b)),rep("Stage III",length(Surv2b)))
 boxplot(c(Surv1nb,Surv2nb,Surv3nb)~type,main="Survival during the non-breeding period in the Northeast")
})  
output$SurvivalNBE=renderPlot({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 # CREATE THE PARED DOWN VERSION OF THE PROBABILITY DISTRIBUTIONS 
 # INITIALIZE STORAGE FOR SURVIVAL OF EACH STAGE IN BREEDING PERIODS
 Surv2b=numeric(length(MODELS[,1]))
 Surv3b=numeric(length(MODELS[,1]))
 # INITALIZE STORAGE FOR SURVIVAL OF EACH STAGE IN NON-BREEDING PERIODS
 Surv1nb=numeric(length(MODELS[,1]))
 Surv2nb=numeric(length(MODELS[,1]))
 Surv3nb=numeric(length(MODELS[,1]))
 # INITIALIZE STORAGE FOR SURVIVAL OF EACH STAGE IN NON-BREEDING OTHER
 Surv1nbe=numeric(length(MODELS[,1]))
 Surv2nbe=numeric(length(MODELS[,1]))
 Surv3nbe=numeric(length(MODELS[,1]))
 # REMOVE THE TRANSITION PROBABILITIES FROM MATRIX ELEMENTS
 # TO LEAVE ONLY THE SURVIVAL IN EACH STAGE 
 for (iii in 1:length(MODELS[,1])){
  Surv2b[iii]=(6*MODELS[iii,9])/5		# Trans Prob = 1/6
  Surv1nb[iii]=MODELS[iii,13]			# Trans Prob = 1
  Surv2nb[iii]=(6*MODELS[iii,14])/5		# Trans Prob = 1/6
  Surv1nbe[iii]=MODELS[iii,18]			# Trans Prob = 1
  Surv2nbe[iii]=(6*MODELS[iii,19])/5		# Trans Prob = 1/6
  Surv2b[iii]=(6*MODELS[iii,9])/5
  x3=1+(1/12)*(Surv2b[iii])-(1/2)*sqrt((24*Surv2b[iii]^2)/(36))
  Surv3b[iii]=MODELS[iii,12]/(1-x3)		# Trans Prob = x3
  xx3=1+(1/12)*(Surv2nb[iii])-(1/2)*sqrt((24*Surv2nb[iii]^2)/(36))
  Surv3nb[iii]=MODELS[iii,17]/(1-xx3)		# Trans Prob = xx3
  xxx3=1+(1/12)*(Surv2nbe[iii])-(1/2)*sqrt((24*Surv2nbe[iii]^2)/(36))
  Surv3nbe[iii]=MODELS[iii,22]/(1-xxx3)	# Trans Prob = xxx3
 }
 for (i in 1:length(Surv3b)){if (Surv3b[i]>=1){Surv3b[i]=.999}}
 for (i in 1:length(Surv3nb)){if (Surv3nb[i]>=1){Surv3nb[i]=.999}}
 for (i in 1:length(Surv3nbe)){if (Surv3nbe[i]>=1){Surv3nbe[i]=.999}}
 type=c(rep("Stage I",length(Surv2b)),rep("Stage II",length(Surv2b)),rep("Stage III",length(Surv2b)))
 boxplot(c(Surv1nbe,Surv2nbe,Surv3nbe)~type,main="Survival during the non-breeding period outside of the Northeast")
})  

# DAMPING RATIOS
output$DampingRatioResidents=renderPlot({
 # Create 0-row data frame which will be used to store data
 dat <- data.frame(x = numeric(0), y = numeric(0))
 
 withProgress(message = 'Calculating', value = 0, {
  # Number of times we'll go through the loop
  n <- 40
  
  for (i in 1:n) {
   # Each time through the loop, add another row of data. This is
   # a stand-in for a long-running computation.
   dat <- rbind(dat, data.frame(x = rnorm(1), y = rnorm(1)))
   
   # Increment the progress bar, and update the detail text.
   incProgress(1/n, detail = paste("", i))
   
   # Pause for 0.1 seconds to simulate a long computation.
   Sys.sleep(0.1)
  }
 })
  MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
  EIGENVALUES.R.DOM=numeric(length(MODELS[,1]))
  EIGENVALUES.R.SUB=numeric(length(MODELS[,1]))
  EIGENVALUES.M.DOM=numeric(length(MODELS[,1]))
  EIGENVALUES.M.SUB=numeric(length(MODELS[,1]))
  DAMP.R=numeric(length(MODELS[,1]))
  DAMP.M=numeric(length(MODELS[,1]))
  for (i in 1:length(MODELS[,1])){
  # THE SHARED BREEDING PERIOD
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  # THE SPLIT MIGRATION PERIOD
  top1=c(0,0,0)
  mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot1=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  EIGENVALUES.R.DOM[i]=c(eigen(Annual)$value[1])
  EIGENVALUES.R.SUB[i]=c(eigen(Annual)$value[2])
  DAMP.R[i]=EIGENVALUES.R.DOM[i]/sqrt(Re(EIGENVALUES.R.SUB[i])^2+Im(EIGENVALUES.R.SUB[i])^2)
  top2=c(0,0,0)
  mid2=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot2=c(0,MODELS[i,21],MODELS[i,22])
  BNB=rbind(top2,mid2,bot2)
  AnnualM=BNB%*%AB
  EIGENVALUES.M.DOM[i]=c(eigen(AnnualM)$value[1])
  EIGENVALUES.M.SUB[i]=c(eigen(AnnualM)$value[2])
  DAMP.M[i]=EIGENVALUES.M.DOM[i]/sqrt(Re(EIGENVALUES.M.SUB[i])^2+Im(EIGENVALUES.M.SUB[i])^2)}
  boxplot(DAMP.R,ylim=c(min(min(DAMP.R),min(DAMP.M)),max(max(DAMP.R),max(DAMP.M))),
     main="Damping ratio for Northeast residents")
})
output$DampingRatioMigrants=renderPlot({
  MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
  
  EIGENVALUES.R.DOM=numeric(length(MODELS[,1]))
  EIGENVALUES.R.SUB=numeric(length(MODELS[,1]))
  EIGENVALUES.M.DOM=numeric(length(MODELS[,1]))
  EIGENVALUES.M.SUB=numeric(length(MODELS[,1]))
  DAMP.R=numeric(length(MODELS[,1]))
  DAMP.M=numeric(length(MODELS[,1]))
  for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot1=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  EIGENVALUES.R.DOM[i]=c(eigen(Annual)$value[1])
  EIGENVALUES.R.SUB[i]=c(eigen(Annual)$value[2])
  DAMP.R[i]=EIGENVALUES.R.DOM[i]/sqrt(Re(EIGENVALUES.R.SUB[i])^2+Im(EIGENVALUES.R.SUB[i])^2)
  top2=c(0,0,0)
  mid2=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot2=c(0,MODELS[i,21],MODELS[i,22])
  BNB=rbind(top2,mid2,bot2)
  AnnualM=BNB%*%AB
  EIGENVALUES.M.DOM[i]=c(eigen(AnnualM)$value[1])
  EIGENVALUES.M.SUB[i]=c(eigen(AnnualM)$value[2])
  DAMP.M[i]=EIGENVALUES.M.DOM[i]/sqrt(Re(EIGENVALUES.M.SUB[i])^2+Im(EIGENVALUES.M.SUB[i])^2)}
  boxplot(DAMP.M,ylim=c(min(min(DAMP.R),min(DAMP.M)),max(max(DAMP.R),max(DAMP.M))),
     main="Damping ratio for Northeast migrants")
})
output$DampingRatioMeanResidents=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 EIGENVALUES.R.DOM=numeric(length(MODELS[,1]))
 EIGENVALUES.R.SUB=numeric(length(MODELS[,1]))
 DAMP.R=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot1=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  EIGENVALUES.R.DOM[i]=c(eigen(Annual)$value[1])
  EIGENVALUES.R.SUB[i]=c(eigen(Annual)$value[2])
  DAMP.R[i]=EIGENVALUES.R.DOM[i]/sqrt(Re(EIGENVALUES.R.SUB[i])^2+Im(EIGENVALUES.R.SUB[i])^2)}
 mean(DAMP.R)
})
output$DampingRatioSDResidents=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 EIGENVALUES.R.DOM=numeric(length(MODELS[,1]))
 EIGENVALUES.R.SUB=numeric(length(MODELS[,1]))
 DAMP.R=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot1=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  EIGENVALUES.R.DOM[i]=c(eigen(Annual)$value[1])
  EIGENVALUES.R.SUB[i]=c(eigen(Annual)$value[2])
  DAMP.R[i]=EIGENVALUES.R.DOM[i]/sqrt(Re(EIGENVALUES.R.SUB[i])^2+Im(EIGENVALUES.R.SUB[i])^2)}
 sd(DAMP.R)
})
output$DampingRatioSDMigrants=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 EIGENVALUES.M.DOM=numeric(length(MODELS[,1]))
 EIGENVALUES.M.SUB=numeric(length(MODELS[,1]))
 DAMP.M=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top2=c(0,0,0)
  mid2=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot2=c(0,MODELS[i,21],MODELS[i,22])
  BNB=rbind(top2,mid2,bot2)
  AnnualM=BNB%*%AB
  EIGENVALUES.M.DOM[i]=c(eigen(AnnualM)$value[1])
  EIGENVALUES.M.SUB[i]=c(eigen(AnnualM)$value[2])
  DAMP.M[i]=EIGENVALUES.M.DOM[i]/sqrt(Re(EIGENVALUES.M.SUB[i])^2+Im(EIGENVALUES.M.SUB[i])^2)}
 sd(DAMP.M)
})
output$DampingRatioMeanMigrants=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 EIGENVALUES.M.DOM=numeric(length(MODELS[,1]))
 EIGENVALUES.M.SUB=numeric(length(MODELS[,1]))
 DAMP.M=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top2=c(0,0,0)
  mid2=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot2=c(0,MODELS[i,21],MODELS[i,22])
  BNB=rbind(top2,mid2,bot2)
  AnnualM=BNB%*%AB
  EIGENVALUES.M.DOM[i]=c(eigen(AnnualM)$value[1])
  EIGENVALUES.M.SUB[i]=c(eigen(AnnualM)$value[2])
  DAMP.M[i]=EIGENVALUES.M.DOM[i]/sqrt(Re(EIGENVALUES.M.SUB[i])^2+Im(EIGENVALUES.M.SUB[i])^2)}
 mean(DAMP.M)
})

# REPRODUTIVE VALUE
output$ReprodResidents=renderPlot({
 # Create 0-row data frame which will be used to store data
 dat <- data.frame(x = numeric(0), y = numeric(0))
 
 withProgress(message = 'Calculating', value = 0, {
  # Number of times we'll go through the loop
  n <- 40
  
  for (i in 1:n) {
   # Each time through the loop, add another row of data. This is
   # a stand-in for a long-running computation.
   dat <- rbind(dat, data.frame(x = rnorm(1), y = rnorm(1)))
   
   # Increment the progress bar, and update the detail text.
   incProgress(1/n, detail = paste("", i))
   
   # Pause for 0.1 seconds to simulate a long computation.
   Sys.sleep(0.1)
  }
 })
  MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
  EVECTORS=matrix(0,3,length(MODELS[,1]))
  for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot1=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  EVECTORS[,i]=eigen(t(Annual))$vector[,1]}
  totalR=matrix(0,2,length(EVECTORS[1,]))
  proportionSR=numeric(length(EVECTORS[1,]))
  proportionAR=numeric(length(EVECTORS[1,]))
  for (j in 1:length(EVECTORS[1,])){
  totalR[j]=abs(sum(EVECTORS[,j]))
  proportionSR[j]=abs(EVECTORS[2,j])/totalR[j]
  proportionAR[j]=abs(EVECTORS[3,j])/totalR[j]}
  par(mfrow=c(1,2))
  boxplot(proportionSR,ylim=c(0,1),main="Immature & non-breeding adult")
  boxplot(proportionAR,ylim=c(0,1),main="Breeding adult")
})
output$ReprodMigrants=renderPlot({
  MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
  EVECTORSM=matrix(0,3,length(MODELS[,1]))
  for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top2=c(0,0,0)
  mid2=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot2=c(0,MODELS[i,21],MODELS[i,22])
  BNB=rbind(top2,mid2,bot2)
  AnnualM=BNB%*%AB
  EVECTORSM[,i]=eigen(t(AnnualM))$vector[,1]}
  totalM=matrix(0,2,length(EVECTORSM[1,]))
  proportionSM=numeric(length(EVECTORSM[1,]))
  proportionAM=numeric(length(EVECTORSM[1,]))
  for (j in 1:length(EVECTORSM[1,])){
  totalM[j]=abs(sum(EVECTORSM[,j]))
  proportionSM[j]=abs(EVECTORSM[2,j])/totalM[j]
  proportionAM[j]=abs(EVECTORSM[3,j])/totalM[j]}
  par(mfrow=c(1,2))
  boxplot(proportionSM,ylim=c(0,1),main="Immature & non-breeding adult")
  boxplot(proportionAM,ylim=c(0,1),main="Breeding adult")
})
output$ReprodRAmean=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 EVECTORS=matrix(0,3,length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot1=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  EVECTORS[,i]=eigen(t(Annual))$vector[,1]}
 totalR=matrix(0,2,length(EVECTORS[1,]))
 proportionSR=numeric(length(EVECTORS[1,]))
 proportionAR=numeric(length(EVECTORS[1,]))
 for (k in 1:length(proportionSR)){
  totalR[k]=abs(sum(EVECTORS[,k]))
  proportionSR[k]=abs(EVECTORS[2,k])/totalR[k]
  proportionAR[k]=abs(EVECTORS[3,k])/totalR[k]}
 mean(proportionAR)
})
output$ReprodRAsd=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 EVECTORS=matrix(0,3,length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot1=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  EVECTORS[,i]=eigen(t(Annual))$vector[,1]}
 totalR=matrix(0,2,length(EVECTORS[1,]))
 proportionSR=numeric(length(EVECTORS[1,]))
 proportionAR=numeric(length(EVECTORS[1,]))
 for (k in 1:length(proportionSR)){
  totalR[k]=abs(sum(EVECTORS[,k]))
  proportionSR[k]=abs(EVECTORS[2,k])/totalR[k]
  proportionAR[k]=abs(EVECTORS[3,k])/totalR[k]}
 sd(proportionAR)
})
output$ReprodRSmean=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 EVECTORS=matrix(0,3,length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot1=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  EVECTORS[,i]=eigen(t(Annual))$vector[,1]}
 totalR=matrix(0,2,length(EVECTORS[1,]))
 proportionSR=numeric(length(EVECTORS[1,]))
 proportionAR=numeric(length(EVECTORS[1,]))
 for (k in 1:length(proportionSR)){
  totalR[k]=abs(sum(EVECTORS[,k]))
  proportionSR[k]=abs(EVECTORS[2,k])/totalR[k]
  proportionAR[k]=abs(EVECTORS[3,k])/totalR[k]}
 mean(proportionSR)
})
output$ReprodRSsd=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 EVECTORS=matrix(0,3,length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot1=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  EVECTORS[,i]=eigen(t(Annual))$vector[,1]}
 totalR=matrix(0,2,length(EVECTORS[1,]))
 proportionSR=numeric(length(EVECTORS[1,]))
 proportionAR=numeric(length(EVECTORS[1,]))
 for (k in 1:length(proportionSR)){
  totalR[k]=abs(sum(EVECTORS[,k]))
  proportionSR[k]=abs(EVECTORS[2,k])/totalR[k]
  proportionAR[k]=abs(EVECTORS[3,k])/totalR[k]}
 sd(proportionSR)
})
output$ReprodMAmean=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 EVECTORSM=matrix(0,3,length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top2=c(0,0,0)
  mid2=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot2=c(0,MODELS[i,21],MODELS[i,22])
  BNB=rbind(top2,mid2,bot2)
  AnnualM=BNB%*%AB
  EVECTORSM[,i]=eigen(t(AnnualM))$vector[,1]}
 totalM=matrix(0,2,length(EVECTORSM[1,]))
 proportionSM=numeric(length(EVECTORSM[1,]))
 proportionAM=numeric(length(EVECTORSM[1,]))
 for (k in 1:length(proportionSM)){
  totalM[k]=abs(sum(EVECTORSM[,k]))
  proportionSM[k]=abs(EVECTORSM[2,k])/totalM[k]
  proportionAM[k]=abs(EVECTORSM[3,k])/totalM[k]}
 mean(proportionAM)
})
output$ReprodMAsd=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 EVECTORSM=matrix(0,3,length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top2=c(0,0,0)
  mid2=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot2=c(0,MODELS[i,21],MODELS[i,22])
  BNB=rbind(top2,mid2,bot2)
  AnnualM=BNB%*%AB
  EVECTORSM[,i]=eigen(t(AnnualM))$vector[,1]}
 totalM=matrix(0,2,length(EVECTORSM[1,]))
 proportionSM=numeric(length(EVECTORSM[1,]))
 proportionAM=numeric(length(EVECTORSM[1,]))
 for (k in 1:length(proportionSM)){
  totalM[k]=abs(sum(EVECTORSM[,k]))
  proportionSM[k]=abs(EVECTORSM[2,k])/totalM[k]
  proportionAM[k]=abs(EVECTORSM[3,k])/totalM[k]}
 sd(proportionAM)
})
output$ReprodMSmean=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 EVECTORSM=matrix(0,3,length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top2=c(0,0,0)
  mid2=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot2=c(0,MODELS[i,21],MODELS[i,22])
  BNB=rbind(top2,mid2,bot2)
  AnnualM=BNB%*%AB
  EVECTORSM[,i]=eigen(t(AnnualM))$vector[,1]}
 totalM=matrix(0,2,length(EVECTORSM[1,]))
 proportionSM=numeric(length(EVECTORSM[1,]))
 proportionAM=numeric(length(EVECTORSM[1,]))
 for (k in 1:length(proportionSM)){
  totalM[k]=abs(sum(EVECTORSM[,k]))
  proportionSM[k]=abs(EVECTORSM[2,k])/totalM[k]
  proportionAM[k]=abs(EVECTORSM[3,k])/totalM[k]}
 mean(proportionSM)
})
output$ReprodMSsd=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 EVECTORSM=matrix(0,3,length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top2=c(0,0,0)
  mid2=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot2=c(0,MODELS[i,21],MODELS[i,22])
  BNB=rbind(top2,mid2,bot2)
  AnnualM=BNB%*%AB
  EVECTORSM[,i]=eigen(t(AnnualM))$vector[,1]}
 totalM=matrix(0,2,length(EVECTORSM[1,]))
 proportionSM=numeric(length(EVECTORSM[1,]))
 proportionAM=numeric(length(EVECTORSM[1,]))
 for (k in 1:length(proportionSM)){
  totalM[k]=abs(sum(EVECTORSM[,k]))
  proportionSM[k]=abs(EVECTORSM[2,k])/totalM[k]
  proportionAM[k]=abs(EVECTORSM[3,k])/totalM[k]}
 sd(proportionSM)
})
output$ReprodRpie=renderPlot({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 EVECTORS=matrix(0,3,length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot1=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  EVECTORS[,i]=eigen(t(Annual))$vector[,1]}
 totalR=matrix(0,2,length(EVECTORS[1,]))
 proportionSR=numeric(length(EVECTORS[1,]))
 proportionAR=numeric(length(EVECTORS[1,]))
 for (k in 1:length(proportionSR)){
  totalR[k]=abs(sum(EVECTORS[,k]))
  proportionSR[k]=abs(EVECTORS[2,k])/totalR[k]
  proportionAR[k]=abs(EVECTORS[3,k])/totalR[k]}
 pie(c(mean(proportionSR),mean(proportionAR)),
   labels=c("Immature and non-breeding adult", "Breeding adult"),
   main="Annual cycle")
})
output$ReprodMpie=renderPlot({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 EVECTORSM=matrix(0,3,length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top2=c(0,0,0)
  mid2=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot2=c(0,MODELS[i,21],MODELS[i,22])
  BNB=rbind(top2,mid2,bot2)
  AnnualM=BNB%*%AB
  EVECTORSM[,i]=eigen(t(AnnualM))$vector[,1]}
 totalM=matrix(0,2,length(EVECTORSM[1,]))
 proportionSM=numeric(length(EVECTORSM[1,]))
 proportionAM=numeric(length(EVECTORSM[1,]))
 for (k in 1:length(proportionSM)){
  totalM[k]=abs(sum(EVECTORSM[,k]))
  proportionSM[k]=abs(EVECTORSM[2,k])/totalM[k]
  proportionAM[k]=abs(EVECTORSM[3,k])/totalM[k]}
 pie(c(mean(proportionSM),mean(proportionAM)),
   labels=c("Immature and non-breeding adult","Breeding adult"),
   main="Annual cycle")
})

# ELASTICITIES
output$ElasticityMigrants=renderPlot({
 # Create 0-row data frame which will be used to store data
 dat <- data.frame(x = numeric(0), y = numeric(0))
 
 withProgress(message = 'Calculating', value = 0, {
  # Number of times we'll go through the loop
  n <- 50
  
  for (i in 1:n) {
   # Each time through the loop, add another row of data. This is
   # a stand-in for a long-running computation.
   dat <- rbind(dat, data.frame(x = rnorm(1), y = rnorm(1)))
   
   # Increment the progress bar, and update the detail text.
   incProgress(1/n, detail = paste("", i))
   
   # Pause for 0.1 seconds to simulate a long computation.
   Sys.sleep(0.1)
  }
 })
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 E.M.TWO.TWO=numeric(length(MODELS[,1]))
 E.M.TWO.THREE=numeric(length(MODELS[,1]))
 E.M.THREE.THREE=numeric(length(MODELS[,1]))
 E.M.THREE.TWO=numeric(length(MODELS[,1]))
 EVALUESM=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot1=c(0,MODELS[i,21],MODELS[i,22])
  ANBE=rbind(top1,mid1,bot1)
  LE=ANBE%*%AB
  EVALUESM[i]=c(eigen(LE)$value[1])
  W=numeric(3);V=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    V[k]=eigen(t(LE))$vector[k,1]/eigen(t(LE))$vector[2,1]
    W[j]=eigen(LE)$vector[j,1]/(eigen(LE)$vector[2,1]+eigen(LE)$vector[3,1])}}
 E.M.TWO.TWO[i]=Re(LE[2,2]/EVALUESM[i])*Re((V[2]%*%W[2])/(V%*%W))
 E.M.TWO.THREE[i]=Re(LE[2,3]/EVALUESM[i])*Re((V[2]%*%W[3])/(V%*%W))
 E.M.THREE.TWO[i]=Re(LE[3,2]/EVALUESM[i])*Re((V[3]%*%W[2])/(V%*%W))
 E.M.THREE.THREE[i]=Re(LE[3,3]/EVALUESM[i])*Re((V[3]%*%W[3])/(V%*%W))}
 pie(c(mean(E.M.TWO.TWO),mean(E.M.TWO.THREE),mean(E.M.THREE.TWO),mean(E.M.THREE.THREE)),col=c("grey45","grey35","grey65","grey50","grey40"),
   labels=c("a22","a23","a32", "a33"))
})
output$ElasticityResidents=renderPlot({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 E.R.TWO.TWO=numeric(length(MODELS[,1]))
 E.R.TWO.THREE=numeric(length(MODELS[,1]))
 E.R.THREE.THREE=numeric(length(MODELS[,1]))
 E.R.THREE.TWO=numeric(length(MODELS[,1]))
 EVALUES=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top=c(0,0,0)
  mid=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top,mid,bot)
  L=ANB%*%AB
  EVALUES[i]=c(eigen(L)$value[1])
  Ww=numeric(3);Vv=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    Vv[k]=eigen(t(L))$vector[k,1]/eigen(t(L))$vector[2,1]
    Ww[j]=eigen(L)$vector[j,1]/(eigen(L)$vector[2,1]+eigen(L)$vector[3,1])}}
  E.R.TWO.TWO[i]=Re(L[2,2]/EVALUES[i])*Re((Vv[2]%*%Ww[2])/(Vv%*%Ww))
  E.R.TWO.THREE[i]=Re(L[2,3]/EVALUES[i])*Re((Vv[2]%*%Ww[3])/(Vv%*%Ww))
  E.R.THREE.TWO[i]=Re(L[3,2]/EVALUES[i])*Re((Vv[3]%*%Ww[2])/(Vv%*%Ww))
  E.R.THREE.THREE[i]=Re(L[3,3]/EVALUES[i])*Re((Vv[3]%*%Ww[3])/(Vv%*%Ww))}
 pie(c(mean(E.R.TWO.TWO),mean(E.R.TWO.THREE),mean(E.R.THREE.TWO),mean(E.R.THREE.THREE)),col=c("grey45","grey35","grey65","grey50","grey40"),
   labels=c("a22","a23","a32", "a33"))
})
output$ElasticityRTwoTwomean=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 E.R.TWO.TWO=numeric(length(MODELS[,1]))
  EVALUES=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top=c(0,0,0)
  mid=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top,mid,bot)
  L=ANB%*%AB
  EVALUES[i]=eigen(L)$value[1]
  Ww=numeric(3);Vv=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    Vv[k]=eigen(t(L))$vector[k,1]/eigen(t(L))$vector[2,1]
    Ww[j]=eigen(L)$vector[j,1]/(eigen(L)$vector[2,1]+eigen(L)$vector[3,1])}}
  E.R.TWO.TWO[i]=Re(L[2,2]/EVALUES[i])*Re((Vv[2]%*%Ww[2])/(Vv%*%Ww))}
 mean(E.R.TWO.TWO)
})
output$ElasticityRTwoTwosd=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 E.R.TWO.TWO=numeric(length(MODELS[,1]))
 EVALUES=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top=c(0,0,0)
  mid=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top,mid,bot)
  L=ANB%*%AB
  EVALUES[i]=eigen(L)$value[1]
  Ww=numeric(3);Vv=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    Vv[k]=eigen(t(L))$vector[k,1]/eigen(t(L))$vector[2,1]
    Ww[j]=eigen(L)$vector[j,1]/(eigen(L)$vector[2,1]+eigen(L)$vector[3,1])}}
  E.R.TWO.TWO[i]=Re(L[2,2]/EVALUES[i])*Re((Vv[2]%*%Ww[2])/(Vv%*%Ww))}
 sd(E.R.TWO.TWO)
})
output$ElasticityMTwoTwomean=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 E.M.TWO.TWO=numeric(length(MODELS[,1]))
 EVALUESM=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot1=c(0,MODELS[i,21],MODELS[i,22])
  ANBE=rbind(top1,mid1,bot1)
  LE=ANBE%*%AB
  EVALUESM[i]=c(eigen(LE)$value[1])
  W=numeric(3);V=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    V[k]=eigen(t(LE))$vector[k,1]/eigen(t(LE))$vector[2,1]
    W[j]=eigen(LE)$vector[j,1]/(eigen(LE)$vector[2,1]+eigen(LE)$vector[3,1])}}
  E.M.TWO.TWO[i]=Re(LE[2,2]/EVALUESM[i])*Re((V[2]%*%W[2])/(V%*%W))}
 mean(E.M.TWO.TWO)
})
output$ElasticityMTwoTwosd=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 E.M.TWO.TWO=numeric(length(MODELS[,1]))
 EVALUESM=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot1=c(0,MODELS[i,21],MODELS[i,22])
  ANBE=rbind(top1,mid1,bot1)
  LE=ANBE%*%AB
  EVALUESM[i]=c(eigen(LE)$value[1])
  W=numeric(3);V=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    V[k]=eigen(t(LE))$vector[k,1]/eigen(t(LE))$vector[2,1]
    W[j]=eigen(LE)$vector[j,1]/(eigen(LE)$vector[2,1]+eigen(LE)$vector[3,1])}}
  E.M.TWO.TWO[i]=Re(LE[2,2]/EVALUESM[i])*Re((V[2]%*%W[2])/(V%*%W))}
 sd(E.M.TWO.TWO)
})
output$ElasticityRTwoThreemean=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 E.R.TWO.THREE=numeric(length(MODELS[,1]))
 EVALUES=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top=c(0,0,0)
  mid=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top,mid,bot)
  L=ANB%*%AB
  EVALUES[i]=eigen(L)$values[1]
  W=numeric(3);V=numeric(3)
  Ww=numeric(3);Vv=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    Vv[k]=eigen(t(L))$vector[k,1]/eigen(t(L))$vector[2,1]
    Ww[j]=eigen(L)$vector[j,1]/(eigen(L)$vector[2,1]+eigen(L)$vector[3,1])}}
  E.R.TWO.THREE[i]=Re(L[2,3]/EVALUES[i])*Re((Vv[2]%*%Ww[3])/(Vv%*%Ww))}
 mean(E.R.TWO.THREE)
})
output$ElasticityRTwoThreesd=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 E.R.TWO.THREE=numeric(length(MODELS[,1]))
 EVALUES=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top=c(0,0,0)
  mid=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top,mid,bot)
  L=ANB%*%AB
  EVALUES[i]=eigen(L)$values[1]
  W=numeric(3);V=numeric(3)
  Ww=numeric(3);Vv=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    Vv[k]=eigen(t(L))$vector[k,1]/eigen(t(L))$vector[2,1]
    Ww[j]=eigen(L)$vector[j,1]/(eigen(L)$vector[2,1]+eigen(L)$vector[3,1])}}
  E.R.TWO.THREE[i]=Re(L[2,3]/EVALUES[i])*Re((Vv[2]%*%Ww[3])/(Vv%*%Ww))}
 sd(E.R.TWO.THREE)
})
output$ElasticityMTwoThreemean=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 E.M.TWO.THREE=numeric(length(MODELS[,1]))
 EVALUESM=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot1=c(0,MODELS[i,21],MODELS[i,22])
  ANBE=rbind(top1,mid1,bot1)
  LE=ANBE%*%AB
  EVALUESM[i]=eigen(LE)$values[1]
  W=numeric(3);V=numeric(3)
  Ww=numeric(3);Vv=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    V[k]=eigen(t(LE))$vector[k,1]/eigen(t(LE))$vector[2,1]
    W[j]=eigen(LE)$vector[j,1]/(eigen(LE)$vector[2,1]+eigen(LE)$vector[3,1])}}
  E.M.TWO.THREE[i]=Re(LE[2,3]/EVALUESM[i])*Re((V[2]%*%W[3])/(V%*%W))}
 mean(E.M.TWO.THREE)
})
output$ElasticityMTwoThreesd=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 E.M.TWO.THREE=numeric(length(MODELS[,1]))
 EVALUESM=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot1=c(0,MODELS[i,21],MODELS[i,22])
  ANBE=rbind(top1,mid1,bot1)
  LE=ANBE%*%AB
  EVALUESM[i]=eigen(LE)$values[1]
  W=numeric(3);V=numeric(3)
  Ww=numeric(3);Vv=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    V[k]=eigen(t(LE))$vector[k,1]/eigen(t(LE))$vector[2,1]
    W[j]=eigen(LE)$vector[j,1]/(eigen(LE)$vector[2,1]+eigen(LE)$vector[3,1])}}
  E.M.TWO.THREE[i]=Re(LE[2,3]/EVALUESM[i])*Re((V[2]%*%W[3])/(V%*%W))}
 sd(E.M.TWO.THREE)
})
output$ElasticityRThreeThreemean=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 E.R.THREE.THREE=numeric(length(MODELS[,1]))
 EVALUES=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top=c(0,0,0)
  mid=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top,mid,bot)
  L=ANB%*%AB
  EVALUES[i]=eigen(L)$values[1]
  W=numeric(3);V=numeric(3)
  Ww=numeric(3);Vv=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    Vv[k]=eigen(t(L))$vector[k,1]/eigen(t(L))$vector[2,1]
    Ww[j]=eigen(L)$vector[j,1]/(eigen(L)$vector[2,1]+eigen(L)$vector[3,1])}}
  E.R.THREE.THREE[i]=Re(L[3,3]/EVALUES[i])*Re((Vv[3]%*%Ww[3])/(Vv%*%Ww))}
 mean(E.R.THREE.THREE)
})
output$ElasticityRThreeThreesd=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 E.R.THREE.THREE=numeric(length(MODELS[,1]))
 EVALUES=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top=c(0,0,0)
  mid=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top,mid,bot)
  L=ANB%*%AB
  EVALUES[i]=eigen(L)$values[1]
  W=numeric(3);V=numeric(3)
  Ww=numeric(3);Vv=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    Vv[k]=eigen(t(L))$vector[k,1]/eigen(t(L))$vector[2,1]
    Ww[j]=eigen(L)$vector[j,1]/(eigen(L)$vector[2,1]+eigen(L)$vector[3,1])}}
  E.R.THREE.THREE[i]=Re(L[3,3]/EVALUES[i])*Re((Vv[3]%*%Ww[3])/(Vv%*%Ww))}
 sd(E.R.THREE.THREE)
})
output$ElasticityMThreeThreemean=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 EVALUESM=numeric(length(MODELS[,1]))
 E.M.THREE.THREE=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot1=c(0,MODELS[i,21],MODELS[i,22])
  ANBE=rbind(top1,mid1,bot1)
  LE=ANBE%*%AB
  EVALUESM[i]=eigen(LE)$values[1]
  W=numeric(3);V=numeric(3)
  Ww=numeric(3);Vv=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    V[k]=eigen(t(LE))$vector[k,1]/eigen(t(LE))$vector[2,1]
    W[j]=eigen(LE)$vector[j,1]/(eigen(LE)$vector[2,1]+eigen(LE)$vector[3,1])}}
  E.M.THREE.THREE[i]=Re(LE[3,3]/EVALUESM[i])*Re((V[3]%*%W[3])/(V%*%W))}
 mean(E.M.THREE.THREE)
})
output$ElasticityMThreeThreesd=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 EVALUESM=numeric(length(MODELS[,1]))
 E.M.THREE.THREE=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot1=c(0,MODELS[i,21],MODELS[i,22])
  ANBE=rbind(top1,mid1,bot1)
  LE=ANBE%*%AB
  EVALUESM[i]=eigen(LE)$values[1]
  W=numeric(3);V=numeric(3)
  Ww=numeric(3);Vv=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    V[k]=eigen(t(LE))$vector[k,1]/eigen(t(LE))$vector[2,1]
    W[j]=eigen(LE)$vector[j,1]/(eigen(LE)$vector[2,1]+eigen(LE)$vector[3,1])}}
  E.M.THREE.THREE[i]=Re(LE[3,3]/EVALUESM[i])*Re((V[3]%*%W[3])/(V%*%W))}
 sd(E.M.THREE.THREE)
})
output$ElasticityRThreeTwomean=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 E.R.THREE.TWO=numeric(length(MODELS[,1]))
 EVALUES=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top=c(0,0,0)
  mid=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top,mid,bot)
  L=ANB%*%AB
  EVALUES[i]=eigen(L)$values[1]
  W=numeric(3);V=numeric(3)
  Ww=numeric(3);Vv=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    Vv[k]=eigen(t(L))$vector[k,1]/eigen(t(L))$vector[2,1]
    Ww[j]=eigen(L)$vector[j,1]/(eigen(L)$vector[2,1]+eigen(L)$vector[3,1])}}
  E.R.THREE.TWO[i]=Re(L[3,2]/EVALUES[i])*Re((Vv[3]%*%Ww[2])/(Vv%*%Ww))}
 mean(E.R.THREE.TWO)
})
output$ElasticityRThreeTwosd=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 E.R.THREE.TWO=numeric(length(MODELS[,1]))
 EVALUES=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top=c(0,0,0)
  mid=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top,mid,bot)
  L=ANB%*%AB
  EVALUES[i]=eigen(L)$values[1]
  W=numeric(3);V=numeric(3)
  Ww=numeric(3);Vv=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    Vv[k]=eigen(t(L))$vector[k,1]/eigen(t(L))$vector[2,1]
    Ww[j]=eigen(L)$vector[j,1]/(eigen(L)$vector[2,1]+eigen(L)$vector[3,1])}}
  E.R.THREE.TWO[i]=Re(L[3,2]/EVALUES[i])*Re((Vv[3]%*%Ww[2])/(Vv%*%Ww))}
 sd(E.R.THREE.TWO)
})
output$ElasticityMThreeTwomean=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 E.M.THREE.TWO=numeric(length(MODELS[,1]))
  EVALUESM=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot1=c(0,MODELS[i,21],MODELS[i,22])
  ANBE=rbind(top1,mid1,bot1)
  LE=ANBE%*%AB
  EVALUESM[i]=eigen(LE)$values[1]
  W=numeric(3);V=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    V[k]=eigen(t(LE))$vector[k,1]/eigen(t(LE))$vector[2,1]
    W[j]=eigen(LE)$vector[j,1]/(eigen(LE)$vector[2,1]+eigen(LE)$vector[3,1])}}
  E.M.THREE.TWO[i]=Re(LE[3,2]/EVALUESM[i])*Re((V[3]%*%W[2])/(V%*%W))}
 mean(E.M.THREE.TWO)
})
output$ElasticityMThreeTwosd=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 
 E.M.THREE.TWO=numeric(length(MODELS[,1]))
 EVALUESM=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot1=c(0,MODELS[i,21],MODELS[i,22])
  ANBE=rbind(top1,mid1,bot1)
  LE=ANBE%*%AB
  EVALUESM[i]=eigen(LE)$values[1]
  W=numeric(3);V=numeric(3)
  for (k in 2:3){
   for (j in 2:3){
    V[k]=eigen(t(LE))$vector[k,1]/eigen(t(LE))$vector[2,1]
    W[j]=eigen(LE)$vector[j,1]/(eigen(LE)$vector[2,1]+eigen(LE)$vector[3,1])}}
  E.M.THREE.TWO[i]=Re(LE[3,2]/EVALUESM[i])*Re((V[3]%*%W[2])/(V%*%W))}
 sd(E.M.THREE.TWO)
})

# STOCHASTIC GROWTH RATE
output$Stoch=renderPlot({
 # Create 0-row data frame which will be used to store data
 dat <- data.frame(x = numeric(0), y = numeric(0))
 
 withProgress(message = 'Calculating', value = 0, {
  # Number of times we'll go through the loop
  n <- 40
  
  for (i in 1:n) {
   # Each time through the loop, add another row of data. This is
   # a stand-in for a long-running computation.
   dat <- rbind(dat, data.frame(x = rnorm(1), y = rnorm(1)))
   
   # Increment the progress bar, and update the detail text.
   incProgress(1/n, detail = paste("", i))
   
   # Pause for 0.1 seconds to simulate a long computation.
   Sys.sleep(0.1)
  }
 })
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
 SGR=matrix(0,length(MODELS[,1]),30)
 for (i in 1:length(MODELS[,1])){
  for (j in 1:29){
   SGR[i,j+1]=exp((1/(j+1))*log(TRAJECTORY_ADULTS_JAN[i,j+1]/TRAJECTORY_ADULTS_JAN[i,1]))}}
 par(mfrow=c(1,1))
 year=seq(1990,2018,1)		
 boxplot(SGR[,30],ylim=c(.9,1.2),main="Stochastic growth rate in the Northeast, USA")
 abline(h=1,lty=2,col="blue")
})
output$StochMean=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
 SGR=matrix(0,length(MODELS[,1]),30)
 for (i in 1:length(MODELS[,1])){
  for (j in 1:29){
   SGR[i,j+1]=exp((1/(j+1))*log(TRAJECTORY_ADULTS_JAN[i,j+1]/TRAJECTORY_ADULTS_JAN[i,1]))}}
 mean(SGR[,30])
})
output$StochSD=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
 SGR=matrix(0,length(MODELS[,1]),30)
 for (i in 1:length(MODELS[,1])){
  for (j in 1:29){
   SGR[i,j+1]=exp((1/(j+1))*log(TRAJECTORY_ADULTS_JAN[i,j+1]/TRAJECTORY_ADULTS_JAN[i,1]))}}
 sd(SGR[,30])
})

# TRANSIENT GROWTH RATE
output$TransGR=renderPlot({
 # Create 0-row data frame which will be used to store data
 dat <- data.frame(x = numeric(0), y = numeric(0))
 
 withProgress(message = 'Calculating', value = 0, {
  # Number of times we'll go through the loop
  n <- 40
  
  for (i in 1:n) {
   # Each time through the loop, add another row of data. This is
   # a stand-in for a long-running computation.
   dat <- rbind(dat, data.frame(x = rnorm(1), y = rnorm(1)))
   
   # Increment the progress bar, and update the detail text.
   incProgress(1/n, detail = paste("", i))
   
   # Pause for 0.1 seconds to simulate a long computation.
   Sys.sleep(0.1)
  }
 })
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt") 
 TPGR=matrix(0,length(MODELS[,1]),30)
 for (i in 1:length(MODELS[,1])){
  for (j in 1:29){
   TPGR[i,j]=log(TRAJECTORY_ADULTS_JAN[i,j+1]/TRAJECTORY_ADULTS_JAN[i,j])
  }}
 par(mfrow=c(1,1))
 year=seq(1990,2018,1)		
 matplot(1:29,t(TPGR[,1:29]),type="l",xlab="Time",xaxt="n",ylab="Transient 
	growth rate",main="Transient growth rate in the Northeast, USA")
 axis(1, at=1:29, labels=year)
})

# LOSS OF GENETIC DIVERSITY
output$LGD=renderPlot({
 # Create 0-row data frame which will be used to store data
 dat <- data.frame(x = numeric(0), y = numeric(0))
 
 withProgress(message = 'Calculating', value = 0, {
  # Number of times we'll go through the loop
  n <- 40
  
  for (i in 1:n) {
   # Each time through the loop, add another row of data. This is
   # a stand-in for a long-running computation.
   dat <- rbind(dat, data.frame(x = rnorm(1), y = rnorm(1)))
   
   # Increment the progress bar, and update the detail text.
   incProgress(1/n, detail = paste("", i))
   
   # Pause for 0.1 seconds to simulate a long computation.
   Sys.sleep(0.1)
  }
 })
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt") 
 Ne=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  Ne[i]=1/((1/29)*sum(1/TRAJECTORY_ADULTS_JAN[i,1:29]))}
 par(mfrow=c(1,1))
 LGD=matrix(0,length(MODELS[,1]),30)
 for (i in 1:length(MODELS[,1])){
  for (j in 1:29){
   LGD[i,j]=(1-(1/(2*Ne[i])))^j}}
 par(mfrow=c(1,1))
 year=seq(1990,2018,1)		
 matplot(1:29,t(LGD[,1:29]),type="l",xlab="Time",xaxt="n",ylab="Loss of genetic diversity through time",
     main="Loss of genetic diversity in each generation in the Northeast, USA")
 axis(1, at=1:29, labels=year)
})

# HARMONIC VS. ARITHMETIC MEAN
output$Effective=renderPlot({
 # Create 0-row data frame which will be used to store data
 dat <- data.frame(x = numeric(0), y = numeric(0))
 
 withProgress(message = 'Calculating', value = 0, {
  # Number of times we'll go through the loop
  n <- 40
  
  for (i in 1:n) {
   # Each time through the loop, add another row of data. This is
   # a stand-in for a long-running computation.
   dat <- rbind(dat, data.frame(x = rnorm(1), y = rnorm(1)))
   
   # Increment the progress bar, and update the detail text.
   incProgress(1/n, detail = paste("", i))
   
   # Pause for 0.1 seconds to simulate a long computation.
   Sys.sleep(0.1)
  }
 })
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt") 
 Ne=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  Ne[i]=1/((1/29)*sum(1/TRAJECTORY_ADULTS_JAN[i,1:29]))}
 Nbar=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  Nbar[i]=(1/29)*sum(TRAJECTORY_ADULTS_JAN[i,1:29])}
 par(mfrow=c(2,1))
 boxplot(Ne,main="Harmonic mean of breeding adults from 1990-2018")
 boxplot(Nbar,main="Arithmetic mean of breeding adults from 1990-2018")
})
output$NbarMean=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt") 
 Nbar=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  Nbar[i]=(1/29)*sum(TRAJECTORY_ADULTS_JAN[i,1:29])}
 mean(Nbar)
})
output$NbarSD=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt") 
 Nbar=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  Nbar[i]=(1/29)*sum(TRAJECTORY_ADULTS_JAN[i,1:29])}
 sd(Nbar)
})
output$NeMean=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt") 
 Ne=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  Ne[i]=1/((1/29)*sum(1/TRAJECTORY_ADULTS_JAN[i,1:29]))}
 mean(Ne)
})
output$NeSD=renderPrint({
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt") 
 Ne=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  Ne[i]=1/((1/29)*sum(1/TRAJECTORY_ADULTS_JAN[i,1:29]))}
 sd(Ne)
})

# CUMULATIVE GROWTH RATE
output$Cumulative=renderPlot({
 # Create 0-row data frame which will be used to store data
 dat <- data.frame(x = numeric(0), y = numeric(0))
 
 withProgress(message = 'Calculating', value = 0, {
  # Number of times we'll go through the loop
  n <- 40
  
  for (i in 1:n) {
   # Each time through the loop, add another row of data. This is
   # a stand-in for a long-running computation.
   dat <- rbind(dat, data.frame(x = rnorm(1), y = rnorm(1)))
   
   # Increment the progress bar, and update the detail text.
   incProgress(1/n, detail = paste("", i))
   
   # Pause for 0.1 seconds to simulate a long computation.
   Sys.sleep(0.1)
  }
 })
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
 TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
 Total=matrix(0,length(MODELS[,1]),29)
 CUM=matrix(0,length(MODELS[,1]),29)
 for(i in 1:length(MODELS[,1])){
 for(j in 1:29){
  Total[i,j]=TRAJECTORY_ADULTS_JAN[i,j]+TRAJECTORY_SUBADULTS_JAN[i,j]
  CUM[i,j]=Total[i,j]/Total[i,1]
 }}
 par(mfrow=c(1,1))
 year=seq(1990,2018,1)		
 matplot(1:29,t(CUM),type="l",xlab="Time",xaxt="n",ylab="Cumulative growth",
     main="Cumulative growth in the Northeast, USA")
 axis(1, at=1:29, labels=year)
 
})

# REACTIVITY
output$ReactR=renderPlot({
 # Create 0-row data frame which will be used to store data
 dat <- data.frame(x = numeric(0), y = numeric(0))
 withProgress(message = 'Calculating', value = 0, {
  # Number of times we'll go through the loop
  n <- 40
  
  for (i in 1:n) {
   # Each time through the loop, add another row of data. This is
   # a stand-in for a long-running computation.
   dat <- rbind(dat, data.frame(x = rnorm(1), y = rnorm(1)))
   
   # Increment the progress bar, and update the detail text.
   incProgress(1/n, detail = paste("", i))
   
   # Pause for 0.1 seconds to simulate a long computation.
   Sys.sleep(0.1)
  }
 })
 library(popdemo)
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
 TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
 ReacR=numeric(length(MODELS[,1]))
 Initial=matrix(0,2,length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  Initial[1,i]=TRAJECTORY_SUBADULTS_JAN[i,1]
  Initial[2,i]=TRAJECTORY_ADULTS_JAN[i,1]
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot1=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  Annual=Annual[2:3,2:3]
  ReacR[i]=reac(Annual,vector=Initial[,i])}
 par(mfrow=c(1,1))
 boxplot(ReacR,main="Population reactivity for year-round Northeast residents") 
})
output$ReactM=renderPlot({
 library(popdemo)
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
 TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
 ReacM=numeric(length(MODELS[,1]))
 Initial=matrix(0,2,length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  Initial[1,i]=TRAJECTORY_SUBADULTS_JAN[i,1]
  Initial[2,i]=TRAJECTORY_ADULTS_JAN[i,1]
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot1=c(0,MODELS[i,21],MODELS[i,22])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  Annual=Annual[2:3,2:3]
  ReacM[i]=reac(Annual,vector=Initial[,i])}
 par(mfrow=c(1,1))
 boxplot(ReacM,main="Population reactivity for part-year Northeast residents") 
})
output$ReacMigrantSD=renderPrint({
 library(popdemo)
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
 TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
 ReacM=numeric(length(MODELS[,1]))
 Initial=matrix(0,2,length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  Initial[1,i]=TRAJECTORY_SUBADULTS_JAN[i,1]
  Initial[2,i]=TRAJECTORY_ADULTS_JAN[i,1]
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot1=c(0,MODELS[i,21],MODELS[i,22])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  Annual=Annual[2:3,2:3]
  ReacM[i]=reac(Annual,vector=Initial[,i])}
sd(ReacM)
})
output$ReacMigrantMean=renderPrint({
 library(popdemo)
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
 TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
 ReacM=numeric(length(MODELS[,1]))
 Initial=matrix(0,2,length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  Initial[1,i]=TRAJECTORY_SUBADULTS_JAN[i,1]
  Initial[2,i]=TRAJECTORY_ADULTS_JAN[i,1]
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot1=c(0,MODELS[i,21],MODELS[i,22])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  Annual=Annual[2:3,2:3]
  ReacM[i]=reac(Annual,vector=Initial[,i])}
 mean(ReacM)
})
output$ReacResidentMean=renderPrint({
 library(popdemo)
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
 TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
 ReacR=numeric(length(MODELS[,1]))
 Initial=matrix(0,2,length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  Initial[1,i]=TRAJECTORY_SUBADULTS_JAN[i,1]
  Initial[2,i]=TRAJECTORY_ADULTS_JAN[i,1]
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot1=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  Annual=Annual[2:3,2:3]
  ReacR[i]=reac(Annual,vector=Initial[,i])}
 mean(ReacR)
})
output$ReacResidentSD=renderPrint({
 library(popdemo)
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
 TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
 ReacR=numeric(length(MODELS[,1]))
 Initial=matrix(0,2,length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  Initial[1,i]=TRAJECTORY_SUBADULTS_JAN[i,1]
  Initial[2,i]=TRAJECTORY_ADULTS_JAN[i,1]
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot1=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  Annual=Annual[2:3,2:3]
  ReacR[i]=reac(Annual,vector=Initial[,i])}
 sd(ReacR)
})

# MAXIMUM AMPLIFICATION 
output$MAXAMPR=renderPlot({
 # Create 0-row data frame which will be used to store data
 dat <- data.frame(x = numeric(0), y = numeric(0))
 withProgress(message = 'Calculating', value = 0, {
  # Number of times we'll go through the loop
  n <- 40
  
  for (i in 1:n) {
   # Each time through the loop, add another row of data. This is
   # a stand-in for a long-running computation.
   dat <- rbind(dat, data.frame(x = rnorm(1), y = rnorm(1)))
   
   # Increment the progress bar, and update the detail text.
   incProgress(1/n, detail = paste("", i))
   
   # Pause for 0.1 seconds to simulate a long computation.
   Sys.sleep(0.1)
  }
 })
 library(popdemo)
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
 TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
 MAXAMPR=numeric(length(MODELS[,1]))
 Initial=matrix(0,2,length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  Initial[1,i]=TRAJECTORY_SUBADULTS_JAN[i,1]
  Initial[2,i]=TRAJECTORY_ADULTS_JAN[i,1]
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot1=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  Annual=Annual[2:3,2:3]
  MAXAMPR[i]=maxamp(Annual)}
 par(mfrow=c(1,1))
 boxplot(MAXAMPR,main="Maximum amplification for year-round Northeast residents") 
})
output$MAXAMPM=renderPlot({
 library(popdemo)
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
 TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
 MAXAMPM=numeric(length(MODELS[,1]))
 Initial=matrix(0,2,length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  Initial[1,i]=TRAJECTORY_SUBADULTS_JAN[i,1]
  Initial[2,i]=TRAJECTORY_ADULTS_JAN[i,1]
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot1=c(0,MODELS[i,21],MODELS[i,22])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  Annual=Annual[2:3,2:3]
  MAXAMPM[i]=maxamp(Annual)}
 par(mfrow=c(1,1))
 boxplot(MAXAMPM,main="Maximum amplification for part-year Northeast residents") 
})
output$MAXAMPMigrantMean=renderPrint({
 library(popdemo)
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
 TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
 MAXAMPM=numeric(length(MODELS[,1]))
 Initial=matrix(0,2,length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  Initial[1,i]=TRAJECTORY_SUBADULTS_JAN[i,1]
  Initial[2,i]=TRAJECTORY_ADULTS_JAN[i,1]
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot1=c(0,MODELS[i,21],MODELS[i,22])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  Annual=Annual[2:3,2:3]
  MAXAMPM[i]=maxamp(Annual)}
mean(MAXAMPM)
})
output$MAXAMPMigrantSD=renderPrint({
 library(popdemo)
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
 TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
 MAXAMPM=numeric(length(MODELS[,1]))
 Initial=matrix(0,2,length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  Initial[1,i]=TRAJECTORY_SUBADULTS_JAN[i,1]
  Initial[2,i]=TRAJECTORY_ADULTS_JAN[i,1]
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot1=c(0,MODELS[i,21],MODELS[i,22])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  Annual=Annual[2:3,2:3]
  MAXAMPM[i]=maxamp(Annual)}
 sd(MAXAMPM)
})
output$MAXAMPResidentSD=renderPrint({
 library(popdemo)
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
 TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
 MAXAMPR=numeric(length(MODELS[,1]))
 Initial=matrix(0,2,length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  Initial[1,i]=TRAJECTORY_SUBADULTS_JAN[i,1]
  Initial[2,i]=TRAJECTORY_ADULTS_JAN[i,1]
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot1=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  Annual=Annual[2:3,2:3]
  MAXAMPR[i]=maxamp(Annual)}
 sd(MAXAMPR)
})
output$MAXAMPResidentMean=renderPrint({
 library(popdemo)
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
 TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
 MAXAMPR=numeric(length(MODELS[,1]))
 Initial=matrix(0,2,length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  Initial[1,i]=TRAJECTORY_SUBADULTS_JAN[i,1]
  Initial[2,i]=TRAJECTORY_ADULTS_JAN[i,1]
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot1=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  Annual=Annual[2:3,2:3]
  MAXAMPR[i]=maxamp(Annual)}
 mean(MAXAMPR)
})

# MAXIMUM ATTENUATION
output$MAXattR=renderPlot({
 # Create 0-row data frame which will be used to store data
 dat <- data.frame(x = numeric(0), y = numeric(0))
 withProgress(message = 'Calculating', value = 0, {
  # Number of times we'll go through the loop
  n <- 40
  
  for (i in 1:n) {
   # Each time through the loop, add another row of data. This is
   # a stand-in for a long-running computation.
   dat <- rbind(dat, data.frame(x = rnorm(1), y = rnorm(1)))
   
   # Increment the progress bar, and update the detail text.
   incProgress(1/n, detail = paste("", i))
   
   # Pause for 0.1 seconds to simulate a long computation.
   Sys.sleep(0.1)
  }
 })
 library(popdemo)
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
 TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
 MAXAMPR=numeric(length(MODELS[,1]))
 Initial=matrix(0,2,length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  Initial[1,i]=TRAJECTORY_SUBADULTS_JAN[i,1]
  Initial[2,i]=TRAJECTORY_ADULTS_JAN[i,1]
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot1=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  Annual=Annual[2:3,2:3]
  MAXAMPR[i]=maxatt(Annual)}
 par(mfrow=c(1,1))
 boxplot(MAXAMPR,main="Maximum attenuation for year-round Northeast residents") 
})
output$MAXattM=renderPlot({
 library(popdemo)
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
 TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
 MAXAMPM=numeric(length(MODELS[,1]))
 Initial=matrix(0,2,length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  Initial[1,i]=TRAJECTORY_SUBADULTS_JAN[i,1]
  Initial[2,i]=TRAJECTORY_ADULTS_JAN[i,1]
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot1=c(0,MODELS[i,21],MODELS[i,22])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  Annual=Annual[2:3,2:3]
  MAXAMPM[i]=maxatt(Annual)}
 par(mfrow=c(1,1))
 boxplot(MAXAMPM,main="Maximum attenuation for part-year Northeast residents") 
})
output$MAXattMigrantMean=renderPrint({
 library(popdemo)
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
 TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
 MAXAMPM=numeric(length(MODELS[,1]))
 Initial=matrix(0,2,length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  Initial[1,i]=TRAJECTORY_SUBADULTS_JAN[i,1]
  Initial[2,i]=TRAJECTORY_ADULTS_JAN[i,1]
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot1=c(0,MODELS[i,21],MODELS[i,22])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  Annual=Annual[2:3,2:3]
  MAXAMPM[i]=maxatt(Annual)}
 mean(MAXAMPM)
})
output$MAXattMigrantSD=renderPrint({
 library(popdemo)
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
 TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
 MAXAMPM=numeric(length(MODELS[,1]))
 Initial=matrix(0,2,length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  Initial[1,i]=TRAJECTORY_SUBADULTS_JAN[i,1]
  Initial[2,i]=TRAJECTORY_ADULTS_JAN[i,1]
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot1=c(0,MODELS[i,21],MODELS[i,22])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  Annual=Annual[2:3,2:3]
  MAXAMPM[i]=maxatt(Annual)}
 sd(MAXAMPM)
})
output$MAXattResidentSD=renderPrint({
 library(popdemo)
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
 TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
 MAXAMPR=numeric(length(MODELS[,1]))
 Initial=matrix(0,2,length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  Initial[1,i]=TRAJECTORY_SUBADULTS_JAN[i,1]
  Initial[2,i]=TRAJECTORY_ADULTS_JAN[i,1]
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot1=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  Annual=Annual[2:3,2:3]
  MAXAMPR[i]=maxatt(Annual)}
 sd(MAXAMPR)
})
output$MAXattResidentMean=renderPrint({
 library(popdemo)
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
 TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
 MAXAMPR=numeric(length(MODELS[,1]))
 Initial=matrix(0,2,length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  Initial[1,i]=TRAJECTORY_SUBADULTS_JAN[i,1]
  Initial[2,i]=TRAJECTORY_ADULTS_JAN[i,1]
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot1=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  Annual=Annual[2:3,2:3]
  MAXAMPR[i]=maxatt(Annual)}
 mean(MAXAMPR)
})

# TIME TO CONVERGENCE
output$ConvergenceResidentMean=renderPrint({
 library(popdemo)
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 ConvergenceR=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot1=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  Annual=Annual[2:3,2:3]
  ConvergenceR[i]=convt(Annual)}
  mean(ConvergenceR)
})
output$ConvergenceResidentSD=renderPrint({
 library(popdemo)
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 ConvergenceR=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot1=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  Annual=Annual[2:3,2:3]
  ConvergenceR[i]=convt(Annual)}
 sd(ConvergenceR)
})
output$ConvergenceMigrantMean=renderPrint({
 library(popdemo)
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 ConvergenceM=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top11=c(0,0,0)
  mid11=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot11=c(0,MODELS[i,21],MODELS[i,22])
  ANB=rbind(top11,mid11,bot11)
  AnnualM=ANB%*%AB
  AnnualM=AnnualM[2:3,2:3]
  ConvergenceM[i]=convt(AnnualM)}
 mean(ConvergenceM)
})
output$ConvergenceMigrantSD=renderPrint({
 library(popdemo)
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 ConvergenceM=numeric(length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top11=c(0,0,0)
  mid11=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot11=c(0,MODELS[i,21],MODELS[i,22])
  ANB=rbind(top11,mid11,bot11)
  AnnualM=ANB%*%AB
  AnnualM=AnnualM[2:3,2:3]
  ConvergenceM[i]=convt(AnnualM)}
 sd(ConvergenceM)
})

# POPULATION INERTIA
output$InertiaResidentMean=renderPrint({
 # Create 0-row data frame which will be used to store data
 dat <- data.frame(x = numeric(0), y = numeric(0))
 withProgress(message = 'Calculating', value = 0, {
  # Number of times we'll go through the loop
  n <- 40
  
  for (i in 1:n) {
   # Each time through the loop, add another row of data. This is
   # a stand-in for a long-running computation.
   dat <- rbind(dat, data.frame(x = rnorm(1), y = rnorm(1)))
   
   # Increment the progress bar, and update the detail text.
   incProgress(1/n, detail = paste("", i))
   
   # Pause for 0.1 seconds to simulate a long computation.
   Sys.sleep(0.1)
  }
 })
 library(popdemo)
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
 TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
 InertiaR=numeric(length(MODELS[,1]))
 Initial=matrix(0,2,length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  Initial[1,i]=TRAJECTORY_SUBADULTS_JAN[i,1]
  Initial[2,i]=TRAJECTORY_ADULTS_JAN[i,1]
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot1=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  Annual=Annual[2:3,2:3]
  InertiaR[i]=inertia(Annual,vector=Initial[,i])}
 mean(InertiaR)
})
output$InertiaResidentSD=renderPrint({
 library(popdemo)
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
 TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
 InertiaR=numeric(length(MODELS[,1]))
 Initial=matrix(0,2,length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  Initial[1,i]=TRAJECTORY_SUBADULTS_JAN[i,1]
  Initial[2,i]=TRAJECTORY_ADULTS_JAN[i,1]
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot1=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  Annual=Annual[2:3,2:3]
  InertiaR[i]=inertia(Annual,vector=Initial[,i])}
 sd(InertiaR)
})
output$InertiaMigrantMean=renderPrint({
 library(popdemo)
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
 TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
 InertiaM=numeric(length(MODELS[,1]))
 Initial=matrix(0,2,length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  Initial[1,i]=TRAJECTORY_SUBADULTS_JAN[i,1]
  Initial[2,i]=TRAJECTORY_ADULTS_JAN[i,1]
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot1=c(0,MODELS[i,21],MODELS[i,22])
  ANB=rbind(top1,mid1,bot1)
  AnnualM=ANB%*%AB
  AnnualM=AnnualM[2:3,2:3]
  InertiaM[i]=inertia(AnnualM,vector=Initial[,i])}
 mean(InertiaM)
})
output$InertiaMigrantSD=renderPrint({
 library(popdemo)
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
 TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
 InertiaM=numeric(length(MODELS[,1]))
 Initial=matrix(0,2,length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  Initial[1,i]=TRAJECTORY_SUBADULTS_JAN[i,1]
  Initial[2,i]=TRAJECTORY_ADULTS_JAN[i,1]
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot1=c(0,MODELS[i,21],MODELS[i,22])
  ANB=rbind(top1,mid1,bot1)
  AnnualM=ANB%*%AB
  AnnualM=AnnualM[2:3,2:3]
  InertiaM[i]=inertia(AnnualM,vector=Initial[,i])}
 sd(InertiaM)
})
output$InertiaResidents=renderPlot({
 library(popdemo)
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
 TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
 InertiaR=numeric(length(MODELS[,1]))
 InertiaUpper=numeric(length(MODELS[,1]))
 InertiaLower=numeric(length(MODELS[,1]))
 Initial=matrix(0,2,length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  Initial[1,i]=TRAJECTORY_SUBADULTS_JAN[i,1]
  Initial[2,i]=TRAJECTORY_ADULTS_JAN[i,1]
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
  bot1=c(0,MODELS[i,16],MODELS[i,17])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  Annual=Annual[2:3,2:3]
  InertiaR[i]=inertia(Annual,vector=Initial[,i])
  InertiaUpper[i]=inertia(Annual,bound="upper")
  InertiaLower[i]=inertia(Annual,bound="lower")
  }
par(mfrow=c(1,1))
 boxplot(InertiaR,main="Population inertia for Northeast residents") 
})
output$InertiaMigrants=renderPlot({
 library(popdemo)
 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
 TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
 TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
 InertiaM=numeric(length(MODELS[,1]))
 InertiaUpper=numeric(length(MODELS[,1]))
 InertiaLower=numeric(length(MODELS[,1]))
 Initial=matrix(0,2,length(MODELS[,1]))
 for (i in 1:length(MODELS[,1])){
  Initial[1,i]=TRAJECTORY_SUBADULTS_JAN[i,1]
  Initial[2,i]=TRAJECTORY_ADULTS_JAN[i,1]
  top=c(0,0,MODELS[i,7])
  mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
  bot=c(0,MODELS[i,11],MODELS[i,12])
  AB=rbind(top,mid,bot)
  top1=c(0,0,0)
  mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
  bot1=c(0,MODELS[i,21],MODELS[i,22])
  ANB=rbind(top1,mid1,bot1)
  Annual=ANB%*%AB
  Annual=Annual[2:3,2:3]
  InertiaM[i]=inertia(Annual,vector=Initial[,i])
  InertiaUpper[i]=inertia(Annual,bound="upper")
  InertiaLower[i]=inertia(Annual,bound="lower")
 }
 par(mfrow=c(1,1))
 boxplot(InertiaM,main="Population inertia for Northeast migrants") 
})

} #end server function

shinyApp(ui=ui,server=server)
